//******************** (C) COPYRIGHT 2022 SmartLogic*******************************
// FileName           : ucp_api_clockGen.c
// Author             : Boheng Lin bhlin919@126.com
// Date First Issued  : 2023-03-04 02:37:50 PM
// Last Modified      : 
// Description        :
// ------------------------------------------------------------
// Modification History:
// Version    Date       Author    Modification Description
//
//**********************************************************************************

#include <stdint.h>
#include <time.h>
#include <stdlib.h>
#include <unistd.h>
#include "adi_ad9528.h"
#include "adi_ad9528_hal.h"
#include "adi_ad9528_utilities.h"
#include "adi_commonLib.h"
#include "ucp_jesd_gpio.h"
#include "ucp_rfic_gpio.h"

#define                    AD9528_CHIP_ID  0x003

static adi_ad9528_Init_t   ad9528InitInst;
static adi_ad9528_Device_t ad9528Device;
static int32_t             recoveryAct = ADI_COMMON_ACT_ERR_RESET_FULL;

static adi_ad9528_ClockFrequencySettings_t clockFrequencies = {
    122880000, //uint32_t vcxoFrequency_Hz;
    30720000,   //uint32_t refAFrequency_Hz;
    //uint32_t outputClock_Hz[ADI_AD9528_NUM_OUTPUT_CHANNELS];
    {
		122880000,       // channels 0   ADRV9026 DEVCLK 122.88M
		960000,          // channels 1   ADRV9026 SYSREF 7.68M
		960000,          // channels 2   UCP_TX   SYSREF 7.68M
		122880000,       // channels 3   UCP_TX   DEVCLK 122.88M
		0,               // channels 4
		960000,          // channels 5   UCP_RX0  SYSREF 7.68M
		122880000,       // channels 6   UCP_RX0  DEVCLK 122.88M
		122880000,       // channels 7   UCP      SYSDEV 122.88M
		960000,          // channels 8   UCP_RX1  SYSREF 7.68M
		122880000,       // channels 9   UCP_RX1  DEVCLK 122.88M
		0,               // channels 10            
		0,               // channels 11
		0,               // channels 12
		0                // channels 13
	},
    //adi_ad9528_OutSourceSel_e outSource[ADI_AD9528_NUM_OUTPUT_CHANNELS];
    {
		ADI_AD9528_CHANNEL_DIV, // channels 0   ADRV9026 DEVCLK 122.88M
		ADI_AD9528_SYSREF,      // channels 1   ADRV9026 SYSREF 7.68M
		ADI_AD9528_SYSREF,      // channels 2   UCP_TX   SYSREF 7.68M
		ADI_AD9528_CHANNEL_DIV, // channels 3   UCP_TX   DEVCLK 122.88M
		ADI_AD9528_CHANNEL_DIV, // channels 4
		ADI_AD9528_SYSREF,      // channels 5   UCP_RX0  SYSREF 7.68M
		ADI_AD9528_CHANNEL_DIV, // channels 6   UCP_RX0  DEVCLK 122.88M
		ADI_AD9528_CHANNEL_DIV, // channels 7   UCP      SYSDEV 122.88M
		ADI_AD9528_SYSREF,      // channels 8   UCP_RX1  SYSREF 7.68M
		ADI_AD9528_CHANNEL_DIV, // channels 9   UCP_RX1  DEVCLK 122.88M
		ADI_AD9528_CHANNEL_DIV, // channels 10 
		ADI_AD9528_CHANNEL_DIV, // channels 11
		ADI_AD9528_CHANNEL_DIV, // channels 12
		ADI_AD9528_CHANNEL_DIV  // channels 13
	}
};

void ucp_api_ad9528_Reset(void)
{
    ucp_jesd_gpioSet(GPIO_INDEX_9528RESET, 0);
    sleep(1);
    ucp_jesd_gpioSet(GPIO_INDEX_9528RESET, 1);

    memset(&ad9528Device, 0, sizeof(adi_ad9528_Device_t));
    memset(&ad9528InitInst, 0, sizeof(adi_ad9528_Init_t));
 
    return;
}

int32_t ucp_api_ad9528_Init(void)
{
    int32_t              ret;
    int32_t              error = ADI_COMMON_HAL_OK;
    uint8_t              reg;
    adi_ad9528_Device_t *ad9528Dev = NULL;
    adi_ad9528_Init_t   *ad9528Init = NULL;
	adi_hal_Cfg_t       *devCfg = NULL;
	
	/* Board Level */
    ad9528Dev = (adi_ad9528_Device_t*)&ad9528Device;
	ad9528Init = (adi_ad9528_Init_t*)&ad9528InitInst;
    
	/* create hal layer for this motherboard daya: SPI_CHIP_SELECT_1 for ad9528*/
	ad9528Dev->common.devHalInfo = NULL;
	ad9528Dev->common.devHalInfo = hal_DevHalCfgCreate((ADI_HAL_INTERFACE_SPI | \
                	                                      ADI_HAL_INTERFACE_LOG | \
                	                                      ADI_HAL_INTERFACE_HWRESET | \
                	                                      ADI_HAL_INTERFACE_TIMER),
                	                                      SPI_CHIP_SELECT_1, "ad9528.txt"); 
	if (ad9528Dev->common.devHalInfo == NULL)
	{
		printf("ERROR: %s:%u has failed.\n",
			   __func__,
			   __LINE__);
		return ADI_HAL_SPI_FAIL;
	}
    
    ad9528Dev->common.error.logEnable = ADI_ENABLE;
	devCfg = (adi_hal_Cfg_t *)ad9528Dev->common.devHalInfo;
	strcpy(devCfg->typeName, "ad9528Dev");
	error = adi_hal_PlatformSetup(ad9528Dev->common.devHalInfo,
								  (adi_hal_Platforms_e)ADI_UCP2_PLATFORM);
	if (error != ADI_HAL_OK)
	{
		printf("ERROR: %s:%u has failed.\n",
			   __func__,
			   __LINE__);
		return ADI_HAL_SPI_FAIL;
	}
    
	adi_ad9528_HwOpen(ad9528Dev);
	adi_ad9528_SpiCfgSet(ad9528Dev, &ad9528Init->spiSettings);
	
	if ((recoveryAct = adi_ad9528_InitStructConfig(ad9528Dev,
                                              &clockFrequencies,
                                              ad9528Init)) < 0)
    {
        return recoveryAct;
    }

	ret = adi_ad9528_Initialize(ad9528Dev, ad9528Init);
	
	adi_ad9528_SpiByteRead(ad9528Dev, AD9528_CHIP_ID, &reg);
	printf("AD9528 ID:         0x%02X\n", reg);

    reg = 0;
    while (!(reg & 0x3)) {
	    adi_ad9528_PllLockStatusGet(ad9528Dev, &reg);
	    sleep(1);
	}
	
	printf("AD9528 LockStatus: 0x%02X\n", reg);

    return ret;
}

uint8_t ucp_api_ad9528_LockStatus(void)
{
    uint8_t data;

	data = 0;
    adi_ad9528_PllLockStatusGet((adi_ad9528_Device_t*)&ad9528Device, &data);
	printf("status = %x\n", data);

	return data;
}

void ucp_api_ad9528_OnePluse(uint8_t enable)
{
    adi_ad9528_SysrefRequest((adi_ad9528_Device_t*)&ad9528Device, enable);
    return;
}


