//******************** (C) COPYRIGHT 2022 SmartLogic*******************************
// FileName           : adi_adrv9025Lib.c
// Author             : Boheng Lin bhlin919@126.com
// Date First Issued  : 2023-09-08 02:37:50 PM
// Last Modified      : 
// Description        :
// ------------------------------------------------------------
// Modification History:
// Version    Date       Author    Modification Description
//
//**********************************************************************************

#include <stdio.h>
#include <stdlib.h>
#include <stdbool.h>
#include <unistd.h>
#include "string.h"
#include "adi_platform.h"
#include "adi_platform_types.h"
#include "adi_adrv9025_utilities.h"
#include "adi_adrv9025.h"
#include "adi_adrv9025_radioctrl.h"
#include "adi_adrv9025_tx.h"
#include "adi_common_error.h"
#include "adi_adrv9025_data_interface.h"
#include "adi_ad9528.h"
#include "adi_ad9528_utilities.h"
#include "initdata.h"
#include "platform_utils/adi_fmc_fru.h"
#include "platform_utils/adi_fmc_eeprom.h"
#include "adi_ad9528_utilities.h"
#include "adi_adrv9025_cals.h"
#include "adi_adrv9025_gpio.h"
#include "adi_adrv9025_rx.h"
#include "adi_ad9528Lib.h"

#include "ucp_jesd_gpio.h"
#include "ucp_param.h"
#include "ucp_reg_io.h"
#include <string.h>
#include <stdio.h>
#include <stdint.h>

#include "adi_adrv9025Lib.h"

#include "ucp_rfic_gpio.h"

static int32_t  recoveryAct = ADI_COMMON_ACT_ERR_RESET_FULL;

static uint32_t mcsStatus     = 0x00;
static uint32_t mcsStatusAnd  = 0x17;

static int8_t rxLinkSelect = 0x00;
static int8_t txLinkSelect = 0x00;
static int    iterator     = 0x00;
static bool   programFlag = false;

static adi_adrv9025_Device_t   *adrv9025Device = NULL;
static adi_adrv9025_Device_t    gAdrv9025Device;

static adi_adrv9025_Init_t                *adrv9025Init        = NULL;
static adi_adrv9025_PinModeSettings_t     *pinModeSettings     = NULL;
static adi_adrv9025_PostMcsInit_t         *adrv9025PostMcsInit = NULL;

static adi_adrv9025_RxGainTableFile_t   rxGainTableFileArr[]  = { { { 0x00 } } };
static adi_adrv9025_TxAttenTableFile_t  txAttenTableFileArr[] = { { { 0x00 } } };

static adi_adrv9025_PinModeSettings_t   pinModeSettingsLoad    = { { {  } } };

extern ucp_rfic_calPara_t ucp_GetRficCalParaInfo(void);
ucp_rfic_calPara_t gRficCalPara;

/* Magic Numbers */
const int8_t   magicNumZero               = 0x00;
const int8_t   magicNumOne                = 0x01;
const int8_t   magicNumTwo                = 0x02;
const int8_t   magicNumThree              = 0x03;
const int8_t   magicNumFour               = 0x04;
const int8_t   magicNumFive               = 0x05;
const int8_t   magicNumSix                = 0x06;
const int8_t   magicNumSeven              = 0x07;
const int8_t   magicNumEight              = 0x08;
const int8_t   magicNumTwelve             = 0x0C;
const int8_t   magicNumThirteen           = 0x0D;
const int8_t   magicNumSixteen            = 0x10;
const int8_t   magicNumFifty              = 0x32;
const int8_t   magicNumNineSix            = 0x60;
const int8_t   magicNumHundred            = 0x64;
const uint8_t  magicNumTwoFiveFive        = 0xFF;
const uint16_t magicNumOneThousand        = 0x3E8;
const uint32_t magicNumOneTwentyThousand  = 0x1D4C0;

// config
static adi_hal_Cfg_t  adiHal[3];
const static int8_t   failureReturn        = -0x01;
static const uint8_t  multichipSyncEnable  = 0x01;
static const uint8_t  multichipSyncDisable = 0x00;
static const uint8_t  rxGainTableSize      = 0x01;
static const uint8_t  txAttenTableSize     = 0x01;
static const uint8_t  enableSync           = 0x01;
static const uint8_t  rxChannelMask        = 0xFF;

static const uint8_t  loadConfigFileEnable = 0x00;
static uint8_t        loadCalMgcGainIndex  = 245; // 183 ~ 255
static uint8_t  	  localTxAtt  = 0; 

const char adiProfileFilePath[] = "/lib/firmware/resources/adrv9025/profiles/daya2_4.9152G.profile";
static adi_adrv9025_PlatformFiles_t platformFiles = { {"/lib/firmware/resources/adrv9025/arm_firmware/ADRV9025_FW.bin;/lib/firmware/resources/adrv9025/arm_firmware/ADRV9025_DPDCORE_FW.bin"},
                                                      {"/lib/firmware/resources/adrv9025/arm_firmware/stream_image_357E871D1928C2A67823336885ACA3E3.bin"},
                                                      { {{"/lib/firmware/resources/adrv9025/gain_tables/RxGainTable.csv"}, 0xFF} },
                                                      1,
                                                      { {{"/lib/firmware/resources/adrv9025/gain_tables/TxAttenTable.csv"}, 0x0F} },
                                                      1};
													  

/**
* \brief This is a helper function that will invoke the API : adi_adrv9025_ConfigFileLoad
*        will initialize an ADRV9025 init struct
*
* \param adrv9025_Device Pointer to data structure that contains ADRV9025 device instance settings
* \param adrv9025_Init   Pointer to ADRV9025 init settings structure
*
* Function will exit on failure
*/
static void configFileLoad(adi_adrv9025_Device_t *adrv9025_Device,
                         adi_adrv9025_Init_t   *adrv9025_Init)
{
    recoveryAct = ADI_COMMON_ACT_ERR_RESET_FULL;
    /* Load ADRV9010 Init structure */
    /* adiProfileFilePath is defined as const global at top of this file */
    recoveryAct = adi_adrv9025_ConfigFileLoad(adrv9025_Device, adiProfileFilePath, adrv9025_Init);
    if (recoveryAct != ADI_COMMON_ACT_NO_ACTION)
    {
        printf("ERROR: : %s:%u has failed.\n", __func__, __LINE__);
        exit(EXIT_FAILURE);
    }
}

/**
 * \brief This function is a helper function to fill out the members of the 
 *         devHalCfg structure with driver names for common platform.
 *
 * This function allows keeping the platform specific knowledge of driver names
 * in this layer of code.  Higher layers of code can call this to fill out the
 * devHalCfg structure correctly for the common platform.
 *
 * Each device gets a unique instance of the devHalCfg structure describing the
 * device resources for that device, such as the SPI chip select, etc.
 *
 * \param interfaceMask A mask that represents which platform interfaces are required by a particular device (SPI, Logging, etc)
 * \param spiChipSelect The chip select index describing the particular device 
 * \param logFilename The filename of the logfile for this device.
 */
 void* hal_DevHalCfgCreate(uint32_t    interfaceMask,
                           uint8_t     spiChipSelect,
                           const char* logFilename)
 {
    uint8_t boardType;
    char SPI_CHIP_DEV_PATH_0[30], SPI_CHIP_DEV_PATH_1[30], SPI_CHIP_DEV_PATH_2[30];
    
    boardType = UCP_API_RFIC_GetBoardInfo();
    if (HW_EVMY == boardType)
    {
        strcpy(SPI_CHIP_DEV_PATH_0, "/dev/spidev3.0\0");
        strcpy(SPI_CHIP_DEV_PATH_1, "/dev/spidev1.1\0"); 
        strcpy(SPI_CHIP_DEV_PATH_2, "/dev/spidev1.0\0");
    }
    else if ((HW_EVMF == boardType) || (HW_EVMT == boardType) || (HW_EVB == boardType))
    {
        strcpy(SPI_CHIP_DEV_PATH_0, "/dev/spidev1.0\0");
        strcpy(SPI_CHIP_DEV_PATH_1, "/dev/spidev1.0\0");
        strcpy(SPI_CHIP_DEV_PATH_2, "/dev/spidev1.0\0");
    }
    else
    {
        printf("error, unknow spi dev. @%s, %d\n",  __FILE__, __LINE__);
    }

     adi_hal_Cfg_t* halCfg = (adi_hal_Cfg_t*)&adiHal[spiChipSelect]; // (adi_hal_Cfg_t*)calloc(1, sizeof(adi_hal_Cfg_t)); // daya debug
     if (halCfg == NULL)
     {
         printf("ERROR: %s:%u has failed.\n",
                __func__,
                __LINE__);
         return NULL;
     }
 
     /* Disable all interfaces, and enable only if they are needed by the specific device */
     halCfg->spiCfg.interfaceEnabled  = 0;
     halCfg->logCfg.interfaceEnabled  = 0;
     halCfg->bbicCfg.interfaceEnabled = 0;
 
     /* If device requires SPI interface */
     if ((interfaceMask & (uint32_t)ADI_HAL_INTERFACE_SPI) > 0)
     {
         halCfg->spiCfg.interfaceEnabled = 1;
         halCfg->spiCfg.chipSelectIndex  = spiChipSelect;
 
         switch (spiChipSelect)
         {
         case SPI_CHIP_SELECT_0:
         {
             strncpy(halCfg->spiCfg.spidevName,
                     SPI_CHIP_DEV_PATH_0,
                     ADI_HAL_STRING_LENGTH);
             break;
         }
         case SPI_CHIP_SELECT_1:
         {
             strncpy(halCfg->spiCfg.spidevName,
                     SPI_CHIP_DEV_PATH_1,
                     ADI_HAL_STRING_LENGTH);
             break;
         }
         case SPI_CHIP_SELECT_2:
         {
             strncpy(halCfg->spiCfg.spidevName,
                     SPI_CHIP_DEV_PATH_2,
                     ADI_HAL_STRING_LENGTH);
             break;
         }
         default:
         {
             // free(halCfg); // daya debug
             return NULL;
         }
         }
 
         /* Default SPI settings */
         halCfg->spiCfg.autoIncAddrUp    = 1;
         halCfg->spiCfg.CPHA             = 0;
         halCfg->spiCfg.CPOL             = 0;
         halCfg->spiCfg.enSpiStreaming   = 0;
         halCfg->spiCfg.fourWireMode     = 1;
         halCfg->spiCfg.spiActionDisable = 0;
         halCfg->spiCfg.spiClkFreq_Hz    = 25000000;
     }

     /* If device requires Logging interface */
     if ((interfaceMask & (uint32_t)ADI_HAL_INTERFACE_LOG) > 0)
     {
         halCfg->logCfg.interfaceEnabled = 1;
         halCfg->logCfg.logLevel         = ADI_HAL_LOG_ALL;
         strncpy(halCfg->logCfg.logFileName,
                 logFilename,
                 ADI_HAL_STRING_LENGTH);
         /* ensure null termination */
         halCfg->logCfg.logFileName[sizeof(halCfg->logCfg.logFileName) - 1] = '\0';
     }
 
#if 0 // by daya
     /* If device requires FPGA register interface */
     if (((interfaceMask & (uint32_t)ADI_HAL_INTERFACE_BBICCTRL) > 0) ||
         ((interfaceMask & (uint32_t)ADI_HAL_INTERFACE_HWRESET) > 0)) /* ADS9 HWRESET interface requires BBICCTRL interface */
     {
         halCfg->bbicCfg.interfaceEnabled = 1;
         strncpy(halCfg->bbicCfg.coreRegsCfg.drvName,
                 BBIC_CORE_REG_PATH,
                 ADI_HAL_STRING_LENGTH);
         halCfg->bbicCfg.coreRegsCfg.mapSize = MEM_SIZE_512MB; /* 512MB */
         strncpy(halCfg->bbicCfg.ramCfg.drvName,
                 BBIC_RAM_PATH,
                 ADI_HAL_STRING_LENGTH);
         halCfg->bbicCfg.ramCfg.mapSize = MEM_SIZE_1GB; /* 1GB */
         strncpy(halCfg->bbicCfg.spiAdvRegsCfg.drvName,
                 BBIC_SPI_ADV_REG_PATH,
                 ADI_HAL_STRING_LENGTH);
         halCfg->bbicCfg.spiAdvRegsCfg.mapSize = MEM_SIZE_16M; /* 16MB */
     }
#endif
 
     if ((interfaceMask & (uint32_t)ADI_HAL_INTERFACE_HWRESET) > 0)
     {
         halCfg->hwResetCfg.interfaceEnabled = 1;
 
         switch (spiChipSelect)
         {
         case SPI_CHIP_SELECT_0:
         {
             halCfg->hwResetCfg.resetPinIndex = 1; /* ADRV9025 reset pin bit position in FPGA register */
             break;
         }
         case SPI_CHIP_SELECT_1:
         {
             halCfg->hwResetCfg.resetPinIndex = 2; /* AD9528 reset pin bit position in FPGA register */
             break;
         }
 
         default:
             printf("ERROR: %s:%u has failed.\n",
                    __func__,
                    __LINE__);
             free(halCfg);
             return NULL;
         }
     }
 
     if ((interfaceMask & (uint32_t)ADI_HAL_INTERFACE_I2C) > 0)
     {
         halCfg->i2cCfg.interfaceEnabled = 1;
         strncpy(halCfg->i2cCfg.drvName,
                 I2C_EEPROM_PATH,
                 ADI_HAL_STRING_LENGTH);
     }
 
     if ((interfaceMask & (uint32_t)ADI_HAL_INTERFACE_TIMER) > 0)
     {
         halCfg->timerCfg.interfaceEnabled = 1;
     }
 
     return halCfg;
}

extern uint32_t ucp_reg32_read(uint64_t reg);
void adrv9025_StatusMoniter (adi_adrv9025_Device_t *device, uint16_t monitMask) 
{
    uint16_t i, j;
    uint32_t pllLockStatus = 0;
    uint8_t enable;
    uint64_t gpIntStatus = 0, mask = 0;
    adi_adrv9025_FramerStatus_t frameLinkStatus;
    adi_adrv9025_DeframerStatus_t deframeLinkStatus;
    char *framerStatusInf[] = { // expect 0x0A
        "farameInf[3]: Current SYNCBIN level(1 = high, 0 = low)\n",  
        "farameInf[2]: SYSREF phase error - a new SYSREF had different timing than the first that set the LMFC timing\n",  
        "farameInf[1]: SYSREF phase established by framer\n", 
        "farameInf[0]: Flag indicating that configuration parameters are not supported when set(1)\n"
    };
    char *deframerStatusInf[] = { // expect 0x87
        "defarameInf[7]: Valid checksum  1 if the checksum calculated by the ADRV9025 matched the one sent in the ILAS data\n",  
        "defarameInf[6]: EOF Event  This bit captures the internal status of the framer End of Frame event. Value =1 if framing error during ILAS\n",  
        "defarameInf[5]: EOMF Event  This bit captures the internal status of the framer End of Multi-Frame event. Value =1 if framing error during ILAS\n",  
        "defarameInf[4]: FS Lost  This bit captures the internal status of the framer Frame Symbol event. Value =1 if framing error during ILAS or user data (invalid replacement characters)\n",  
        "defarameInf[3]: Reserved  Reserved\n",  
        "defarameInf[2]: User Data Valid  =1 when in user data (deframer link is up and sending valid DAC data)\n",  
        "defarameInf[1]: SYSREF Received  Deframer has received the external SYSREF signal\n",  
        "defarameInf[0]: Syncb level  Current level of Syncb signal internal to deframer (=1 means link is up)\n"
    };
    
/*-------------------------------------—-------------------— 
Status for JESD204B: 
framerStatus->status 
Description -------------------— 

    [7]  Reserved  
    [6]  Reserved  
    [5]  Reserved  
    [4]  Reserved  
    [3]  Current SYNCBIN level(1 = high, 0 = low)  
    [2]  SYSREF phase error - a new SYSREF had different timing than the first that set the LMFC timing.  
    [1]  SYSREF phase established by framer  
    [0]  Flag indicating that configuration parameters are not supported when set(1) 

framerSynbcNeCount : 8 bit counter of negative edge Sync transitions
qbfStateStatus 
Description --------------------— 

    [7]  Reserved  
    [6]  Reserved  
    [5]  Reserved  
    [4]  Reserved  
    [3]  Reserved  
    [2]  QBF bit 2  
    [1]  QBF bit 1  
    [0]  QBF bit 0  

syncNSel 
Description --------------------— 

    [7]  Reserved  
    [6]  Reserved  
    [5]  Reserved  
    [4]  Reserved  
    [3]  Reserved  
    [2]  Syncb crossbar select  
    [1]  Syncb crossbar select  
    [0]  Syncb crossbar select  

Status for JESD204C: 
framerStatus->status 
Description --------------------— 

    [0]  Sysref received bit  
-------------------------------------—-------------------—  */
    printf("--------------------------------------------------------------------\n");
    memset(&frameLinkStatus, 0, sizeof(adi_adrv9025_FramerStatus_t));
    adi_adrv9025_FramerStatusGet(device, ADI_ADRV9025_FRAMER_0, &frameLinkStatus);
    printf("adiFramer 0 LinkStatus = %X SyncNeCount = %d qbfStateStatus = %X syncNSel = %X\n", 
           frameLinkStatus.status,
           frameLinkStatus.framerSyncNeCount,
           frameLinkStatus.qbfStateStatus,
           frameLinkStatus.syncNSel);
    mask = 1 << 3;
    for (j = 0;j < 4;j++) {
        if (mask & frameLinkStatus.status) {
            printf("  #%s", framerStatusInf[j]);
        }
        mask >>= 1;
    }

    printf("\n");
    memset(&frameLinkStatus, 0, sizeof(adi_adrv9025_FramerStatus_t));
    adi_adrv9025_FramerStatusGet(device, ADI_ADRV9025_FRAMER_1, &frameLinkStatus);
    printf("adiFramer 1 LinkStatus = %X SyncNeCount = %d qbfStateStatus = %X syncNSel = %X\n", 
                               frameLinkStatus.status,
                               frameLinkStatus.framerSyncNeCount,
                               frameLinkStatus.qbfStateStatus,
                               frameLinkStatus.syncNSel);
    mask = 1 << 3;
    for (j = 0;j < 4;j++) {
        if (mask & frameLinkStatus.status) {
            printf("  #%s", framerStatusInf[j]);
        }
        mask >>= 1;
    }

    printf("\n");
    memset(&frameLinkStatus, 0, sizeof(adi_adrv9025_FramerStatus_t));
    adi_adrv9025_FramerStatusGet(device, ADI_ADRV9025_FRAMER_2, &frameLinkStatus);
    printf("adiFramer 2 LinkStatus = %X SyncNeCount = %d qbfStateStatus = %X syncNSel = %X\n", 
                               frameLinkStatus.status,
                               frameLinkStatus.framerSyncNeCount,
                               frameLinkStatus.qbfStateStatus,
                               frameLinkStatus.syncNSel);
    mask = 1 << 3;
    for (j = 0;j < 4;j++) {
        if (mask & frameLinkStatus.status) {
            printf("  #%s", framerStatusInf[j]);
        }
        mask >>= 1;
    }

/*
Status for JESD204B: 
deframerStatus 
Bit Name 
Description -------------— 

    [7]  Valid checksum  1 if the checksum calculated by the ADRV9025 matched the one sent in the ILAS data.  
    [6]  EOF Event  This bit captures the internal status of the framer End of Frame event. Value =1 if framing error during ILAS  
    [5]  EOMF Event  This bit captures the internal status of the framer End of Multi-Frame event. Value =1 if framing error during ILAS  
    [4]  FS Lost  This bit captures the internal status of the framer Frame Symbol event. Value =1 if framing error during ILAS or user data (invalid replacement characters)  
    [3]  Reserved  Reserved  
    [2]  User Data Valid  =1 when in user data (deframer link is up and sending valid DAC data)  
    [1]  SYSREF Received  Deframer has received the external SYSREF signal  
    [0]  Syncb level  Current level of Syncb signal internal to deframer (=1 means link is up)  

Status for JESD204C: 
deframerStatus 
Bit Name 
Description -------------— 

    [2:0]  Current lock state  These 3 bits indicate state of JESD204C Lock  
    
An explanation of what each the value of the 3 bits relates to is below: 
value 
Description -------------— 

    0  Reset  
    1  Unlocked  
    2  Block(Blocks aligned)  
    3  M_Block(Lanes aligned)  
    4  E_M_Block(Multiblock aligned)  
    5  FEC_BUF  
    6  FEC_READY (Good State!)  
    7  Reserved  
*/
    printf("\n");
    memset(&deframeLinkStatus, 0, sizeof(adi_adrv9025_DeframerStatus_t));
    adi_adrv9025_DeframerStatusGet(device, ADI_ADRV9025_DEFRAMER_0, &deframeLinkStatus);
    printf("adiDeframer 0 LinkStatus = %X reserved = %X\n",
                    deframeLinkStatus.status,
                    deframeLinkStatus.reserved);
    mask = 1 << 7;
    for (j = 0;j < 8;j++) {
        if (mask & deframeLinkStatus.status) {
            if (4 != j) {
                printf("  #%s", deframerStatusInf[j]);
            }
        }
        mask >>= 1;
    }

    printf("\n");
    adi_adrv9025_DeframerStatusGet(device, ADI_ADRV9025_DEFRAMER_1, &deframeLinkStatus);
    printf("adiDeframer 1 LinkStatus = %X reserved = %X\n",
                    deframeLinkStatus.status,
                    deframeLinkStatus.reserved);
    mask = 1 << 7;
    for (j = 0;j < 8;j++) {
        if (mask & deframeLinkStatus.status) {
            if (4 != j) {
                printf("  #%s", deframerStatusInf[j]);
            }
        }
        mask >>= 1;
    }

    printf("\n");
    printf("RxCGS: %X\n", ucp_reg32_read(0x060013f4)); // cgs status
    adi_adrv9025_FramerLinkStateGet(device, &enable);
    printf("FramerLinkState = %d\n", enable);
    adi_adrv9025_DfrmLinkStateGet(device, &enable);
    printf("DeframerLinkState = %d\n", enable);

    /*
    CLK_PLL_LOCK_STATUS  bit0
    LO1_PLL_LOCK_STATUS  bit1
    LO2_PLL_LOCK_STATUS  bit2
    AUX_PLL_LOCK_STATUS  bit3
    */
    adi_adrv9025_PllStatusGet(device, &pllLockStatus);
    printf("pllLockStatus = %X\n", pllLockStatus);
    
char *gpIntInf[] = {
//------------------------------------------------------------------------------- 
//## Deframer 
    "D49 Deframer IRQ 11: Deframer1 JESD204C CRC error\n",
    "D48 Deframer IRQ 10: Deframer1 JESD204C loss of sync\n",

//-------------------------------------------------------------------------------
//## PLL
    "D47 LO1 PLL unlock\n",                                      
    "D46 LO2 PLL unlock\n",                                      
    "D45 Auxiliary PLL unlock\n",                                
    "D44 Clock PLL unlock\n",                                    
    "D43 LO1 PLL charge pump overrange\n",
    "D42 LO2 PLL charge pump overrange\n",                       
    "D41 Auxiliary PLL charge pump overrange\n",
    "D40 Clock PLL charge pump overrange\n",
    "D39 SERDES PLL unlock\n",                                   

//------------------------------------------------------------------------------- 
//## Deframer 
    "D38 Deframer IRQ 9: Deframer1 JESD204B quad byte deframer (QBD) IRQ\n",
    "D37 Deframer IRQ 8: Deframer1 SYSREF out of phase\n",
    "D36 Deframer IRQ 7: Deframer1 elastic buffer error\n",
    "D35 Deframer IRQ 6: Deframer1 lane FIFO pointer error\n",
    "D34 Deframer IRQ 5: Deframer0 JESD204C CRC error\n",
    "D33 Deframer IRQ 4: Deframer0 JESD204C loss of sync\n", 
    "D32 Deframer IRQ 3: Deframer0 JESD204B QBD IRQ\n",
    "D31 Deframer IRQ 2: Deframer0 SYSREF out of phase\n",
    "D30 Deframer IRQ 1: Deframer0 elastic buffer error\n",
    "D29 Deframer IRQ 0: Deframer0 lane FIFO pointer error\n",

//------------------------------------------------------------------------------- 
//## Framer
    "D28 Framer IRQ 8: Framer2 transport not sending data\n",
    "D27 Framer IRQ 7: Framer2 SYSREF out of phase\n",
    "D26 Framer IRQ 6: Framer2 lane FIFO pointer error\n",
    "D25 Framer IRQ 5: Framer1 transport layer not sending data\n",
    "D24 Framer IRQ 4: Framer1 SYSREF out of phase\n",
    "D23 Framer IRQ 3: Framer1 lane FIFO pointer error\n",
    "D22 Framer IRQ 2: Framer0 Transport layer not sending data\n",
    "D21 Framer IRQ 1: Framer0 SYSREF out of phase\n",
    "D20 Framer IRQ 0: Framer0 lane FIFO pointer error\n",

//------------------------------------------------------------------------------- 
//## Transmitter    ADI_ADRV9025_ACT_ERR_BBIC_LOG_ERROR
    "D19 Power Amplifier Protection Error Tx4 (threshold exceeded)\n",
    "D18 Power Amplifier Protection Error Tx3 (threshold exceeded)\n", 
    "D17 Power Amplifier Protection Error Tx2 (threshold exceeded)\n",
    "D16 Power Amplifier Protection Error Tx1 (threshold exceeded)\n",

//------------------------------------------------------------------------------- 
//## ARM  ADI_COMMON_ACT_ERROR_RESET_FULL
    "D15 ARM has forced interrupt\n",
    "D14 ARM watchdog timer timeout \n",
    "D13 Slew rate limiter IRQ\n", 
    "D12 ARM system error\n", 

//------------------------------------------------------------------------------- 
//## Stream processor
    "D11 ORx3 or ORx4 stream processor error\n",
    "D10 ORx1 or ORx2 stream processor error\n",
    "D9 Tx4 stream processor error\n",
    "D8 Tx3 stream processor error\n",
    "D7 Tx2 stream processor error\n",
    "D6 Tx1 stream processor error\n",
    "D5 Rx4 stream processor error\n",
    "D4 Rx3 stream processor error\n",
    "D3 Rx2 stream processor error\n",
    "D2 Rx1 stream processor error\n",
    "D1 Core stream processor error\n",

//------------------------------------------------------------------------------- 
//## ARM
    "D0 Memory ECC error\n"  
};

    gpIntStatus = 0;
    adi_adrv9025_GpIntStatusGet(device, &  gpIntStatus);
    printf("gpIntStatus = %08X %08X\n", (uint32_t)((gpIntStatus >> 32) & 0xFFFFFFFF), (uint32_t)(gpIntStatus & 0xFFFFFFFF));
    mask = 1;
    for (j = 0;j < 50;j++) {
        if (mask & gpIntStatus) {
            printf("  #%s", gpIntInf[49-j]);
        }
        mask <<= 1;
    }
    adi_adrv9025_GPIntClearStatusRegister(device);

    // printf("PCS_BIT_REV_CTRL: %X\n", ucp_reg32_read(JS_PMA0_PCS_BIT_REV_CTRL));
    
    adi_adrv9025_DfrmCompareData_t dfrData;
    adi_adrv9025_DfrmIlasMismatchGet(device, ADI_ADRV9025_DEFRAMER_0, &dfrData);
    printf("\nchkFlag: %X, MismatchDfrm: %X\n\n",
            dfrData.zeroCheckFlag,
            dfrData.ilasMismatchDfrm);
    printf("ilas: DID %d, BID %d, LID0 %d, L %d, SRC %d, F %d, K %d, M %d, N %d, CS %d, NP %d, S %d, CF %d, HD %X, FCHK0 %X\n",
            dfrData.dfrmIlasData.dfrmDID,
            dfrData.dfrmIlasData.dfrmBID,
            dfrData.dfrmIlasData.dfrmLID0,
            dfrData.dfrmIlasData.dfrmL,
            dfrData.dfrmIlasData.dfrmSCR,
            dfrData.dfrmIlasData.dfrmF,
            dfrData.dfrmIlasData.dfrmK,
            dfrData.dfrmIlasData.dfrmM,
            dfrData.dfrmIlasData.dfrmN,
            dfrData.dfrmIlasData.dfrmCS,
            dfrData.dfrmIlasData.dfrmNP,
            dfrData.dfrmIlasData.dfrmS,
            dfrData.dfrmIlasData.dfrmCF,
            dfrData.dfrmIlasData.dfrmHD,
            dfrData.dfrmIlasData.dfrmFCHK0);
    printf("cfig: DID %d, BID %d, LID0 %d, L %d, SRC %d, F %d, K %d, M %d, N %d, CS %d, NP %d, S %d, CF %d, HD %X, FCHK0 %X\n\n",
            dfrData.dfrmCfgData.dfrmDID,
            dfrData.dfrmCfgData.dfrmBID,
            dfrData.dfrmCfgData.dfrmLID0,
            dfrData.dfrmCfgData.dfrmL,
            dfrData.dfrmCfgData.dfrmSCR,
            dfrData.dfrmCfgData.dfrmF,
            dfrData.dfrmCfgData.dfrmK,
            dfrData.dfrmCfgData.dfrmM,
            dfrData.dfrmCfgData.dfrmN,
            dfrData.dfrmCfgData.dfrmCS,
            dfrData.dfrmCfgData.dfrmNP,
            dfrData.dfrmCfgData.dfrmS,
            dfrData.dfrmCfgData.dfrmCF,
            dfrData.dfrmCfgData.dfrmHD,
            dfrData.dfrmCfgData.dfrmFCHK0);

/*
    laneStatus  deframer status bits  
    bdCntValue  Bad-Disparity error counter current value 
    uekCntValue UnExpected-K error counter current value 
    nitCntValue Not-In-Table error counter current value 
    
UnExpected 
    K-charactoer (UEK), 
    Not-In-Table (NIT), 
    Initial Lane Synchronization (ILS), 
    Inter-Lane De-skew (ILD), 
    Frame Sync (FS), 
    Computed CheckSum (CCS), 
    Code Group Sync (CGS), 
    Bad Disparity (BD).

Lane Status Bit 
Description ------— 
    [7]  UEK Error, 0 = No Error, 1 = Error  
    [6]  NIT Error, 0 = No Error, 1 = Error  
    [5]  ILS Status, 0 = Not Completed, 1 = Completed Successfully  
    [4]  ILD Status, 0 = Not Completed, 1 = Completed Successfully  
    [3]  FS Status, 0 = Not Completed, 1 = Completed Successfully  
    [2]  CCS Status, 0 = Not Completed, 1 = Completed Successfully  
    [1]  CGS Status, 0 = Not Completed, 1 = Completed Successfully  
    [0]  BD Error, 0 = No Error, 1 = Error  
*/

    adi_adrv9025_DfrmErrCounterStatus_t errCounterStatus;
    for (i = 0;i < 4;i++)
    {
        // memset(&errCounterStatus, 0, sizeof(adi_adrv9025_DfrmErrCounterStatus_t));
        adi_adrv9025_DfrmErrCounterStatusGet(device,
                                                ADI_ADRV9025_DEFRAMER_0,
                                                i,
                                                &errCounterStatus);
        printf("  #deframe_%d lane%d: laneStatus %X, bdCntValue %d, nitCntValue %d, uekCntValue %d\n",
            ADI_ADRV9025_DEFRAMER_0,
            i,
            errCounterStatus.laneStatus,
            errCounterStatus.bdCntValue,
            errCounterStatus.nitCntValue,
            errCounterStatus.uekCntValue);
   }
   
   printf("\n");
   for (i = 0;i < 4;i++)
   {
       // memset(&errCounterStatus, 0, sizeof(adi_adrv9025_DfrmErrCounterStatus_t));
       adi_adrv9025_DfrmErrCounterStatusGet(device,
                                               ADI_ADRV9025_DEFRAMER_1,
                                               i,
                                               &errCounterStatus);
       printf("  #deframe_%d lane%d: laneStatus %X, bdCntValue %d, nitCntValue %d, uekCntValue %d\n",
            ADI_ADRV9025_DEFRAMER_1,
            i,
            errCounterStatus.laneStatus,
            errCounterStatus.bdCntValue,
            errCounterStatus.nitCntValue,
            errCounterStatus.uekCntValue);
   }

   printf("--------------------------------------------------------------------\n");
}

static int32_t adi_board_adrv9025_JesdTxBringup(adi_adrv9025_Device_t*       adrv9025Device,
                                              uint32_t                 link)
{
    int32_t                 recoveryAction   = ADI_COMMON_ACT_NO_ACTION;
    
#if 0    
    /* Unmask incoming sysref in FPGA framers (leave rx links untouched) */
    recoveryAction = adi_fpga9025_SysRefEnableSet(fpga9025Device,
                                                  (uint8_t)link,
                                                  0,
                                                  ADI_ENABLE);
    ADI_ERROR_REPORT(&fpga9025Device->common,
                     ADI_COMMON_ERRSRC_API,
                     fpga9025Device->common.error.errCode,
                     recoveryAction,
                     NULL,
                     fpga9025Device->common.error.errormessage);
    ADI_ERROR_RETURN(fpga9025Device->common.error.newAction);

    /* Enable/reset FPGA Framer(s) */
    recoveryAction = adi_fpga9025_FramerReset(fpga9025Device,
                                              (uint8_t)link);
    ADI_ERROR_REPORT(&fpga9025Device->common,
                     ADI_COMMON_ERRSRC_API,
                     fpga9025Device->common.error.errCode,
                     recoveryAction,
                     NULL,
                     fpga9025Device->common.error.errormessage);
    ADI_ERROR_RETURN(fpga9025Device->common.error.newAction);
#endif
    /* Request sysref to start fpga framers sending data */
    ucp_api_ad9528_OnePluse(1);
    
#if 0
    /* Mask the sysref for the fpga framers as a precaution for the next sysref (leave rx links untouched) */
    recoveryAction = adi_fpga9025_SysRefEnableSet(fpga9025Device,
                                                  (uint8_t)link,
                                                  0,
                                                  ADI_DISABLE);
    ADI_ERROR_REPORT(&fpga9025Device->common,
                     ADI_COMMON_ERRSRC_API,
                     fpga9025Device->common.error.errCode,
                     recoveryAction,
                     NULL,
                     fpga9025Device->common.error.errormessage);
    ADI_ERROR_RETURN(fpga9025Device->common.error.newAction);
#endif
    /* Reset/Enable Adrv9025 Deframer(s) */
    recoveryAction = adi_adrv9025_DfrmLinkStateSet(adrv9025Device,
                                                   (uint8_t)link,
                                                   ADI_DISABLE);
    ADI_ERROR_REPORT(&adrv9025Device->common,
                     ADI_COMMON_ERRSRC_API,
                     adrv9025Device->common.error.errCode,
                     recoveryAction,
                     NULL,
                     adrv9025Device->common.error.errormessage);
    ADI_ERROR_RETURN(adrv9025Device->common.error.newAction);

    recoveryAction = adi_common_hal_Wait_ms(&adrv9025Device->common,
                                            50);
    ADI_ERROR_REPORT(&adrv9025Device->common,
                     ADI_COMMON_ERRSRC_API,
                     adrv9025Device->common.error.errCode,
                     recoveryAction,
                     NULL,
                     adrv9025Device->common.error.errormessage);
    ADI_ERROR_RETURN(adrv9025Device->common.error.newAction);

    recoveryAction = adi_adrv9025_DfrmLinkStateSet(adrv9025Device,
                                                   (uint8_t)link,
                                                   ADI_ENABLE);
    ADI_ERROR_REPORT(&adrv9025Device->common,
                     ADI_COMMON_ERRSRC_API,
                     adrv9025Device->common.error.errCode,
                     recoveryAction,
                     NULL,
                     adrv9025Device->common.error.errormessage);
    ADI_ERROR_RETURN(adrv9025Device->common.error.newAction);

    sleep(1);
#if 0
    /* Notify ARM to run SERDES Calbriation if necessary */
    serdesCal.calMask     = ADI_ADRV9025_SERDES_INIT;
    serdesCal.channelMask = CAL_ALL_CHANNELS;
    serdesCal.warmBoot    = 0;
    recoveryAction        = adi_adrv9025_InitCalsRun(adrv9025Device,
                                                     &serdesCal);
    ADI_ERROR_REPORT(&adrv9025Device->common,
                     ADI_COMMON_ERRSRC_API,
                     adrv9025Device->common.error.errCode,
                     recoveryAction,
                     NULL,
                     adrv9025Device->common.error.errormessage);
    ADI_ERROR_RETURN(adrv9025Device->common.error.newAction);

    /* Wait up to 60 seconds for ARM */
    recoveryAction = adi_adrv9025_InitCalsWait(adrv9025Device,
                                               60000,
                                               &errFlags);
    ADI_ERROR_REPORT(&adrv9025Device->common,
                     ADI_COMMON_ERRSRC_API,
                     adrv9025Device->common.error.errCode,
                     recoveryAction,
                     NULL,
                     adrv9025Device->common.error.errormessage);
    ADI_ERROR_RETURN(adrv9025Device->common.error.newAction);
#endif
    /* Adrv9025 Unmask Sysref in Deframer(s) */
    recoveryAction = adi_adrv9025_DeframerSysrefCtrlSet(adrv9025Device,
                                                        (adi_adrv9025_DeframerSel_e)link,
                                                        ADI_ENABLE);
    ADI_ERROR_REPORT(&adrv9025Device->common,
                     ADI_COMMON_ERRSRC_API,
                     adrv9025Device->common.error.errCode,
                     recoveryAction,
                     NULL,
                     adrv9025Device->common.error.errormessage);
    ADI_ERROR_RETURN(adrv9025Device->common.error.newAction);

    /* Request sysref for adrv9025 deframers only */
    ucp_api_ad9528_OnePluse(1);
    
    /* Adrv9025 mask Sysref in Deframer(s) as a precaution */
    recoveryAction = adi_adrv9025_DeframerSysrefCtrlSet(adrv9025Device,
                                                        (adi_adrv9025_DeframerSel_e)link,
                                                        ADI_DISABLE);
    ADI_ERROR_REPORT(&adrv9025Device->common,
                     ADI_COMMON_ERRSRC_API,
                     adrv9025Device->common.error.errCode,
                     recoveryAction,
                     NULL,
                     adrv9025Device->common.error.errormessage);
    ADI_ERROR_RETURN(adrv9025Device->common.error.newAction);

    return recoveryAction;
}

static int32_t adi_board_adrv9025_JesdRxBringup(adi_adrv9025_Device_t*       adrv9025Device,
                                              uint32_t                 link)
{
    int32_t                recoveryAction          = ADI_COMMON_ACT_NO_ACTION;
    uint8_t                sysrefEnabledForFramer2 = ADI_FALSE;

    if (adrv9025Device->devStateInfo.linkSharingEnabled == 1)
    {
        /* Start the AUX Sys Ref in JTX Link 1*/
        recoveryAction = adi_adrv9025_FramerLinkStateSet(adrv9025Device,
                                                         ADI_ADRV9025_FRAMER_1,
                                                         ADI_ENABLE);
        ADI_ERROR_REPORT(&adrv9025Device->common,
                         ADI_COMMON_ERRSRC_API,
                         adrv9025Device->common.error.errCode,
                         recoveryAction,
                         NULL,
                         adrv9025Device->common.error.errormessage);
        ADI_ERROR_RETURN(adrv9025Device->common.error.newAction);

        /* Adrv9025 Unmask incoming Sysref in Framer(s) */
        recoveryAction = adi_adrv9025_FramerSysrefCtrlSet(adrv9025Device,
                                                          ADI_ADRV9025_FRAMER_1,
                                                          ADI_ENABLE);
        ADI_ERROR_REPORT(&adrv9025Device->common,
                         ADI_COMMON_ERRSRC_API,
                         adrv9025Device->common.error.errCode,
                         recoveryAction,
                         NULL,
                         adrv9025Device->common.error.errormessage);
        ADI_ERROR_RETURN(adrv9025Device->common.error.newAction);

        ucp_api_ad9528_OnePluse(1);
       
        recoveryAction = adi_adrv9025_FramerLinkStateSet(adrv9025Device,
                                                         ADI_ADRV9025_FRAMER_1,
                                                         ADI_DISABLE);
        ADI_ERROR_REPORT(&adrv9025Device->common,
                         ADI_COMMON_ERRSRC_API,
                         adrv9025Device->common.error.errCode,
                         recoveryAction,
                         NULL,
                         adrv9025Device->common.error.errormessage);
        ADI_ERROR_RETURN(adrv9025Device->common.error.newAction);

        recoveryAction = adi_adrv9025_FramerSysrefCtrlSet(adrv9025Device,
                                                          ADI_ADRV9025_FRAMER_1,
                                                          ADI_DISABLE);
        ADI_ERROR_REPORT(&adrv9025Device->common,
                         ADI_COMMON_ERRSRC_API,
                         adrv9025Device->common.error.errCode,
                         recoveryAction,
                         NULL,
                         adrv9025Device->common.error.errormessage);
        ADI_ERROR_RETURN(adrv9025Device->common.error.newAction);

        recoveryAction = adi_adrv9025_FramerLinkStateSet(adrv9025Device,
                                                         ADI_ADRV9025_FRAMER_0,
                                                         ADI_ENABLE);
        ADI_ERROR_REPORT(&adrv9025Device->common,
                         ADI_COMMON_ERRSRC_API,
                         adrv9025Device->common.error.errCode,
                         recoveryAction,
                         NULL,
                         adrv9025Device->common.error.errormessage);
        ADI_ERROR_RETURN(adrv9025Device->common.error.newAction);

        recoveryAction = adi_adrv9025_FramerSysrefCtrlSet(adrv9025Device,
                                                          ADI_ADRV9025_FRAMER_0,
                                                          ADI_ENABLE);
        ADI_ERROR_REPORT(&adrv9025Device->common,
                         ADI_COMMON_ERRSRC_API,
                         adrv9025Device->common.error.errCode,
                         recoveryAction,
                         NULL,
                         adrv9025Device->common.error.errormessage);
        ADI_ERROR_RETURN(adrv9025Device->common.error.newAction);

        /* Check that if the profile uses Framer 2 */
        if ((link & (uint32_t)ADI_ADRV9025_FRAMER_2) == (uint32_t)ADI_ADRV9025_FRAMER_2)
        {
            recoveryAction = adi_adrv9025_FramerLinkStateSet(adrv9025Device,
                                                             ADI_ADRV9025_FRAMER_2,
                                                             ADI_ENABLE);
            ADI_ERROR_REPORT(&adrv9025Device->common,
                             ADI_COMMON_ERRSRC_API,
                             adrv9025Device->common.error.errCode,
                             recoveryAction,
                             NULL,
                             adrv9025Device->common.error.errormessage);
            ADI_ERROR_RETURN(adrv9025Device->common.error.newAction);

            recoveryAction = adi_adrv9025_FramerSysrefCtrlSet(adrv9025Device,
                                                              ADI_ADRV9025_FRAMER_2,
                                                              ADI_ENABLE);
            ADI_ERROR_REPORT(&adrv9025Device->common,
                             ADI_COMMON_ERRSRC_API,
                             adrv9025Device->common.error.errCode,
                             recoveryAction,
                             NULL,
                             adrv9025Device->common.error.errormessage);
            ADI_ERROR_RETURN(adrv9025Device->common.error.newAction);

            sysrefEnabledForFramer2 = ADI_TRUE;
        }
    }
    else
    {
        /* Enable/reset Adrv9025 Framer(s) */
        recoveryAction = adi_adrv9025_FramerLinkStateSet(adrv9025Device,
                                                         link,
                                                         ADI_DISABLE);
        ADI_ERROR_REPORT(&adrv9025Device->common,
                         ADI_COMMON_ERRSRC_API,
                         adrv9025Device->common.error.errCode,
                         recoveryAction,
                         NULL,
                         adrv9025Device->common.error.errormessage);
        ADI_ERROR_RETURN(adrv9025Device->common.error.newAction);

        recoveryAction = adi_common_hal_Wait_ms(&adrv9025Device->common,
                                                50);
        ADI_ERROR_REPORT(&adrv9025Device->common,
                         ADI_COMMON_ERRSRC_API,
                         adrv9025Device->common.error.errCode,
                         recoveryAction,
                         NULL,
                         adrv9025Device->common.error.errormessage);
        ADI_ERROR_RETURN(adrv9025Device->common.error.newAction);

        recoveryAction = adi_adrv9025_FramerLinkStateSet(adrv9025Device,
                                                         link,
                                                         ADI_ENABLE);
        ADI_ERROR_REPORT(&adrv9025Device->common,
                         ADI_COMMON_ERRSRC_API,
                         adrv9025Device->common.error.errCode,
                         recoveryAction,
                         NULL,
                         adrv9025Device->common.error.errormessage);
        ADI_ERROR_RETURN(adrv9025Device->common.error.newAction);

        /* Adrv9025 Unmask incoming Sysref in Framer(s) */
        recoveryAction = adi_adrv9025_FramerSysrefCtrlSet(adrv9025Device,
                                                          (uint8_t)link,
                                                          ADI_ENABLE);
        ADI_ERROR_REPORT(&adrv9025Device->common,
                         ADI_COMMON_ERRSRC_API,
                         adrv9025Device->common.error.errCode,
                         recoveryAction,
                         NULL,
                         adrv9025Device->common.error.errormessage);
        ADI_ERROR_RETURN(adrv9025Device->common.error.newAction);
    }

#if 0
    /* Disable DFE LPM in PHY before after sys ref */
    adi_fpga9025_ChannelDfeLpmOverrideSet(fpga9025Device,
                                          0xFF,
                                          0);
    ADI_ERROR_REPORT(&fpga9025Device->common,
                     ADI_COMMON_ERRSRC_API,
                     fpga9025Device->common.error.errCode,
                     recoveryAction,
                     NULL,
                     fpga9025Device->common.error.errormessage);
    ADI_ERROR_RETURN(fpga9025Device->common.error.newAction);
#endif

    /* Wait 100ms for clock recovery on FPGA to lock */
    recoveryAction = adi_common_hal_Wait_ms(&adrv9025Device->common,
                                            100);
    ADI_ERROR_REPORT(&adrv9025Device->common,
                     ADI_COMMON_ERRSRC_API,
                     adrv9025Device->common.error.errCode,
                     recoveryAction,
                     NULL,
                     adrv9025Device->common.error.errormessage);
    ADI_ERROR_RETURN(adrv9025Device->common.error.newAction);
#if 0
    /* Enable/reset FPGA Deframer(s) */
    recoveryAction = adi_fpga9025_DeframerReset(fpga9025Device,
                                                (uint8_t)link);
    ADI_ERROR_REPORT(&fpga9025Device->common,
                     ADI_COMMON_ERRSRC_API,
                     fpga9025Device->common.error.errCode,
                     recoveryAction,
                     NULL,
                     fpga9025Device->common.error.errormessage);
    ADI_ERROR_RETURN(fpga9025Device->common.error.newAction);

    /* Disable DFE LPM in PHY before after sys ref */
    recoveryAction = adi_fpga9025_ChannelDfeLpmOverrideSet(fpga9025Device,
                                                           0xFF,
                                                           0);
    ADI_ERROR_REPORT(&fpga9025Device->common,
                     ADI_COMMON_ERRSRC_API,
                     fpga9025Device->common.error.errCode,
                     recoveryAction,
                     NULL,
                     fpga9025Device->common.error.errormessage);
    ADI_ERROR_RETURN(fpga9025Device->common.error.newAction);

    /* Unmask incoming sysref in FPGA deframers (leave tx links untouched) */
    recoveryAction = adi_fpga9025_SysRefEnableSet(fpga9025Device,
                                                  0,
                                                  (uint8_t)link,
                                                  ADI_ENABLE);
    ADI_ERROR_REPORT(&fpga9025Device->common,
                     ADI_COMMON_ERRSRC_API,
                     fpga9025Device->common.error.errCode,
                     recoveryAction,
                     NULL,
                     fpga9025Device->common.error.errormessage);
    ADI_ERROR_RETURN(fpga9025Device->common.error.newAction);
#endif
    /* Request sysref to bring up Rx links */
    ucp_api_ad9528_OnePluse(1);
    
    if (adrv9025Device->devStateInfo.linkSharingEnabled == 0)
    {
        /* Adrv9025 mask sysref in Framers. Precaution against future sysref signals */
        recoveryAction = adi_adrv9025_FramerSysrefCtrlSet(adrv9025Device,
                                                          (uint8_t)link,
                                                          ADI_DISABLE);
        ADI_ERROR_REPORT(&adrv9025Device->common,
                         ADI_COMMON_ERRSRC_API,
                         adrv9025Device->common.error.errCode,
                         recoveryAction,
                         NULL,
                         adrv9025Device->common.error.errormessage);
        ADI_ERROR_RETURN(adrv9025Device->common.error.newAction);
    }

    if (sysrefEnabledForFramer2 == ADI_TRUE)
    {
        recoveryAction = adi_adrv9025_FramerSysrefCtrlSet(adrv9025Device,
                                                          ADI_ADRV9025_FRAMER_2,
                                                          ADI_DISABLE);
        ADI_ERROR_REPORT(&adrv9025Device->common,
                         ADI_COMMON_ERRSRC_API,
                         adrv9025Device->common.error.errCode,
                         recoveryAction,
                         NULL,
                         adrv9025Device->common.error.errormessage);
        ADI_ERROR_RETURN(adrv9025Device->common.error.newAction);
    }
#if 0
    /* Mask sysref in fpga deframers. Precaution against future sysref signals */
    recoveryAction = adi_fpga9025_SysRefEnableSet(fpga9025Device,
                                                  0,
                                                  (uint8_t)link,
                                                  ADI_DISABLE);
    ADI_ERROR_REPORT(&fpga9025Device->common,
                     ADI_COMMON_ERRSRC_API,
                     fpga9025Device->common.error.errCode,
                     recoveryAction,
                     NULL,
                     fpga9025Device->common.error.errormessage);
    ADI_ERROR_RETURN(fpga9025Device->common.error.newAction);
#endif
    return recoveryAction;
}

static int32_t adi_board_adrv9025_JesdBringup(adi_adrv9025_Device_t     *  adrv9025Device,
                                            uint32_t                 txLinkSel,
                                            uint32_t                 rxLinkSel)
{
    int32_t              recoveryAction = ADI_COMMON_ACT_NO_ACTION;
    uint8_t                i                     = 0;
    uint8_t                adrv9025LinkStatus    = 0;
    uint8_t                deframerLinkCondition = 0;
    
    /* Mask all sysrefs in Adrv9025 */
    recoveryAction = adi_adrv9025_DeframerSysrefCtrlSet(adrv9025Device,
                                                        ADI_ADRV9025_DEFRAMER_0,
                                                        ADI_DISABLE);
    ADI_ERROR_REPORT(&adrv9025Device->common,
                     ADI_COMMON_ERRSRC_API,
                     adrv9025Device->common.error.errCode,
                     recoveryAction,
                     NULL,
                     adrv9025Device->common.error.errormessage);
    ADI_ERROR_RETURN(adrv9025Device->common.error.newAction);

    recoveryAction = adi_adrv9025_FramerSysrefCtrlSet(adrv9025Device,
                                                      ADI_ADRV9025_ALL_FRAMERS,
                                                      ADI_DISABLE);
    ADI_ERROR_REPORT(&adrv9025Device->common,
                     ADI_COMMON_ERRSRC_API,
                     adrv9025Device->common.error.errCode,
                     recoveryAction,
                     NULL,
                     adrv9025Device->common.error.errormessage);
    ADI_ERROR_RETURN(adrv9025Device->common.error.newAction);
#if 0
    /* Mask all sysrefs in fpga */
    recoveryAction = adi_fpga9025_SysRefEnableSet(fpga9025Device,
                                                  ADI_FPGA9025_FRAMER_ALL,
                                                  ADI_FPGA9025_DEFRAMER_ALL,
                                                  ADI_DISABLE);
    ADI_ERROR_REPORT(&fpga9025Device->common,
                     ADI_COMMON_ERRSRC_API,
                     fpga9025Device->common.error.errCode,
                     recoveryAction,
                     NULL,
                     fpga9025Device->common.error.errormessage);
    ADI_ERROR_RETURN(fpga9025Device->common.error.newAction);

    /* Disable all the FPGA framer & deframers */
    recoveryAction = adi_fpga9025_FramerDisable(fpga9025Device,
                                                ADI_FPGA9025_FRAMER_ALL);
    ADI_ERROR_REPORT(&fpga9025Device->common,
                     ADI_COMMON_ERRSRC_API,
                     fpga9025Device->common.error.errCode,
                     recoveryAction,
                     NULL,
                     fpga9025Device->common.error.errormessage);
    ADI_ERROR_RETURN(fpga9025Device->common.error.newAction);

    recoveryAction = adi_fpga9025_DeframerDisable(fpga9025Device,
                                                  ADI_FPGA9025_DEFRAMER_ALL);
    ADI_ERROR_REPORT(&fpga9025Device->common,
                     ADI_COMMON_ERRSRC_API,
                     fpga9025Device->common.error.errCode,
                     recoveryAction,
                     NULL,
                     fpga9025Device->common.error.errormessage);
    ADI_ERROR_RETURN(fpga9025Device->common.error.newAction);
#endif
    /* Disable all the ADRV9025 framer & deframers */
    recoveryAction = adi_adrv9025_DfrmLinkStateSet(adrv9025Device,
                                                   (uint8_t)ADI_ADRV9025_DEFRAMER_0,
                                                   ADI_DISABLE);
    ADI_ERROR_REPORT(&adrv9025Device->common,
                     ADI_COMMON_ERRSRC_API,
                     adrv9025Device->common.error.errCode,
                     recoveryAction,
                     NULL,
                     adrv9025Device->common.error.errormessage);
    ADI_ERROR_RETURN(adrv9025Device->common.error.newAction);

    recoveryAction = adi_adrv9025_FramerLinkStateSet(adrv9025Device,
                                                     (uint8_t)ADI_ADRV9025_ALL_FRAMERS,
                                                     ADI_DISABLE);
    ADI_ERROR_REPORT(&adrv9025Device->common,
                     ADI_COMMON_ERRSRC_API,
                     adrv9025Device->common.error.errCode,
                     recoveryAction,
                     NULL,
                     adrv9025Device->common.error.errormessage);
    ADI_ERROR_RETURN(adrv9025Device->common.error.newAction);
#if 0
    /* Override DFE LPM in PHY before sending sys ref */
    recoveryAction = adi_fpga9025_ChannelDfeLpmOverrideSet(fpga9025Device,
                                                           0xFF,
                                                           1);
    ADI_ERROR_REPORT(&fpga9025Device->common,
                     ADI_COMMON_ERRSRC_API,
                     fpga9025Device->common.error.errCode,
                     recoveryAction,
                     NULL,
                     fpga9025Device->common.error.errormessage);
    ADI_ERROR_RETURN(fpga9025Device->common.error.newAction);
#endif
    if (rxLinkSel != 0)
    {
        /* Bring up the Rx links */
        recoveryAction = adi_board_adrv9025_JesdRxBringup(adrv9025Device,
                                                          rxLinkSel);
        ADI_ERROR_REPORT(&adrv9025Device->common,
                         ADI_COMMON_ERRSRC_API,
                         adrv9025Device->common.error.errCode,
                         recoveryAction,
                         NULL,
                         adrv9025Device->common.error.errormessage);
        ADI_ERROR_RETURN(adrv9025Device->common.error.newAction);
#if 0
        if (fpga9025Device->devStateInfo.designId == ADI_FPGA9025_JESD204C_DEVICEID)
        {
            recoveryAction = adi_fpga9025_Jesd204CDeframerCmdDataSet(fpga9025Device,
                                                                     rxLinkSel,
                                                                     ADI_ENABLE,
                                                                     ADI_ENABLE);
            ADI_ERROR_REPORT(&fpga9025Device->common,
                             ADI_COMMON_ERRSRC_API,
                             fpga9025Device->common.error.errCode,
                             recoveryAction,
                             NULL,
                             fpga9025Device->common.error.errormessage);
            ADI_ERROR_RETURN(fpga9025Device->common.error.newAction);
        }
#endif
    }

    if (txLinkSel != 0)
    {
        /* Bring up the Tx links */
        recoveryAction = adi_board_adrv9025_JesdTxBringup(adrv9025Device,
                                                          txLinkSel);
        ADI_ERROR_REPORT(&adrv9025Device->common,
                         ADI_COMMON_ERRSRC_API,
                         adrv9025Device->common.error.errCode,
                         recoveryAction,
                         NULL,
                         adrv9025Device->common.error.errormessage);
        ADI_ERROR_RETURN(adrv9025Device->common.error.newAction);
#if 0
        if (fpga9025Device->devStateInfo.designId == ADI_FPGA9025_JESD204C_DEVICEID)
        {
            recoveryAction = adi_fpga9025_Jesd204CFramerCmdDataSet(fpga9025Device,
                                                                   txLinkSel,
                                                                   ADI_ENABLE,
                                                                   ADI_ENABLE);
            ADI_ERROR_REPORT(&fpga9025Device->common,
                             ADI_COMMON_ERRSRC_API,
                             fpga9025Device->common.error.errCode,
                             recoveryAction,
                             NULL,
                             fpga9025Device->common.error.errormessage);
            ADI_ERROR_RETURN(fpga9025Device->common.error.newAction);
        }
#endif
    }
    
    /* Adrv9025 Deframer Status get*/
    for (i = 0; i < 2; i++)
    {
        if ((txLinkSel & (1 << i)) > 0)
        {
            deframerLinkCondition = 0;
            recoveryAction        = adi_adrv9025_DfrmLinkConditionGet(adrv9025Device,
                                                                      (adi_adrv9025_DeframerSel_e)((uint8_t)(1 << i)),
                                                                      &deframerLinkCondition);
            ADI_ERROR_REPORT(&adrv9025Device->common,
                             ADI_COMMON_ERRSRC_API,
                             adrv9025Device->common.error.errCode,
                             recoveryAction,
                             NULL,
                             adrv9025Device->common.error.errormessage);
            ADI_ERROR_RETURN(adrv9025Device->common.error.newAction);

            if (deframerLinkCondition & 0x01)
            {
                adrv9025LinkStatus |= (1 << i);
            }
        }
    }
#if 0
    /* Fpga Reading User Data Ready bit*/
    recoveryAction = adi_fpga9025_DeframerStatusGet(fpga9025Device,
                                                    rxLinkSel,
                                                    &fpga9025LinkStatus);
    ADI_ERROR_REPORT(&fpga9025Device->common,
                     ADI_COMMON_ERRSRC_API,
                     fpga9025Device->common.error.errCode,
                     recoveryAction,
                     NULL,
                     fpga9025Device->common.error.errormessage);
    ADI_ERROR_RETURN(fpga9025Device->common.error.newAction);

    if (adrv9025LinkStatus != txLinkSel)
    {
        recoveryAction = ADI_COMMON_ACT_ERR_RESET_INTERFACE;
        ADI_ERROR_REPORT(&adrv9025Device->common,
                         ADI_COMMON_ERRSRC_API,
                         ADI_COMMON_ERR_API_FAIL,
                         recoveryAction,
                         NULL,
                         "Not all Tx links have been established.");

        /* Disable all the FPGA deframers. Don't update the error though, this is just cleanup */
        adi_fpga9025_FramerDisable(fpga9025Device,
                                   ADI_FPGA9025_FRAMER_ALL);
    }
    if (fpga9025LinkStatus != rxLinkSel)
    {
        recoveryAction = ADI_COMMON_ACT_ERR_RESET_INTERFACE;
        ADI_ERROR_REPORT(&adrv9025Device->common,
                         ADI_COMMON_ERRSRC_API,
                         ADI_COMMON_ERR_API_FAIL,
                         recoveryAction,
                         NULL,
                         "Not all Rx links have been established.");

        /* Disable all the FPGA deframers. Don't update the error though, this is just cleanup */
        adi_fpga9025_DeframerDisable(fpga9025Device,
                                     ADI_FPGA9025_DEFRAMER_ALL);
    }
#endif

    /* Kick off SERDES tracking cal if lanes are up */
	recoveryAction = adi_adrv9025_TrackingCalsEnableSet(adrv9025Device,
														0x100FFFFFF, // ADI_ADRV9025_TRACK_DESERIALIZER,
														ADI_ADRV9025_TRACKING_CAL_DISABLE); // ADI_ADRV9025_TRACKING_CAL_ENABLE);
	ADI_ERROR_REPORT(&adrv9025Device->common,
					 ADI_COMMON_ERRSRC_API,
					 adrv9025Device->common.error.errCode,
					 recoveryAction,
					 NULL,
					 adrv9025Device->common.error.errormessage);
	ADI_ERROR_RETURN(adrv9025Device->common.error.newAction);

    return recoveryAction;
}

int32_t adrv9025_setAtt (uint8_t chanMask, uint16_t att)
{
    int32_t recoveryAction = 0;
    adi_adrv9025_TxAtten_t txAtten = { 0 };

    if (att > 41000)
    {
        printf("err: att out of range!\n");
        return ADI_COMMON_ACT_ERR_RESET_FULL;
    }
	
	printf("txAtt:  0x%02X  %d\n", chanMask, att);
    txAtten.txChannelMask = chanMask;
    txAtten.txAttenuation_mdB = att; /* Back off Tx output power by 30dB */
    recoveryAction = adi_adrv9025_TxAttenSet(adrv9025Device, &txAtten, 1);
    if (recoveryAction != ADI_COMMON_ACT_NO_ACTION)
    {
         printf("Failed to set ADRV9025 Tx Attenuation\n");
         printf("ERROR: Error number %d, Recovery action %d. In file %s, in function %s, in line %d, variable name %s. Error message %s.\n",
                adrv9025Device->common.error.errCode,
                adrv9025Device->common.error.newAction,
                adrv9025Device->common.error.errFile,
                adrv9025Device->common.error.errFunc,
                adrv9025Device->common.error.errLine,
                adrv9025Device->common.error.varName,
                adrv9025Device->common.error.errormessage);
         /* Call action handler */
         return ADI_COMMON_ACT_ERR_RESET_FULL;
    }

    return recoveryAction;
}

int32_t adrv9025_spiRxTxEnableSet(uint32_t               rxChannelMask,
                                     uint32_t            txChannelMask) 
{
   int32_t recoveryAction = ADI_COMMON_ACT_NO_ACTION;

   recoveryAction = adi_adrv9025_RxTxEnableSet(adrv9025Device, rxChannelMask, txChannelMask);
   if (recoveryAction != ADI_COMMON_ACT_NO_ACTION)
   {
        printf("Failed to enable ADRV9025 Tx RF output\n");
        printf("ERROR: Error number %d, Recovery action %d. In file %s, in function %s, in line %d, variable name %s. Error message %s.\n",
            adrv9025Device->common.error.errCode,
            adrv9025Device->common.error.newAction,
            adrv9025Device->common.error.errFile,
            adrv9025Device->common.error.errFunc,
            adrv9025Device->common.error.errLine,
            adrv9025Device->common.error.varName,
            adrv9025Device->common.error.errormessage);
            
        /* Call action handler */
        return ADI_COMMON_ACT_ERR_RESET_FULL;
   }

   return recoveryAction;
}

void adrv9025_setGainMode (uint8_t mgcEn)
{
    adi_adrv9025_RxAgcMode_t gainMode[2];
    adi_adrv9025_RxAgcMode_e mode;

    mode = mgcEn ? ADI_ADRV9025_MGC : ADI_ADRV9025_AGCFAST;
    
    gainMode[0].agcMode = mode;
    gainMode[0].rxChannelMask = 0xFF;
    gainMode[1].agcMode = mode;
    gainMode[1].rxChannelMask = 0xFF;
    gainMode[2].agcMode = mode;
    gainMode[2].rxChannelMask = 0xFF;
    gainMode[3].agcMode = mode;
    gainMode[3].rxChannelMask = 0xFF;
    adi_adrv9025_RxGainCtrlModeSet(adrv9025Device, gainMode, 4);
}

int32_t adi_adrv9025_EnableTxExample (adi_adrv9025_Device_t *device)
{
    int32_t recoveryAction = 0;
     
    if (device == NULL)
    {
         printf("NULL ADRV9025 device pointer\n");
         return -1;
    }
   
    /* Setup internal Tx test tone frequency */
    adi_adrv9025_TxTestToneCfg_t toneCfg = { 0 }; 
    toneCfg.txChannelMask = ADI_ADRV9025_TXALL;
    toneCfg.txToneFreq_Hz = 2800000;
    toneCfg.txToneGain = ADI_ADRV9025_TX_NCO_0_DB;
    toneCfg.enable = 1;     
    recoveryAction = adi_adrv9025_TxTestToneSet(device, &toneCfg, 1);
    if (recoveryAction != ADI_COMMON_ACT_NO_ACTION)
    {
        printf("Failed to setup ADRV9025 Tx Test Tone\n");
        printf("ERROR: Error number %d, Recovery action %d. In file %s, in function %s, in line %d, variable name %s. Error message %s.\n",
            device->common.error.errCode,
            device->common.error.newAction,
            device->common.error.errFile,
            device->common.error.errFunc,
            device->common.error.errLine,
            device->common.error.varName,
            device->common.error.errormessage);
        /* Call action handler */
        return ADI_COMMON_ACT_ERR_RESET_FULL;
    }
    
#if 0     
    adi_adrv9025_TxAtten_t txAtten = { 0 };
    txAtten.txChannelMask = ADI_ADRV9025_TXALL;
    txAtten.txAttenuation_mdB = 30000; // 15000; /* Back off Tx output power by 30dB */
    recoveryAction = adi_adrv9025_TxAttenSet(device, &txAtten, 1);
    if (recoveryAction != ADI_COMMON_ACT_NO_ACTION)
    {
         printf("Failed to set ADRV9025 Tx Attenuation\n");
         printf("ERROR: Error number %d, Recovery action %d. In file %s, in function %s, in line %d, variable name %s. Error message %s.\n",
                device->common.error.errCode,
                device->common.error.newAction,
                device->common.error.errFile,
                device->common.error.errFunc,
                device->common.error.errLine,
                device->common.error.varName,
                device->common.error.errormessage);
         /* Call action handler */
         return ADI_COMMON_ACT_ERR_RESET_FULL;
    }
#endif  
    return 0;
}

int32_t adrv9025_tone (bool set)
{
    int32_t recoveryAction = 0;

	UCP_API_GPIO_Tx();
	recoveryAction = adi_adrv9025_EnableTxExample(adrv9025Device);
	return recoveryAction;
}

int32_t ad9025_MGC_Cfg(uint8_t en)
{
    adi_adrv9025_RxAgcMode_t gainMode[3];

    if (en) 
    {
        gainMode[0].agcMode = ADI_ADRV9025_MGC;
    }
    else
    {
        gainMode[0].agcMode = ADI_ADRV9025_AGCFAST;
    }
    
    gainMode[0].rxChannelMask = 0xFF;
    adi_adrv9025_RxGainCtrlModeSet(adrv9025Device, gainMode, 1);

    return 1;
}

int32_t ad9025_Gain_Set(double gain_db)
{
	adi_adrv9025_RxGain_t gain[3];
	uint8_t gain_index = 0;

	gain_index = (uint8_t)(gain_db*2);
	gain[0].rxChannelMask = 0xFF;
	loadCalMgcGainIndex = ((gain_index + 183) > 255) ? 255 : (gain_index + 183);
	gain[0].gainIndex = loadCalMgcGainIndex;
	adi_adrv9025_RxGainSet(adrv9025Device, gain, 1);

	return 0;
}

double ad9025_Gain_Get(void)
{
    return (double)((loadCalMgcGainIndex - 183)*0.5);
}

int32_t ad9025_Att_Set(uint8_t att_db)
{
	localTxAtt = (att_db > 20) ? 20 : att_db;
    printf("localTxAtt: %d db\n", localTxAtt);

    // HW_EVMT/HW_EVMF: 15000 14500 14500 16450
    // HW_EVMY:         10000 10000 10000 12450
    // HW_EVB:          0 0 0 0
    adrv9025_setAtt(0x1, localTxAtt*1000 + gRficCalPara.calChAttPara[0]);

    return 0;
}

uint8_t ad9025_Att_Get(void)
{
    return localTxAtt;
}

void ad9025_rssi(void)
{
    uint16_t rssi[8] = {0};
    adi_adrv9025_RxAgcMode_t gainMode[3];
	adi_adrv9025_RxGain_t gain[3];
	uint8_t gainIndex;
	double para_calRxInstrument, para_calOrxInstrument, 
	        para_calRx, para_calOrx;
	
    printf("start rssi test:\n");

    adrv9025_spiRxTxEnableSet(0xFF, 0x0F);
    
    gainMode[0].agcMode = ADI_ADRV9025_MGC;
    gainMode[0].rxChannelMask = 0xFF;
    adi_adrv9025_RxGainCtrlModeSet(adrv9025Device, gainMode, 1);
	
	gain[0].rxChannelMask = 0xFF;
	gain[0].gainIndex = loadCalMgcGainIndex; // 183~255  20.7225@183 18.3475@185
	adi_adrv9025_RxGainSet(adrv9025Device, gain, 1);

    // orx - rx = 14.1875db
    // rxNoisy = -36.155dbm@183   orxNoisy = -21.9675@183
    // rxRawNosiy = -57.1875db@183 orxRawNosiy = -42.5db@183
    // rxNoisy = -36.155;
    para_calRx =  20.7225;
    para_calOrx = para_calRx;
    gainIndex = (gain[0].gainIndex < 183) ? 255 : gain[0].gainIndex;
    para_calRxInstrument  =  para_calRx - (gainIndex - 183)*0.5;
    para_calOrxInstrument = para_calOrx - (gainIndex - 183)*0.5;
    
    while (1)
    {
        adi_adrv9025_RxDecPowerGet(adrv9025Device, ADI_ADRV9025_RX1, &rssi[0]);
        adi_adrv9025_RxDecPowerGet(adrv9025Device, ADI_ADRV9025_RX2, &rssi[1]);
        adi_adrv9025_RxDecPowerGet(adrv9025Device, ADI_ADRV9025_RX3, &rssi[2]);
        adi_adrv9025_RxDecPowerGet(adrv9025Device, ADI_ADRV9025_RX4, &rssi[3]);
        adi_adrv9025_RxDecPowerGet(adrv9025Device, ADI_ADRV9025_ORX1, &rssi[4]);
        adi_adrv9025_RxDecPowerGet(adrv9025Device, ADI_ADRV9025_ORX2, &rssi[5]);
        adi_adrv9025_RxDecPowerGet(adrv9025Device, ADI_ADRV9025_ORX3, &rssi[6]);
        adi_adrv9025_RxDecPowerGet(adrv9025Device, ADI_ADRV9025_ORX4, &rssi[7]);
        printf("rssiInst = %.2f | %.2f | %.2f | %.2f | %.2f | %.2f | %.2f | %.2f\r\n", 
                -(rssi[0]*1.0/1000.0) + para_calRxInstrument,
                -(rssi[1]*1.0/1000.0) + para_calRxInstrument,
                -(rssi[2]*1.0/1000.0) + para_calRxInstrument,
                -(rssi[3]*1.0/1000.0) + para_calRxInstrument,
                -(rssi[4]*1.0/1000.0) + para_calOrxInstrument,
                -(rssi[5]*1.0/1000.0) + para_calOrxInstrument,
                -(rssi[6]*1.0/1000.0) + para_calOrxInstrument,
                -(rssi[7]*1.0/1000.0) + para_calOrxInstrument);
        printf("rssiPad  = %.2f | %.2f | %.2f | %.2f | %.2f | %.2f | %.2f | %.2f\r\n", 
                -(rssi[0]*1.0/1000.0) + para_calRx,
                -(rssi[1]*1.0/1000.0) + para_calRx,
                -(rssi[2]*1.0/1000.0) + para_calRx,
                -(rssi[3]*1.0/1000.0) + para_calRx,
                -(rssi[4]*1.0/1000.0) + para_calOrx,
                -(rssi[5]*1.0/1000.0) + para_calOrx,
                -(rssi[6]*1.0/1000.0) + para_calOrx,
                -(rssi[7]*1.0/1000.0) + para_calOrx);
        printf("rssi_db  = %.2f | %.2f | %.2f | %.2f | %.2f | %.2f | %.2f | %.2f\r\n\n", 
                -(rssi[0]*1.0/1000.0),
                -(rssi[1]*1.0/1000.0),
                -(rssi[2]*1.0/1000.0),
                -(rssi[3]*1.0/1000.0),
                -(rssi[4]*1.0/1000.0),
                -(rssi[5]*1.0/1000.0),
                -(rssi[6]*1.0/1000.0),
                -(rssi[7]*1.0/1000.0));
        sleep(3);
        rssi[0] = 0; rssi[1] = 0; rssi[2] = 0; rssi[3] = 0;
        rssi[4] = 0; rssi[5] = 0; rssi[6] = 0; rssi[7] = 0;
    }

    UCP_API_GPIO_Off();
}

uint32_t adrv9026_getLockStatus (void)
{
	uint32_t mcsStatus = 0x00, pllLockStatus = 0x00;
	
	adi_adrv9025_MultichipSyncStatusGet(adrv9025Device, &mcsStatus);
	printf("MCS Status 0x%X\n", mcsStatus);
	
	adi_adrv9025_PllStatusGet(adrv9025Device, &pllLockStatus);
    printf("pllLockStatus = %X\n", pllLockStatus);
	
	return pllLockStatus; 
}

int16_t adrv9026_getTemperature (void)
{
	int16_t temperatureDegC;
	
	adi_adrv9025_TemperatureGet(adrv9025Device, &temperatureDegC);
	printf("Temperature: %d\n", temperatureDegC);
	
	return temperatureDegC;
}
#if 0
void adi_cofigPrbs_send(uint8_t prbsIndex)
{
    adi_adrv9025_FrmTestDataCfg_t testCfg;
    testCfg.injectPoint = ADI_ADRV9025_FTD_FRAMERINPUT; // ADI_ADRV9025_FTD_SERIALIZER; // ADI_ADRV9025_FTD_POST_LANEMAP; // ;
    testCfg.framerSelMask = ADI_ADRV9025_FRAMER_0;
    if (0 == prbsIndex)
    {
        testCfg.testDataSource = ADI_ADRV9025_FTD_PRBS31;
        printf("adiSend_PRBS31\n");
    }
    else
    {
        testCfg.testDataSource = ADI_ADRV9025_FTD_PRBS7;
        printf("adiSend_PRBS7\n");
    }
    adi_adrv9025_FramerTestDataSet(adrv9025Device, &testCfg);

    adrv9025_DeserializerLaneEnable(adrv9025Device, 0xF, 1);
}

void adi_cofigPrbsCheck(uint8_t prbsIndex)
{
    adi_adrv9025_DfrmPrbsCfg_t testCfg;

    if (0 == prbsIndex)
    {
        testCfg.polyOrder = ADI_ADRV9025_PRBS31;
        printf("adiCheck_PRBS31\n");
    }
    else
    {
        testCfg.polyOrder = ADI_ADRV9025_FTD_PRBS7;
        printf("adiCheck_PRBS7\n");
    }
    testCfg.deframerSel = ADI_ADRV9025_DEFRAMER_0;
    testCfg.checkerLocation = ADI_ADRV9025_PRBSCHECK_SAMPLEDATA; // ADI_ADRV9025_PRBSCHECK_LANEDATA; // 
    adi_adrv9025_DfrmPrbsCheckerStateSet(adrv9025Device, &testCfg);
}

void adi_resetPrbsCheckCount (void)
{
    adi_adrv9025_DfrmPrbsCountReset(adrv9025Device);
}

uint32_t adi_prbsCheckCount(void)
{
    adi_adrv9025_DfrmPrbsErrCounters_t count;

     adi_adrv9025_DfrmPrbsErrCountGet(adrv9025Device, &count);

     printf("adiPrbs: %d %d %d %d. s %X status %X %X %X %X\n", 
            count.laneErrors[0], count.laneErrors[1], count.laneErrors[2], count.laneErrors[3],
            count.sampleSource,
            count.errorStatus[0],count.errorStatus[1],count.errorStatus[2],count.errorStatus[3]);
}

void ucp_testCsuTx (void)
{
    ucp_csu_config_test();

    rf_txSwitch();

    while (1)
    {
        js_csu_ioctrl_tx();
    }
}

void ucp_testCsuRx (void)
{
    int getData;
    uint16_t rssi[8] = {0}, rfSwitch = 0;

    ucp_csu_config_test();

    adi_adrv9025_RxAgcMode_t gainMode[2];
    printf("start cus data sample\n");

    gainMode[0].agcMode = ADI_ADRV9025_MGC;
    gainMode[0].rxChannelMask = 0xFF;
    gainMode[1].agcMode = ADI_ADRV9025_MGC;
    gainMode[1].rxChannelMask = 0xFF;
    gainMode[2].agcMode = ADI_ADRV9025_MGC;
    gainMode[2].rxChannelMask = 0xFF;
    rf_rxSwitch();
    adi_adrv9025_RxGainCtrlModeSet(adrv9025Device, gainMode, 3);
    
    while (1)
    {
        getData = getchar();
        
        if (('s' == getData) || ('S' == getData))
        {
            js_csu_ioctrl_rx();
            printf("sample one block!\n");
        }

        if (('b' == getData) || ('B' == getData))
        {
            js_csu_ioctrl_rx();
            printf("sample over!\n");
            break;
        }

        getData = 0;
    }
}

enum {
    PRBS_UCP2TRX,
    PRBS_TRX2UCP,
    PRBS_UCP2TRX_ERR,
    PRBS_TRX2UCP_ERR,
    PRBS_NEAREND_LOOPBACK,
    PRBS_FAREND_LOOPBACK,
    PRBS_NEAREND_LOOPBACK_ERR,
    PRBS_FAREND_LOOPBACK_ERR
};

void adi_prbsTest (uint8_t testcase)
{
    adi_adrv9025_FramerStatus_t frameLinkStatus;
    adi_adrv9025_DeframerStatus_t deframeLinkStatus;

    if ((PRBS_UCP2TRX == testcase) || (PRBS_NEAREND_LOOPBACK == testcase))
    {
        ucp_cofigPrbsSend(0);
    }
    
    if ((PRBS_UCP2TRX_ERR == testcase) || (PRBS_NEAREND_LOOPBACK_ERR == testcase))
    {
        ucp_cofigPrbsSend(1);
    }

    if ((PRBS_TRX2UCP == testcase) || (PRBS_FAREND_LOOPBACK == testcase))
    {
        adi_cofigPrbs_send(0);
    }
    
    if ((PRBS_TRX2UCP_ERR == testcase) || (PRBS_FAREND_LOOPBACK_ERR == testcase))
    {
        adi_cofigPrbs_send(1);
    }

    if ((PRBS_UCP2TRX == testcase) \
       || (PRBS_FAREND_LOOPBACK == testcase) \
       || (PRBS_UCP2TRX_ERR == testcase) \
       || (PRBS_FAREND_LOOPBACK_ERR == testcase))
    {
        adi_cofigPrbsCheck(0);
        adi_resetPrbsCheckCount();
    }

    if ((PRBS_TRX2UCP == testcase) \
       || (PRBS_NEAREND_LOOPBACK == testcase) \
       || (PRBS_TRX2UCP_ERR == testcase) \
       || (PRBS_NEAREND_LOOPBACK_ERR == testcase))
    {
        ucp_cofigPrbsCheck(0);
    }


    if ((PRBS_NEAREND_LOOPBACK == testcase) 
     || (PRBS_NEAREND_LOOPBACK_ERR == testcase))
    {
        ucp_cofigPrbsNearEndLoopBack();
    }

    if ((PRBS_FAREND_LOOPBACK == testcase) 
     || (PRBS_FAREND_LOOPBACK_ERR == testcase))
    {
        ucp_cofigPrbsFarEndLoopBack();
    }
    
    while (1) {
        if ((PRBS_UCP2TRX == testcase) \
         || (PRBS_FAREND_LOOPBACK == testcase) \
         || (PRBS_UCP2TRX_ERR == testcase) \
         || (PRBS_FAREND_LOOPBACK_ERR == testcase))
       {
            adi_prbsCheckCount();
            adi_resetPrbsCheckCount();
       }

        if ((PRBS_TRX2UCP == testcase) \
        || (PRBS_NEAREND_LOOPBACK == testcase) \
        || (PRBS_TRX2UCP_ERR == testcase) \
        || (PRBS_NEAREND_LOOPBACK_ERR == testcase))
       {
            ucp_prbsCheckCount();
       }
       
       sleep(1);
    }
}
#endif

void adrv9025_setup_platform(void *adiInit, void *adiPostMcsStru)
{
	int32_t error = ADI_COMMON_HAL_OK;
	adi_hal_Cfg_t* devCfg = NULL;

	/* Board Level */
    adrv9025Device = (adi_adrv9025_Device_t*)&gAdrv9025Device;
    adrv9025Init = (adi_adrv9025_Init_t*)adiInit;    
    adrv9025PostMcsInit = (adi_adrv9025_PostMcsInit_t *)adiPostMcsStru;
	pinModeSettings     = (adi_adrv9025_PinModeSettings_t *)&pinModeSettingsLoad;

	/* create hal layer for this motherboard daya: SPI_CHIP_SELECT_1 for adrv9025*/
	adrv9025Device->common.devHalInfo = NULL;
	adrv9025Device->common.devHalInfo = hal_DevHalCfgCreate((ADI_HAL_INTERFACE_SPI | \
                    	                                      ADI_HAL_INTERFACE_LOG | \
                    	                                      ADI_HAL_INTERFACE_HWRESET | \
                    	                                      ADI_HAL_INTERFACE_TIMER),
                    	                                      SPI_CHIP_SELECT_0, "adrv9025.txt"); 
	if (adrv9025Device->common.devHalInfo == NULL)
	{
		printf("ERROR: %s:%u has failed.\n",
			   __func__,
			   __LINE__);
		return;
	}

    adrv9025Device->common.error.logEnable = ADI_ENABLE;
    devCfg = (adi_hal_Cfg_t*)adrv9025Device->common.devHalInfo;
    strcpy(devCfg->typeName, "adrv9025Dev");
    
	error = adi_hal_PlatformSetup(adrv9025Device->common.devHalInfo,
								  (adi_hal_Platforms_e)ADI_UCP2_PLATFORM);
	if (error != ADI_HAL_OK)
	{
		printf("ERROR: %s:%u has failed.\n",
			   __func__,
			   __LINE__);
		return;
	}
	
	adi_adrv9025_SpiSettings_t spiSettings = {
        .msbFirst = 1,
        .enSpiStreaming = 0,
        .autoIncAddrUp = 1,
        .fourWireMode = 1,
        .cmosPadDrvStrength = ADI_ADRV9025_CMOSPAD_DRV_STRONG,
    };

	adi_adrv9025_HwOpen(adrv9025Device, &spiSettings);
	
	printf("adrv9025Device init ok!\n");
	
	return;
}

void adrv9025_remove_platform(void)
{
    adi_adrv9025_HwClose(adrv9025Device);
    
    return;
}

void ad9025_InitInstAdjust(uint64_t txLo, uint64_t rxLo, uint64_t auxLo, uint16_t enOrx)
{
    uint8_t boardType;
    
    boardType = UCP_API_RFIC_GetBoardInfo();

    if (txLo == rxLo)
	{
		adrv9025Init->clocks.rx12LoSelect = ADI_ADRV9025_LOSEL_LO1;
		adrv9025Init->clocks.rx34LoSelect = ADI_ADRV9025_LOSEL_LO1;
		adrv9025Init->clocks.tx12LoSelect = ADI_ADRV9025_LOSEL_LO1;
		adrv9025Init->clocks.tx34LoSelect = ADI_ADRV9025_LOSEL_LO1;
		
		adrv9025PostMcsInit->radioCtrlInit.lo1PllFreq_Hz = rxLo;
		adrv9025PostMcsInit->radioCtrlInit.lo2PllFreq_Hz = 0u;
	}
	else
	{
		adrv9025Init->clocks.rx12LoSelect = ADI_ADRV9025_LOSEL_LO1;
		adrv9025Init->clocks.rx34LoSelect = ADI_ADRV9025_LOSEL_LO1;
		adrv9025Init->clocks.tx12LoSelect = ADI_ADRV9025_LOSEL_LO2;
		adrv9025Init->clocks.tx34LoSelect = ADI_ADRV9025_LOSEL_LO2;
		
		adrv9025PostMcsInit->radioCtrlInit.lo1PllFreq_Hz = rxLo;
		adrv9025PostMcsInit->radioCtrlInit.lo2PllFreq_Hz = txLo;
	}
    
    switch (enOrx)
    {
        case CFG_TLO_ORX:
        adrv9025Init->clocks.orx12LoSelect = ADI_ADRV9025_ORXLOSEL_TXLO;
		adrv9025Init->clocks.orx34LoSelect = ADI_ADRV9025_ORXLOSEL_TXLO;
        break;
        
        case CFG_ALO_ORX:
        adrv9025Init->clocks.orx12LoSelect = ADI_ADRV9025_ORXLOSEL_AUXLO;
		adrv9025Init->clocks.orx34LoSelect = ADI_ADRV9025_ORXLOSEL_AUXLO;
        
        adrv9025PostMcsInit->radioCtrlInit.auxPllFreq_Hz = auxLo;
        break;
        
        case CFG_RLO_ORX:
        printf("adrv9025 can't support CFG_RLO_ORX mode\n");
        break;
        
        default:
        break;    
    }        
    
	if (HW_EVMY == boardType)
	{
        adrv9025Init->dataInterface.framer[0].syncbInSelect = 1;
        adrv9025Init->dataInterface.framer[1].syncbInSelect = 0;
    }
    
    if (HW_EVB == boardType)
	{
        adrv9025PostMcsInit->radioCtrlInit.radioCtrlModeCfg.txRadioCtrlModeCfg.txEnableMode = ADI_ADRV9025_TX_EN_SPI_MODE;
        adrv9025PostMcsInit->radioCtrlInit.radioCtrlModeCfg.rxRadioCtrlModeCfg.rxEnableMode = ADI_ADRV9025_RX_EN_SPI_MODE;
    }
    
    if ((HW_EVMT == boardType) || (HW_EVMF == boardType) || (HW_EVMY == boardType))
    {
        adrv9025Init->tx.txChannelCfg[0].dacFullScale = 1;
        adrv9025Init->tx.txChannelCfg[0].txAttenCtrl.dacFullScale = 1;
        adrv9025Init->tx.txChannelCfg[0].txAttenCtrl.txAttenInit_mdB = 10000;

        adrv9025Init->tx.txChannelCfg[1].dacFullScale = 1;
        adrv9025Init->tx.txChannelCfg[1].txAttenCtrl.dacFullScale = 1;
        adrv9025Init->tx.txChannelCfg[1].txAttenCtrl.txAttenInit_mdB = 10000;

        adrv9025Init->tx.txChannelCfg[2].dacFullScale = 1;
        adrv9025Init->tx.txChannelCfg[2].txAttenCtrl.dacFullScale = 1;
        adrv9025Init->tx.txChannelCfg[2].txAttenCtrl.txAttenInit_mdB = 10000;

        adrv9025Init->tx.txChannelCfg[3].dacFullScale = 1;
        adrv9025Init->tx.txChannelCfg[3].txAttenCtrl.dacFullScale = 1;
        adrv9025Init->tx.txChannelCfg[3].txAttenCtrl.txAttenInit_mdB = 10000;
    }
}

void ucp_api_adrv9025_Reset(void)
{
    ucp_jesd_gpioSet(GPIO_INDEX_9025RESET, 0);
    sleep(1);
    ucp_jesd_gpioSet(GPIO_INDEX_9025RESET, 1);

    memset(&gAdrv9025Device, 0, sizeof(adi_adrv9025_Device_t));
 
    return;
}

/****
The initialization process

The following steps are the pre-multichip synchronization (MCS) initialization sequence:
1. adi_adrv9025_Initialize
    a. Set SPI controller settings
    b. Set master bias
    c. Enable pin pads
    d. Set device clock hsdig divider
    e. Load PFIRs per channel
    f. Load gain tables
    g. Load transmitter attenuation tables
    h. Load stream binary
    i. Load ARM binary
    j. Write initialization structure/receiver/transmitter profile info into ARM memory
    k. ARM run = 1
    l. Wait for ARM boot to complete
    m. Verify ARM checksum
2. ARM configuration
    a. Receiver/transmitter channel configuration (all half-band filter enables, clock dividers)
    b. Clock PLL and SERDES PLL configuration
    c. JESD204B and JESD204C configuration
    d. ARM switches to clock PLL output after PLL locked
The following steps are the post MCS initialization sequence:
1. MCS:
    a. Set ARM run = 0
    b. Enable MCS state machine to listen for new SYSREF pulses
    c. Customer sends SYSREF pulses
    d. When MCS state machine complete, ARM run = 1
2. Run ARM init calibrations
3. Enable tracking cals
    a. Enable radio control pin mode or not
    b. Setup any GPIO for ARM/streams
The system is now ready
****/
int32_t adrv9025_init(uint64_t txLo, uint64_t rxLo, uint16_t initAtt, uint16_t initGain, 
                        uint64_t auxLo, uint16_t enOrx,
                        ucp_rfic_calPara_t calPara)
{
	uint8_t data = 0, boardType;	
    int32_t  recoveryAction = ADI_COMMON_ACT_ERR_RESET_FULL;
	
	adi_adrv9025_RxAgcMode_t gainMode[3];
	adi_adrv9025_RxGain_t gain[3];
	uint8_t                 errFlags         = 0;
	adi_adrv9025_InitCals_t serdesCal        = {0};

	boardType = UCP_API_RFIC_GetBoardInfo();
	gRficCalPara = calPara;
	
	adi_adrv9025_HwReset(adrv9025Device);
	UCP_API_GPIO_Off();
    UCP_API_GPIO_OrxOff();
	
	// step 1 >>> set platform
    // step 2 >>> load config
    /* Clear the common errors */
    if (loadConfigFileEnable)
    {
        if ((recoveryAction = adi_adrv9025_ConfigFileLoad(adrv9025Device, adiProfileFilePath, adrv9025Init)) != ADI_COMMON_ACT_NO_ACTION)
        {
            printf("Error loading the requested profile to ADRV9025 init");
            printf("ERROR: Error number %d, Recovery action %d. In file %s, in function %s, in line %d, variable name %s. Error message %s.\n",
                   adrv9025Device->common.error.errCode,
                   adrv9025Device->common.error.newAction,
                   adrv9025Device->common.error.errFile,
                   adrv9025Device->common.error.errFunc,
                   adrv9025Device->common.error.errLine,
                   adrv9025Device->common.error.varName,
                   adrv9025Device->common.error.errormessage);
            /* Call action handler */
            return ADI_COMMON_ACT_ERR_RESET_FULL;
        }
    }
    else
    {
        /* ADRV9025 settings are used from initdata.c 
         * they are already loaded in deviceInitInst.
         * Verify that the structure was generated for the same API */

        adi_adrv9025_ApiVersion_t apiVersion;
        recoveryAction = adi_adrv9025_ApiVersionGet(adrv9025Device, &apiVersion);
        if (recoveryAction != ADI_COMMON_ACT_NO_ACTION)
        {
            printf("ERROR: adi_adrv9025_ApiVersionGet has failed.\n");
            return ADI_COMMON_ACT_ERR_RESET_FULL;
        }

        if (initStructApiVersion.majorVer != apiVersion.majorVer || initStructApiVersion.minorVer != apiVersion.minorVer || initStructApiVersion.maintenanceVer != apiVersion.maintenanceVer || initStructApiVersion.buildVer != apiVersion.buildVer)
        {
            printf("ERROR: Device initialization structure in \"initdata.c\" was generated for API version %d.%d.%d.%d, but the detected version on the device is %d.%d.%d.%d.\n\n",
                initStructApiVersion.majorVer, initStructApiVersion.minorVer, initStructApiVersion.maintenanceVer, initStructApiVersion.buildVer,
                apiVersion.majorVer, apiVersion.minorVer, apiVersion.maintenanceVer, apiVersion.buildVer);
            return ADI_COMMON_ACT_ERR_RESET_FULL;
        }
    }
    ad9025_InitInstAdjust(txLo, rxLo, auxLo, enOrx);
    
    // step 3 >>> Pre-MCS
    /*********************************************************************************************/
    /**************** Pre-MCS V2 init sequence ***************************************************/
    /*********************************************************************************************/
    strcpy(rxGainTableFileArr[0].rxGainTableCsvFileName, (char*)platformFiles.rxGainTableFileArr);
    rxGainTableFileArr[0].rxChannelMask = rxChannelMask;

    strcpy(txAttenTableFileArr[0].txAttenTableCsvFileName, (char*)platformFiles.txAttenTableFileArr);
    txAttenTableFileArr[0].txChannelMask = adrv9025PostMcsInit->radioCtrlInit.radioCtrlModeCfg.txRadioCtrlModeCfg.txChannelMask;

    /* Execute API */
    recoveryAct = adi_adrv9025_PreMcsInit_v2(adrv9025Device,
                                            adrv9025Init,
                                            (const char*)platformFiles.armImageFile,
                                            (const char*)platformFiles.streamImageFile,
                                            rxGainTableFileArr,
                                            rxGainTableSize,
                                            txAttenTableFileArr,
                                            txAttenTableSize);
    if (recoveryAct != ADI_COMMON_ACT_NO_ACTION)
    {
        printf("ERROR: : %s:%u has failed.\n", __func__, __LINE__);
        return recoveryAct;
    }
    /**************** END: Pre-MCS init sequence *************************************************/
    // step 4 >>> non-broadcastable MCS
    /*********************************************************************************************/
    /**************** Pre-MCS non-broadcastable init sequence ************************************/
    /*********************************************************************************************/
    /* Call PreMcsInit_NonBroadCast and Set the state to ARM Loaded */
    if (loadConfigFileEnable) 
    {
        configFileLoad(adrv9025Device, adrv9025Init);
    }
    ad9025_InitInstAdjust(txLo, rxLo, auxLo, enOrx);
    
    recoveryAct = adi_adrv9025_PreMcsInit_NonBroadCast(adrv9025Device, adrv9025Init);
    if (recoveryAct != ADI_COMMON_ACT_NO_ACTION)
    {
        printf("ERROR: : %s:%u has failed.\n", __func__, __LINE__);
        return recoveryAct;
    }

    /**************** END: Pre-MCS non-broadcastable init sequence *******************************/
    /**************** END: Programming Sequence Phase 1 ******************************************/

    
    /*********************************************************************************************/
    /**************** Programming Sequence Phase 2 ***********************************************/
    /*********************************************************************************************/
    /* MCS start sequence */

    /*********************************************************************************************/
    /**************** Setup the transceiver to listen for incoming SYSREF ************************/
    /**************** pulses to synchronize the internal clock tree ******************************/
    /*********************************************************************************************/
    recoveryAct = adi_adrv9025_MultichipSyncSet(adrv9025Device, multichipSyncEnable);
    if (recoveryAct != ADI_COMMON_ACT_NO_ACTION)
    {
        printf("ERROR: : %s:%u has failed.\n", __func__, __LINE__);
        return recoveryAct;
    }
    /**************** END: Transceiver Setup *****************************************************/

    /*********************************************************************************************/
    /**************** Send SPI messages to request a SYSREF pulse ********************************/
    /*********************************************************************************************/

    /* Loop over SysrefRequest 255 times, unless MCS status is achived before the loop completes */
    for (iterator = 0; iterator < magicNumTwoFiveFive; iterator++)
    {
        ucp_api_ad9528_OnePluse(enableSync);
        
        /*********************************************************************************************/
        /**************** Reads back the multi-chip sync status **************************************/
        /*********************************************************************************************/
        /*
        mcsStatus 
        bit Description --------— 
        
        [0]  MCS JESD SYSREF Status (1 = sync occurred)  
        [1]  MCS Digital Clocks Sync Status (1 = sync occurred)  
        [2]  MCS Clock Gen Sync Status (1 = sync occurred)  
        [3]  MCS CLKPLL SDM Sync Status (1 = sync occurred)  
        [4]  MCS Device Clock divider Sync Status (1 = sync occurred)  
        */
        recoveryAct = adi_adrv9025_MultichipSyncStatusGet(adrv9025Device, &mcsStatus);
        if (recoveryAct != ADI_COMMON_ACT_NO_ACTION)
        {
            printf("ERROR: : %s:%u has failed.\n", __func__, __LINE__);
            return recoveryAct;
        }

        if ((mcsStatus & mcsStatusAnd) == mcsStatusAnd)
        {
            break;
        }
    }

    /* Confirm mcsStatus is correct value after iteration */
    if ((mcsStatus & mcsStatusAnd) != mcsStatusAnd)
    {
        printf("ERROR: : %s:%u has failed mcsStatus = %X\n.\n", __func__, __LINE__, mcsStatus);
        return failureReturn;
    } 
    else
    {
        printf("SUCESS: MCS Status 0x%X\n", mcsStatus);
    }

    /**************** END: Reads back the multi-chip sync status *********************************/
    /**************** END: Send SPI messages to request a SYSREF pulse ***************************/
    
    /*********************************************************************************************/
    /**************** Disable the transceiver to listen for incoming SYSREF **********************/
    /**************** pulses to synchronize the internal clock tree ******************************/
    /*********************************************************************************************/
    recoveryAct = adi_adrv9025_MultichipSyncSet(adrv9025Device, multichipSyncDisable);
    if (recoveryAct != ADI_COMMON_ACT_NO_ACTION)
    {
        printf("ERROR: : %s:%u has failed.\n", __func__, __LINE__);
        return recoveryAct;
    }
    /**************** END: Disable the transceiver ***********************************************/

    /*********************************************************************************************/
    /**************** Post MCS Sequence **********************************************************/
    /*********************************************************************************************/
    recoveryAct = adi_adrv9025_PostMcsInit(adrv9025Device, adrv9025PostMcsInit);
    if (recoveryAct != ADI_COMMON_ACT_NO_ACTION)
    {
        printf("ERROR: : %s:%u has failed.\n", __func__, __LINE__);
        return recoveryAct;
    }

    // add by daya debug
	recoveryAct = adi_adrv9025_PostMcsInit(adrv9025Device, adrv9025PostMcsInit);
    if (recoveryAct != ADI_COMMON_ACT_NO_ACTION)
    {
        printf("ERROR: : %s:%u has failed.\n", __func__, __LINE__);
        return recoveryAct;
    }

    /**************** END: Post MCS Sequence *****************************************************/

    /*********************************************************************************************/
    /**************** Reset the serializer *******************************************************/
    /*********************************************************************************************/
    recoveryAct = adi_adrv9025_SerializerReset(adrv9025Device, adrv9025Init->clocks.serdesPllVcoFreq_kHz); // pllClkSource);
    if (recoveryAct != ADI_COMMON_ACT_NO_ACTION)
    {
        printf("ERROR: : %s:%u has failed.\n", __func__, __LINE__);
        return recoveryAct;
    }
    /**************** END: Reset the serializer **************************************************/
	
    /*********************************************************************************************/
    /**************** Bring up the JESD204 data link *********************************************/
    /*********************************************************************************************/
    for (iterator = magicNumZero; iterator < magicNumThree; iterator++)
    {
        if (adrv9025Init->dataInterface.framer[iterator].serializerLanesEnabled > magicNumZero)
        {
            rxLinkSelect |= magicNumOne << iterator;
        }
    }

    for (iterator = magicNumZero; iterator < magicNumTwo; iterator++)
    {
        if (adrv9025Init->dataInterface.deframer[iterator].deserializerLanesEnabled > magicNumZero)
        {
            txLinkSelect |= magicNumOne << iterator;
        }
    }

    printf("txLink = %X, rxLink = %X\n", txLinkSelect, rxLinkSelect);

    /* JESD204 link bring up */
    recoveryAct = adi_board_adrv9025_JesdBringup(adrv9025Device, txLinkSelect, rxLinkSelect);
    if (recoveryAct != ADI_COMMON_ACT_NO_ACTION)
    {
        printf("ERROR: : %s:%u has failed.\n", __func__, __LINE__);
        return recoveryAct;
    }	
    /**************** END: Bring up the JESD204 data link ****************************************/

    /*********************************************************************************************/
    /**************** Clear Jesd Dfrm Irq's ******************************************************/
    /*********************************************************************************************/
    recoveryAct = adi_adrv9025_TxRampDownInit(adrv9025Device, adrv9025Init);
    if (recoveryAct != ADI_COMMON_ACT_NO_ACTION)
    {
        printf("ERROR: : %s:%u has failed.\n", __func__, __LINE__);
        return recoveryAct;
    }

    /**************** END: Clear Jesd Dfrm Irq's *************************************************/

    /*********************************************************************************************/
    /**************** Initialize GP interrupt masks for pin0 & pin1 ******************************/
    /*********************************************************************************************/
    recoveryAct = adi_adrv9025_GpIntInit(adrv9025Device, &adrv9025Init->gpInterrupts);
    if (recoveryAct != ADI_COMMON_ACT_NO_ACTION)
    {
        printf("ERROR: : %s:%u has failed.\n", __func__, __LINE__);
        return recoveryAct;
    }
    /**************** END: Initialize GP interrupt masks for pin0 & pin1 *************************/
    /**************** END: Programming Sequence Phase 2 ******************************************/
    /**************** END: The programming sequence **********************************************/
    printf("LO1: %lu  LO2: %lu  auxLO: %lu\n", 
            adrv9025PostMcsInit->radioCtrlInit.lo1PllFreq_Hz,
            adrv9025PostMcsInit->radioCtrlInit.lo2PllFreq_Hz,
            adrv9025PostMcsInit->radioCtrlInit.auxPllFreq_Hz);
    adi_adrv9025_ProductIdGet(adrv9025Device, &data);
    printf("ADRV9025 ID:  0x%X\n", data);
    printf("\n*** Platform Programmed Successfully *** \n\n");

    programFlag = true;
													 
	adrv9025_StatusMoniter(adrv9025Device, 1);
    
// ext LO cal ------------------------------------------------
    printf("start extLo cal\n");

    // ext cal att
    printf("extCal attSet\n");
    adrv9025_setAtt(0x1, 10000);
    
    gainMode[0].agcMode = ADI_ADRV9025_MGC;
    gainMode[0].rxChannelMask = 0xFF;
    adi_adrv9025_RxGainCtrlModeSet(adrv9025Device, gainMode, 1);

	gain[0].rxChannelMask = 0x10;
	gain[0].gainIndex = 240; //gRficCalPara.calOrxGainIndex;
	adi_adrv9025_RxGainSet(adrv9025Device, gain, 1);
	// HW_EVMT: 240  other: 245
	printf("extCal gainIndex: %d\n", gRficCalPara.calOrxGainIndex);
    
    UCP_API_GPIO_OrxOn();
    UCP_API_GPIO_Tx();

	serdesCal.calMask     = (0x00000800U);
	serdesCal.warmBoot    = 0;
    serdesCal.channelMask = 0x01;
	adrv9025_spiRxTxEnableSet(ADI_ADRV9025_RX1 | ADI_ADRV9025_ORX1, ADI_ADRV9025_TX1);
    adi_adrv9025_InitCalsRun(adrv9025Device, &serdesCal);
	adi_adrv9025_InitCalsWait(adrv9025Device, 60000, &errFlags);

	UCP_API_GPIO_Off();
    
//------------------------------------------------
    printf("Init attSet\n");
	ad9025_Att_Set(initAtt);
	
	gain[0].rxChannelMask = 0x0F;
	gain[0].gainIndex = initGain;
	adi_adrv9025_RxGainSet(adrv9025Device, gain, 1);
	printf("Init gainIndex: %d\n", initGain);

    if (HW_EVMF == boardType)
    {
        UCP_API_GPIO_On();
        printf("LNA & PA On\n");
    }
	
	printf("adrv9025 init over.\n");
    
	return recoveryAct;
								
}






