//******************** (C) COPYRIGHT 2022 SmartLogic*******************************
// FileName           : ucp_api_clockGen.c
// Author             : Boheng Lin bhlin919@126.com
// Date First Issued  : 2023-03-04 02:37:50 PM
// Last Modified      : 
// Description        :
// ------------------------------------------------------------
// Modification History:
// Version    Date       Author    Modification Description
//
//**********************************************************************************

#include <stdint.h>
#include <string.h>
#include "ucp_api_transceiver.h"
#include "ucp_api_jesd.h"
#include "ucp_api_rfic.h"
#include "ucp_jesd_gpio.h"
#include "ucp_rfic_gpio.h"
#include "initdata.h"

#define UCP_TXR_CONFIG_FILE  "/lib/firmware/resources/ucp_trx_gpioCfg.json"
#define NR_BW             (100000000u)
#define MAX_BOARD         5

extern ucp_jesd_Init_t ucpJesdInitInstNr;
extern ucp_jesd_Init_t ucpJesdInitInstNr_bandwidth200M;
extern ucp_jesd_Init_t ucpJesdInitInstNrFdd2Ant;
extern ucp_jesd_Init_t ucpJesdInitInstLte2Ant;
extern ucp_jesd_Init_t ucpJesdInitInstLte4Ant;
extern ucp_jesd_Init_t ucpJesdInitInstNr_orx;
extern ucp_jesd_Init_t ucpJesdInitInstNr204C;
extern ucp_jesd_Init_t ucpJesdInitInstNrBw200MFdd1Ant;

typedef struct tRficConfigList {
    char *item;
    uint64_t sampleRate;
    uint64_t bw;
    uint16_t antNumb;
    uint16_t enFdd;
    uint16_t enOrx;
    uint16_t en204C;
    void *ucpInitStru;
    void *adiInitStru;
    void *adiPostMcsStru;
} tRficConfigList_t;

const char *boardTypeString[MAX_BOARD] = 
{
    "Unknow\0",
    "EVMT\0",
    "EVMF\0",
    "EVB\0",
    "EVMY\0"
};

tRficConfigList_t gRficConfigList[] = {
    {"122.88M/100M/4ANT/TDD/NORX/204B", CFG_SAMPLERATE_122_88MHZ, CFG_BW_100MHZ, CFG_4ANT, CFG_TDD, CFG_NORX, CFG_204B,    (void*)&ucpJesdInitInstNr,               (void*)&deviceInitInst_122_88M_4_9152G,         (void*)&devicePostMcsInitInst_122_88M_4_9152G},
    {"122.88M/100M/4ANT/TDD/TORX/204B", CFG_SAMPLERATE_122_88MHZ, CFG_BW_100MHZ, CFG_4ANT, CFG_TDD, CFG_TLO_ORX, CFG_204B, (void*)&ucpJesdInitInstNr_orx,           (void*)&deviceInitInst_122_88M_9_8304G_ORX,     (void*)&devicePostMcsInitInst_122_88M_9_8304G_ORX},
    {"122.88M/100M/4ANT/TDD/AORX/204B", CFG_SAMPLERATE_122_88MHZ, CFG_BW_100MHZ, CFG_4ANT, CFG_TDD, CFG_ALO_ORX, CFG_204B, (void*)&ucpJesdInitInstNr_orx,           (void*)&deviceInitInst_122_88M_9_8304G_ORX,     (void*)&devicePostMcsInitInst_122_88M_9_8304G_ORX},
    {"245.76M/200M/4ANT/TDD/NORX/204B", CFG_SAMPLERATE_245_76MHZ, CFG_BW_200MHZ, CFG_4ANT, CFG_TDD, CFG_NORX,  CFG_204B,   (void*)&ucpJesdInitInstNr_bandwidth200M, (void*)&deviceInitInst_245_76M_9_8304G,         (void*)&devicePostMcsInitInst_245_76M_9_8304G},
    {"122.88M/100M/2ANT/FDD/NORX/204B", CFG_SAMPLERATE_122_88MHZ, CFG_BW_100MHZ, CFG_2ANT, CFG_FDD, CFG_NORX, CFG_204B,    (void*)&ucpJesdInitInstNrFdd2Ant,        (void*)&deviceInitInst_122_88M_4_9152G_FDD2ANT, (void*)&devicePostMcsInitInst_122_88M_4_9152G_FDD2ANT},
    {"122.88M/100M/4ANT/FDD/NORX/204B", CFG_SAMPLERATE_122_88MHZ, CFG_BW_100MHZ, CFG_4ANT, CFG_FDD, CFG_NORX, CFG_204B,    (void*)&ucpJesdInitInstNr,               (void*)&deviceInitInst_122_88M_4_9152G,         (void*)&devicePostMcsInitInst_122_88M_4_9152G},
    {"61.44M/50M/2ANT/FDD/NORX/204B",   CFG_SAMPLERATE_61_44MHZ,  CFG_BW_50MHZ,  CFG_2ANT, CFG_FDD, CFG_NORX, CFG_204B,    (void*)&ucpJesdInitInstLte2Ant,          (void*)&deviceInitInst_61_44M_4_9152G_FDD2ANT,  (void*)&devicePostMcsInitInst_61_44M_4_9152G_FDD2ANT},
    {"61.44M/50M/4ANT/FDD/NORX/204B",   CFG_SAMPLERATE_61_44MHZ,  CFG_BW_50MHZ,  CFG_4ANT, CFG_FDD, CFG_NORX, CFG_204B,    (void*)&ucpJesdInitInstLte4Ant,          (void*)&deviceInitInst_61_44M_4_9152G_FDD4ANT,  (void*)&devicePostMcsInitInst_61_44M_4_9152G_FDD4ANT},
    {"122.88M/100M/4ANT/TDD/NORX/204C", CFG_SAMPLERATE_122_88MHZ, CFG_BW_100MHZ, CFG_4ANT, CFG_TDD, CFG_NORX, CFG_204C,    (void*)&ucpJesdInitInstNr204C,           (void*)&deviceInitInst_122_88M_8_11008G,        (void*)&devicePostMcsInitInst_122_88M_8_11008G},
    {"122.88M/240M/4ANT/TDD/NORX/204B", CFG_SAMPLERATE_122_88MHZ, CFG_BW_240MHZ, CFG_4ANT, CFG_TDD, CFG_NORX, CFG_204B,    (void*)&ucpJesdInitInstNr_bandwidth200M, (void*)&deviceInitInst_240M,                    (void*)&devicePostMcsInitInst_240M},
    {"245.76M/200M/1ANT/FDD/NORX/204B", CFG_SAMPLERATE_245_76MHZ, CFG_BW_200MHZ, CFG_1ANT, CFG_FDD, CFG_NORX, CFG_204B,    (void*)&ucpJesdInitInstNrBw200MFdd1Ant,  (void*)&deviceInitInst_245_76M_9_8304G_FDD1ANT, (void*)&devicePostMcsInitInst_245_76M_9_8304G_FDD1ANT}
};

static uint8_t gBoardType = HW_UNKNOW;
static uint16_t gConfigIndex = 0;
static uint8_t evmtGpio[][2] = 
{
/* PD11/AP_GPIOB24             "9025reset"   */ {GPIO_PORT0B, 24},
/* PA6/AP_GPIOA6               "9025cs"      */ {GPIO_PORT0A, 6},

/* PD13/AP_GPIOB26             "9528reset"   */ {GPIO_PORT0B, 26},
/* PD6/AP_GPIOB19              "9528cs"      */ {GPIO_PORT0B, 19},
/* PD4/AP_GPIOB17              "sysref"      */ {GPIO_PORT0B, 17},
/* LVDS_RF_D15_P/CP_GPIOB27    "9528status0" */ {GPIO_PORT1B, 27},
/* LVDS_RF_D15_N/CP_GPIOB26    "9528status1" */ {GPIO_PORT1B, 26},

/* LVDS_RF_RXFRM_P/CP_GPIOB01  "orx0ctrl"    */ {GPIO_PORT1B, 1},
/* LVDS_RF_RXFRM_N/CP_GPIOB00  "orx1ctrl"    */ {GPIO_PORT1B, 0},
/* LVDS_RF_TXFRM_N/CP_GPIOB02  "switchcal"   */ {GPIO_PORT1B, 2},
/* LVDS_RF_TXFRM_P/CP_GPIOB03  "lnavpd"      */ {GPIO_PORT1B, 3}
};

static uint8_t evmfGpio[][2] = 
{
/* PB11/AP_GPIOB24             "9026reset"   */ {GPIO_PORT0B, 24},
/* PA6/AP_GPIOA6               "9026cs"      */ {GPIO_PORT0A, 6},

/* LVDS_RF_D03_P/CP_GPIOB11    "9528reset"   */ {GPIO_PORT1B, 11},
/* PD6/AP_GPIOB19              "9528cs"      */ {GPIO_PORT0B, 19},
/* PD4/AP_GPIOB17              "sysref"      */ {GPIO_PORT0B, 17},
/* LVDS_RF_D15_P/CP_GPIOB27    "9528status0" */ {GPIO_PORT1B, 27},
/* LVDS_RF_D15_N/CP_GPIOB26    "9528status1" */ {GPIO_PORT1B, 26}
};

static uint8_t evbGpio[][2] = 
{
/* LVDS_RF_D02_P/CP_GPIOB9     "9026reset"   */ {GPIO_PORT1B, 9},
/* PA6/AP_GPIOA6               "9026cs"      */ {GPIO_PORT0A, 6},

/* LVDS_RF_D03_P/CP_GPIOB11    "9528reset"   */ {GPIO_PORT1B, 11},
/* PD6/AP_GPIOB19              "9528cs"      */ {GPIO_PORT0B, 19},
/* LVDS_RF_D03_N/CP_GPIOB10    "sysref"      */ {GPIO_PORT1B, 10},
/* LVDS_RF_D15_P/CP_GPIOB27    "9528status0" */ {GPIO_PORT1B, 27},
/* LVDS_RF_D15_N/CP_GPIOB26    "9528status1" */ {GPIO_PORT1B, 26}
};

static uint8_t evmyGpio[][2] = 
{
/* PD20/CP_GPIOA1              "9026reset"  */ {GPIO_PORT1A, 1},
/* PA2/AP_GPIOA2               "9026cs"     */ {GPIO_PORT0A, 2},

/* PD4/AP_GPIOB17              "9528reset"  */ {GPIO_PORT0B, 17},
/* PA6/AP_GPIOA6               "9528cs"     */ {GPIO_PORT0A, 6},
/* PD21/CP_GPIOA2              "sysref"     */ {GPIO_PORT1A, 2},
/* LVDS_RF_D15_P/CP_GPIOB27    "9528status0"*/ {GPIO_PORT1B, 27},
/* LVDS_RF_D15_N/CP_GPIOB26    "9528status1"*/ {GPIO_PORT1B, 26},

/* LVDS_RF_RXFRM_P/CP_GPIOB01  "orx0ctrl"   */ {GPIO_PORT1B, 29},
/* LVDS_RF_RXFRM_N/CP_GPIOB00  "orx1ctrl"   */ {GPIO_PORT1B, 30},                            
/* LVDS_RF_D03_P/CP_GPIOB11    "switchcal"  */ {GPIO_PORT1B, 11},
/* LVDS_RF_TXFRM_P/CP_GPIOB03  "lnavpd"     */ {GPIO_PORT1B, 9},

/* PA0/AP_GPIOA0               "spi1sel"    */ {GPIO_PORT0A,  0},
/* PA1/AP_GPIOA1               "spi3sel"    */ {GPIO_PORT0A,  1},
/* PD13/AP_GPIOB26             "pllsel"     */ {GPIO_PORT0B, 26}
};

static void ucp_rfic_SaveBoardInfo (ucp_jesd_TrxGpioCfg_t *trxGpio)
{
    uint8_t i;

    gBoardType = 0;
    for (i = 0; i < MAX_BOARD;i++)
    {
        if (!strncmp(trxGpio->board, (const char*)boardTypeString[i], 16))
        {
            gBoardType = i;
            break;
        }
    }

    printf("BOARD:             %s\n", boardTypeString[gBoardType]);
}

static int32_t ucp_rfic_pickCofigIndex (uint64_t sampleRate, 
          uint64_t bw,
          uint16_t antNumb, 
          uint16_t enFdd,
          uint16_t enOrx,
          uint16_t en204C)
{
    
    uint16_t maxIndex, i;

    maxIndex = sizeof(gRficConfigList)/sizeof(tRficConfigList_t);
    printf("TotalCofig: %d\n", maxIndex);

    for (i = 0;i < maxIndex; i++)
    {
        if ((gRficConfigList[i].sampleRate == sampleRate) \
           && (gRficConfigList[i].bw == bw) \
           && (gRficConfigList[i].antNumb == antNumb) \
           && (gRficConfigList[i].enFdd == enFdd) \
           && (gRficConfigList[i].enOrx == enOrx) \
           && (gRficConfigList[i].en204C == en204C))
           {
               printf("Configture: %s\n", gRficConfigList[i].item);
               gConfigIndex = i;
               return gConfigIndex;
           }
    }

    printf("\nError: Can't find configture: (sampleRate)%.5fM / (bw)%.5fM / (antNumb)%d / (enFdd)%d / (enOrx)%d / (en204C)%d\n\n", \
            sampleRate*1.0/1e6, bw*1.0/1e6, antNumb, enFdd, enOrx, en204C);
    printf("Please change to:\n\n");
    printf("    sampleRate/bw/antNumb/enFdd/enOrx/en204C\n\n");
    for (i = 0;i < maxIndex; i++)
    {
        printf("    %s\n", gRficConfigList[i].item);
    }

    printf("\n");
    
    printf("NOTE:\n\nsampleRate keyValue:\n");
    printf("  CFG_SAMPLERATE_61_44MHZ:  61440000\n");
    printf("  CFG_SAMPLERATE_122_88MHZ: 122880000\n");
    printf("  CFG_SAMPLERATE_245_76MHZ: 245760000\n\n");

    printf("bw keyValue:\n");
    printf("  CFG_BW_20MHZ:   20000000\n");
    printf("  CFG_BW_50MHZ:   50000000\n");
    printf("  CFG_BW_100MHZ:  100000000\n");
    printf("  CFG_BW_200MHZ:  200000000\n");
    printf("  CFG_BW_240MHZ:  240000000\n\n");

    printf("antNumb keyValue:\n");
    printf("  CFG_1ANT:     1\n");
    printf("  CFG_2ANT:     2\n");
    printf("  CFG_3ANT:     3\n");
    printf("  CFG_4ANT:     4\n");
    printf("  CFG_5ANT:     5\n");
    printf("  CFG_6ANT:     6\n");
    printf("  CFG_7ANT:     7\n");
    printf("  CFG_8ANT:     8\n\n");

    printf("enFdd keyValue:\n");
    printf("  CFG_TDD:      0\n");
    printf("  CFG_FDD:      1\n\n");

    printf("enOrx keyValue:\n");
    printf("  CFG_NORX:     0\n");
    printf("  CFG_TLO_ORX:  1\n");
    printf("  CFG_ALO_ORX:  2\n");
    printf("  CFG_RLO_ORX:  3\n\n");    

    printf("en204C keyValue:\n");
    printf("  CFG_204B:     0\n");
    printf("  CFG_204C:     1\n\n");

    printf("enUcpLog keyValue:\n");
    printf("  CFG_NONE_LOG: 0\n");
    printf("  CFG_LOG:      1\n\n");
    
    printf("\n");
    exit(1);
    
    return -1;

}

static void ucp_rfic_GpioInit(void)
{
    uint8_t (*pGpio)[2], boardType;

    boardType = UCP_API_RFIC_GetBoardInfo();
    switch (boardType)
    {
        case HW_EVMT:
            pGpio = evmtGpio;
            break;

        case HW_EVMF:
            pGpio = evmfGpio;
            break;

        case HW_EVMY:
            pGpio = evmyGpio;
            break;

        case HW_EVB:
            pGpio = evbGpio;
            break;
            
        default:
            printf("error, unknow board. @%s, %d\n",  __FILE__, __LINE__);
            exit(1);
            break;
    }

    
    // config adrv9025
    ucp_jesd_gpioConfig(GPIO_INDEX_9025RESET,   GPIO_DIR_OUT, UCP_JESD_TRX_GPIO_VALID_HIGH, UCP_GPIO(pGpio[0][0], pGpio[0][1]));
    ucp_jesd_gpioConfig(GPIO_INDEX_9025CS,      GPIO_DIR_OUT, UCP_JESD_TRX_GPIO_VALID_HIGH, UCP_GPIO(pGpio[1][0], pGpio[1][1])); 
   
    // config ad9528
    ucp_jesd_gpioConfig(GPIO_INDEX_9528RESET,   GPIO_DIR_OUT, UCP_JESD_TRX_GPIO_VALID_HIGH, UCP_GPIO(pGpio[2][0], pGpio[2][1]));
    ucp_jesd_gpioConfig(GPIO_INDEX_9528CS,      GPIO_DIR_OUT, UCP_JESD_TRX_GPIO_VALID_HIGH, UCP_GPIO(pGpio[3][0], pGpio[3][1]));       
    ucp_jesd_gpioConfig(GPIO_INDEX_SYSREF,      GPIO_DIR_OUT, UCP_JESD_TRX_GPIO_VALID_HIGH, UCP_GPIO(pGpio[4][0], pGpio[4][1]));       
    ucp_jesd_gpioConfig(GPIO_INDEX_9528STATUS0, GPIO_DIR_IN,  UCP_JESD_TRX_GPIO_VALID_LOW,  UCP_GPIO(pGpio[5][0], pGpio[5][1]));   
    ucp_jesd_gpioConfig(GPIO_INDEX_9528STATUS1, GPIO_DIR_IN,  UCP_JESD_TRX_GPIO_VALID_LOW,  UCP_GPIO(pGpio[6][0], pGpio[6][1]));

    if ((HW_EVMT == boardType) || (HW_EVMY == boardType))
    {
        ucp_jesd_gpioConfig(GPIO_INDEX_ORX0CTRL, GPIO_DIR_OUT, UCP_JESD_TRX_GPIO_VALID_HIGH,   UCP_GPIO(pGpio[7][0], pGpio[7][1])); 
        ucp_jesd_gpioConfig(GPIO_INDEX_ORX1CTRL, GPIO_DIR_OUT, UCP_JESD_TRX_GPIO_VALID_HIGH,   UCP_GPIO(pGpio[8][0], pGpio[8][1])); 
        ucp_jesd_gpioConfig(GPIO_INDEX_SWCAL,    GPIO_DIR_OUT, UCP_JESD_TRX_GPIO_VALID_LOW,    UCP_GPIO(pGpio[9][0], pGpio[9][1])); 
        ucp_jesd_gpioConfig(GPIO_INDEX_LNAVPD,   GPIO_DIR_OUT, UCP_JESD_TRX_GPIO_VALID_HIGH,   UCP_GPIO(pGpio[10][0], pGpio[10][1])); 
    }
    
    if (HW_EVMY == boardType)
    {
        ucp_jesd_gpioConfig(GPIO_INDEX_SPI1_SEL,  GPIO_DIR_OUT, UCP_JESD_TRX_GPIO_VALID_LOW,   UCP_GPIO(pGpio[11][0], pGpio[11][1]));         
        ucp_jesd_gpioConfig(GPIO_INDEX_SPI3_SEL,  GPIO_DIR_OUT, UCP_JESD_TRX_GPIO_VALID_LOW,   UCP_GPIO(pGpio[12][0], pGpio[12][1]));   
        ucp_jesd_gpioConfig(GPIO_INDEX_PLL_SEL,   GPIO_DIR_OUT, UCP_JESD_TRX_GPIO_VALID_LOW,   UCP_GPIO(pGpio[13][0], pGpio[13][1]));       
    //*----------------------------------------------------------------
        // (boardType == HW_EVMY) // ioremap can't contorl AP_GPIOB26 (GPIO_INDEX_PLL_SEL)
        {
            #include <fcntl.h>
            #include <unistd.h>
            
            static int export_fd, dir_fd, value_fd; 

            export_fd = open("/sys/class/gpio/export", O_WRONLY);
            char export_buf[32] = { 0 };
            int len = sprintf(export_buf, "%d", 474);
            if (export_fd > 0) {
                write(export_fd, export_buf, len);
            }

            dir_fd = open("/sys/class/gpio/gpio474/direction" , O_RDWR);
            value_fd = open("/sys/class/gpio/gpio474/value", O_RDWR);

            write(dir_fd , "/sys/class/gpio/gpio474/direction", 4);
            write(value_fd , "0", 1);

            close(export_fd);
            close(dir_fd);
            close(value_fd);
        }
    }
    //----------------------------------------------------------------*/  
}

int32_t UCP_API_RFIC_CellInit(uint64_t sampleRate, 
                                 uint64_t bw,
                                 uint16_t antNumb,
                                 uint16_t enFdd,
                                 uint16_t enOrx,
                                 uint16_t en204C,
                                 uint16_t enUcpLog)
{
	ucp_jesd_TrxGpioCfg_t *pTrxGpio;

	UCP_API_JESD_ApeWorkStep(UCP_JESD_APE_POWERONRESET);
	UCP_API_JESD_Version();
	UCP_API_JESD_TrxGpioSetup((const char *)UCP_TXR_CONFIG_FILE, enUcpLog);

	pTrxGpio = UCP_API_JESD_TrxGpioGet();
	ucp_rfic_SaveBoardInfo(pTrxGpio);
	ucp_rfic_GpioInit();
 	ucp_rfic_pickCofigIndex(sampleRate, bw, antNumb, enFdd, enOrx, en204C);

	UCP_API_CLOCKGEN_Init();
    UCP_API_JESD_Init((ucp_jesd_Init_t*)gRficConfigList[gConfigIndex].ucpInitStru);
	UCP_API_JESD_ApeWorkStep(UCP_JESD_APE_CLOCKGENRUN);
	
	return 0;
}

int32_t UCP_API_RFIC_CellSetup(uint64_t txLo, uint64_t rxLo, uint16_t initAtt, 
                                   uint16_t initGain, uint64_t auxLo, uint16_t enOrx, 
                                   ucp_rfic_calPara_t calPara)
{
    UCP_API_TRANSCEIVER_Init((void*)gRficConfigList[gConfigIndex].adiInitStru, 
                               (void*)gRficConfigList[gConfigIndex].adiPostMcsStru, 
                               txLo, rxLo, initAtt, initGain, auxLo, enOrx, calPara);
    UCP_API_JESD_ApeWorkStep(UCP_JESD_APE_CELLRUN);

    return 0;
}

int32_t UCP_API_RFIC_CellDelete(void)
{
    UCP_API_JESD_ApeWorkStep(UCP_JESD_APE_POWERONRESET);
    UCP_API_JESD_CellDelete();
    UCP_API_CLOCKGEN_Reset();
    UCP_API_TRANSCEIVER_Reset();
    
	return 0;
}

uint8_t UCP_API_RFIC_GetBoardInfo (void)
{
    return gBoardType;
}

