//******************** (C) COPYRIGHT 2022 SmartLogic*******************************
// FileName           : ucp_jesd_core.c
// Author             : Boheng Lin bhlin919@126.com
// Date First Issued  : 2022-09-08 02:37:50 PM
// Last Modified      : 
// Description        :
// ------------------------------------------------------------
// Modification History:
// Version    Date       Author    Modification Description
//
//**********************************************************************************

// 1.js_ctrl(lvds & js_subctrl) -> 2.js_crg -> 3.jesd_subctrl -> 
// 4.phyPcsPma -> 5.jesd204B/C -> 
// 6.jesd_timer(cp) -> 7.jesd_csu(cp) -> 
// 8.pinmux & gpio

#include "ucp_param.h"
#include "csu.h"
#include <math.h>
#include <string.h>
#include <stdio.h>
#include <stdint.h>
#include <unistd.h>
#include <float.h>
#include "jesd204.h"
#include "ucp_pma.h"
#include "ucp_js_subcrg.h"
#include "ucp_js_ctrl.h"
#include "ucp_reg_io.h"
#include "ucp_api_jesd.h"
#include "ucp_jsonTools.h"
#include "ucp_hardware.h"

#define JS_204B_RX0_CODING_T     0 
#define JS_204B_RX0_SUBCLASS     1 
#define JS_204B_RX0_CF           0 
#define JS_204B_RX0_CS           0 
#define JS_204B_RX0_F            8 
#define JS_204B_RX0_K            32
#define JS_204B_RX0_L            1 
#define JS_204B_RX0_N            16
#define JS_204B_RX0_M            4 
#define JS_204B_RX0_NTOTAL       16
#define JS_204B_RX0_S            1 
#define JS_204B_RX0_SONI         1
#define JS_204B_RX0_HD           0 
#define JS_204B_RX0_SCR          1 
#define JS_204B_RX0_E            1 
#define JS_204B_RX0_FEC          0
#define JS_204B_RX0_CRC3         0
#define JS_204B_RX0_CRC12        0

#define JS_204B_RX1_CODING_T     0 
#define JS_204B_RX1_SUBCLASS     1 
#define JS_204B_RX1_CF           0 
#define JS_204B_RX1_CS           0 
#define JS_204B_RX1_F            8 
#define JS_204B_RX1_K            32
#define JS_204B_RX1_L            1 
#define JS_204B_RX1_N            16
#define JS_204B_RX1_M            4 
#define JS_204B_RX1_NTOTAL       16
#define JS_204B_RX1_S            1 
#define JS_204B_RX1_SONI         1
#define JS_204B_RX1_HD           0 
#define JS_204B_RX1_SCR          1 
#define JS_204B_RX1_E            1 
#define JS_204B_RX1_FEC          0
#define JS_204B_RX1_CRC3         0
#define JS_204B_RX1_CRC12        0

#define JS_204B_TX_CODING_T      0 
#define JS_204B_TX_SUBCLASS      1 
#define JS_204B_TX_CF            0 
#define JS_204B_TX_CS            0 
#define JS_204B_TX_F             8 
#define JS_204B_TX_K             32
#define JS_204B_TX_L             1 
#define JS_204B_TX_N             16
#define JS_204B_TX_M             4 
#define JS_204B_TX_NTOTAL        16
#define JS_204B_TX_S             1 
#define JS_204B_TX_SONI          1
#define JS_204B_TX_HD            0 
#define JS_204B_TX_SCR           1 
#define JS_204B_TX_E             1 
#define JS_204B_TX_FEC           0
#define JS_204B_TX_CRC3          0
#define JS_204B_TX_CRC12         0

#define UCP_OPT_SKIP             0
#define UCP_OPT_W                1
#define UCP_OPT_ANDW             2
#define UCP_OPT_ORW              3

typedef struct tUcpAutoConfigPara {
    uint32_t addr;
    uint32_t value;
    uint32_t opt;
    uint32_t step;
} tUcpAutoConfigPara_t;

enum {
    SAMPLE_FACTOR_1_1 = 0,
    SAMPLE_FACTOR_1_2
};

#define  UCP_PLL_FACT   2  // range: 2/4/8
#define  GetL(byte)  (((BIT3 & byte) >> 3) + ((BIT2 & byte) >> 2) + ((BIT1 & byte) >> 1) + (BIT0 & byte))
#define  PrintUcpReg(reg)  {printf("register: "); printf("(0x%08X, 0x%08X) // ", reg, ucp_reg32_read(reg)); printf(#reg); printf("\n");}

static uint64_t frameLaneRate, deframe0LaneRate, deframe1LaneRate;
static uint32_t pllFactor, sampleFactor[4];
static uint32_t cal_lmfc_lemc_delay(uint32_t coding_type, uint32_t f, uint32_t k, uint32_t e);
static uint32_t cal_ratio(uint32_t mode, uint32_t no_converters, uint32_t no_samples, uint32_t ntotal, uint32_t no_frames, uint32_t no_lanes, uint32_t no_samples_on_if);
extern int pma_fw[16384*2];

static tUcpAutoConfigPara_t ucpCrgConfig[44] = {
    {0x05F10120, 0x00000000, UCP_OPT_W, 0}, //00 JS_CRG_TMR_EN_SAM_CLK_SEL      
    {0x05F10000, 0x00802A00, UCP_OPT_W, 0}, //01 JS_CRG_CLK_SEL
    {0x05F10004, 0x0000002A, UCP_OPT_W, 0}, //02 JS_CRG_DPLL0_CTRL_0
    {0x05F10008, 0x00000000, UCP_OPT_W, 0}, //03 JS_CRG_DPLL0_CTRL_1
    {0x05F10014, 0x00400000, UCP_OPT_W, 0}, //04 JS_CRG_SAM0_CLK_CTRL
    {0x05F10018, 0x00400000, UCP_OPT_W, 0}, //05 JS_CRG_SAM1_CLK_CTRL
    {0x05F1001C, 0x00401000, UCP_OPT_W, 0}, //06 JS_CRG_SAM2_CLK_CTRL
    {0x05F1002C, 0x00401000, UCP_OPT_W, 0}, //07 JS_CRG_SAM3_CLK_CTRL
    {0x05F10020, 0x00400000, UCP_OPT_W, 0}, //08 JS_CRG_CHA0_CLK_CTRL
    {0x05F10024, 0x00400000, UCP_OPT_W, 0}, //09 JS_CRG_CHA1_CLK_CTRL
    {0x05F10028, 0x00400000, UCP_OPT_W, 0}, //10 JS_CRG_CHA2_CLK_CTRL
    {0x05F10090, 0x00400000, UCP_OPT_W, 0}, //11 JS_CRG_CHA3_CLK_CTRL
    {0x05F10108, 0x0503F007, UCP_OPT_W, 0}, //12 JS_CRG_SAM_CHA0_RST_CTRL
    {0x05F1010C, 0x0503F007, UCP_OPT_W, 0}, //13 JS_CRG_SAM_CHA1_RST_CTRL
    {0x05F10110, 0x0503F007, UCP_OPT_W, 0}, //14 JS_CRG_SAM_CHA2_RST_CTRL
    {0x05F10114, 0x0503F007, UCP_OPT_W, 0}, //15 JS_CRG_SAM_CHA3_RST_CTRL
    {0x05F10118, 0x0503F007, UCP_OPT_W, 0}, //16 JS_CRG_SAM_CHA4_RST_CTRL
    {0x05F1011C, 0x0503F007, UCP_OPT_W, 0}, //17 JS_CRG_SAM_CHA5_RST_CTRL
    {0x05F10094, 0x0503F007, UCP_OPT_W, 0}, //18 JS_CRG_SAM_CHA6_RST_CTRL
    {0x05F10098, 0x0503F007, UCP_OPT_W, 0}, //19 JS_CRG_SAM_CHA7_RST_CTRL
    {0x05F10038, 0x0503F007, UCP_OPT_W, 0}, //20 JS_CRG_JESD0_TIME_CTRL
    {0x05F1003C, 0x0503F007, UCP_OPT_W, 0}, //21 JS_CRG_JESD1_TIME_CTRL
    {0x05F10040, 0x0503F007, UCP_OPT_W, 0}, //22 JS_CRG_JESD2_TIME_CTRL
    {0x05F10044, 0x0503F007, UCP_OPT_W, 0}, //23 JS_CRG_JESD3_TIME_CTRL
    {0x05F10048, 0x0503F007, UCP_OPT_W, 0}, //24 JS_CRG_JESD4_TIME_CTRL
    {0x05F1004C, 0x0503F007, UCP_OPT_W, 0}, //25 JS_CRG_JESD5_TIME_CTRL
    {0x05F10050, 0x0503F007, UCP_OPT_W, 0}, //26 JS_CRG_JESD6_TIME_CTRL
    {0x05F10054, 0x0503F007, UCP_OPT_W, 0}, //27 JS_CRG_JESD7_TIME_CTRL
    {0x05F10070, 0x05F00807, UCP_OPT_W, 0}, //28 JS_CRG_PHY_TX_RSTN_JS_CTRL_0
    {0x05F10074, 0x05F00807, UCP_OPT_W, 0}, //29 JS_CRG_PHY_TX_RSTN_JS_CTRL_1
    {0x05F10078, 0x05F00807, UCP_OPT_W, 0}, //30 JS_CRG_PHY_TX_RSTN_JS_CTRL_2
    {0x05F1007C, 0x05F00807, UCP_OPT_W, 0}, //31 JS_CRG_PHY_TX_RSTN_JS_CTRL_3
    {0x05F10080, 0x05F00807, UCP_OPT_W, 0}, //32 JS_CRG_PHY_RX_RSTN_JS_CTRL_0
    {0x05F10084, 0x05F00807, UCP_OPT_W, 0}, //33 JS_CRG_PHY_RX_RSTN_JS_CTRL_1
    {0x05F10088, 0x05F00807, UCP_OPT_W, 0}, //34 JS_CRG_PHY_RX_RSTN_JS_CTRL_2
    {0x05F1008C, 0x05F00807, UCP_OPT_W, 0}, //35 JS_CRG_PHY_RX_RSTN_JS_CTRL_3
    {0x05F100D8, 0x05F00807, UCP_OPT_W, 0}, //36 JS_CRG_PHY_EQ_RSTN_JS_CTRL_0
    {0x05F100DC, 0x05F00807, UCP_OPT_W, 0}, //37 JS_CRG_PHY_EQ_RSTN_JS_CTRL_1
    {0x05F100E0, 0x05F00807, UCP_OPT_W, 0}, //38 JS_CRG_PHY_EQ_RSTN_JS_CTRL_2
    {0x05F100E4, 0x05F00807, UCP_OPT_W, 0}, //39 JS_CRG_PHY_EQ_RSTN_JS_CTRL_3
    {0x05F100F8, 0x05F00807, UCP_OPT_W, 0}, //40 JS_CRG_PHY_PWR_ON_RST_JS_CTRL
    {0x05F10030, 0x00000004, UCP_OPT_SKIP, 0}, //41 JS_CRG_DPLL_PMA_CTRL
    {0x05F10120, 0x00000000, UCP_OPT_SKIP, 0}, //42 JS_CRG_TMR_EN_SAM_CLK_SEL
    {0x05F10120, 0x00000080, UCP_OPT_W, 1}  //43 JS_CRG_TMR_EN_SAM_CLK_SEL
};

static tUcpAutoConfigPara_t ucpPmaConfig[80] =
{
    {0x05FC40C4, 0x00000001, UCP_OPT_W, 0}, //00 JS_PMA0_PHY_RESET
    {0x05FD4088, 0x00000011, UCP_OPT_W, 0}, //01 JS_PMA0_PCS_BIT_REV_CTRL
    {0x05FC41A0, 0x00000101, UCP_OPT_W, 0}, //02 JS_PMA0_SRAM_CTRL
    {0x05FC43C0, 0x00000002, UCP_OPT_W, 0}, //03 JS_PMA0_TX_CLK_SEL
    {0x05FC4108, 0x00000040, UCP_OPT_W, 0}, //04 JS_PMA0_REFA_CLK_CTRL2
    {0x05FC4100, 0x00001111, UCP_OPT_W, 0}, //05 JS_PMA0_REF_CLK_CTRL
    {0x05FC4014, 0x00000000, UCP_OPT_W, 0}, //06 JS_PMA0_MPLLA_PARAM6
    {0x05FC400C, 0x000000B4, UCP_OPT_W, 0}, //07 JS_PMA0_MPLLA_PARAM4
    {0x05FC4010, 0x00000110, UCP_OPT_W, 0}, //08 JS_PMA0_MPLLA_PARAM5
    {0x05FC406C, 0x00000000, UCP_OPT_W, 0}, //09 JS_PMA0_MPLLA_SSC_CTRL1
    {0x05FC4078, 0x00000000, UCP_OPT_W, 0}, //10 JS_PMA0_MPLLA_SSC_CTRL4
    {0x05FC4070, 0x00000000, UCP_OPT_W, 0}, //11 JS_PMA0_MPLLA_SSC_CTRL2
    {0x05FC4074, 0x00000000, UCP_OPT_W, 0}, //12 JS_PMA0_MPLLA_SSC_CTRL3
    {0x05FC407C, 0x00000000, UCP_OPT_W, 0}, //13 JS_PMA0_MPLLA_SSC_CTRL5
    {0x05FC4080, 0x00000000, UCP_OPT_W, 0}, //14 JS_PMA0_MPLLA_SSC_CTRL6
    {0x05FC4060, 0x00000000, UCP_OPT_W, 0}, //15 JS_PMA0_MPLLA_FRAC_CTRL2
    {0x05FC4064, 0x00000000, UCP_OPT_W, 0}, //16 JS_PMA0_MPLLA_FRAC_CTRL3
    {0x05FC405C, 0x00000000, UCP_OPT_W, 0}, //17 JS_PMA0_MPLLA_FRAC_CTRL1
    {0x05FC4068, 0x00000000, UCP_OPT_W, 0}, //18 JS_PMA0_MPLLA_FRAC_CTRL4
    {0x05FC4008, 0x0000004B, UCP_OPT_W, 0}, //19 JS_PMA0_MPLLA_PARAM3
    {0x05FC4004, 0x0000063F, UCP_OPT_W, 0}, //20 JS_PMA0_MPLLA_PARAM2
    {0x05FC4000, 0x0000063F, UCP_OPT_W, 0}, //21 JS_PMA0_MPLLA_PARAM1
    {0x05F50050, 0x000002D0, UCP_OPT_W, 0}, //22 JS_PHY_BS_CTRL
    {0x05FC4158, 0x00000000, UCP_OPT_W, 0}, //23 JS_PMA0_RTUNE_CTRL1
    {0x05FC415C, 0x00000000, UCP_OPT_W, 0}, //24 JS_PMA0_RTUNE_CTRL2
    {0x05FC4160, 0x00000000, UCP_OPT_W, 0}, //25 JS_PMA0_RTUNE_CTRL3
    {0x05FC4058, 0x00000003, UCP_OPT_W, 0}, //26 JS_PMA0_SUP_MISC
    {0x05FC4164, 0x00000005, UCP_OPT_W, 0}, //27 JS_PMA0_RX_BIAS_CURRENT_CTRL
    {0x05FBC280, 0x00000000, UCP_OPT_W, 0}, //28 JS_PMA0_BROADCAST_LANE_REFCLK_SEL
    {0x05FBC024, 0x00000550, UCP_OPT_W, 0}, //29 JS_PMA0_BROADCAST_RECEIVER_REQ_PARAM8
    {0x05FBC084, 0x00000012, UCP_OPT_W, 0}, //30 JS_PMA0_BROADCAST_RECEIVER_DATAPATH_SETTING1
    {0x05FBC1C4, 0x00000000, UCP_OPT_W, 0}, //31 JS_PMA0_BROADCAST_TRANSMITTER_CONTROL2
    {0x05FBC340, 0x00000088, UCP_OPT_W, 0}, //32 JS_PMA0_BROADCAST_TRANS_REQ_CTRL1
    {0x05FBC14C, 0x00000052, UCP_OPT_W, 0}, //33 JS_PMA0_BROADCAST_TRANSMITTER_REQ_PARAM2
    {0x05FBC344, 0x00005B5B, UCP_OPT_W, 0}, //34 JS_PMA0_BROADCAST_TRANS_REQ_CTRL2
    {0x05FBC34C, 0x0000C941, UCP_OPT_W, 0}, //35 JS_PMA0_BROADCAST_TRANS_REQ_CTRL4
    {0x05FBC350, 0x00000133, UCP_OPT_W, 0}, //36 JS_PMA0_BROADCAST_TRANS_REQ_CTRL5
    {0x05FBC2C0, 0x00004000, UCP_OPT_W, 0}, //37 JS_PMA0_BROADCAST_ETH_CLK_CTRL
    {0x05FBC358, 0x00000000, UCP_OPT_W, 0}, //38 JS_PMA0_BROADCAST_TRANS_INTERFACE_CTRL
    {0x05FBC32C, 0x00000000, UCP_OPT_W, 0}, //39 JS_PMA0_BROADCAST_TX_DIV_CLK_CTRL
    {0x05FBC248, 0x00000000, UCP_OPT_W, 0}, //40 JS_PMA0_BROADCAST_CONTEXT_RESTORE_CTRL3
    {0x05FBC348, 0x00000410, UCP_OPT_W, 0}, //41 JS_PMA0_BROADCAST_TRANS_REQ_CTRL3
    {0x05FBC188, 0x00000000, UCP_OPT_W, 0}, //42 JS_PMA0_BROADCAST_TRANSMITTER_DATAPATH_SETTING
    {0x05FBC010, 0x00000050, UCP_OPT_W, 0}, //43 JS_PMA0_BROADCAST_RECEIVER_REQ_PARAM3
    {0x05FBC014, 0x00000110, UCP_OPT_W, 0}, //44 JS_PMA0_BROADCAST_RECEIVER_REQ_PARAM4
    {0x05FBC30C, 0x00001080, UCP_OPT_W, 0}, //45 JS_PMA0_BROADCAST_RX_EQ_CTRL2
    {0x05FBC308, 0x0000014C, UCP_OPT_W, 0}, //46 JS_PMA0_BROADCAST_RX_EQ_CTRL1
    {0x05FBC018, 0x00000000, UCP_OPT_W, 0}, //47 JS_PMA0_BROADCAST_RECEIVER_REQ_PARAM5
    {0x05FBC00C, 0x00000423, UCP_OPT_W, 0}, //48 JS_PMA0_BROADCAST_RECEIVER_REQ_PARAM2
    {0x05FBC304, 0x000000BB, UCP_OPT_W, 0}, //49 JS_PMA0_BROADCAST_RX_DCC_CTRL
    {0x05FBC088, 0x00004200, UCP_OPT_W, 0}, //50 JS_PMA0_BROADCAST_RECEIVER_DATAPATH_SETTING2
    {0x05FBC01C, 0x00000000, UCP_OPT_W, 0}, //51 JS_PMA0_BROADCAST_RECEIVER_REQ_PARAM6
    {0x05FBC0C4, 0x00000121, UCP_OPT_W, 0}, //52 JS_PMA0_BROADCAST_RECEIVER_CONTROL
    {0x05FBC028, 0x00000005, UCP_OPT_W, 0}, //53 JS_PMA0_BROADCAST_RECEIVER_REQ_PARAM9
    {0x05FBC328, 0x00000000, UCP_OPT_W, 0}, //54 JS_PMA0_BROADCAST_RX_DIV_CLK_CTRL
    {0x05FBC04C, 0x00000141, UCP_OPT_W, 0}, //55 JS_PMA0_BROADCAST_RECEIVER_ADAPT_SETTING
    {0x05FBC08C, 0x00000000, UCP_OPT_W, 0}, //56 JS_PMA0_BROADCAST_RECEIVER_DATAPATH_SETTING3
    {0x05FBC300, 0x00000000, UCP_OPT_W, 0}, //57 JS_PMA0_BROADCAST_RX_ADAPT_CTRL
    {0x05FBC200, 0x00000018, UCP_OPT_W, 0}, //58 JS_PMA0_BROADCAST_TRANSMITTER_EQ1
    {0x05FBC204, 0x00000000, UCP_OPT_W, 0}, //59 JS_PMA0_BROADCAST_TRANSMITTER_EQ2
    {0x05FBC208, 0x00000000, UCP_OPT_W, 0}, //60 JS_PMA0_BROADCAST_TRANSMITTER_EQ3
    {0x05FC40C4, 0x00000000, UCP_OPT_W, 0}, //61 JS_PMA0_PHY_RESET
    {0x05FC4104, 0x00000110, UCP_OPT_W, 0}, //62 JS_PMA0_REFA_CLK_CTRL1
    {0x05FBC1C0, 0x00000000, UCP_OPT_W, 1}, //63 JS_PMA0_BROADCAST_TRANSMITTER_CONTROL1
    {0x05FBC0C0, 0x00000000, UCP_OPT_W, 1}, //64 JS_PMA0_BROADCAST_RECEIVER_RESET
    {0x05FBC148, 0x00000200, UCP_OPT_W, 2}, //65 JS_PMA0_BROADCAST_TRANSMITTER_REQ_PARAM1
    {0x05FBC020, 0x00001112, UCP_OPT_W, 2}, //66 JS_PMA0_BROADCAST_RECEIVER_REQ_PARAM7
    {0x05FBC140, 0x00000001, UCP_OPT_W, 2}, //67 JS_PMA0_BROADCAST_TRANSMITTER_REQ
    {0x05FBC004, 0x00000001, UCP_OPT_W, 2}, //68 JS_PMA0_BROADCAST_RECEIVER_REQ
    {0x05FBC140, 0x00000000, UCP_OPT_W, 3}, //69 JS_PMA0_BROADCAST_TRANSMITTER_REQ
    {0x05FBC004, 0x00000000, UCP_OPT_W, 3}, //70 JS_PMA0_BROADCAST_RECEIVER_REQ
    {0x05FBC020, 0x00001110, UCP_OPT_W, 4}, //71 JS_PMA0_BROADCAST_RECEIVER_REQ_PARAM7
    {0x05FBC148, 0x00000010, UCP_OPT_W, 4}, //72 JS_PMA0_BROADCAST_TRANSMITTER_REQ_PARAM1
    {0x05FBC184, 0x00000001, UCP_OPT_W, 4}, //73 JS_PMA0_BROADCAST_TRANSMITTER_DATAPATH_CLKRDY
    {0x05FBC140, 0x00000001, UCP_OPT_W, 4}, //74 JS_PMA0_BROADCAST_TRANSMITTER_REQ
    {0x05FBC004, 0x00000001, UCP_OPT_W, 4}, //75 JS_PMA0_BROADCAST_RECEIVER_REQ
    {0x05FBC140, 0x00000000, UCP_OPT_W, 5}, //76 JS_PMA0_BROADCAST_TRANSMITTER_REQ
    {0x05FBC004, 0x00000000, UCP_OPT_W, 5}, //77 JS_PMA0_BROADCAST_RECEIVER_REQ
    {0x05FBC180, 0x00000001, UCP_OPT_W, 6}, //78 JS_PMA0_BROADCAST_TRANSMITTER_DATAPATH_EN
    {0x05FBC080, 0x00000001, UCP_OPT_W, 6}  //79 JS_PMA0_BROADCAST_RECEIVER_DATAPATH_EN
};

static void js_csu_loc_cfg(uint32_t all);
static void js_csu_glb_cfg(uint64_t addr, uint32_t all, uint32_t id);
static void js_csu_glb_cfg_sep(uint64_t addr, uint32_t all, uint32_t id, uint32_t sep_num, uint32_t sep_margin);

void ucp4008_jesd_js_ctrl_init (void);
void ucp4008_jesd_crg_init (ucp_jesd_Init_t *setting);
void ucp4008_jesd_subctrl_init (ucp_jesd_Init_t *setting);
void ucp4008_jesd_pma_init (ucp_jesd_Init_t *setting);
void ucp4008_jesd204b_init(ucp_jesd_Init_t *setting);
void ucp4008_jesd204c_init(ucp_jesd_Init_t *setting);
void ucp4008_jesd_timer_init (void);
void ucp4008_jesd204b_bringup (void);

static void ucp4008_jesd_calLarate (ucp_jesd_Init_t *setting);
static void ucp4008_autoStepConfig (tUcpAutoConfigPara_t *para, uint32_t step, uint32_t size);
static void ucp4008_jesd_crg_print (void);
static void ucp4008_jesd_pma_print (void);

void ucp_jesd_init(ucp_jesd_Init_t *setting)
{
    ucp4008_jesd_calLarate(setting);
    ucp4008_jesd_js_ctrl_init();
    ucp4008_jesd_crg_init(setting);
    ucp4008_jesd_subctrl_init(setting);
    if (0 == setting->common.enableJesd204C)
    {
        ucp4008_jesd204b_init(setting);
    }
    else
    {
        ucp4008_jesd204c_init(setting);
    }
    ucp4008_jesd_pma_init(setting);
    ucp4008_jesd_timer_init();
    ucp4008_jesd204b_bringup();

    return;
}

void ucp4008_jesd_js_ctrl_init (void)
{
	ucp_jesd_TrxGpioCfg_t *pTrxGpioCfg;
    
    pTrxGpioCfg = UCP_API_JESD_TrxGpioGet(); 
    
    //---------------------- Config JS-CTRL ---------------------
	//
	// bit[ 8]: o_jesda_rx1_sync
	// bit[ 7]: o_jesda_rx0_sync
	// bit[ 6]: i_jesda_tx_sync    
	// bit[ 5]: i_jesd_tx_sysref   
	// bit[ 4]: i_jesd_rx1_sysref  
	// bit[ 3]: i_jesd_rx0_sysref  
	// bit[ 2]: i_jesd_tx_dev_clk  
	// bit[ 1]: i_jesd_rx1_dev_clk 
	// bit[ 0]: i_jesd_rx0_dev_clk 
	ucp_reg32_write(JS_CTRL_LVDS_BIAS_EN,      0x1FF);
    ucp_reg32_write(JS_CTRL_LVDS_VBIAS_SEL,    0x1FF);
    ucp_reg32_write(JS_CTRL_LVDS_PULLDN,       0x000);
    ucp_reg32_write(JS_CTRL_LVDS_SCHMITT_EN,   0x000);
    ucp_reg32_write(JS_CTRL_LVDS_RTERM_EN,     0x07F);
    ucp_reg32_write(JS_CTRL_LVDS_RTERM_VAL_0,  0xDB6DB);
    ucp_reg32_write(JS_CTRL_LVDS_RTERM_VAL_1,  0x000);
    ucp_reg32_write(JS_CTRL_LVDS_RTERM_VAL_2,  0x000);
    ucp_reg32_write(JS_CTRL_LVDS_RTERM_VAL_3,  0x000);
    if (pTrxGpioCfg->version > 1)
    {
        printf("%s-coupled: ", pTrxGpioCfg->lvdsCoupling);
        if ('D' == pTrxGpioCfg->lvdsCoupling[0])
        {
            ucp_reg32_write(JS_CTRL_LVDS_RXCM_EN,      0x000); // dc-coupled disable cm
            printf("lvds CM disable\n");
        }
        else if ('A' == pTrxGpioCfg->lvdsCoupling[0])
        {
            ucp_reg32_write(JS_CTRL_LVDS_RXCM_EN,      0x07F); // ac-coupled enable cm
            printf("lvds CM enable\n");
        }
        else
        {
            ucp_reg32_write(JS_CTRL_LVDS_RXCM_EN,      0x07F); // unknown-coupled enable cm
            printf("** unknown-coupled, lvds CM enable\n");
        }
    }
    else
    {
        ucp_reg32_write(JS_CTRL_LVDS_RXCM_EN,      0x07F); // enable cm
    }
    ucp_reg32_write(JS_CTRL_LVDS_RXEN,         0x07F);
    ucp_reg32_write(JS_CTRL_LVDS_TXDRV_0,      0x50000000);
    ucp_reg32_write(JS_CTRL_LVDS_TXDRV_1,      0x005);
    ucp_reg32_write(JS_CTRL_LVDS_TXDRV_2,      0x000);
    ucp_reg32_write(JS_CTRL_LVDS_TXDRV_3,      0x000);
    ucp_reg32_write(JS_CTRL_LVDS_TXEN,         0x180);
    ucp_reg32_write(JS_CTRL_LVDS_TX_CM,        0x180);

	// PCS Protocol Sel
	// phy_protocol_sel_sub0      <= pwdata_s10_js_subctrl[0];    //0: JESD, 1:SRIO
	// phy_protocol_sel_sub1      <= pwdata_s10_js_subctrl[1];
	// phy_out_test_clk_sel       <= pwdata_s10_js_subctrl[2];
	// phy_srds_tx_clk_sel_sub0   <= pwdata_s10_js_subctrl[5:3];
	// phy_tx_clk_mode_sub0       <= pwdata_s10_js_subctrl[6]; 
	// phy_srds_tx_clk_sel_sub1   <= pwdata_s10_js_subctrl[9:7];
	// phy_tx_clk_mode_sub1       <= pwdata_s10_js_subctrl[10];
	ucp_reg32_write(JS_CTRL_PHY_MISC_SEL_0,   ucp_reg32_read(JS_CTRL_PHY_MISC_SEL_0) & 0xFFFFFBBC);

	// coding of jesd_mode_sel
	// 000:jesd204b TX + jesd204b RX
	// 001:jesd204b TX + jesd204b RX + jesd204b ORX
	// 010:jesd204c TX + jesd204c RX
	// 011:jesd204c TX + jesd204c RX + jesd204c ORX
	// 100:jesd204b TX + jesd204c TX + jesd204b RX + jesd204c RX
	// jesd-csu data of RX0/RX1/TX0/TX1
	// RX0: RX_204B_L(M=8,N=16,jesdcsu_through_from_204b_rx1) / ORX_204C(M=2,N=24,jesdcsu_through_from_204c_rx0)
	// RX1: RX_204B_H(M=8,N=16,jesdcsu_through_from_204b_rx1) / ORX_204B(M=2,N=24,jesdcsu_through_from_204b_rx0) / RX_204C(M=8,N=24,jesdcsu_through_from_204c_rx1)
	// TX0: TX_204B_L(M=8,N=16,jesdcsu_through_to_204b_tx0) 
	// TX1: TX_204B_H(M=8,N=16,jesdcsu_through_to_204b_tx0)   / TX_204C(M=8,N=16,jesdcsu_through_to_204c_tx1)
	ucp_reg32_write(JS_CTRL_JESD204_MODE_SEL, 0x0);
    ucp_reg32_write(JS_SERDES_CLK_EN,         0x1FFF);

    // printf("\033[0;42;31m");
	printf("js_ctrl ok\n");
}


 void ucp4008_jesd_crg_init (ucp_jesd_Init_t *setting)
 {
    uint32_t size;
    tUcpAutoConfigPara_t *pConfig;
    ucp_jesd_TrxGpioCfg_t *pTrxGpioCfg;

    size = 44;
    pConfig = ucpCrgConfig;
    pTrxGpioCfg = UCP_API_JESD_TrxGpioGet(); 

    // PLL_CLK = refdiv*2^refdiv 
    // refdiv bit1:bit0, postdiv bit6:bit4
    switch (pllFactor)
    {
        case 2:  // deviceClk*2
        pConfig[2].value = 0x0000002A;
        break;

        case 4:  // deviceClk*4
        pConfig[2].value = 0x00000026;
        break;

        case 8:  // deviceClk*8
        pConfig[2].value = 0x00000022;
        break;
        
        default:
        printf("Invalid pll divFactor: %d. pllFactor \n", pllFactor);
        exit(1);
        break;
    }

    // SAM_div CHA_div bit16:bit22 为 (N+1) 分频
    if (setting->deframer[0].enable)
    {
        if (1 == sampleFactor[0]) {
            pConfig[4].value = 0x00400000;
        } else if (2 == sampleFactor[0]) {
            pConfig[4].value = 0x00401000;
        } else if (4 == sampleFactor[0]) {
            pConfig[4].value = 0x00403000;
        } else if (8 == sampleFactor[0]) {
            pConfig[4].value = 0x00407000;
        } else {
            printf("Invalid deframer[0] sampleFactor: %d\n", sampleFactor[0]);
            exit(1);
        }
    }

    if (setting->deframer[1].enable)
    {
        if (1 == sampleFactor[1]) {
            pConfig[5].value = 0x00400000;
        } else if (2 == sampleFactor[1]) {
            pConfig[5].value = 0x00401000;
        } else if (4 == sampleFactor[1]) {
            pConfig[5].value = 0x00403000;
        } else if (8 == sampleFactor[1]) {
            pConfig[5].value = 0x00407000;
        } else {
            printf("Invalid deframer[1] sampleFactor: %d\n", sampleFactor[1]);
            exit(1);
        }
    }
    
    if (setting->framer.enable)
    {
        if (1 == sampleFactor[2]) {
            pConfig[6].value = 0x00400000;
            pConfig[7].value = 0x00400000;
        } else if (2 == sampleFactor[2]) {
            pConfig[6].value = 0x00401000;
            pConfig[7].value = 0x00401000;
        } else if (4 == sampleFactor[2]) {
            pConfig[6].value = 0x00403000;
            pConfig[7].value = 0x00403000;
        } else if (8 == sampleFactor[2]) {
            pConfig[6].value = 0x00407000;
            pConfig[7].value = 0x00407000;
        } else {
            printf("Invalid framer sampleFactor: %d\n", sampleFactor[2]);
            exit(1);
        }
    }
    
    
    switch (pTrxGpioCfg->devClkSrc)
    {
        case 1: // src as rx1 devClk
            pConfig[1].value = 0x00806A00;
            printf("DevClkSrc: Rx1\n");
            break;
        case 2: // src as tx devClk
            pConfig[1].value = 0x0080AA00;
            printf("DevClkSrc: Tx\n");
            break;
        default: // src as rx0 devClk
            pConfig[1].value = 0x00802A00;
            printf("DevClkSrc: Rx0\n");
            break; 
    }
    
    ucp4008_autoStepConfig(pConfig, 0, size);
    printf("DevClkReg: 0x%04X\n", ucp_reg32_read(0x05F10000));
	
	while((ucp_reg32_read(JS_CRG_DPLL_PMA_CTRL) & BIT2) != 0x4);
	
    ucp4008_autoStepConfig(pConfig, 1, size);

	printf("js_crg ok\n");
}

void ucp4008_jesd_subctrl_init (ucp_jesd_Init_t *setting)
{
    uint32_t reg;
    ucp_jesd_TrxGpioCfg_t* pTrxGpioCfg;

    //--------------------- Config jesd_subctrl ----------------------
	// sl_MUX2D2 u_sysref_mux0(.S0(sysref_sel[0]),.B(jesd_rx1_sysref  ),.A(jesd_rx0_sysref            ),.Y(sysref_mux_out[0])); //0:A,1:B
	// sl_MUX2D2 u_sysref_mux1(.S0(sysref_sel[1]),.B(sysref_mux_out[0]),.A(jesd_tx_sysref             ),.Y(sysref_mux_out[1])); //0:A,1:B
	// sl_MUX2D2 u_sysref_mux2(.S0(sysref_sel[2]),.B(sysref_mux_out[1]),.A(jesd_int_sysref            ),.Y(sysref_mux_out[2])); //0:A,1:B
	// sl_MUX2D2 u_sysref_mux3(.S0(sysref_sel[3]),.B(sysref_mux_out[2]),.A(sysref_pulse_char_rx0_sub0 ),.Y(sysref_mux_out[3])); //0:A,1:B
	// sl_MUX2D2 u_sysref_mux4(.S0(sysref_sel[4]),.B(sysref_mux_out[3]),.A(sysref_pulse_char_rx1_sub0 ),.Y(sysref_mux_out[4])); //0:A,1:B
	// sl_MUX2D2 u_sysref_mux5(.S0(sysref_sel[5]),.B(sysref_mux_out[4]),.A(sysref_pulse_char_tx_sub0  ),.Y(sysref_mux_out[5])); //0:A,1:B
	// sl_MUX2D2 u_sysref_mux6(.S0(sysref_sel[6]),.B(sysref_mux_out[5]),.A(sysref_pulse_char_rx0_sub1 ),.Y(sysref_mux_out[6])); //0:A,1:B
	// sl_MUX2D2 u_sysref_mux7(.S0(sysref_sel[7]),.B(sysref_mux_out[6]),.A(sysref_pulse_char_rx1_sub1 ),.Y(sysref_mux_out[7])); //0:A,1:B
	// sl_MUX2D2 u_sysref_mux8(.S0(sysref_sel[8]),.B(sysref_mux_out[7]),.A(sysref_pulse_char_tx_sub1  ),.Y(sysref_out       )); //0:A,1:B
	//#JS_204B_RX0_SUBCTRL_SYSREF_RX_SEL   = 0x1FE ;  // rx0_sysref
	//#JS_204B_RX1_SUBCTRL_SYSREF_RX_SEL   = 0x1FF ;  // rx1_sysref
	//#JS_204B_TX_SUBCTRL_SYSREF_TX_SEL    = 0x1FC ;  // tx_sysref
	pTrxGpioCfg = UCP_API_JESD_TrxGpioGet(); 
	switch (pTrxGpioCfg->devClkSrc)
	{
	    case 1: // src as rx1 devClk
            reg = 0x1FF; 
            printf("RefClkSrc: Rx1 ");
            break;
        case 2: // src as tx devClk
            reg = 0x1FC;
            printf("RefClkSrc: Tx ");
            break;
        default: // src as rx0 devClk
            reg = 0x1FE;
            printf("RefClkSrc: Rx0 ");
            break;    
	}
	printf("%04X\n", reg);
	ucp_reg32_write(JS_204B_RX0_SUBCTRL_SYSREF_RX_SEL,              reg);
    ucp_reg32_write(JS_204B_RX1_SUBCTRL_SYSREF_RX_SEL,              reg);
    ucp_reg32_write(JS_204B_TX_SUBCTRL_SYSREF_TX_SEL,               reg);
	
	// sl_MUX2D2 u_sync_b_mux0(.S0(sync_b_o_sel[0]),.B(sync_b_o_rx1_sub0  ),.A(sync_b_o_rx0_sub0  ),.Y(sync_b_o_mux_out[0])); //0:A,1:B
	// sl_MUX2D2 u_sync_b_mux1(.S0(sync_b_o_sel[1]),.B(sync_b_o_rx1_sub1  ),.A(sync_b_o_rx0_sub1  ),.Y(sync_b_o_mux_out[1])); //0:A,1:B
	// sl_MUX2D2 u_sync_b_mux2(.S0(sync_b_o_sel[2]),.B(sync_b_o_mux_out[1]),.A(sync_b_o_mux_out[0]),.Y(sync_b_o_mux_out[2])); //0:A,1:B
	// sl_MUX2D2 u_sync_b_mux3(.S0(sync_b_o_sel[3]),.B(sync_b_o_masked_int),.A(sync_b_o_mux_out[2]),.Y(sync_b_out         )); //0:A,1:B
	//#JS_204B_RX0_SUBCTRL_SYNC_B_SEL      = 0x0   ;  // sync_b_o_rx0_sub0
	//#JS_204B_RX1_SUBCTRL_SYNC_B_SEL      = 0x1   ;  // sync_b_o_rx1_sub0
	ucp_reg32_write(JS_204B_RX0_SUBCTRL_SYNC_B_SEL,                 0x01);
    ucp_reg32_write(JS_204B_RX1_SUBCTRL_SYNC_B_SEL,                 0x01);
	
	// sl_MUX2D2 u_sync_b_mux0(.S0(sync_b_i_sel[8] ),.B(sync_b_i_sub0[1]     ),.A(sync_b_i_sub0[0] ),.Y(sync_b_mux_out[0])); //0:A,1:B
	// sl_MUX2D2 u_sync_b_mux1(.S0(sync_b_i_sel[9] ),.B(sync_b_mux_out[0]    ),.A(sync_b_i_sub0[2] ),.Y(sync_b_mux_out[1])); //0:A,1:B
	// sl_MUX2D2 u_sync_b_mux2(.S0(sync_b_i_sel[10]),.B(sync_b_mux_out[1]    ),.A(sync_b_i_sub0[3] ),.Y(sync_b_mux_out[2])); //0:A,1:B
	// sl_MUX2D2 u_sync_b_mux3(.S0(sync_b_i_sel[11]),.B(synci_sub0_masked_int),.A(sync_b_mux_out[2]),.Y(sync_b_mux_out[3])); //0:A,1:B
	// sl_MUX2D2 u_sync_b_mux4(.S0(sync_b_i_sel[12]),.B(sync_b_i_sub1[1]     ),.A(sync_b_i_sub1[0] ),.Y(sync_b_mux_out[4])); //0:A,1:B
	// sl_MUX2D2 u_sync_b_mux5(.S0(sync_b_i_sel[13]),.B(sync_b_mux_out[4]    ),.A(sync_b_i_sub1[2] ),.Y(sync_b_mux_out[5])); //0:A,1:B
	// sl_MUX2D2 u_sync_b_mux6(.S0(sync_b_i_sel[14]),.B(sync_b_mux_out[5]    ),.A(sync_b_i_sub1[3] ),.Y(sync_b_mux_out[6])); //0:A,1:B
	// sl_MUX2D2 u_sync_b_mux7(.S0(sync_b_i_sel[15]),.B(synci_sub1_masked_int),.A(sync_b_mux_out[6]),.Y(sync_b_mux_out[7])); //0:A,1:B
	// sl_MUX2D2 u_sync_b_mux8(.S0(sync_b_i_sel[16]),.B(sync_b_mux_out[7]    ),.A(sync_b_mux_out[3]),.Y(sync_b_out)       ); //0:A,1:B
	//#JS_204B_TX_SUBCTRL_SYNC_B_SEL      = 0x6<<8 ;  // jesda_tx_sync0
	ucp_reg32_write(JS_204B_TX_SUBCTRL_SYNC_B_SEL,                 (0x6<<8));

    // 000: JESD204B TX + RX
    // 001: JESD204B TX + RX + ORX
    // 010: JESD204C TX + RX
    // 011: JESD204C TX + RX + ORX
    ucp_reg32_write(JS_CTRL_JESD204_MODE_SEL, 0x01);
    
	printf("jesd subctrl ok\n");
}

void ucp4008_jesd_pma_init (ucp_jesd_Init_t *setting)
{
    uint64_t i;
	uint32_t size;
	tUcpAutoConfigPara_t *pConfig;

    size = 80;
    
    pConfig = ucpPmaConfig;

    if (4915200000 == frameLaneRate) {
        pConfig[3].value  = 0x00000002;
        pConfig[33].value = 0x00000052;
        pConfig[37].value = 0x00004000;
    } else if (9830400000 == frameLaneRate) {
        pConfig[3].value  = 0x00000001;
        pConfig[33].value = 0x00000051;
        pConfig[37].value = 0x00006000;
    } else if (8110080000 == frameLaneRate) {
        pConfig[3].value  = 0x00000001;
        pConfig[33].value = 0x00000051;
        pConfig[37].value = 0x00006000;
    }else {
        exit(1);
    }

    if (4915200000 == deframe0LaneRate) {
        pConfig[43].value = 0x00000061;
        pConfig[44].value = 0x0000010C;
        pConfig[46].value = 0x00000514;
        pConfig[55].value = 0x00000101;
        pConfig[66].value = 0x00001122;
        pConfig[71].value = 0x00001120;
    } else if (9830400000 == deframe0LaneRate) {
        pConfig[43].value = 0x00000050;
        pConfig[44].value = 0x00000110;
        pConfig[46].value = 0x0000014C;
        pConfig[55].value = 0x00000141;
        pConfig[66].value = 0x00001112;
        pConfig[71].value = 0x00001110;
    } else if (8110080000 == deframe0LaneRate) {
        pConfig[43].value = 0x00000050;
        pConfig[44].value = 0x00000110;
        pConfig[46].value = 0x0000014C;
        pConfig[55].value = 0x00000141;
        pConfig[66].value = 0x00001112;
        pConfig[71].value = 0x00001110;
    } else {
        exit(1);
    }
    
// step 1 ------------------------------------------------------------------------------
    ucp4008_autoStepConfig(pConfig, 0, size);

    // Wait sram_init_done
	// c_rd_data[0] = r_ro1_sram_init_done;
	while((ucp_reg32_read(JS_PMA0_SRAM_STATUS) & BIT0) != BIT0);
	printf("pma step1 ok\n");
	
	for(i=0;i<16384;i++){
		ucp_reg32_write((JS_PMA0_CFG + 0xc000*4 + i*4), pma_fw[i]);
	}
	ucp_reg32_or_write((JS_PMA0_CFG + 0x101*4), BIT1);
	for(i=0;i<16384;i++){
		ucp_reg32_write((JS_PMA0_CFG + 0xc000*4 + i*4), pma_fw[i + 16384]);
	}
	// sram_ext_ld_done
	// r_rw1_sram_bootload_bypass <= c_wr_data[ 0];
	// r_rw1_sram_bypass          <= c_wr_data[ 4];
	// r_rw1_sram_ecc_en          <= c_wr_data[ 8];
	// r_rw1_sram_ext_ld_done     <= c_wr_data[12];
	ucp_reg32_or_write(JS_PMA0_SRAM_CTRL,                            BIT12); // sram bypass
	printf("sram_init_done\n");
	
// step 2 ------------------------------------------------------------------------------
    ucp4008_autoStepConfig(pConfig, 1, size);
    
    // Wait Ack Done
	while((ucp_reg32_read(JS_PMA0_LANE0_TRANSMITTER_REQ_ACK) & BIT0) || (ucp_reg32_read(JS_PMA0_LANE0_RECEIVER_REQ_ACK) & BIT0));
    while((ucp_reg32_read(JS_PMA0_LANE1_TRANSMITTER_REQ_ACK) & BIT0) || (ucp_reg32_read(JS_PMA0_LANE1_RECEIVER_REQ_ACK) & BIT0));
    while((ucp_reg32_read(JS_PMA0_LANE2_TRANSMITTER_REQ_ACK) & BIT0) || (ucp_reg32_read(JS_PMA0_LANE2_RECEIVER_REQ_ACK) & BIT0));
    while((ucp_reg32_read(JS_PMA0_LANE3_TRANSMITTER_REQ_ACK) & BIT0) || (ucp_reg32_read(JS_PMA0_LANE3_RECEIVER_REQ_ACK) & BIT0));
    printf("pma step2 ok\n");
    
// step 3 ------------------------------------------------------------------------------
    ucp4008_autoStepConfig(pConfig, 2, size);

    // Wait ACK and Disable Req
	while(!((ucp_reg32_read(JS_PMA0_LANE0_TRANSMITTER_REQ_ACK) & BIT0) || (ucp_reg32_read(JS_PMA0_LANE0_RECEIVER_REQ_ACK) & BIT0)));
    while(!((ucp_reg32_read(JS_PMA0_LANE1_TRANSMITTER_REQ_ACK) & BIT0) || (ucp_reg32_read(JS_PMA0_LANE1_RECEIVER_REQ_ACK) & BIT0)));
    while(!((ucp_reg32_read(JS_PMA0_LANE2_TRANSMITTER_REQ_ACK) & BIT0) || (ucp_reg32_read(JS_PMA0_LANE2_RECEIVER_REQ_ACK) & BIT0)));
    while(!((ucp_reg32_read(JS_PMA0_LANE3_TRANSMITTER_REQ_ACK) & BIT0) || (ucp_reg32_read(JS_PMA0_LANE3_RECEIVER_REQ_ACK) & BIT0)));
    printf("pma step3 ok\n");
    
// step 4 ------------------------------------------------------------------------------
    ucp4008_autoStepConfig(pConfig, 3, size);

    // Wait Ack Done
	while((ucp_reg32_read(JS_PMA0_LANE0_TRANSMITTER_REQ_ACK) & BIT0) || (ucp_reg32_read(JS_PMA0_LANE0_RECEIVER_REQ_ACK) & BIT0));
    while((ucp_reg32_read(JS_PMA0_LANE1_TRANSMITTER_REQ_ACK) & BIT0) || (ucp_reg32_read(JS_PMA0_LANE1_RECEIVER_REQ_ACK) & BIT0));
    while((ucp_reg32_read(JS_PMA0_LANE2_TRANSMITTER_REQ_ACK) & BIT0) || (ucp_reg32_read(JS_PMA0_LANE2_RECEIVER_REQ_ACK) & BIT0));
    while((ucp_reg32_read(JS_PMA0_LANE3_TRANSMITTER_REQ_ACK) & BIT0) || (ucp_reg32_read(JS_PMA0_LANE3_RECEIVER_REQ_ACK) & BIT0));
    printf("pma step4 ok\n");
    
// step 5 ------------------------------------------------------------------------------
    ucp4008_autoStepConfig(pConfig, 4, size);

    //Wait ACK and Disable Req
	while(!((ucp_reg32_read(JS_PMA0_LANE0_TRANSMITTER_REQ_ACK) & BIT0) && (ucp_reg32_read(JS_PMA0_LANE0_RECEIVER_REQ_ACK) & BIT0)));
    while(!((ucp_reg32_read(JS_PMA0_LANE1_TRANSMITTER_REQ_ACK) & BIT0) && (ucp_reg32_read(JS_PMA0_LANE1_RECEIVER_REQ_ACK) & BIT0)));
    while(!((ucp_reg32_read(JS_PMA0_LANE2_TRANSMITTER_REQ_ACK) & BIT0) && (ucp_reg32_read(JS_PMA0_LANE2_RECEIVER_REQ_ACK) & BIT0)));
    while(!((ucp_reg32_read(JS_PMA0_LANE3_TRANSMITTER_REQ_ACK) & BIT0) && (ucp_reg32_read(JS_PMA0_LANE3_RECEIVER_REQ_ACK) & BIT0)));
    printf("pma step5 ok\n");
    
// step 6 ------------------------------------------------------------------------------
    ucp4008_autoStepConfig(pConfig, 5, size);

    // Wait Ack Done
	while((ucp_reg32_read(JS_PMA0_LANE0_TRANSMITTER_REQ_ACK) & BIT0) || (ucp_reg32_read(JS_PMA0_LANE0_RECEIVER_REQ_ACK) & BIT0));
    while((ucp_reg32_read(JS_PMA0_LANE1_TRANSMITTER_REQ_ACK) & BIT0) || (ucp_reg32_read(JS_PMA0_LANE1_RECEIVER_REQ_ACK) & BIT0));
    while((ucp_reg32_read(JS_PMA0_LANE2_TRANSMITTER_REQ_ACK) & BIT0) || (ucp_reg32_read(JS_PMA0_LANE2_RECEIVER_REQ_ACK) & BIT0));
    while((ucp_reg32_read(JS_PMA0_LANE3_TRANSMITTER_REQ_ACK) & BIT0) || (ucp_reg32_read(JS_PMA0_LANE3_RECEIVER_REQ_ACK) & BIT0));
    printf("pma step6 ok\n");
    
// step 7 ------------------------------------------------------------------------------
    ucp4008_autoStepConfig(pConfig, 6, size);

    // JS PMA TX VALID
	while(ucp_reg32_read(JS_PMA0_LANE0_TRANS_PLL_STATE) == 0);

	while(ucp_reg32_read(JS_PMA0_LANE0_RX_VALID_PHY) == 0);
	while(ucp_reg32_read(JS_PMA0_LANE1_RX_VALID_PHY) == 0);
	while(ucp_reg32_read(JS_PMA0_LANE2_RX_VALID_PHY) == 0);
	while(ucp_reg32_read(JS_PMA0_LANE3_RX_VALID_PHY) == 0);
	printf("pma step7 ok\n");

	printf("pma ok\n");
}

void ucp4008_jesd204b_init (ucp_jesd_Init_t *setting)
{
    uint32_t tx_ratio  ;
	uint32_t rx0_ratio ;
	uint32_t rx1_ratio ;

	uint32_t tx_lmfc_lemc_delay  ;
	uint32_t rx0_lmfc_lemc_delay ;
	uint32_t rx1_lmfc_lemc_delay ;

	uint32_t jesd204L;

    //--------------------  Config comcore IP  ---------------------
    // Config jesd_sub0 comcore ip rx0
    if (setting->deframer[1].enable)
    {
        jesd204L =  GetL(setting->deframer[1].deserializerLanesEnabled);

        rx0_ratio = cal_ratio(JS_204B_RX0_CODING_T,  setting->deframer[1].jesd204M, JS_204B_RX0_S,  setting->deframer[1].jesd204Np,  setting->deframer[1].jesd204F, jesd204L, JS_204B_RX0_SONI);
        rx0_lmfc_lemc_delay = cal_lmfc_lemc_delay(JS_204B_RX0_CODING_T, setting->deframer[1].jesd204F, setting->deframer[1].jesd204K, JS_204B_RX0_E);

        //#JS_COMC_204B_RX0_BANK_ID          = 1                        ;
        ucp_reg32_write(JS_COMC_204B_RX0_BANK_ID,          1);    
        //#JS_COMC_204B_RX0_DID              = 1                        ;
        ucp_reg32_write(JS_COMC_204B_RX0_DID,              1);    
        //#JS_COMC_204B_RX0_SUBCLASS         = JS_204B_RX0_SUBCLASS   ;
        ucp_reg32_write(JS_COMC_204B_RX0_SUBCLASS,         JS_204B_RX0_SUBCLASS);    
        //#JS_COMC_204B_RX0_CF               = JS_204B_RX0_CF + (JS_204B_RX0_M<<18)  ;
        ucp_reg32_write(JS_COMC_204B_RX0_CF,               JS_204B_RX0_CF + (JS_204B_RX0_M<<18));    
        //#JS_COMC_204B_RX0_CS               = JS_204B_RX0_CS         ;
        ucp_reg32_write(JS_COMC_204B_RX0_CS,               JS_204B_RX0_CS);   
        //#JS_COMC_204B_RX0_F                = JS_204B_RX0_F      -1  ;
        ucp_reg32_write(JS_COMC_204B_RX0_F,                setting->deframer[1].jesd204F - 1);    
        //#JS_COMC_204B_RX0_K                = JS_204B_RX0_K      -1  ;
        ucp_reg32_write(JS_COMC_204B_RX0_K,                setting->deframer[1].jesd204K - 1);
        //#JS_COMC_204B_RX0_L                = JS_204B_RX0_L      -1  ;
        ucp_reg32_write(JS_COMC_204B_RX0_L,                jesd204L - 1);    
        //#JS_COMC_204B_RX0_N                = JS_204B_RX0_N      -1  ;
        ucp_reg32_write(JS_COMC_204B_RX0_N,                JS_204B_RX0_N - 1);   
        //#JS_COMC_204B_RX0_M                = JS_204B_RX0_M      -1  ;
        ucp_reg32_write(JS_COMC_204B_RX0_M,                setting->deframer[1].jesd204M - 1);    
        //#JS_COMC_204B_RX0_NTOTAL           = JS_204B_RX0_NTOTAL -1  ;
        ucp_reg32_write(JS_COMC_204B_RX0_NTOTAL,           setting->deframer[1].jesd204Np - 1);    
        //#JS_COMC_204B_RX0_S                = JS_204B_RX0_S      -1  ;
        ucp_reg32_write(JS_COMC_204B_RX0_S,                JS_204B_RX0_S - 1);    
        //#JS_COMC_204B_RX0_HD               = JS_204B_RX0_HD         ;
        ucp_reg32_write(JS_COMC_204B_RX0_HD,               JS_204B_RX0_HD);    
        //#JS_COMC_204B_RX0_SCR              = JS_204B_RX0_SCR        ;
        ucp_reg32_write(JS_COMC_204B_RX0_SCR,              JS_204B_RX0_SCR);    
        //#JS_COMC_204B_RX0_E                = JS_204B_RX0_E      -1  ;
        ucp_reg32_write(JS_COMC_204B_RX0_E,                setting->deframer[1].jesd204E - 1);
        //#JS_COMC_204B_RX0_S_ON_IF_REG      = (JS_204B_RX0_SONI-1) + (((JS_204B_RX0_S*(JS_204B_RX0_CODING_T ? 8:4))/JS_204B_RX0_SONI)<<5)   ;
        ucp_reg32_write(JS_COMC_204B_RX0_S_ON_IF_REG,      (JS_204B_RX0_SONI - 1) + (((JS_204B_RX0_S * (JS_204B_RX0_CODING_T ? 8 : 4)) / JS_204B_RX0_SONI) << 5));
        //#JS_COMC_204B_RX0_CLK_RATIO        = rx0_ratio                ;
        ucp_reg32_write(JS_COMC_204B_RX0_CLK_RATIO,        rx0_ratio);    
        //#JS_COMC_204B_RX0_LMFC_LEMC_DELAY  = rx0_lmfc_lemc_delay      ;
        ucp_reg32_write(JS_COMC_204B_RX0_LMFC_LEMC_DELAY,  rx0_lmfc_lemc_delay);
        //#JS_COMC_204B_RX0_ILAS_DETAILS     = 0x3000000+JS_204B_RX0_F*JS_204B_RX0_K   ;
        ucp_reg32_write(JS_COMC_204B_RX0_ILAS_DETAILS,     0x3000000 + setting->deframer[1].jesd204F *  setting->deframer[1].jesd204K);    
        //#JS_COMC_204B_RX0_FEC_EN           = JS_204B_RX0_FEC        ;
        ucp_reg32_write(JS_COMC_204B_RX0_FEC_EN,           JS_204B_RX0_FEC);    
        //#JS_COMC_204B_RX0_CRC3_EN          = JS_204B_RX0_CRC3       ;
        ucp_reg32_write(JS_COMC_204B_RX0_CRC3_EN,          JS_204B_RX0_CRC3);
        //#JS_COMC_204B_RX0_CRC12_EN         = JS_204B_RX0_CRC12      ;
        ucp_reg32_write(JS_COMC_204B_RX0_CRC12_EN,         JS_204B_RX0_CRC12);	
    }
    
    // Config jesd_sub0 comcore ip rx1
    if (setting->deframer[0].enable)
    {
        jesd204L =  GetL(setting->deframer[0].deserializerLanesEnabled);

        rx1_ratio = cal_ratio(JS_204B_RX1_CODING_T,  setting->deframer[0].jesd204M, JS_204B_RX1_S,  setting->deframer[0].jesd204Np,  setting->deframer[0].jesd204F, jesd204L, JS_204B_RX1_SONI);
        rx1_lmfc_lemc_delay = cal_lmfc_lemc_delay(JS_204B_RX1_CODING_T, setting->deframer[0].jesd204F, setting->deframer[0].jesd204K, JS_204B_RX1_E);

        //#JS_COMC_204B_RX1_BANK_ID          = 1                      ;
        ucp_reg32_write(JS_COMC_204B_RX1_BANK_ID,          1);
        //#JS_COMC_204B_RX1_DID              = 1                      ;
        ucp_reg32_write(JS_COMC_204B_RX1_DID,              1);
        //#JS_COMC_204B_RX1_SUBCLASS         = JS_204B_RX1_SUBCLASS   ;
        ucp_reg32_write(JS_COMC_204B_RX1_SUBCLASS,         JS_204B_RX1_SUBCLASS);
        //#JS_COMC_204B_RX1_CF               = JS_204B_RX1_CF + (JS_204B_RX1_M<<18)  ;
        ucp_reg32_write(JS_COMC_204B_RX1_CF,               JS_204B_RX1_CF + (JS_204B_RX1_M << 18));
        //#JS_COMC_204B_RX1_CS               = JS_204B_RX1_CS         ;
        ucp_reg32_write(JS_COMC_204B_RX1_CS,               JS_204B_RX1_CS);
        //#JS_COMC_204B_RX1_F                = JS_204B_RX1_F      -1  ;
        ucp_reg32_write(JS_COMC_204B_RX1_F,                setting->deframer[0].jesd204F - 1);
        //#JS_COMC_204B_RX1_K                = JS_204B_RX1_K      -1  ;
        ucp_reg32_write(JS_COMC_204B_RX1_K,                setting->deframer[0].jesd204K - 1);    
        //#JS_COMC_204B_RX1_L                = JS_204B_RX1_L      -1  ;
        ucp_reg32_write(JS_COMC_204B_RX1_L,                jesd204L - 1);  
        //#JS_COMC_204B_RX1_N                = JS_204B_RX1_N      -1  ;
        ucp_reg32_write(JS_COMC_204B_RX1_N,                JS_204B_RX1_N - 1);
        //#JS_COMC_204B_RX1_M                = JS_204B_RX1_M      -1  ;
        ucp_reg32_write(JS_COMC_204B_RX1_M,                setting->deframer[0].jesd204M - 1);
        //#JS_COMC_204B_RX1_NTOTAL           = JS_204B_RX1_NTOTAL -1  ;
        ucp_reg32_write(JS_COMC_204B_RX1_NTOTAL,           setting->deframer[0].jesd204Np - 1);
        //#JS_COMC_204B_RX1_S                = JS_204B_RX1_S      -1  ;
        ucp_reg32_write(JS_COMC_204B_RX1_S,                JS_204B_RX1_S - 1);
        //#JS_COMC_204B_RX1_HD               = JS_204B_RX1_HD         ;
        ucp_reg32_write(JS_COMC_204B_RX1_HD,               JS_204B_RX1_HD);
        //#JS_COMC_204B_RX1_SCR              = JS_204B_RX1_SCR        ;
        ucp_reg32_write(JS_COMC_204B_RX1_SCR,              JS_204B_RX1_SCR);
        //#JS_COMC_204B_RX1_E                = JS_204B_RX1_E      -1  ;
        ucp_reg32_write(JS_COMC_204B_RX1_E,                setting->deframer[0].jesd204E - 1);
        //#JS_COMC_204B_RX1_S_ON_IF_REG      = (JS_204B_RX1_SONI-1) + (((JS_204B_RX1_S*(JS_204B_RX1_CODING_T ? 8:4))/JS_204B_RX1_SONI)<<5)   ;
        ucp_reg32_write(JS_COMC_204B_RX1_S_ON_IF_REG,      (JS_204B_RX1_SONI - 1) + (((JS_204B_RX1_S * (JS_204B_RX1_CODING_T ? 8 : 4)) / JS_204B_RX1_SONI) << 5));
        //#JS_COMC_204B_RX1_CLK_RATIO        = rx1_ratio              ;
        ucp_reg32_write(JS_COMC_204B_RX1_CLK_RATIO,        rx1_ratio);
        //#JS_COMC_204B_RX1_LMFC_LEMC_DELAY  = rx1_lmfc_lemc_delay    ;
        ucp_reg32_write(JS_COMC_204B_RX1_LMFC_LEMC_DELAY,  rx1_lmfc_lemc_delay);
        //#JS_COMC_204B_RX1_ILAS_DETAILS     = 0x3000000+JS_204B_RX1_F*JS_204B_RX1_K   ;
        ucp_reg32_write(JS_COMC_204B_RX1_ILAS_DETAILS,     0x03000000 +  setting->deframer[0].jesd204F *  setting->deframer[0].jesd204K);
        //#JS_COMC_204B_RX1_FEC_EN           = JS_204B_RX1_FEC        ;
        ucp_reg32_write(JS_COMC_204B_RX1_FEC_EN,           JS_204B_RX1_FEC);
        //#JS_COMC_204B_RX1_CRC3_EN          = JS_204B_RX1_CRC3       ;
        ucp_reg32_write(JS_COMC_204B_RX1_CRC3_EN,          JS_204B_RX1_CRC3);
        //#JS_COMC_204B_RX1_CRC12_EN         = JS_204B_RX1_CRC12      ;
        ucp_reg32_write(JS_COMC_204B_RX1_CRC12_EN,         JS_204B_RX1_CRC12);
    }

    // Config jesd_sub0 comcore ip tx
    if (setting->framer.enable)
    {
        jesd204L =  GetL(setting->framer.serializerLanesEnabled);

        tx_ratio = cal_ratio(JS_204B_TX_CODING_T,  setting->framer.jesd204M, JS_204B_TX_S,  setting->framer.jesd204Np,  setting->framer.jesd204F,  jesd204L, JS_204B_TX_SONI);
        tx_lmfc_lemc_delay = cal_lmfc_lemc_delay(JS_204B_TX_CODING_T,  setting->framer.jesd204F,  setting->framer.jesd204K, JS_204B_TX_E);

        //#JS_COMC_204B_TX_BANK_ID           = 1                     ;
        ucp_reg32_write(JS_COMC_204B_TX_BANK_ID,           1);
        //#JS_COMC_204B_TX_DID               = 1                     ;
        ucp_reg32_write(JS_COMC_204B_TX_DID,               1);
        //#JS_COMC_204B_TX_SUBCLASS          = JS_204B_TX_SUBCLASS   ; 
        ucp_reg32_write(JS_COMC_204B_TX_SUBCLASS,          JS_204B_TX_SUBCLASS);
        //#JS_COMC_204B_TX_CF                = JS_204B_TX_CF + (JS_204B_TX_M<<18)  ; 
        ucp_reg32_write(JS_COMC_204B_TX_CF,                JS_204B_TX_CF + (JS_204B_TX_M << 18));
        //#JS_COMC_204B_TX_CS                = JS_204B_TX_CS         ;
        ucp_reg32_write(JS_COMC_204B_TX_CS,                JS_204B_TX_CS);
        //#JS_COMC_204B_TX_F                 = JS_204B_TX_F      -1  ; 
        ucp_reg32_write(JS_COMC_204B_TX_F,                setting->framer.jesd204F - 1);
        //#JS_COMC_204B_TX_K                 = JS_204B_TX_K      -1  ; 
        ucp_reg32_write(JS_COMC_204B_TX_K,                 setting->framer.jesd204K - 1);
        //#JS_COMC_204B_TX_L                 = JS_204B_TX_L      -1  ; 
        ucp_reg32_write(JS_COMC_204B_TX_L,                jesd204L - 1);  
        //#JS_COMC_204B_TX_N                 = JS_204B_TX_N      -1  ; 
        ucp_reg32_write(JS_COMC_204B_TX_N,                 JS_204B_TX_N - 1);
        //#JS_COMC_204B_TX_M                 = JS_204B_TX_M      -1  ; 
        ucp_reg32_write(JS_COMC_204B_TX_M,                 setting->framer.jesd204M - 1);
        //#JS_COMC_204B_TX_NTOTAL            = JS_204B_TX_NTOTAL -1  ; 
        ucp_reg32_write(JS_COMC_204B_TX_NTOTAL,            setting->framer.jesd204Np - 1);
        //#JS_COMC_204B_TX_S                 = JS_204B_TX_S      -1  ; 
        ucp_reg32_write(JS_COMC_204B_TX_S,                 JS_204B_TX_S - 1);
        //#JS_COMC_204B_TX_HD                = JS_204B_TX_HD         ; 
        ucp_reg32_write(JS_COMC_204B_TX_HD,                JS_204B_TX_HD);
        //#JS_COMC_204B_TX_SCR               = JS_204B_TX_SCR        ; 
        ucp_reg32_write(JS_COMC_204B_TX_SCR,               JS_204B_TX_SCR);
        //#JS_COMC_204B_TX_E                 = JS_204B_TX_E      -1  ; 
        ucp_reg32_write(JS_COMC_204B_TX_E,                 setting->framer.jesd204E - 1);
        //#JS_COMC_204B_TX_S_ON_IF_REG       = (JS_204B_TX_SONI-1) + (((JS_204B_TX_S*(JS_204B_TX_CODING_T ? 8:4))/JS_204B_TX_SONI)<<5)  ; 
        ucp_reg32_write(JS_COMC_204B_TX_S_ON_IF_REG,       (JS_204B_TX_SONI - 1) + (((JS_204B_TX_S * (JS_204B_TX_CODING_T ? 8 : 4)) / JS_204B_TX_SONI) << 5));
        //#JS_COMC_204B_TX_CLK_RATIO         = tx_ratio              ; 
        ucp_reg32_write(JS_COMC_204B_TX_CLK_RATIO,         tx_ratio);
        //#JS_COMC_204B_TX_TL_LATENCY        = 58                    ; 
        ucp_reg32_write(JS_COMC_204B_TX_TL_LATENCY,        58);
        //#JS_COMC_204B_TX_LMFC_LEMC_DELAY   = tx_lmfc_lemc_delay    ; 
        ucp_reg32_write(JS_COMC_204B_TX_LMFC_LEMC_DELAY,   tx_lmfc_lemc_delay);
        //#JS_COMC_204B_TX_ILAS_DETAILS      = 0x3000000+JS_204B_TX_F*JS_204B_TX_K  ; 
        ucp_reg32_write(JS_COMC_204B_TX_ILAS_DETAILS,      0x03000000 + setting->framer.jesd204F * setting->framer.jesd204K);
        //#JS_COMC_204B_TX_SAMPLE_REQ        = 0x0101                ;
        ucp_reg32_write(JS_COMC_204B_TX_SAMPLE_REQ,        0x0101);
        //#JS_COMC_204B_TX_FEC_EN            = JS_204B_TX_FEC        ; 
        ucp_reg32_write(JS_COMC_204B_TX_FEC_EN,            JS_204B_TX_FEC);
        //#JS_COMC_204B_TX_CRC3_EN           = JS_204B_TX_CRC3       ; 
        ucp_reg32_write(JS_COMC_204B_TX_CRC3_EN,           JS_204B_TX_CRC3);
        //#JS_COMC_204B_TX_CRC12_EN          = JS_204B_TX_CRC12      ; 
        ucp_reg32_write(JS_COMC_204B_TX_CRC12_EN,          JS_204B_TX_CRC12);
   }
    
    printf("jesd204B ok\n");

}

void ucp4008_jesd204c_init (ucp_jesd_Init_t *setting)
{
    uint32_t tx_ratio  ;
	uint32_t rx0_ratio ;
	uint32_t rx1_ratio ;

	uint32_t tx_lmfc_lemc_delay  ;
	uint32_t rx0_lmfc_lemc_delay ;
	uint32_t rx1_lmfc_lemc_delay ;

	uint32_t jesd204L;

    //--------------------  Config comcore IP  ---------------------
    // Config jesd_sub0 comcore ip rx0
    if (setting->deframer[0].enable)
    {
        jesd204L =  GetL(setting->deframer[0].deserializerLanesEnabled);

        // JS_204B_RX0_CODING_T
        rx0_ratio = cal_ratio(1,  setting->deframer[0].jesd204M, JS_204B_RX0_S,  setting->deframer[0].jesd204Np,  setting->deframer[0].jesd204F, jesd204L, JS_204B_RX0_SONI);
        //JS_204B_RX0_CODING_T
        rx0_lmfc_lemc_delay = cal_lmfc_lemc_delay(1, setting->deframer[0].jesd204F, setting->deframer[0].jesd204K, JS_204B_RX0_E);

        //#JS_COMC_204C_RX0_BANK_ID          = 1                        ;
        ucp_reg32_write(JS_COMC_204C_RX0_BANK_ID,          1);    
        //#JS_COMC_204C_RX0_DID              = 1                        ;
        ucp_reg32_write(JS_COMC_204C_RX0_DID,              1);    
        //#JS_COMC_204C_RX0_SUBCLASS         = JS_204B_RX0_SUBCLASS   ;
        ucp_reg32_write(JS_COMC_204C_RX0_SUBCLASS,         JS_204B_RX0_SUBCLASS);    
        //#JS_COMC_204C_RX0_CF               = JS_204B_RX0_CF + (JS_204B_RX0_M<<18)  ;
        ucp_reg32_write(JS_COMC_204C_RX0_CF,               JS_204B_RX0_CF + (JS_204B_RX0_M<<18));    
        //#JS_COMC_204C_RX0_CS               = JS_204B_RX0_CS         ;
        ucp_reg32_write(JS_COMC_204C_RX0_CS,               JS_204B_RX0_CS);   
        //#JS_COMC_204C_RX0_F                = JS_204B_RX0_F      -1  ;
        ucp_reg32_write(JS_COMC_204C_RX0_F,                setting->deframer[0].jesd204F - 1);    
        //#JS_COMC_204C_RX0_K                = JS_204B_RX0_K      -1  ;
        ucp_reg32_write(JS_COMC_204C_RX0_K,                setting->deframer[0].jesd204K - 1);
        //#JS_COMC_204C_RX0_L                = JS_204B_RX0_L      -1  ;
        ucp_reg32_write(JS_COMC_204C_RX0_L,                jesd204L - 1);    
        //#JS_COMC_204C_RX0_N                = JS_204B_RX0_N      -1  ;
        ucp_reg32_write(JS_COMC_204C_RX0_N,                JS_204B_RX0_N - 1);   
        //#JS_COMC_204C_RX0_M                = JS_204B_RX0_M      -1  ;
        ucp_reg32_write(JS_COMC_204C_RX0_M,                setting->deframer[0].jesd204M - 1);    
        //#JS_COMC_204C_RX0_NTOTAL           = JS_204B_RX0_NTOTAL -1  ;
        ucp_reg32_write(JS_COMC_204C_RX0_NTOTAL,           setting->deframer[0].jesd204Np - 1);    
        //#JS_COMC_204C_RX0_S                = JS_204B_RX0_S      -1  ;
        ucp_reg32_write(JS_COMC_204C_RX0_S,                JS_204B_RX0_S - 1);    
        //#JS_COMC_204C_RX0_HD               = JS_204B_RX0_HD         ;
        ucp_reg32_write(JS_COMC_204C_RX0_HD,               JS_204B_RX0_HD);    
        //#JS_COMC_204C_RX0_SCR              = JS_204B_RX0_SCR        ;
        ucp_reg32_write(JS_COMC_204C_RX0_SCR,              JS_204B_RX0_SCR);    
        //#JS_COMC_204C_RX0_E                = JS_204B_RX0_E      -1  ;
        ucp_reg32_write(JS_COMC_204C_RX0_E,                setting->deframer[0].jesd204E - 1);
        //#JS_COMC_204C_RX0_S_ON_IF_REG      = (JS_204B_RX0_SONI-1) + (((JS_204B_RX0_S*(JS_204B_RX0_CODING_T ? 8:4))/JS_204B_RX0_SONI)<<5)   ;
        ucp_reg32_write(JS_COMC_204C_RX0_S_ON_IF_REG,      (JS_204B_RX0_SONI - 1) + (((JS_204B_RX0_S * (JS_204B_RX0_CODING_T ? 8 : 4)) / JS_204B_RX0_SONI) << 5));
        //#JS_COMC_204C_RX0_CLK_RATIO        = rx0_ratio                ;
        ucp_reg32_write(JS_COMC_204C_RX0_CLK_RATIO,        rx0_ratio);    
        //#JS_COMC_204C_RX0_LMFC_LEMC_DELAY  = rx0_lmfc_lemc_delay      ;
        ucp_reg32_write(JS_COMC_204C_RX0_LMFC_LEMC_DELAY,  rx0_lmfc_lemc_delay);
        //#JS_COMC_204C_RX0_ILAS_DETAILS     = 0x3000000+JS_204B_RX0_F*JS_204B_RX0_K   ;
        ucp_reg32_write(JS_COMC_204C_RX0_ILAS_DETAILS,     0x3000000 + setting->deframer[0].jesd204F *  setting->deframer[0].jesd204K);    
        //#JS_COMC_204C_RX0_FEC_EN           = JS_204B_RX0_FEC        ;
        ucp_reg32_write(JS_COMC_204C_RX0_FEC_EN,           JS_204B_RX0_FEC);    
        //#JS_COMC_204C_RX0_CRC3_EN          = JS_204B_RX0_CRC3       ;
        ucp_reg32_write(JS_COMC_204C_RX0_CRC3_EN,          JS_204B_RX0_CRC3);
        //#JS_COMC_204C_RX0_CRC12_EN         = JS_204B_RX0_CRC12      ;
        ucp_reg32_write(JS_COMC_204C_RX0_CRC12_EN,         JS_204B_RX0_CRC12);	
    }
    
    // Config jesd_sub0 comcore ip rx1
    if (setting->deframer[1].enable)
    {
        jesd204L =  GetL(setting->deframer[1].deserializerLanesEnabled);

        rx1_ratio = cal_ratio(1,  setting->deframer[1].jesd204M, JS_204B_RX1_S,  setting->deframer[1].jesd204Np,  setting->deframer[1].jesd204F, jesd204L, JS_204B_RX1_SONI);
        rx1_lmfc_lemc_delay = cal_lmfc_lemc_delay(1, setting->deframer[1].jesd204F, setting->deframer[1].jesd204K, JS_204B_RX1_E);

        //#JS_COMC_204C_RX1_BANK_ID          = 1                      ;
        ucp_reg32_write(JS_COMC_204C_RX1_BANK_ID,          1);
        //#JS_COMC_204C_RX1_DID              = 1                      ;
        ucp_reg32_write(JS_COMC_204C_RX1_DID,              1);
        //#JS_COMC_204C_RX1_SUBCLASS         = JS_204B_RX1_SUBCLASS   ;
        ucp_reg32_write(JS_COMC_204C_RX1_SUBCLASS,         JS_204B_RX1_SUBCLASS);
        //#JS_COMC_204C_RX1_CF               = JS_204B_RX1_CF + (JS_204B_RX1_M<<18)  ;
        ucp_reg32_write(JS_COMC_204C_RX1_CF,               JS_204B_RX1_CF + (JS_204B_RX1_M << 18));
        //#JS_COMC_204C_RX1_CS               = JS_204B_RX1_CS         ;
        ucp_reg32_write(JS_COMC_204C_RX1_CS,               JS_204B_RX1_CS);
        //#JS_COMC_204C_RX1_F                = JS_204B_RX1_F      -1  ;
        ucp_reg32_write(JS_COMC_204C_RX1_F,                setting->deframer[1].jesd204F - 1);
        //#JS_COMC_204C_RX1_K                = JS_204B_RX1_K      -1  ;
        ucp_reg32_write(JS_COMC_204C_RX1_K,                setting->deframer[1].jesd204K - 1);    
        //#JS_COMC_204C_RX1_L                = JS_204B_RX1_L      -1  ;
        ucp_reg32_write(JS_COMC_204C_RX1_L,                jesd204L - 1);  
        //#JS_COMC_204C_RX1_N                = JS_204B_RX1_N      -1  ;
        ucp_reg32_write(JS_COMC_204C_RX1_N,                JS_204B_RX1_N - 1);
        //#JS_COMC_204C_RX1_M                = JS_204B_RX1_M      -1  ;
        ucp_reg32_write(JS_COMC_204C_RX1_M,                setting->deframer[1].jesd204M - 1);
        //#JS_COMC_204C_RX1_NTOTAL           = JS_204B_RX1_NTOTAL -1  ;
        ucp_reg32_write(JS_COMC_204C_RX1_NTOTAL,           setting->deframer[1].jesd204Np - 1);
        //#JS_COMC_204C_RX1_S                = JS_204B_RX1_S      -1  ;
        ucp_reg32_write(JS_COMC_204C_RX1_S,                JS_204B_RX1_S - 1);
        //#JS_COMC_204C_RX1_HD               = JS_204B_RX1_HD         ;
        ucp_reg32_write(JS_COMC_204C_RX1_HD,               JS_204B_RX1_HD);
        //#JS_COMC_204C_RX1_SCR              = JS_204B_RX1_SCR        ;
        ucp_reg32_write(JS_COMC_204C_RX1_SCR,              JS_204B_RX1_SCR);
        //#JS_COMC_204C_RX1_E                = JS_204B_RX1_E      -1  ;
        ucp_reg32_write(JS_COMC_204C_RX1_E,                setting->deframer[1].jesd204E - 1);
        //#JS_COMC_204C_RX1_S_ON_IF_REG      = (JS_204B_RX1_SONI-1) + (((JS_204B_RX1_S*(JS_204B_RX1_CODING_T ? 8:4))/JS_204B_RX1_SONI)<<5)   ;
        ucp_reg32_write(JS_COMC_204C_RX1_S_ON_IF_REG,      (JS_204B_RX1_SONI - 1) + (((JS_204B_RX1_S * (JS_204B_RX1_CODING_T ? 8 : 4)) / JS_204B_RX1_SONI) << 5));
        //#JS_COMC_204C_RX1_CLK_RATIO        = rx1_ratio              ;
        ucp_reg32_write(JS_COMC_204C_RX1_CLK_RATIO,        rx1_ratio);
        //#JS_COMC_204C_RX1_LMFC_LEMC_DELAY  = rx1_lmfc_lemc_delay    ;
        ucp_reg32_write(JS_COMC_204C_RX1_LMFC_LEMC_DELAY,  rx1_lmfc_lemc_delay);
        //#JS_COMC_204C_RX1_ILAS_DETAILS     = 0x3000000+JS_204B_RX1_F*JS_204B_RX1_K   ;
        ucp_reg32_write(JS_COMC_204C_RX1_ILAS_DETAILS,     0x03000000 +  setting->deframer[1].jesd204F *  setting->deframer[1].jesd204K);
        //#JS_COMC_204C_RX1_FEC_EN           = JS_204B_RX1_FEC        ;
        ucp_reg32_write(JS_COMC_204C_RX1_FEC_EN,           JS_204B_RX1_FEC);
        //#JS_COMC_204C_RX1_CRC3_EN          = JS_204B_RX1_CRC3       ;
        ucp_reg32_write(JS_COMC_204C_RX1_CRC3_EN,          JS_204B_RX1_CRC3);
        //#JS_COMC_204C_RX1_CRC12_EN         = JS_204B_RX1_CRC12      ;
        ucp_reg32_write(JS_COMC_204C_RX1_CRC12_EN,         JS_204B_RX1_CRC12);
    }

    // Config jesd_sub0 comcore ip tx
    if (setting->framer.enable)
    {
        jesd204L =  GetL(setting->framer.serializerLanesEnabled);

        tx_ratio = cal_ratio(1,  setting->framer.jesd204M, JS_204B_TX_S,  setting->framer.jesd204Np,  setting->framer.jesd204F,  jesd204L, JS_204B_TX_SONI);
        tx_lmfc_lemc_delay = cal_lmfc_lemc_delay(1,  setting->framer.jesd204F,  setting->framer.jesd204K, JS_204B_TX_E);

        //#JS_COMC_204C_TX_BANK_ID           = 1                     ;
        ucp_reg32_write(JS_COMC_204C_TX_BANK_ID,           1);
        //#JS_COMC_204C_TX_DID               = 1                     ;
        ucp_reg32_write(JS_COMC_204C_TX_DID,               1);
        //#JS_COMC_204C_TX_SUBCLASS          = JS_204B_TX_SUBCLASS   ; 
        ucp_reg32_write(JS_COMC_204C_TX_SUBCLASS,          JS_204B_TX_SUBCLASS);
        //#JS_COMC_204C_TX_CF                = JS_204B_TX_CF + (JS_204B_TX_M<<18)  ; 
        ucp_reg32_write(JS_COMC_204C_TX_CF,                JS_204B_TX_CF + (JS_204B_TX_M << 18));
        //#JS_COMC_204C_TX_CS                = JS_204B_TX_CS         ;
        ucp_reg32_write(JS_COMC_204C_TX_CS,                JS_204B_TX_CS);
        //#JS_COMC_204C_TX_F                 = JS_204B_TX_F      -1  ; 
        ucp_reg32_write(JS_COMC_204C_TX_F,                setting->framer.jesd204F - 1);
        //#JS_COMC_204C_TX_K                 = JS_204B_TX_K      -1  ; 
        ucp_reg32_write(JS_COMC_204C_TX_K,                 setting->framer.jesd204K - 1);
        //#JS_COMC_204C_TX_L                 = JS_204B_TX_L      -1  ; 
        ucp_reg32_write(JS_COMC_204C_TX_L,                jesd204L - 1);  
        //#JS_COMC_204C_TX_N                 = JS_204B_TX_N      -1  ; 
        ucp_reg32_write(JS_COMC_204C_TX_N,                 JS_204B_TX_N - 1);
        //#JS_COMC_204C_TX_M                 = JS_204B_TX_M      -1  ; 
        ucp_reg32_write(JS_COMC_204C_TX_M,                 setting->framer.jesd204M - 1);
        //#JS_COMC_204C_TX_NTOTAL            = JS_204B_TX_NTOTAL -1  ; 
        ucp_reg32_write(JS_COMC_204C_TX_NTOTAL,            setting->framer.jesd204Np - 1);
        //#JS_COMC_204C_TX_S                 = JS_204B_TX_S      -1  ; 
        ucp_reg32_write(JS_COMC_204C_TX_S,                 JS_204B_TX_S - 1);
        //#JS_COMC_204C_TX_HD                = JS_204B_TX_HD         ; 
        ucp_reg32_write(JS_COMC_204C_TX_HD,                JS_204B_TX_HD);
        //#JS_COMC_204C_TX_SCR               = JS_204B_TX_SCR        ; 
        ucp_reg32_write(JS_COMC_204C_TX_SCR,               JS_204B_TX_SCR);
        //#JS_COMC_204C_TX_E                 = JS_204B_TX_E      -1  ; 
        ucp_reg32_write(JS_COMC_204C_TX_E,                 setting->framer.jesd204E - 1);
        //#JS_COMC_204C_TX_S_ON_IF_REG       = (JS_204B_TX_SONI-1) + (((JS_204B_TX_S*(JS_204B_TX_CODING_T ? 8:4))/JS_204B_TX_SONI)<<5)  ; 
        ucp_reg32_write(JS_COMC_204C_TX_S_ON_IF_REG,       (JS_204B_TX_SONI - 1) + (((JS_204B_TX_S * (JS_204B_TX_CODING_T ? 8 : 4)) / JS_204B_TX_SONI) << 5));
        //#JS_COMC_204C_TX_CLK_RATIO         = tx_ratio              ; 
        ucp_reg32_write(JS_COMC_204C_TX_CLK_RATIO,         tx_ratio);
        //#JS_COMC_204C_TX_TL_LATENCY        = 58                    ; 
        ucp_reg32_write(JS_COMC_204C_TX_TL_LATENCY,        58);
        //#JS_COMC_204C_TX_LMFC_LEMC_DELAY   = tx_lmfc_lemc_delay    ; 
        ucp_reg32_write(JS_COMC_204C_TX_LMFC_LEMC_DELAY,   tx_lmfc_lemc_delay);
        //#JS_COMC_204C_TX_ILAS_DETAILS      = 0x3000000+JS_204B_TX_F*JS_204B_TX_K  ; 
        ucp_reg32_write(JS_COMC_204C_TX_ILAS_DETAILS,      0x03000000 + setting->framer.jesd204F * setting->framer.jesd204K);
        //#JS_COMC_204C_TX_SAMPLE_REQ        = 0x0101                ;
        ucp_reg32_write(JS_COMC_204C_TX_SAMPLE_REQ,        0x0101);
        //#JS_COMC_204C_TX_FEC_EN            = JS_204B_TX_FEC        ; 
        ucp_reg32_write(JS_COMC_204C_TX_FEC_EN,            JS_204B_TX_FEC);
        //#JS_COMC_204C_TX_CRC3_EN           = JS_204B_TX_CRC3       ; 
        ucp_reg32_write(JS_COMC_204C_TX_CRC3_EN,           JS_204B_TX_CRC3);
        //#JS_COMC_204C_TX_CRC12_EN          = JS_204B_TX_CRC12      ; 
        ucp_reg32_write(JS_COMC_204C_TX_CRC12_EN,          JS_204B_TX_CRC12);
   }
    
    printf("jesd204C ok\n");

}


void ucp4008_jesd_timer_init (void)
{
    //-------------------------  Timer-204  --------------------------
	// RX0_TMR -- ORX_204C + RX_204B
	// RX1_TMR -- ORX_204B + RX_204C
	// TX0_TMR -- TX_204B
	// TX1_TMR -- TX_204C
	// ctrl_oe      <= wdata_i[0];  // RX_EN, TX_EN, ...
	// ctrl_sel     <= wdata_i[1];  // 0->reg, 1->tmr
	// rx_scrath_en <= wdata_i[2];
	// tx_scrath_en <= wdata_i[3];
	//#JS_RX0_PIN_CTRL_REG = 0xD;
	//#JS_RX1_PIN_CTRL_REG = 0xD;
	//#JS_TX0_PIN_CTRL_REG = 0xD;
	ucp_reg32_write(JS_RX0_PIN_CTRL_REG,                0x0D);
	ucp_reg32_write(JS_RX1_PIN_CTRL_REG,                0x0D);
	ucp_reg32_write(JS_TX0_PIN_CTRL_REG,                0x0D);
	
	// io_rxen0_reg <= wdata_i[0];
	// io_txen0_reg <= wdata_i[1];
	// io_rxen1_reg <= wdata_i[2];
	// io_txen1_reg <= wdata_i[3];
	// io_rxen2csu_reg <= wdata_i[4];
	// io_txen2csu_reg <= wdata_i[5];
	//#JS_RX0_IO_CTRL_REG = 0x10;
	//#JS_RX1_IO_CTRL_REG = 0x10;
	//#JS_TX0_IO_CTRL_REG = 0x20;
	ucp_reg32_write(JS_RX0_IO_CTRL_REG,                 0x10);
	ucp_reg32_write(JS_RX1_IO_CTRL_REG,                 0x10);
	ucp_reg32_write(JS_TX0_IO_CTRL_REG,                 0x10);

	return;
}

void ucp4008_jesd204b_bringup (void)
{
    ucp_reg32_write(JS_COMC_204B_RX0_ENABLEMODULE, 0x1);
    ucp_reg32_write(JS_COMC_204B_RX1_ENABLEMODULE, 0x1);
    ucp_reg32_write(JS_COMC_204B_TX_ENABLEMODULE, 0x1);
    printf("enable jesd\n");

}

static uint8_t ucp4008_jesd_calSamClkDiv (uint8_t is204C, uint8_t f)
{
    double   factD, divPara;

    divPara = (is204C) ? 8.0 : 4.0;
    factD = divPara/f;

    if (((factD > 0.0) && (factD < 1.0)) || (fabs(factD - 1.0) < DBL_EPSILON))
    {
        return 1;
    }

    if (((factD > 1.0) && (factD < 2.0)) || (fabs(factD - 2.0) < DBL_EPSILON))
    {
        return 2;
    }

    if (((factD > 2.0) && (factD < 4.0)) || (fabs(factD - 4.0) < DBL_EPSILON))
    {
        return 4;
    }

    if (((factD > 4.0) && (factD < 8.0)) || (fabs(factD - 8.0) < DBL_EPSILON))
    {
        return 8;
    }

    printf("error: invalid samClk divFact\n");
    exit(1);
    return 0;
}

static void ucp4008_jesd_calLarate (ucp_jesd_Init_t *setting)
{
    uint8_t jesd204L, samClkFactor, chaClkFactor, samClkDiv;
    uint32_t pllClk, samClk, chaClk;

    ucp_reg32_write(UCP_JESDPARA_RX0, 0);
    ucp_reg32_write(UCP_CLKPARA0_RX0, 0); 
    ucp_reg32_write(UCP_CLKPARA1_RX0, 0); 
    ucp_reg32_write(UCP_JESDPARA_RX1, 0);
    ucp_reg32_write(UCP_CLKPARA0_RX1, 0); 
    ucp_reg32_write(UCP_CLKPARA1_RX1, 0); 
    ucp_reg32_write(UCP_JESDPARA_TX0, 0);
    ucp_reg32_write(UCP_CLKPARA0_TX0, 0); 
    ucp_reg32_write(UCP_CLKPARA1_TX0, 0); 
    ucp_reg32_write(UCP_JESDPARA_TX1, 0);
    ucp_reg32_write(UCP_CLKPARA0_TX1, 0); 
    ucp_reg32_write(UCP_CLKPARA1_TX1, 0); 
    
    sampleFactor[0] = SAMPLE_FACTOR_1_1;
    sampleFactor[1] = SAMPLE_FACTOR_1_1;
    sampleFactor[2] = SAMPLE_FACTOR_1_1;
    sampleFactor[3] = SAMPLE_FACTOR_1_1;

    pllFactor = UCP_PLL_FACT; // range: 2/4/8
    pllClk = pllFactor*setting->common.devClock_kHz*1e3;
    printf("deviceClk: %.4fMhz\n", setting->common.devClock_kHz*1e-3);
    printf("pllClk:    %.4fMhz\n", pllClk*1e-6);
    if (0 == setting->common.enableJesd204C) // is JESD204B
    {
       jesd204L =  GetL(setting->framer.serializerLanesEnabled);
       if (jesd204L > 0)
       {
            frameLaneRate = setting->framer.sampleClock_kHz*1e3*setting->framer.jesd204M*setting->framer.jesd204Np*JS_204B_TX_S*10/8/jesd204L;
            chaClk = frameLaneRate/40;                   // chaClk
            chaClkFactor = chaClk/setting->framer.sampleClock_kHz/1000;
            samClkDiv = ucp4008_jesd_calSamClkDiv(setting->common.enableJesd204C ,setting->framer.jesd204F);
            samClk = chaClk*samClkDiv;                   // samClk
            samClkFactor = samClk/setting->framer.sampleClock_kHz/1000;
            sampleFactor[2] = pllClk/samClk;

            ucp_reg32_write(UCP_JESDPARA_TX0, (jesd204L | (setting->framer.jesd204M << 8) | (setting->framer.jesd204Np << 16)));
            ucp_reg32_write(UCP_CLKPARA0_TX0, setting->framer.sampleClock_kHz*1e3); 
            ucp_reg32_write(UCP_CLKPARA1_TX0, (chaClkFactor << 8) | samClkFactor); 
            printf("jesd frameLaneRate:    %.8fGhz\n", frameLaneRate*1.0/1e9);
            printf("jesd frameLane:        %d            %04X\n", jesd204L, setting->framer.serializerLanesEnabled);
            printf("sampleClk: %.4fMhz  SAM: %.4fMhz(Ssf: %d)  CHA: %.4fMhz(Csf: %d)  PSf: %d\n",  
                    setting->framer.sampleClock_kHz*0.001, 
                    samClk*0.000001, samClkFactor,
                    chaClk*0.000001, chaClkFactor,
                    sampleFactor[2]);
       }

       jesd204L =  GetL(setting->deframer[0].deserializerLanesEnabled);
       if (jesd204L > 0)
       {
            deframe0LaneRate = setting->deframer[0].sampleClock_kHz*1e3*setting->deframer[0].jesd204M*setting->deframer[0].jesd204Np*JS_204B_RX0_S*10/8/jesd204L;
            chaClk = deframe0LaneRate/40;                   // chaClk
            chaClkFactor = chaClk/setting->deframer[0].sampleClock_kHz/1000;
            samClkDiv = ucp4008_jesd_calSamClkDiv(setting->common.enableJesd204C ,setting->deframer[0].jesd204F);
            samClk = chaClk*samClkDiv;                      // samClk
            samClkFactor = samClk/setting->deframer[0].sampleClock_kHz/1000;
            sampleFactor[0] = pllClk/samClk;
            
            ucp_reg32_write(UCP_JESDPARA_RX0, (jesd204L | (setting->deframer[0].jesd204M << 8) | (setting->deframer[0].jesd204Np << 16)));
            ucp_reg32_write(UCP_CLKPARA0_RX0, setting->deframer[0].sampleClock_kHz*1e3); 
            ucp_reg32_write(UCP_CLKPARA1_RX0, (chaClkFactor << 8) | samClkFactor); 
            ucp_reg32_write(UCP_JESDPARA_RX1, (jesd204L | (setting->deframer[0].jesd204M << 8) | (setting->deframer[0].jesd204Np << 16)));
            ucp_reg32_write(UCP_CLKPARA0_RX1, setting->deframer[0].sampleClock_kHz*1e3); 
            ucp_reg32_write(UCP_CLKPARA1_RX1, (chaClkFactor << 8) | samClkFactor); 
            printf("jesd deframe0LaneRate: %.8fGhz\n", deframe0LaneRate*1.0/1e9);
            printf("jesd deframeLane:      %d            %04X\n", jesd204L, setting->deframer[0].deserializerLanesEnabled);
            printf("sampleClk: %.4fMhz  SAM: %.4fMhz(Ssf: %d)  CHA: %.4fMhz(Csf: %d)  PSf: %d\n", 
                    setting->deframer[0].sampleClock_kHz*0.001, 
                    samClk*0.000001, samClkFactor,
                    chaClk*0.000001, chaClkFactor,
                    sampleFactor[0]);
       }

       jesd204L =  GetL(setting->deframer[1].deserializerLanesEnabled);
       if (jesd204L > 0)
       {
            deframe1LaneRate = setting->deframer[1].sampleClock_kHz*1e3*setting->deframer[1].jesd204M*setting->deframer[1].jesd204Np*JS_204B_RX1_S*10/8/jesd204L;
            chaClk = deframe1LaneRate/40;                   // chaClk
            chaClkFactor = chaClk/setting->deframer[1].sampleClock_kHz/1000;
            samClkDiv = ucp4008_jesd_calSamClkDiv(setting->common.enableJesd204C ,setting->deframer[1].jesd204F);
            samClk = chaClk*samClkDiv;                      // samClk
            samClkFactor = samClk/setting->deframer[1].sampleClock_kHz/1000;
            sampleFactor[1] = pllClk/samClk;
            
            ucp_reg32_write(UCP_JESDPARA_RX1, (jesd204L | (setting->deframer[1].jesd204M << 8) | (setting->deframer[1].jesd204Np << 16)));
            ucp_reg32_write(UCP_CLKPARA0_RX1, setting->deframer[1].sampleClock_kHz*1e3); 
            ucp_reg32_write(UCP_CLKPARA1_RX1, (chaClkFactor << 8) | samClkFactor); 
            printf("jesd deframe1LaneRate: %.8fGhz\n", deframe1LaneRate*1.0/1e9);
            printf("jesd deframeLane:      %d            %04X\n", jesd204L, setting->deframer[1].deserializerLanesEnabled);
            printf("sampleClk: %.4fMhz  SAM: %.4fMhz(Ssf: %d)  CHA: %.4fMhz(Csf: %d)  PSf: %d\n",  
                    setting->deframer[1].sampleClock_kHz*0.001, 
                    samClk*0.000001, samClkFactor,
                    chaClk*0.000001, chaClkFactor,
                    sampleFactor[1]);
       }
    }
    else // is JESD204C
    {
       jesd204L =  GetL(setting->framer.serializerLanesEnabled);
       if (jesd204L > 0)
       {
            frameLaneRate   = setting->framer.sampleClock_kHz*1e3*setting->framer.jesd204M*setting->framer.jesd204Np*JS_204B_TX_S*66/64/jesd204L;
            chaClk = frameLaneRate/66;                   // chaClk
            chaClkFactor = chaClk/setting->framer.sampleClock_kHz/1000;
            samClkDiv = ucp4008_jesd_calSamClkDiv(setting->common.enableJesd204C ,setting->framer.jesd204F);
            samClk = chaClk*samClkDiv;                   // samClk
            samClkFactor = samClk/setting->framer.sampleClock_kHz/1000;
            sampleFactor[2] = pllClk/samClk;
            
            ucp_reg32_write(UCP_JESDPARA_TX0, (jesd204L | (setting->framer.jesd204M << 8) | (setting->framer.jesd204Np << 16)));
            ucp_reg32_write(UCP_CLKPARA0_TX0, setting->framer.sampleClock_kHz*1e3); 
            ucp_reg32_write(UCP_CLKPARA1_TX0, (chaClkFactor << 8) | samClkFactor); 
            printf("jesd frameLaneRate:    %.8fGhz\n", frameLaneRate*1.0/1e9);
            printf("jesd frameLane:        %d            %04X\n", jesd204L, setting->framer.serializerLanesEnabled);
            printf("sampleClk: %.4fMhz  SAM: %.4fMhz(Ssf: %d)  CHA: %.4fMhz(Csf: %d)  PSf: %d\n",  
                    setting->framer.sampleClock_kHz*0.001, 
                    samClk*0.000001, samClkFactor,
                    chaClk*0.000001, chaClkFactor,
                    sampleFactor[2]);
       }

       jesd204L =  GetL(setting->deframer[0].deserializerLanesEnabled);
       if (jesd204L > 0)
       {
            deframe0LaneRate = setting->deframer[0].sampleClock_kHz*1e3*setting->deframer[0].jesd204M*setting->deframer[0].jesd204Np*JS_204B_RX0_S*66/64/jesd204L;
            chaClk = deframe0LaneRate/66;                   // chaClk
            chaClkFactor = chaClk/setting->deframer[0].sampleClock_kHz/1000;
            samClkDiv = ucp4008_jesd_calSamClkDiv(setting->common.enableJesd204C ,setting->deframer[0].jesd204F);
            samClk = chaClk*samClkDiv;                      // samClk
            samClkFactor = samClk/setting->deframer[0].sampleClock_kHz/1000;
            sampleFactor[0] = pllClk/samClk;
            
            ucp_reg32_write(UCP_JESDPARA_RX0, (jesd204L | (setting->deframer[0].jesd204M << 8) | (setting->deframer[0].jesd204Np << 16)));
            ucp_reg32_write(UCP_CLKPARA0_RX0, setting->deframer[0].sampleClock_kHz*1e3); 
            ucp_reg32_write(UCP_CLKPARA1_RX0, (chaClkFactor << 8) | samClkFactor); 
            ucp_reg32_write(UCP_JESDPARA_RX1, (jesd204L | (setting->deframer[0].jesd204M << 8) | (setting->deframer[0].jesd204Np << 16)));
            ucp_reg32_write(UCP_CLKPARA0_RX1, setting->deframer[0].sampleClock_kHz*1e3); 
            ucp_reg32_write(UCP_CLKPARA1_RX1, (chaClkFactor << 8) | samClkFactor); 
            printf("jesd deframe0LaneRate: %.8fGhz\n", deframe0LaneRate*1.0/1e9);
            printf("jesd deframeLane:      %d            %04X\n", jesd204L, setting->deframer[0].deserializerLanesEnabled);
            printf("sampleClk: %.4fMhz  SAM: %.4fMhz(Ssf: %d)  CHA: %.4fMhz(Csf: %d)  PSf: %d\n", 
                    setting->deframer[0].sampleClock_kHz*0.001, 
                    samClk*0.000001, samClkFactor,
                    chaClk*0.000001, chaClkFactor,
                    sampleFactor[0]);
       }

       jesd204L =  GetL(setting->deframer[1].deserializerLanesEnabled);
       if (jesd204L > 0)
       {
            deframe1LaneRate = setting->deframer[1].sampleClock_kHz*1e3*setting->deframer[1].jesd204M*setting->deframer[1].jesd204Np*JS_204B_RX1_S*66/64/jesd204L;
            chaClk = deframe1LaneRate/66;                   // chaClk
            chaClkFactor = chaClk/setting->deframer[1].sampleClock_kHz/1000;
            samClkDiv = ucp4008_jesd_calSamClkDiv(setting->common.enableJesd204C ,setting->deframer[1].jesd204F);
            samClk = chaClk*samClkDiv;                      // samClk
            samClkFactor = samClk/setting->deframer[1].sampleClock_kHz/1000;
            sampleFactor[1] = pllClk/samClk;
            
            ucp_reg32_write(UCP_JESDPARA_RX1, (jesd204L | (setting->deframer[1].jesd204M << 8) | (setting->deframer[1].jesd204Np << 16)));
            ucp_reg32_write(UCP_CLKPARA0_RX1, setting->deframer[1].sampleClock_kHz*1e3); 
            ucp_reg32_write(UCP_CLKPARA1_RX1, (chaClkFactor << 8) | samClkFactor); 
            printf("jesd deframe1LaneRate: %.8fGhz\n", deframe1LaneRate*1.0/1e9);
            printf("jesd deframeLane:      %d            %04X\n", jesd204L, setting->deframer[1].deserializerLanesEnabled);
            printf("sampleClk: %.4fMhz  SAM: %.4fMhz(Ssf: %d)  CHA: %.4fMhz(Csf: %d)  PSf: %d\n", 
                    setting->deframer[1].sampleClock_kHz*0.001, 
                    samClk*0.000001, samClkFactor,
                    chaClk*0.000001, chaClkFactor,
                    sampleFactor[1]);
       }
   }

   return;
}

static void ucp4008_autoStepConfig (tUcpAutoConfigPara_t *para, uint32_t step, uint32_t size)
{
    uint32_t i;

    for (i = 0; i < size; i++)
    {
        if (para[i].step != step)
        {
            continue;
        }
    
        switch (para[i].opt)
        {
            case UCP_OPT_SKIP:
                break;

            case UCP_OPT_W:
                ucp_reg32_write(para[i].addr, para[i].value);
                break;
            
            case UCP_OPT_ANDW:
                ucp_reg32_and_write(para[i].addr, para[i].value);
                break;
                
            case UCP_OPT_ORW:
                ucp_reg32_or_write(para[i].addr, para[i].value);
                break;
               
            default:
                break;
             
        }
    }

    return;
}

static void ucp4008_jesd_crg_print (void)
{
    PrintUcpReg(JS_CRG_TMR_EN_SAM_CLK_SEL);
    PrintUcpReg(JS_CRG_CLK_SEL);
    PrintUcpReg(JS_CRG_DPLL0_CTRL_0);  // 
    PrintUcpReg(JS_CRG_DPLL0_CTRL_1); // 
    PrintUcpReg(JS_CRG_SAM0_CLK_CTRL);
    PrintUcpReg(JS_CRG_SAM1_CLK_CTRL);
    PrintUcpReg(JS_CRG_SAM2_CLK_CTRL);
    PrintUcpReg(JS_CRG_SAM3_CLK_CTRL);
    PrintUcpReg(JS_CRG_CHA0_CLK_CTRL);
    PrintUcpReg(JS_CRG_CHA1_CLK_CTRL);
    PrintUcpReg(JS_CRG_CHA2_CLK_CTRL);
    PrintUcpReg(JS_CRG_CHA3_CLK_CTRL);
    PrintUcpReg(JS_CRG_SAM_CHA0_RST_CTRL);
    PrintUcpReg(JS_CRG_SAM_CHA1_RST_CTRL);
    PrintUcpReg(JS_CRG_SAM_CHA2_RST_CTRL);
    PrintUcpReg(JS_CRG_SAM_CHA3_RST_CTRL);
    PrintUcpReg(JS_CRG_SAM_CHA4_RST_CTRL);
    PrintUcpReg(JS_CRG_SAM_CHA5_RST_CTRL);
    PrintUcpReg(JS_CRG_SAM_CHA6_RST_CTRL);
    PrintUcpReg(JS_CRG_SAM_CHA7_RST_CTRL);
    PrintUcpReg(JS_CRG_JESD0_TIME_CTRL);
    PrintUcpReg(JS_CRG_JESD1_TIME_CTRL);
    PrintUcpReg(JS_CRG_JESD2_TIME_CTRL);
    PrintUcpReg(JS_CRG_JESD3_TIME_CTRL);
    PrintUcpReg(JS_CRG_JESD4_TIME_CTRL);
    PrintUcpReg(JS_CRG_JESD5_TIME_CTRL);
    PrintUcpReg(JS_CRG_JESD6_TIME_CTRL);
    PrintUcpReg(JS_CRG_JESD7_TIME_CTRL);
    PrintUcpReg(JS_CRG_PHY_TX_RSTN_JS_CTRL_0);
    PrintUcpReg(JS_CRG_PHY_TX_RSTN_JS_CTRL_1);
    PrintUcpReg(JS_CRG_PHY_TX_RSTN_JS_CTRL_2);
    PrintUcpReg(JS_CRG_PHY_TX_RSTN_JS_CTRL_3);
    PrintUcpReg(JS_CRG_PHY_RX_RSTN_JS_CTRL_0);
    PrintUcpReg(JS_CRG_PHY_RX_RSTN_JS_CTRL_1);
    PrintUcpReg(JS_CRG_PHY_RX_RSTN_JS_CTRL_2);
    PrintUcpReg(JS_CRG_PHY_RX_RSTN_JS_CTRL_3);
    PrintUcpReg(JS_CRG_PHY_EQ_RSTN_JS_CTRL_0);
    PrintUcpReg(JS_CRG_PHY_EQ_RSTN_JS_CTRL_1);
    PrintUcpReg(JS_CRG_PHY_EQ_RSTN_JS_CTRL_2);
    PrintUcpReg(JS_CRG_PHY_EQ_RSTN_JS_CTRL_3);
    PrintUcpReg(JS_CRG_PHY_PWR_ON_RST_JS_CTRL);
    PrintUcpReg(JS_CRG_DPLL_PMA_CTRL);       // 
    PrintUcpReg(JS_CRG_DPLL_PMA_CTRL);       // read
    PrintUcpReg(JS_CRG_TMR_EN_SAM_CLK_SEL); // 

    return;
}

static void ucp4008_jesd_pma_print (void)
{
    // step 1
    PrintUcpReg(JS_PMA0_PHY_RESET);                            
    PrintUcpReg(JS_PMA0_PCS_BIT_REV_CTRL);                     
    PrintUcpReg(JS_PMA0_SRAM_CTRL);                            
    PrintUcpReg(JS_PMA0_TX_CLK_SEL);                           
    PrintUcpReg(JS_PMA0_REFA_CLK_CTRL2);                      
    PrintUcpReg(JS_PMA0_REF_CLK_CTRL);                         
    PrintUcpReg(JS_PMA0_MPLLA_PARAM6);                         
    PrintUcpReg(JS_PMA0_MPLLA_PARAM4);                        
    PrintUcpReg(JS_PMA0_MPLLA_PARAM5);                         
    PrintUcpReg(JS_PMA0_MPLLA_SSC_CTRL1);                      
    PrintUcpReg(JS_PMA0_MPLLA_SSC_CTRL4);                      
    PrintUcpReg(JS_PMA0_MPLLA_SSC_CTRL2);                      
    PrintUcpReg(JS_PMA0_MPLLA_SSC_CTRL3);                      
    PrintUcpReg(JS_PMA0_MPLLA_SSC_CTRL5);                      
    PrintUcpReg(JS_PMA0_MPLLA_SSC_CTRL6);                      
    PrintUcpReg(JS_PMA0_MPLLA_FRAC_CTRL2);                     
    PrintUcpReg(JS_PMA0_MPLLA_FRAC_CTRL3);                     
    PrintUcpReg(JS_PMA0_MPLLA_FRAC_CTRL1);                     
    PrintUcpReg(JS_PMA0_MPLLA_FRAC_CTRL4);                     
    PrintUcpReg(JS_PMA0_MPLLA_PARAM3);                        
    PrintUcpReg(JS_PMA0_MPLLA_PARAM2);                         
    PrintUcpReg(JS_PMA0_MPLLA_PARAM1);                         
    PrintUcpReg(JS_PHY_BS_CTRL);                               
    PrintUcpReg(JS_PMA0_RTUNE_CTRL1);                          
    PrintUcpReg(JS_PMA0_RTUNE_CTRL2);                          
    PrintUcpReg(JS_PMA0_RTUNE_CTRL3);                         
    PrintUcpReg(JS_PMA0_SUP_MISC);                             
    PrintUcpReg(JS_PMA0_RX_BIAS_CURRENT_CTRL);                 
    PrintUcpReg(JS_PMA0_BROADCAST_LANE_REFCLK_SEL);            
    PrintUcpReg(JS_PMA0_BROADCAST_RECEIVER_REQ_PARAM8);        
    PrintUcpReg(JS_PMA0_BROADCAST_RECEIVER_DATAPATH_SETTING1); 
    PrintUcpReg(JS_PMA0_BROADCAST_TRANSMITTER_CONTROL2);      
    PrintUcpReg(JS_PMA0_BROADCAST_TRANS_REQ_CTRL1);           
    PrintUcpReg(JS_PMA0_BROADCAST_TRANSMITTER_REQ_PARAM2);     
    PrintUcpReg(JS_PMA0_BROADCAST_TRANS_REQ_CTRL2);            
    PrintUcpReg(JS_PMA0_BROADCAST_TRANS_REQ_CTRL4);           
    PrintUcpReg(JS_PMA0_BROADCAST_TRANS_REQ_CTRL5);            
    PrintUcpReg(JS_PMA0_BROADCAST_ETH_CLK_CTRL);               
    PrintUcpReg(JS_PMA0_BROADCAST_TRANS_INTERFACE_CTRL);      
    PrintUcpReg(JS_PMA0_BROADCAST_TX_DIV_CLK_CTRL);            
    PrintUcpReg(JS_PMA0_BROADCAST_CONTEXT_RESTORE_CTRL3);      
    PrintUcpReg(JS_PMA0_BROADCAST_TRANS_REQ_CTRL3);           
    PrintUcpReg(JS_PMA0_BROADCAST_TRANSMITTER_DATAPATH_SETTING);
    PrintUcpReg(JS_PMA0_BROADCAST_RECEIVER_REQ_PARAM3);        
    PrintUcpReg(JS_PMA0_BROADCAST_RECEIVER_REQ_PARAM4);       
    PrintUcpReg(JS_PMA0_BROADCAST_RX_EQ_CTRL2);              
    PrintUcpReg(JS_PMA0_BROADCAST_RX_EQ_CTRL1);               
    PrintUcpReg(JS_PMA0_BROADCAST_RECEIVER_REQ_PARAM5);       
    PrintUcpReg(JS_PMA0_BROADCAST_RECEIVER_REQ_PARAM2);        
    PrintUcpReg(JS_PMA0_BROADCAST_RX_DCC_CTRL);                
    PrintUcpReg(JS_PMA0_BROADCAST_RECEIVER_DATAPATH_SETTING2); 
    PrintUcpReg(JS_PMA0_BROADCAST_RECEIVER_REQ_PARAM6);       
    PrintUcpReg(JS_PMA0_BROADCAST_RECEIVER_CONTROL);           
    PrintUcpReg(JS_PMA0_BROADCAST_RECEIVER_REQ_PARAM9);       
    PrintUcpReg(JS_PMA0_BROADCAST_RX_DIV_CLK_CTRL);            
    PrintUcpReg(JS_PMA0_BROADCAST_RECEIVER_ADAPT_SETTING);     
    PrintUcpReg(JS_PMA0_BROADCAST_RECEIVER_DATAPATH_SETTING3);
    PrintUcpReg(JS_PMA0_BROADCAST_RX_ADAPT_CTRL);             
    PrintUcpReg(JS_PMA0_BROADCAST_TRANSMITTER_EQ1);          
    PrintUcpReg(JS_PMA0_BROADCAST_TRANSMITTER_EQ2);            
    PrintUcpReg(JS_PMA0_BROADCAST_TRANSMITTER_EQ3);           
    PrintUcpReg(JS_PMA0_PHY_RESET);                            
    PrintUcpReg(JS_PMA0_REFA_CLK_CTRL1);  

    // step 2
    PrintUcpReg(JS_PMA0_BROADCAST_TRANSMITTER_CONTROL1); 
    PrintUcpReg(JS_PMA0_BROADCAST_RECEIVER_RESET);       

    // step 3
    PrintUcpReg(JS_PMA0_BROADCAST_TRANSMITTER_REQ_PARAM1);      
    PrintUcpReg(JS_PMA0_BROADCAST_RECEIVER_REQ_PARAM7);         
    PrintUcpReg(JS_PMA0_BROADCAST_TRANSMITTER_REQ);            
    PrintUcpReg(JS_PMA0_BROADCAST_RECEIVER_REQ);               
    
    // step 4
    PrintUcpReg(JS_PMA0_BROADCAST_TRANSMITTER_REQ);             
    PrintUcpReg(JS_PMA0_BROADCAST_RECEIVER_REQ);                

    // step 5
    PrintUcpReg(JS_PMA0_BROADCAST_RECEIVER_REQ_PARAM7);         
    PrintUcpReg(JS_PMA0_BROADCAST_TRANSMITTER_REQ_PARAM1);      
    PrintUcpReg(JS_PMA0_BROADCAST_TRANSMITTER_DATAPATH_CLKRDY); 
    PrintUcpReg(JS_PMA0_BROADCAST_TRANSMITTER_REQ);            
    PrintUcpReg(JS_PMA0_BROADCAST_RECEIVER_REQ); 
    
    // step 6
    PrintUcpReg(JS_PMA0_BROADCAST_TRANSMITTER_REQ);             
    PrintUcpReg(JS_PMA0_BROADCAST_RECEIVER_REQ);                

    // step 7
    PrintUcpReg(JS_PMA0_BROADCAST_TRANSMITTER_DATAPATH_EN); 
    PrintUcpReg(JS_PMA0_BROADCAST_RECEIVER_DATAPATH_EN);
    
}
// ----------------------------------- CSU -----------------------------------
extern uint32_t nr_fm20000000_1slot_all[];
extern uint32_t nr_fm20000000_1slot_pre7[];
extern uint32_t nr_fm20000000_1slot_post7[];
void ucp_csu_config_test(void)
{
    // 0.5us 
    // 0.5us oneAnt: 61,440*2bytes_I*2bytes_Q = 245,760 bytes/oneAnt
    // 0.5us 4Ants:  61,440*2bytes_I*2bytes_Q*4ants = 245760*4 bytes = 983,040bytes
    // 1s    oneAnt: 245,760/0.0005 = 491,520,000 bytes
    // 1s    4Ants:  491,520,000*4 = 1,966,080,000 bytes
    #define TONELEN 61440  
    #define N15DBFS_FIX_AMP 6515
    double alfa;
    int16_t iData, qData;
    uint32_t i;
    uint64_t addrRxMem, addrTxMem;
    
    //-------------------------  Timer-204  --------------------------
    // RX0_TMR -- ORX_204C + RX_204B
    // RX1_TMR -- ORX_204B + RX_204C
    // TX0_TMR -- TX_204B
    // TX1_TMR -- TX_204C
    // ctrl_oe      <= wdata_i[0];  // RX_EN, TX_EN, ...
    // ctrl_sel     <= wdata_i[1];  // 0->reg, 1->tmr
    // rx_scrath_en <= wdata_i[2];
    // tx_scrath_en <= wdata_i[3];
    //#JS_RX0_PIN_CTRL_REG = 0xD;
    //#JS_RX1_PIN_CTRL_REG = 0xD;
    //#JS_TX0_PIN_CTRL_REG = 0xD;
    ucp_reg32_write(JS_RX0_PIN_CTRL_REG,               0x0D);
    ucp_reg32_write(JS_RX1_PIN_CTRL_REG,                0x0D);
    ucp_reg32_write(JS_TX0_PIN_CTRL_REG,               0x0D);
    
    // io_rxen0_reg <= wdata_i[0];
    // io_txen0_reg <= wdata_i[1];
    // io_rxen1_reg <= wdata_i[2];
    // io_txen1_reg <= wdata_i[3];
    // io_rxen2csu_reg <= wdata_i[4];
    // io_txen2csu_reg <= wdata_i[5];
    //#JS_RX0_IO_CTRL_REG = 0x10;
    //#JS_RX1_IO_CTRL_REG = 0x10;
    //#JS_TX0_IO_CTRL_REG = 0x20;
    ucp_reg32_write(JS_RX0_IO_CTRL_REG,                 0x10);
    ucp_reg32_write(JS_RX1_IO_CTRL_REG,                 0x10);
    ucp_reg32_write(JS_TX0_IO_CTRL_REG,                 0x20);
    
	//--------------------------  CSU-DMA  ---------------------------
	addrRxMem = 0x6BC44800;
	addrTxMem = 0x60F00000;

    #if 0
	js_csu_loc_cfg(0x4000);
	js_csu_glb_cfg(addrRxMem + 0*TONELEN*4*4, TONELEN*4*4, 1);
	printf("CsuMem Rx 1: %X\n", addrRxMem + 0*TONELEN*4*4);
	js_csu_glb_cfg(addrRxMem + 1*TONELEN*4*4, TONELEN*4*4, 2);
	printf("CsuMem Rx 2: %X\n", addrRxMem + 1*TONELEN*4*4);
	js_csu_glb_cfg(addrRxMem + 2*TONELEN*4*4, TONELEN*4*4, 3);
	printf("CsuMem Rx 3: %X\n", addrRxMem + 2*TONELEN*4*4);

	js_csu_glb_cfg(addrTxMem + 0*TONELEN*4*4, TONELEN*4*4, 4);
	printf("CsuMem Tx 1: %X\n", addrTxMem + 0*TONELEN*4*4);
	js_csu_glb_cfg(addrTxMem + 1*TONELEN*4*4, TONELEN*4*4, 5);
	printf("CsuMem Tx 2: %X\n", addrTxMem + 1*TONELEN*4*4);
	js_csu_glb_cfg(addrTxMem + 2*TONELEN*4*4, TONELEN*4*4, 6);
	printf("CsuMem Tx 3: %X\n", addrTxMem + 2*TONELEN*4*4);
	#else
	js_csu_loc_cfg(0xF0000);
	
	js_csu_glb_cfg_sep(addrRxMem + 0*0xF0000, 0xF0000, 1, 4, 0);
	printf("CsuMem Rx 1: %#lX\n", addrRxMem + 0*0xF0000);
	js_csu_glb_cfg_sep(addrRxMem + 1*0xF0000, 0xF0000, 2, 4, 0);
	printf("CsuMem Rx 2: %#lX\n", addrRxMem + 1*0xF0000);
	js_csu_glb_cfg_sep(addrRxMem + 2*0xF0000, 0xF0000, 3, 4, 0);
	printf("CsuMem Rx 3: %#lX\n", addrRxMem + 2*0xF0000);

	js_csu_glb_cfg_sep(addrTxMem + 0*0xF0000, 0xF0000, 4, 4, 0);
	printf("CsuMem Tx 1: %#lX\n", addrTxMem + 0*0xF0000);
	js_csu_glb_cfg_sep(addrTxMem + 1*0xF0000, 0xF0000, 5, 4, 0);
	printf("CsuMem Tx 2: %#lX\n", addrTxMem + 1*0xF0000);
	js_csu_glb_cfg_sep(addrTxMem + 2*0xF0000, 0xF0000, 6, 4, 0);
	printf("CsuMem Tx 3: %#lX\n", addrTxMem + 2*0xF0000);
    #endif

    
    
	//  [ 1: 0] -> CS
	//  [ 6: 4] -> Margin
	//  [15: 8] -> Num, (16+2*Num)=2*N
	//  [23:16] -> N*M
	//  [25:24] -> SepNum
	//  [27:26] -> M/2-1
	//# JS_CSU_JESDRX0SET = ((JS_204B_RX1_M/2-1)<<26)+((JS_204B_RX1_NTOTAL*JS_204B_RX1_M)<<16)+((JS_204B_RX1_N-8)<<8)+JS_204B_RX1_CS;
	//# JS_CSU_JESDRX1SET = ((JS_204B_RX0_M/2-1)<<26)+((JS_204B_RX0_NTOTAL*JS_204B_RX0_M)<<16)+((JS_204B_RX0_N-8)<<8)+JS_204B_RX0_CS;
	//# JS_CSU_JESDTXSET  = ((JS_204B_TX_M /2-1)<<26)+((JS_204B_TX_NTOTAL *JS_204B_TX_M )<<16)+((JS_204B_TX_N -8)<<8)+JS_204B_TX_CS ;
	ucp_reg32_write(JS_CSU_JESDRX0SET, ((JS_204B_RX1_M / 2 - 1) << 26) + (3 << 24) + ((JS_204B_RX1_NTOTAL * JS_204B_RX1_M/4) << 16) + ((JS_204B_RX1_N - 8) << 8 ) + JS_204B_RX1_CS);
	// ucp_reg32_write(JS_CSU_JESDRX1SET, ((JS_204B_RX0_M / 2 -1) << 26) + (3 << 24) + ((JS_204B_RX0_NTOTAL * JS_204B_RX0_M/4) << 16)+((JS_204B_RX0_N - 8) << 8) + JS_204B_RX0_CS);
	ucp_reg32_write(JS_CSU_JESDTXSET, ((JS_204B_TX_M  / 2 -1) << 26) + (3 << 24) + ((JS_204B_TX_NTOTAL * JS_204B_TX_M/4) << 16)+((JS_204B_TX_N - 8) << 8) + JS_204B_TX_CS);
	
	//   almostfull=0x10, 
	//   sendthred=0x4
	//# JS_CSU_ALMOSTFULLSENDTHRED = 0x00040400; 
	//# JS_CSU_ALMOSTFULLSENDTHRED = 0x80048400; 
	//# JS_CSU_FINDDMATAG = 0x60 ;  // st wait wr resp
	ucp_reg32_write(JS_CSU_ALMOSTFULLSENDTHRED, 0x00040100);
	ucp_reg32_write(JS_CSU_ALMOSTFULLSENDTHRED, 0x80048100);
	ucp_reg32_write(JS_CSU_FINDDMATAG, 0x60);

    for(i = 0; i < 0x78200/4; i++)
    {
        alfa = -2 * M_PI * i / 122.88;
        iData = (int16_t)(N15DBFS_FIX_AMP * cos(alfa));
        qData = (int16_t)(N15DBFS_FIX_AMP * sin(alfa));
        //iqData <<= 16;
        //iqData += (int16_t)(N15DBFS_FIX_AMP * sin(alfa));

#if 1
        ucp_reg16_write(addrTxMem  + 0*0xF0000 + i*4 + 0x0, iData);
        ucp_reg16_write(addrTxMem  + 0*0xF0000 + i*4 + 0x2, qData);
        
        ucp_reg16_write(addrTxMem  + 1*0xF0000 + i*4 + 0x0, iData);
        ucp_reg16_write(addrTxMem  + 1*0xF0000 + i*4 + 0x2, qData);
        
        ucp_reg16_write(addrTxMem  + 2*0xF0000 + i*4 + 0x0, iData);
        ucp_reg16_write(addrTxMem  + 2*0xF0000 + i*4 + 0x2, qData);
#else
        ucp_reg32_write(addrTxMem + 0*0xF0000 + i*4, nr_fm20000000_1slot_all[i]);
        ucp_reg32_write(addrTxMem + 1*0xF0000 + i*4, nr_fm20000000_1slot_all[i]);
        ucp_reg32_write(addrTxMem + 2*0xF0000 + i*4, nr_fm20000000_1slot_all[i]);
#endif
    }

#if 0
    for(i = 0; i < 0x78200/4; i++)
    {
        ucp_reg32_write(addrTxMem + 0*0xF0000 + i*4, nr_fm20000000_1slot_pre7[i]);  
    }
    for(i = 0; i < 0x77e00/4; i++)
    {
        ucp_reg32_write(addrTxMem + 1*0xF0000 + i*4, nr_fm20000000_1slot_post7[i]);
    }
#endif
    
#if 0
	//-----------------------  Start Sequence  ------------------------
	//
	//  [45:40] -> ecpri par
	//  [39:32] -> ecpri user
	//  [31:31] -> stall
	//  [30:30] -> AllNum Sel
	//  [29:28] -> ZNum or YNum send end 
	//  [27:27] -> ZNum or AllNum 
	//  [26:24] -> ecpri end 
	//  [23:23] -> flush 
	//  [22:18] -> DMA Tag
	//  [17:13] -> dest DMA config buffer id
	//  [12: 8] -> soure DMA config buffer id
	//  [ 7: 7] -> continue the last DMA
	//  [ 6: 6] -> continue the next DMA  
	//  [ 5: 5] -> cachable, used to read DDR, cci (axi1 port)
	//  [ 4: 4] -> enable 3D
	//  [ 3: 2] -> W , 00: Normal 01 ; 01: One Dimo List without num ; 10: One Dimo List with num ; 11 : Two Dimo List ; 
	//  [ 1: 0] -> R , 00: Normal 01 ; 01: One Dimo List without num ; 10: One Dimo List with num ; 11 : Two Dimo List ; 
	//# JS_CSU_CMDFIFO0 = (1<<30)+(0x0<<18)+(2<<13)+(0<<8)+(0<<5)+(1<<4)+0; // rx0   --> SM1      _
	//# JS_CSU_CMDFIFO2 = (1<<30)+(0x1<<18)+(3<<13)+(0<<8)+(1<<5)+(1<<4)+0; // rx1   --> SM2      /
	//# JS_CSU_CMDFIFO1 = (0<<30)+(0x2<<18)+(0<<13)+(1<<8)+(0<<5)+(1<<4)+0; // tx    <-- SM0     /
	ucp_reg32_write(JS_CSU_CMDFIFO0, (1<<30)+(0x0<<18)+(2<<13)+(0<<8)+(0<<5)+(1<<4)+0);
	ucp_reg32_write(JS_CSU_CMDFIFO2, (1<<30)+(0x1<<18)+(3<<13)+(0<<8)+(1<<5)+(1<<4)+0);
	ucp_reg32_write(JS_CSU_CMDFIFO1, (0<<30)+(0x2<<18)+(0<<13)+(1<<8)+(0<<5)+(1<<4)+0);
																  //                   > diff glb     _
	//# JS_CSU_CMDFIFO0 = (1<<30)+(0x3<<18)+(5<<13)+(0<<8)+(0<<5)+(1<<4)+0; // rx0   --> SM4    / diff tag id    |
	//# JS_CSU_CMDFIFO2 = (1<<30)+(0x4<<18)+(6<<13)+(0<<8)+(1<<5)+(1<<4)+0; // rx1   --> SM5   /                 |
	//# JS_CSU_CMDFIFO1 = (0<<30)+(0x5<<18)+(0<<13)+(4<<8)+(0<<5)+(1<<4)+0; // tx    <-- SM3 _/      |           |
	ucp_reg32_write(JS_CSU_CMDFIFO0, (1<<30)+(0x3<<18)+(5<<13)+(0<<8)+(0<<5)+(1<<4)+0);
	ucp_reg32_write(JS_CSU_CMDFIFO2, (1<<30)+(0x4<<18)+(6<<13)+(0<<8)+(1<<5)+(1<<4)+0);
	ucp_reg32_write(JS_CSU_CMDFIFO1, (0<<30)+(0x5<<18)+(0<<13)+(4<<8)+(0<<5)+(1<<4)+0);
																  //                       | same glb  |
	//JS_CSU_CMDFIFO0 = (1<<30)+(0x6<<18)+(2<<13)+(0<<8)+(0<<5)+(1<<4)+0; // rx0   --> SM1      _  |same tag id >  repeat 2 times
	//JS_CSU_CMDFIFO2 = (1<<30)+(0x7<<18)+(3<<13)+(0<<8)+(1<<5)+(1<<4)+0; // rx1   --> SM2      /  |           |
	//JS_CSU_CMDFIFO1 = (0<<30)+(0x8<<18)+(0<<13)+(1<<8)+(0<<5)+(1<<4)+0; // tx    <-- SM0     /   V           |
	//                                                                    //                   > diff glb      |
	//JS_CSU_CMDFIFO0 = (1<<30)+(0x9<<18)+(5<<13)+(0<<8)+(0<<5)+(1<<4)+0; // rx0   --> SM4    / diff tag id   _|
	//JS_CSU_CMDFIFO2 = (1<<30)+(0xa<<18)+(6<<13)+(0<<8)+(1<<5)+(1<<4)+0; // rx1   --> SM5   /
	//JS_CSU_CMDFIFO1 = (0<<30)+(0xb<<18)+(0<<13)+(4<<8)+(0<<5)+(1<<4)+0; // tx    <-- SM3 _/

	//JS_CSU_TAGMASK0 = 0x1<<0;
	//JS_CSU_TAGMASK2 = 0x1<<1;
	//JS_CSU_TAGMASK1 = 0x1<<2;
	//JS_CSU_INTMASK = (BIT12|BIT13|BIT14);

	printf("CMDFIFO1_NUM 3: %X\n", ucp_reg32_read(JS_CSU_CMDFIFO1_NUM));
    printf("CSU_DMASTATUS: %X\n", ucp_reg32_read(JS_CSU_DMASTATUS));
	//-----------------------  Wait DMA finish  ------------------------
	//# while(!(JS_CSU_DMASTATUS&BIT0));
	while(!(ucp_reg32_read(JS_CSU_DMASTATUS) & BIT0));
	printf("DMA 1th tag0(jesd-rx0) has finished.\n");

	//# while(!(JS_CSU_DMASTATUS&BIT1));
	//while(!(ucp_reg32_read(JS_CSU_DMASTATUS) & BIT1));
	//printf("DMA 1th tag1(jesd-rx1) has finished.\n");

	//# while(!(JS_CSU_DMASTATUS&BIT2));
	while(!(ucp_reg32_read(JS_CSU_DMASTATUS) & BIT2));
	printf("DMA 1th tag2(jesd-tx ) has finished.\n");

	//# while(!(JS_CSU_DMASTATUS&BIT3));
	while(!(ucp_reg32_read(JS_CSU_DMASTATUS) & BIT3));
	printf("DMA 1th tag3(jesd-rx0) has finished.\n");

	//# while(!(JS_CSU_DMASTATUS&BIT4));
	//while(!(ucp_reg32_read(JS_CSU_DMASTATUS) & BIT4));
	//printf("DMA 1th tag4(jesd-rx1) has finished.\n");

	//# while(!(JS_CSU_DMASTATUS&BIT5));
	while(!(ucp_reg32_read(JS_CSU_DMASTATUS) & BIT5));
	printf("DMA 1th tag5(jesd-tx ) has finished.\n");

	//----------------------------  End  ----------------------------- 
#endif

	return;
}

//  [45:40] -> ecpri par
//  [39:32] -> ecpri user
//  [31:31] -> stall
//  [30:30] -> AllNum Sel: 0 src 1 des
//  [29:28] -> ZNum or YNum send end 
//  [27:27] -> ZNum or AllNum 
//  [26:24] -> ecpri end 
//  [23:23] -> flush 
//  [22:18] -> DMA Tag
//  [17:13] -> dest DMA config buffer id
//  [12: 8] -> soure DMA config buffer id
//  [ 7: 7] -> continue the last DMA
//  [ 6: 6] -> continue the next DMA  
//  [ 5: 5] -> cachable, used to read DDR, cci (axi1 port)
//  [ 4: 4] -> enable 3D
//  [ 3: 2] -> W , 00: Normal 01 ; 01: One Dimo List without num ; 10: One Dimo List with num ; 11 : Two Dimo List ; 
//  [ 1: 0] -> R , 00: Normal 01 ; 01: One Dimo List without num ; 10: One Dimo List with num ; 11 : Two Dimo List ; 
void js_csu_ioctrl_tx (void)
{
    ucp_reg32_write(JS_CSU_CMDFIFO1, (0<<30)+(0x3<<18)+(0<<13)+(4<<8)+(0<<5)+(1<<4)+0);
    while(!(ucp_reg32_read(JS_CSU_DMASTATUS) & BIT3)) {};

	ucp_reg32_write(JS_CSU_CMDFIFO1, (0<<30)+(0x4<<18)+(0<<13)+(5<<8)+(0<<5)+(1<<4)+0);
	while(!(ucp_reg32_read(JS_CSU_DMASTATUS) & BIT4)) {};
	
#if 0
	ucp_reg32_write(JS_CSU_CMDFIFO1, (0<<30)+(0x5<<18)+(0<<13)+(6<<8)+(1<<5)+(1<<4)+0);
	while(!(ucp_reg32_read(JS_CSU_DMASTATUS) & BIT5));
#endif
}

void js_csu_ioctrl_rx (void)
{
    ucp_reg32_write(JS_CSU_CMDFIFO0, (1<<30)+(0x0<<18)+(1<<13)+(0<<8)+(0<<5)+(1<<4)+0);
	while(!(ucp_reg32_read(JS_CSU_DMASTATUS) & BIT0));

	ucp_reg32_write(JS_CSU_CMDFIFO0, (1<<30)+(0x1<<18)+(2<<13)+(0<<8)+(0<<5)+(1<<4)+0);
	while(!(ucp_reg32_read(JS_CSU_DMASTATUS) & BIT1));

	ucp_reg32_write(JS_CSU_CMDFIFO0, (1<<30)+(0x2<<18)+(3<<13)+(0<<8)+(0<<5)+(1<<4)+0);
	while(!(ucp_reg32_read(JS_CSU_DMASTATUS) & BIT2));
}


static void js_csu_loc_cfg(uint32_t all)
{
  ucp_reg32_write(JS_CSU_DMAADDRL0   , 0x0);
  ucp_reg32_write(JS_CSU_DMAADDRH0   , 0x0);
  ucp_reg32_write(JS_CSU_DMAYSTEPL0  , 0x20);
  ucp_reg32_write(JS_CSU_DMAYSTEPH0  , 0x0);
  ucp_reg32_write(JS_CSU_DMAZSTEPL0  , 0x20);
  ucp_reg32_write(JS_CSU_DMAZSTEPH0  , 0x0);
  ucp_reg32_write(JS_CSU_DMAYNUMXNUM0 , (1<<16)+0x20);
  ucp_reg32_write(JS_CSU_DMASIZEGRANALLNUM0 , (0x0<<28)+(0x8<<24)+all);
}

static void js_csu_glb_cfg(uint64_t addr, uint32_t all, uint32_t id)
{
  if(id == 0x1){
    ucp_reg32_write(JS_CSU_DMAADDRL1   , addr&0xffffffff);
    ucp_reg32_write(JS_CSU_DMAADDRH1   , addr>>32);
    ucp_reg32_write(JS_CSU_DMAYSTEPL1  , 0x80);
    ucp_reg32_write(JS_CSU_DMAYSTEPH1  , 0x0);
    ucp_reg32_write(JS_CSU_DMAZSTEPL1  , all/0x80*0x80);
    ucp_reg32_write(JS_CSU_DMAZSTEPH1  , 0x0);
    ucp_reg32_write(JS_CSU_DMAYNUMXNUM1 , ((all/0x80)<<16)+0x80);
    ucp_reg32_write(JS_CSU_DMASIZEGRANALLNUM1 , (0x7<<28)+(0xd<<24)+all);
  }else if(id == 0x2){
    ucp_reg32_write(JS_CSU_DMAADDRL2   , addr&0xffffffff);
    ucp_reg32_write(JS_CSU_DMAADDRH2   , addr>>32);
    ucp_reg32_write(JS_CSU_DMAYSTEPL2  , 0x80);
    ucp_reg32_write(JS_CSU_DMAYSTEPH2  , 0x0);
    ucp_reg32_write(JS_CSU_DMAZSTEPL2  , all/0x80*0x80);
    ucp_reg32_write(JS_CSU_DMAZSTEPH2  , 0x0);
    ucp_reg32_write(JS_CSU_DMAYNUMXNUM2 , ((all/0x80)<<16)+0x80);
    ucp_reg32_write(JS_CSU_DMASIZEGRANALLNUM2 , (0x7<<28)+(0xd<<24)+all);
  }else if(id == 0x3){
    ucp_reg32_write(JS_CSU_DMAADDRL3   , addr&0xffffffff);
    ucp_reg32_write(JS_CSU_DMAADDRH3   , addr>>32);
    ucp_reg32_write(JS_CSU_DMAYSTEPL3  , 0x80);
    ucp_reg32_write(JS_CSU_DMAYSTEPH3  , 0x0);
    ucp_reg32_write(JS_CSU_DMAZSTEPL3  , all/0x80*0x80);
    ucp_reg32_write(JS_CSU_DMAZSTEPH3  , 0x0);
    ucp_reg32_write(JS_CSU_DMAYNUMXNUM3 , ((all/0x80)<<16)+0x80);
    ucp_reg32_write(JS_CSU_DMASIZEGRANALLNUM3 , (0x7<<28)+(0xd<<24)+all);
  }else if(id == 0x4){
    ucp_reg32_write(JS_CSU_DMAADDRL4   , addr&0xffffffff);
    ucp_reg32_write(JS_CSU_DMAADDRH4   , addr>>32);
    ucp_reg32_write(JS_CSU_DMAYSTEPL4  , 0x80);
    ucp_reg32_write(JS_CSU_DMAYSTEPH4  , 0x0);
    ucp_reg32_write(JS_CSU_DMAZSTEPL4  , all/0x80*0x80);
    ucp_reg32_write(JS_CSU_DMAZSTEPH4  , 0x0);
    ucp_reg32_write(JS_CSU_DMAYNUMXNUM4 , ((all/0x80)<<16)+0x80);
    ucp_reg32_write(JS_CSU_DMASIZEGRANALLNUM4 , (0x7<<28)+(0xd<<24)+all);
  }else if(id == 0x5){
    ucp_reg32_write(JS_CSU_DMAADDRL5   , addr&0xffffffff);
    ucp_reg32_write(JS_CSU_DMAADDRH5   , addr>>32);
    ucp_reg32_write(JS_CSU_DMAYSTEPL5  , 0x80);
    ucp_reg32_write(JS_CSU_DMAYSTEPH5  , 0x0);
    ucp_reg32_write(JS_CSU_DMAZSTEPL5  , all/0x80*0x80);
    ucp_reg32_write(JS_CSU_DMAZSTEPH5  , 0x0);
    ucp_reg32_write(JS_CSU_DMAYNUMXNUM5 , ((all/0x80)<<16)+0x80);
    ucp_reg32_write(JS_CSU_DMASIZEGRANALLNUM5 , (0x7<<28)+(0xd<<24)+all);
  }else if(id == 0x6){
    ucp_reg32_write(JS_CSU_DMAADDRL6   , addr&0xffffffff);
    ucp_reg32_write(JS_CSU_DMAADDRH6   , addr>>32);
    ucp_reg32_write(JS_CSU_DMAYSTEPL6  , 0x80);
    ucp_reg32_write(JS_CSU_DMAYSTEPH6  , 0x0);
    ucp_reg32_write(JS_CSU_DMAZSTEPL6  , all/0x80*0x80);
    ucp_reg32_write(JS_CSU_DMAZSTEPH6  , 0x0);
    ucp_reg32_write(JS_CSU_DMAYNUMXNUM6 , ((all/0x80)<<16)+0x80);
    ucp_reg32_write(JS_CSU_DMASIZEGRANALLNUM6 , (0x7<<28)+(0xd<<24)+all);
  }else if(id == 0x7){
    ucp_reg32_write(JS_CSU_DMAADDRL7   , addr&0xffffffff);
    ucp_reg32_write(JS_CSU_DMAADDRH7   , addr>>32);
    ucp_reg32_write(JS_CSU_DMAYSTEPL7  , 0x80);
    ucp_reg32_write(JS_CSU_DMAYSTEPH7  , 0x0);
    ucp_reg32_write(JS_CSU_DMAZSTEPL7  , all/0x80*0x80);
    ucp_reg32_write(JS_CSU_DMAZSTEPH7  , 0x0);
    ucp_reg32_write(JS_CSU_DMAYNUMXNUM7 , ((all/0x80)<<16)+0x80);
    ucp_reg32_write(JS_CSU_DMASIZEGRANALLNUM7 , (0x7<<28)+(0xd<<24)+all);
  }else if(id == 0x8){
    ucp_reg32_write(JS_CSU_DMAADDRL8   , addr&0xffffffff);
    ucp_reg32_write(JS_CSU_DMAADDRH8   , addr>>32);
    ucp_reg32_write(JS_CSU_DMAYSTEPL8  , 0x80);
    ucp_reg32_write(JS_CSU_DMAYSTEPH8  , 0x0);
    ucp_reg32_write(JS_CSU_DMAZSTEPL8  , all/0x80*0x80);
    ucp_reg32_write(JS_CSU_DMAZSTEPH8  , 0x0);
    ucp_reg32_write(JS_CSU_DMAYNUMXNUM8 , ((all/0x80)<<16)+0x80);
    ucp_reg32_write(JS_CSU_DMASIZEGRANALLNUM8 , (0x7<<28)+(0xd<<24)+all);
  }else if(id == 0x9){
    ucp_reg32_write(JS_CSU_DMAADDRL9   , addr&0xffffffff);
    ucp_reg32_write(JS_CSU_DMAADDRH9   , addr>>32);
    ucp_reg32_write(JS_CSU_DMAYSTEPL9  , 0x80);
    ucp_reg32_write(JS_CSU_DMAYSTEPH9  , 0x0);
    ucp_reg32_write(JS_CSU_DMAZSTEPL9  , all/0x80*0x80);
    ucp_reg32_write(JS_CSU_DMAZSTEPH9  , 0x0);
    ucp_reg32_write(JS_CSU_DMAYNUMXNUM9 , ((all/0x80)<<16)+0x80);
    ucp_reg32_write(JS_CSU_DMASIZEGRANALLNUM9 , (0x7<<28)+(0xd<<24)+all);
  }else if(id == 0xa){
    ucp_reg32_write(JS_CSU_DMAADDRL10   , addr&0xffffffff);
    ucp_reg32_write(JS_CSU_DMAADDRH10   , addr>>32);
    ucp_reg32_write(JS_CSU_DMAYSTEPL10  , 0x80);
    ucp_reg32_write(JS_CSU_DMAYSTEPH10  , 0x0);
    ucp_reg32_write(JS_CSU_DMAZSTEPL10  , all/0x80*0x80);
    ucp_reg32_write(JS_CSU_DMAZSTEPH10  , 0x0);
    ucp_reg32_write(JS_CSU_DMAYNUMXNUM10 , ((all/0x80)<<16)+0x80);
    ucp_reg32_write(JS_CSU_DMASIZEGRANALLNUM10 , (0x7<<28)+(0xd<<24)+all);
  }else if(id == 0xb){
    ucp_reg32_write(JS_CSU_DMAADDRL11   , addr&0xffffffff);
    ucp_reg32_write(JS_CSU_DMAADDRH11   , addr>>32);
    ucp_reg32_write(JS_CSU_DMAYSTEPL11  , 0x80);
    ucp_reg32_write(JS_CSU_DMAYSTEPH11  , 0x0);
    ucp_reg32_write(JS_CSU_DMAZSTEPL11  , all/0x80*0x80);
    ucp_reg32_write(JS_CSU_DMAZSTEPH11  , 0x0);
    ucp_reg32_write(JS_CSU_DMAYNUMXNUM11 , ((all/0x80)<<16)+0x80);
    ucp_reg32_write(JS_CSU_DMASIZEGRANALLNUM11 , (0x7<<28)+(0xd<<24)+all);
  }else if(id == 0xc){
    ucp_reg32_write(JS_CSU_DMAADDRL12   , addr&0xffffffff);
    ucp_reg32_write(JS_CSU_DMAADDRH12   , addr>>32);
    ucp_reg32_write(JS_CSU_DMAYSTEPL12  , 0x80);
    ucp_reg32_write(JS_CSU_DMAYSTEPH12  , 0x0);
    ucp_reg32_write(JS_CSU_DMAZSTEPL12  , all/0x80*0x80);
    ucp_reg32_write(JS_CSU_DMAZSTEPH12  , 0x0);
    ucp_reg32_write(JS_CSU_DMAYNUMXNUM12 , ((all/0x80)<<16)+0x80);
    ucp_reg32_write(JS_CSU_DMASIZEGRANALLNUM12 , (0x7<<28)+(0xd<<24)+all);
  }else if(id == 0xd){
    ucp_reg32_write(JS_CSU_DMAADDRL13   , addr&0xffffffff);
    ucp_reg32_write(JS_CSU_DMAADDRH13   , addr>>32);
    ucp_reg32_write(JS_CSU_DMAYSTEPL13  , 0x80);
    ucp_reg32_write(JS_CSU_DMAYSTEPH13  , 0x0);
    ucp_reg32_write(JS_CSU_DMAZSTEPL13  , all/0x80*0x80);
    ucp_reg32_write(JS_CSU_DMAZSTEPH13  , 0x0);
    ucp_reg32_write(JS_CSU_DMAYNUMXNUM13 , ((all/0x80)<<16)+0x80);
    ucp_reg32_write(JS_CSU_DMASIZEGRANALLNUM13 , (0x7<<28)+(0xd<<24)+all);
  }else if(id == 0xd){
    ucp_reg32_write(JS_CSU_DMAADDRL14   , addr&0xffffffff);
    ucp_reg32_write(JS_CSU_DMAADDRH14   , addr>>32);
    ucp_reg32_write(JS_CSU_DMAYSTEPL14  , 0x80);
    ucp_reg32_write(JS_CSU_DMAYSTEPH14  , 0x0);
    ucp_reg32_write(JS_CSU_DMAZSTEPL14  , all/0x80*0x80);
    ucp_reg32_write(JS_CSU_DMAZSTEPH14  , 0x0);
    ucp_reg32_write(JS_CSU_DMAYNUMXNUM14 , ((all/0x80)<<16)+0x80);
    ucp_reg32_write(JS_CSU_DMASIZEGRANALLNUM14 , (0x7<<28)+(0xd<<24)+all);
  }else if(id == 0xf){
    ucp_reg32_write(JS_CSU_DMAADDRL15   , addr&0xffffffff);
    ucp_reg32_write(JS_CSU_DMAADDRH15   , addr>>32);
    ucp_reg32_write(JS_CSU_DMAYSTEPL15  , 0x80);
    ucp_reg32_write(JS_CSU_DMAYSTEPH15  , 0x0);
    ucp_reg32_write(JS_CSU_DMAZSTEPL15  , all/0x80*0x80);
    ucp_reg32_write(JS_CSU_DMAZSTEPH15  , 0x0);
    ucp_reg32_write(JS_CSU_DMAYNUMXNUM15 , ((all/0x80)<<16)+0x80);
    ucp_reg32_write(JS_CSU_DMASIZEGRANALLNUM15 , (0x7<<28)+(0xd<<24)+all);
  }else{
    printf("The id is invalid!");
  }
}

static void js_csu_glb_cfg_sep(uint64_t addr, uint32_t all, uint32_t id, uint32_t sep_num, uint32_t sep_margin)
{
  if(id == 0x1){
    ucp_reg32_write(JS_CSU_DMAADDRL1   , addr&0xffffffff);
    ucp_reg32_write(JS_CSU_DMAADDRH1   , addr>>32);
    ucp_reg32_write(JS_CSU_DMAYSTEPL1  , all/sep_num);
    ucp_reg32_write(JS_CSU_DMAYSTEPH1  , 0x0);
    ucp_reg32_write(JS_CSU_DMAZSTEPL1  , 32*(1<<sep_margin));
    ucp_reg32_write(JS_CSU_DMAZSTEPH1  , 0x0);
    ucp_reg32_write(JS_CSU_DMAYNUMXNUM1 , (sep_num<<16)+32*(1<<sep_margin));
    ucp_reg32_write(JS_CSU_DMASIZEGRANALLNUM1 , (0x7<<28)+(0xd<<24)+all);
  }else if(id == 0x2){
    ucp_reg32_write(JS_CSU_DMAADDRL2   , addr&0xffffffff);
    ucp_reg32_write(JS_CSU_DMAADDRH2   , addr>>32);
    ucp_reg32_write(JS_CSU_DMAYSTEPL2  , all/sep_num);
    ucp_reg32_write(JS_CSU_DMAYSTEPH2  , 0x0);
    ucp_reg32_write(JS_CSU_DMAZSTEPL2  , 32*(1<<sep_margin));
    ucp_reg32_write(JS_CSU_DMAZSTEPH2  , 0x0);
    ucp_reg32_write(JS_CSU_DMAYNUMXNUM2 , (sep_num<<16)+32*(1<<sep_margin));
    ucp_reg32_write(JS_CSU_DMASIZEGRANALLNUM2 , (0x7<<28)+(0xd<<24)+all);
  }else if(id == 0x3){
    ucp_reg32_write(JS_CSU_DMAADDRL3   , addr&0xffffffff);
    ucp_reg32_write(JS_CSU_DMAADDRH3   , addr>>32);
    ucp_reg32_write(JS_CSU_DMAYSTEPL3  , all/sep_num);
    ucp_reg32_write(JS_CSU_DMAYSTEPH3  , 0x0);
    ucp_reg32_write(JS_CSU_DMAZSTEPL3  , 32*(1<<sep_margin));
    ucp_reg32_write(JS_CSU_DMAZSTEPH3  , 0x0);
    ucp_reg32_write(JS_CSU_DMAYNUMXNUM3 , (sep_num<<16)+32*(1<<sep_margin));
    ucp_reg32_write(JS_CSU_DMASIZEGRANALLNUM3 , (0x7<<28)+(0xd<<24)+all);
  }else if(id == 0x4){
    ucp_reg32_write(JS_CSU_DMAADDRL4   , addr&0xffffffff);
    ucp_reg32_write(JS_CSU_DMAADDRH4   , addr>>32);
    ucp_reg32_write(JS_CSU_DMAYSTEPL4  , all/sep_num);
    ucp_reg32_write(JS_CSU_DMAYSTEPH4  , 0x0);
    ucp_reg32_write(JS_CSU_DMAZSTEPL4  , 32*(1<<sep_margin));
    ucp_reg32_write(JS_CSU_DMAZSTEPH4  , 0x0);
    ucp_reg32_write(JS_CSU_DMAYNUMXNUM4 , (sep_num<<16)+32*(1<<sep_margin));
    ucp_reg32_write(JS_CSU_DMASIZEGRANALLNUM4 , (0x7<<28)+(0xd<<24)+all);
  }else if(id == 0x5){
    ucp_reg32_write(JS_CSU_DMAADDRL5   , addr&0xffffffff);
    ucp_reg32_write(JS_CSU_DMAADDRH5   , addr>>32);
    ucp_reg32_write(JS_CSU_DMAYSTEPL5  , all/sep_num);
    ucp_reg32_write(JS_CSU_DMAYSTEPH5  , 0x0);
    ucp_reg32_write(JS_CSU_DMAZSTEPL5  , 32*(1<<sep_margin));
    ucp_reg32_write(JS_CSU_DMAZSTEPH5  , 0x0);
    ucp_reg32_write(JS_CSU_DMAYNUMXNUM5 , (sep_num<<16)+32*(1<<sep_margin));
    ucp_reg32_write(JS_CSU_DMASIZEGRANALLNUM5 , (0x7<<28)+(0xd<<24)+all);
  }else if(id == 0x6){
    ucp_reg32_write(JS_CSU_DMAADDRL6   , addr&0xffffffff);
    ucp_reg32_write(JS_CSU_DMAADDRH6   , addr>>32);
    ucp_reg32_write(JS_CSU_DMAYSTEPL6  , all/sep_num);
    ucp_reg32_write(JS_CSU_DMAYSTEPH6  , 0x0);
    ucp_reg32_write(JS_CSU_DMAZSTEPL6  , 32*(1<<sep_margin));
    ucp_reg32_write(JS_CSU_DMAZSTEPH6  , 0x0);
    ucp_reg32_write(JS_CSU_DMAYNUMXNUM6 , (sep_num<<16)+32*(1<<sep_margin));
    ucp_reg32_write(JS_CSU_DMASIZEGRANALLNUM6 , (0x7<<28)+(0xd<<24)+all);
  }else if(id == 0x7){
    ucp_reg32_write(JS_CSU_DMAADDRL7   , addr&0xffffffff);
    ucp_reg32_write(JS_CSU_DMAADDRH7   , addr>>32);
    ucp_reg32_write(JS_CSU_DMAYSTEPL7  , all/sep_num);
    ucp_reg32_write(JS_CSU_DMAYSTEPH7  , 0x0);
    ucp_reg32_write(JS_CSU_DMAZSTEPL7  , 32*(1<<sep_margin));
    ucp_reg32_write(JS_CSU_DMAZSTEPH7  , 0x0);
    ucp_reg32_write(JS_CSU_DMAYNUMXNUM7 , (sep_num<<16)+32*(1<<sep_margin));
    ucp_reg32_write(JS_CSU_DMASIZEGRANALLNUM7 , (0x7<<28)+(0xd<<24)+all);
  }else if(id == 0x8){
    ucp_reg32_write(JS_CSU_DMAADDRL8   , addr&0xffffffff);
    ucp_reg32_write(JS_CSU_DMAADDRH8   , addr>>32);
    ucp_reg32_write(JS_CSU_DMAYSTEPL8  , all/sep_num);
    ucp_reg32_write(JS_CSU_DMAYSTEPH8  , 0x0);
    ucp_reg32_write(JS_CSU_DMAZSTEPL8  , 32*(1<<sep_margin));
    ucp_reg32_write(JS_CSU_DMAZSTEPH8  , 0x0);
    ucp_reg32_write(JS_CSU_DMAYNUMXNUM8 , (sep_num<<16)+32*(1<<sep_margin));
    ucp_reg32_write(JS_CSU_DMASIZEGRANALLNUM8 , (0x7<<28)+(0xd<<24)+all);
  }else if(id == 0x9){
    ucp_reg32_write(JS_CSU_DMAADDRL9   , addr&0xffffffff);
    ucp_reg32_write(JS_CSU_DMAADDRH9   , addr>>32);
    ucp_reg32_write(JS_CSU_DMAYSTEPL9  , all/sep_num);
    ucp_reg32_write(JS_CSU_DMAYSTEPH9  , 0x0);
    ucp_reg32_write(JS_CSU_DMAZSTEPL9  , 32*(1<<sep_margin));
    ucp_reg32_write(JS_CSU_DMAZSTEPH9  , 0x0);
    ucp_reg32_write(JS_CSU_DMAYNUMXNUM9 , (sep_num<<16)+32*(1<<sep_margin));
    ucp_reg32_write(JS_CSU_DMASIZEGRANALLNUM9 , (0x7<<28)+(0xd<<24)+all);
  }else if(id == 0xa){
    ucp_reg32_write(JS_CSU_DMAADDRL10   , addr&0xffffffff);
    ucp_reg32_write(JS_CSU_DMAADDRH10   , addr>>32);
    ucp_reg32_write(JS_CSU_DMAYSTEPL10  , all/sep_num);
    ucp_reg32_write(JS_CSU_DMAYSTEPH10  , 0x0);
    ucp_reg32_write(JS_CSU_DMAZSTEPL10  , 32*(1<<sep_margin));
    ucp_reg32_write(JS_CSU_DMAZSTEPH10  , 0x0);
    ucp_reg32_write(JS_CSU_DMAYNUMXNUM10 , (sep_num<<16)+32*(1<<sep_margin));
    ucp_reg32_write(JS_CSU_DMASIZEGRANALLNUM10 , (0x7<<28)+(0xd<<24)+all);
  }else if(id == 0xb){
    ucp_reg32_write(JS_CSU_DMAADDRL11   , addr&0xffffffff);
    ucp_reg32_write(JS_CSU_DMAADDRH11   , addr>>32);
    ucp_reg32_write(JS_CSU_DMAYSTEPL11  , all/sep_num);
    ucp_reg32_write(JS_CSU_DMAYSTEPH11  , 0x0);
    ucp_reg32_write(JS_CSU_DMAZSTEPL11  , 32*(1<<sep_margin));
    ucp_reg32_write(JS_CSU_DMAZSTEPH11  , 0x0);
    ucp_reg32_write(JS_CSU_DMAYNUMXNUM11 , (sep_num<<16)+32*(1<<sep_margin));
    ucp_reg32_write(JS_CSU_DMASIZEGRANALLNUM11 , (0x7<<28)+(0xd<<24)+all);
  }else if(id == 0xc){
    ucp_reg32_write(JS_CSU_DMAADDRL12   , addr&0xffffffff);
    ucp_reg32_write(JS_CSU_DMAADDRH12   , addr>>32);
    ucp_reg32_write(JS_CSU_DMAYSTEPL12  , all/sep_num);
    ucp_reg32_write(JS_CSU_DMAYSTEPH12  , 0x0);
    ucp_reg32_write(JS_CSU_DMAZSTEPL12  , 32*(1<<sep_margin));
    ucp_reg32_write(JS_CSU_DMAZSTEPH12  , 0x0);
    ucp_reg32_write(JS_CSU_DMAYNUMXNUM12 , (sep_num<<16)+32*(1<<sep_margin));
    ucp_reg32_write(JS_CSU_DMASIZEGRANALLNUM12 , (0x7<<28)+(0xd<<24)+all);
  }else if(id == 0xd){
    ucp_reg32_write(JS_CSU_DMAADDRL13   , addr&0xffffffff);
    ucp_reg32_write(JS_CSU_DMAADDRH13   , addr>>32);
    ucp_reg32_write(JS_CSU_DMAYSTEPL13  , all/sep_num);
    ucp_reg32_write(JS_CSU_DMAYSTEPH13  , 0x0);
    ucp_reg32_write(JS_CSU_DMAZSTEPL13  , 32*(1<<sep_margin));
    ucp_reg32_write(JS_CSU_DMAZSTEPH13  , 0x0);
    ucp_reg32_write(JS_CSU_DMAYNUMXNUM13 , (sep_num<<16)+32*(1<<sep_margin));
    ucp_reg32_write(JS_CSU_DMASIZEGRANALLNUM13 , (0x7<<28)+(0xd<<24)+all);
  }else if(id == 0xd){
    ucp_reg32_write(JS_CSU_DMAADDRL14   , addr&0xffffffff);
    ucp_reg32_write(JS_CSU_DMAADDRH14   , addr>>32);
    ucp_reg32_write(JS_CSU_DMAYSTEPL14  , all/sep_num);
    ucp_reg32_write(JS_CSU_DMAYSTEPH14  , 0x0);
    ucp_reg32_write(JS_CSU_DMAZSTEPL14  , 32*(1<<sep_margin));
    ucp_reg32_write(JS_CSU_DMAZSTEPH14  , 0x0);
    ucp_reg32_write(JS_CSU_DMAYNUMXNUM14 , (sep_num<<16)+32*(1<<sep_margin));
    ucp_reg32_write(JS_CSU_DMASIZEGRANALLNUM14 , (0x7<<28)+(0xd<<24)+all);
  }else if(id == 0xf){
    ucp_reg32_write(JS_CSU_DMAADDRL15   , addr&0xffffffff);
    ucp_reg32_write(JS_CSU_DMAADDRH15   , addr>>32);
    ucp_reg32_write(JS_CSU_DMAYSTEPL15  , all/sep_num);
    ucp_reg32_write(JS_CSU_DMAYSTEPH15  , 0x0);
    ucp_reg32_write(JS_CSU_DMAZSTEPL15  , 32*(1<<sep_margin));
    ucp_reg32_write(JS_CSU_DMAZSTEPH15  , 0x0);
    ucp_reg32_write(JS_CSU_DMAYNUMXNUM15 , (sep_num<<16)+32*(1<<sep_margin));
    ucp_reg32_write(JS_CSU_DMASIZEGRANALLNUM15 , (0x7<<28)+(0xd<<24)+all);
  }else{
    printf("The id is invalid!");
  }
}

//--------------------------- JESD -----------------------------------
static uint32_t cal_ratio(uint32_t mode, 
                 uint32_t no_converters, 
                 uint32_t no_samples, 
                 uint32_t ntotal, 
                 uint32_t no_frames, 
                 uint32_t no_lanes, 
                 uint32_t no_samples_on_if)
{
  double frame_filled, total_bits, bits_per_clock_sample ,bits_per_clock_character, bit_division, bit_modified, frame_size;

  frame_size = 8*no_frames*no_lanes;

  if(mode == 0){
    bits_per_clock_character = 32*no_lanes;
  } else {
    bits_per_clock_character = 64*no_lanes;
  }

  bits_per_clock_sample = no_converters*ntotal*no_samples_on_if;
  total_bits            = no_converters*ntotal*no_samples;

  frame_filled = total_bits/frame_size;
  bit_modified = (bits_per_clock_character/bits_per_clock_sample)*frame_filled;
  bit_division = bit_modified;

  if(bit_division<=1){
    return 0;
  } else if(bit_division>1 && bit_division<=2){
    return 1;
  } else if(bit_division>2 && bit_division<=4){
    return 2;
  } else if(bit_division>4 && bit_division<=8){
    return 3;
  }
  
  return 4;
}

static uint32_t cal_lmfc_lemc_delay(uint32_t coding_type,
                           uint32_t f,
                           uint32_t k,
                           uint32_t e)
{
  if(coding_type){  // LEMC
    return 32*e;
  } else {  // LMFC
    return f*k/4;
  }
}

void ucp_jesd_pcsReset(void)
{
    ucp_reg32_write(JS_PMA0_PCS_SOFT_RESET, 0x8FFF);
    usleep(1000);
    ucp_reg32_write(JS_PMA0_PCS_SOFT_RESET, 0x0);
    usleep(10);
}

void ucp_cofigPrbsSend(uint8_t prbsIndex)
{
    
    ucp_reg32_write(JS_PMA0_PCS_BIT_REV_CTRL,                       0x001);
    if (0 == prbsIndex)
    {
        ucp_reg32_write(JS_PMA0_PCS_PRBS_UDP_SEND,     0xf0); // daya debug PRBS31 SEND
        printf("ucpSend_PRBS31\n");
    }
    else
    {
        ucp_reg32_write(JS_PMA0_PCS_PRBS_UDP_SEND,     0xf); // daya debug PRBS9 SEND
        printf("ucpSend_PRBS9\n");
    }
}

void ucp_insertPrbsErr (void)
{
    ucp_reg32_write(JS_PMA0_PCS_PRBS_SEND_ERRINS,     0xf);
}

void ucp_cofigPrbsCheck(uint8_t prbsIndex)
{
    ucp_reg32_write(JS_PMA0_PCS_BIT_REV_CTRL,                       0x001);
    if (0 == prbsIndex)
    {
        ucp_reg32_write(JS_PMA0_PCS_PRBS_UDP_CHK,     0xf0); // daya debug PRBS31 check
        printf("ucpCheck_PRBS31\n");
    }
    else
    {
        ucp_reg32_write(JS_PMA0_PCS_PRBS_UDP_CHK,     0xf); // daya debug PRBS9 check
        printf("ucpCheck_PRBS9\n");
    }
}

void ucp_cofigPrbsFarEndLoopBack (void)
{
    ucp_reg32_write(JS_PMA0_PCS_LOOPBACK_CTRL,   0x10);
    printf("ucpFarEndLoopback\n");
}

void ucp_cofigPrbsNearEndLoopBack (void)
{
    ucp_reg32_write(JS_PMA0_PCS_LOOPBACK_CTRL,   0x1);
    printf("ucpNearEndLoopback\n");
}

void ucp_resetPrbsCheckCount (void)
{
    ucp_reg32_write(JS_PMA0_PCS_LOOPBACK_CTRL,   0x1);
    printf("ucpNearEndLoopback\n");
}

void ucp_prbsCheckCount (void)
{
    printf("ucpPrbs: %d %d %d %d\n",
               ucp_reg32_read (JS_PMA0_PCS_RXPRBS_ERRCNT_L0),
               ucp_reg32_read (JS_PMA0_PCS_RXPRBS_ERRCNT_L1),
               ucp_reg32_read (JS_PMA0_PCS_RXPRBS_ERRCNT_L2),
               ucp_reg32_read (JS_PMA0_PCS_RXPRBS_ERRCNT_L3));

}

uint32_t ucp_linkTestCount1(void) // for K code
{
    return ucp_reg32_read(JS_COMC_204B_RX1_LINKTEST_1_RECEIVECOUNTER);
}

void ucp_jesd204_interrupt(uint8_t en)
{
    if (en)
    {
        ucp_reg32_write(JS_COMC_204B_RX1_CORE_INTERRUPT_MASK, 0);
    }
    else
    {
        ucp_reg32_write(JS_COMC_204B_RX1_CORE_INTERRUPT_MASK, 0xFFFFFFFF);
    }
}

void ucp_configRxFeature(void)
{
    // ucp_reg32_write(JS_COMC_204C_RX0_FEATURE_DISABLE, 0x9F);
}

void wno_unused_myheadername(void)
{
  /* don't need to actually call the functions to avoid the warnings */
  (void)&js_csu_glb_cfg;
  (void)&ucp4008_jesd_pma_print;
  (void)&ucp4008_jesd_crg_print;
  return;
 }

