//******************** (C) COPYRIGHT 2022 SmartLogic*******************************
// FileName           : ucp_jsonTools.c
// Author             : Boheng Lin bhlin919@126.com
// Date First Issued  : 2023-08-15 02:37:50 PM
// Last Modified      : 
// Description        :
// ------------------------------------------------------------
// Modification History:
// Version    Date       Author    Modification Description
//
//**********************************************************************************

#include <stdio.h>
#include <stdlib.h>
#include "xzJSON.h"
#include <string.h>
#include "ucp_jsonTools.h"

#define RFIC_CFG_FILE_PATH    "/lib/firmware/resources/ucp_rfic_cfg.json"
#define RFIC_CAL_FILE_PATH    "/lib/firmware/resources/ucp_rfic_calpara.json"

typedef struct ucp_rfic_cfg
{
    uint64_t txLo;
    uint64_t rxLo;
    uint64_t auxLo;
    uint16_t initAtt;
    uint16_t initGain;
    
    uint64_t sampleRate;
    uint64_t bw;
    uint16_t antNumb;
    uint16_t enFdd;
    uint16_t enOrx;
    uint16_t en204C;
    uint16_t enUcpLog;

    int16_t  calOrxGainIndex;
    int16_t  calChAttPara[4];
    
    uint16_t padding;
} ucp_rfic_cfg_t;


typedef struct ucp_rfic_calPara
{
    int16_t  calOrxGainIndex;
    int16_t  calChAttPara[4];
} ucp_rfic_calPara_t;

static void printfJson(xzJSON *json) {
    if (NULL == json) {
        return;
    }
    char *cjson = xzJSON_Print(json);
    printf("json:%s\n", cjson);
    free(cjson);
}

void ucp_printGpioConfigStruct (ucp_jesd_TrxGpioCfg_t gpioConfig)
{
	printf("-----------------------------------------\n");
	printf("board        = %s\n", gpioConfig.board);
	printf("version      = %d\n", gpioConfig.version);
	printf("maxCh        = %d\n", gpioConfig.maxCh);
	printf("devClkSrc    = %d\n", gpioConfig.devClkSrc);
    printf("uldelay      = %d\n", gpioConfig.uldelay);
    printf("dldelay      = %d\n", gpioConfig.dldelay);
    if (gpioConfig.version > 1)
    {
        printf("lvdsCoupling = %s\n\n", gpioConfig.lvdsCoupling);
    }
 
	printf("triger port:         %02d\n", gpioConfig.triger.port);
	printf("triger pin:          %02d\n", gpioConfig.triger.pin);
	printf("triger enableLevel:  %02d\n", gpioConfig.triger.enableLevel);
	
	printf("\nPORT/PIN/EN   CH0          CH1          CH2          CH3 \n");
	printf("tx trx:   %02d  %02d  %02d | %02d  %02d  %02d | %02d  %02d  %02d | %02d  %02d  %02d\n", 
		  gpioConfig.ch[0].tx.trx.port, gpioConfig.ch[0].tx.trx.pin, gpioConfig.ch[0].tx.trx.enableLevel,
		  gpioConfig.ch[1].tx.trx.port, gpioConfig.ch[1].tx.trx.pin, gpioConfig.ch[1].tx.trx.enableLevel,
		  gpioConfig.ch[2].tx.trx.port, gpioConfig.ch[2].tx.trx.pin, gpioConfig.ch[2].tx.trx.enableLevel,
		  gpioConfig.ch[3].tx.trx.port, gpioConfig.ch[3].tx.trx.pin, gpioConfig.ch[3].tx.trx.enableLevel);
	printf("tx rf:    %02d  %02d  %02d | %02d  %02d  %02d | %02d  %02d  %02d | %02d  %02d  %02d\n",                                   
		  gpioConfig.ch[0].tx.rf.port,  gpioConfig.ch[0].tx.rf.pin,  gpioConfig.ch[0].tx.rf.enableLevel,
		  gpioConfig.ch[1].tx.rf.port,  gpioConfig.ch[1].tx.rf.pin,  gpioConfig.ch[1].tx.rf.enableLevel,
		  gpioConfig.ch[2].tx.rf.port,  gpioConfig.ch[2].tx.rf.pin,  gpioConfig.ch[2].tx.rf.enableLevel,
		  gpioConfig.ch[3].tx.rf.port,  gpioConfig.ch[3].tx.rf.pin,  gpioConfig.ch[3].tx.rf.enableLevel);
	printf("tx sw:    %02d  %02d  %02d | %02d  %02d  %02d | %02d  %02d  %02d | %02d  %02d  %02d\n\n",                                      
		  gpioConfig.ch[0].tx.sw.port,  gpioConfig.ch[0].tx.sw.pin,  gpioConfig.ch[0].tx.sw.enableLevel,
		  gpioConfig.ch[1].tx.sw.port,  gpioConfig.ch[1].tx.sw.pin,  gpioConfig.ch[1].tx.sw.enableLevel,
		  gpioConfig.ch[2].tx.sw.port,  gpioConfig.ch[2].tx.sw.pin,  gpioConfig.ch[2].tx.sw.enableLevel,
		  gpioConfig.ch[3].tx.sw.port,  gpioConfig.ch[3].tx.sw.pin,  gpioConfig.ch[3].tx.sw.enableLevel);

	printf("rx trx:   %02d  %02d  %02d | %02d  %02d  %02d | %02d  %02d  %02d | %02d  %02d  %02d\n", 
		  gpioConfig.ch[0].rx.trx.port, gpioConfig.ch[0].rx.trx.pin, gpioConfig.ch[0].rx.trx.enableLevel,
		  gpioConfig.ch[1].rx.trx.port, gpioConfig.ch[1].rx.trx.pin, gpioConfig.ch[1].rx.trx.enableLevel,
		  gpioConfig.ch[2].rx.trx.port, gpioConfig.ch[2].rx.trx.pin, gpioConfig.ch[2].rx.trx.enableLevel,
		  gpioConfig.ch[3].rx.trx.port, gpioConfig.ch[3].rx.trx.pin, gpioConfig.ch[3].rx.trx.enableLevel);
	printf("rx rf:    %02d  %02d  %02d | %02d  %02d  %02d | %02d  %02d  %02d | %02d  %02d  %02d\n",                                   
		  gpioConfig.ch[0].rx.rf.port,  gpioConfig.ch[0].rx.rf.pin,  gpioConfig.ch[0].rx.rf.enableLevel,
		  gpioConfig.ch[1].rx.rf.port,  gpioConfig.ch[1].rx.rf.pin,  gpioConfig.ch[1].rx.rf.enableLevel,
		  gpioConfig.ch[2].rx.rf.port,  gpioConfig.ch[2].rx.rf.pin,  gpioConfig.ch[2].rx.rf.enableLevel,
		  gpioConfig.ch[3].rx.rf.port,  gpioConfig.ch[3].rx.rf.pin,  gpioConfig.ch[3].rx.rf.enableLevel);
	printf("rx sw:    %02d  %02d  %02d | %02d  %02d  %02d | %02d  %02d  %02d | %02d  %02d  %02d\n\n",                                  
		  gpioConfig.ch[0].rx.sw.port,  gpioConfig.ch[0].rx.sw.pin,  gpioConfig.ch[0].rx.sw.enableLevel,
		  gpioConfig.ch[1].rx.sw.port,  gpioConfig.ch[1].rx.sw.pin,  gpioConfig.ch[1].rx.sw.enableLevel,
		  gpioConfig.ch[2].rx.sw.port,  gpioConfig.ch[2].rx.sw.pin,  gpioConfig.ch[2].rx.sw.enableLevel,
		  gpioConfig.ch[3].rx.sw.port,  gpioConfig.ch[3].rx.sw.pin,  gpioConfig.ch[3].rx.sw.enableLevel);

	printf("orx trx:  %02d  %02d  %02d | %02d  %02d  %02d | %02d  %02d  %02d | %02d  %02d  %02d\n", 
		  gpioConfig.ch[0].orx.trx.port, gpioConfig.ch[0].orx.trx.pin, gpioConfig.ch[0].orx.trx.enableLevel,
		  gpioConfig.ch[1].orx.trx.port, gpioConfig.ch[1].orx.trx.pin, gpioConfig.ch[1].orx.trx.enableLevel,
		  gpioConfig.ch[2].orx.trx.port, gpioConfig.ch[2].orx.trx.pin, gpioConfig.ch[2].orx.trx.enableLevel,
		  gpioConfig.ch[3].orx.trx.port, gpioConfig.ch[3].orx.trx.pin, gpioConfig.ch[3].orx.trx.enableLevel);
	printf("orx rf:   %02d  %02d  %02d | %02d  %02d  %02d | %02d  %02d  %02d | %02d  %02d  %02d\n",                                        
		  gpioConfig.ch[0].orx.rf.port,  gpioConfig.ch[0].orx.rf.pin,  gpioConfig.ch[0].orx.rf.enableLevel,
		  gpioConfig.ch[1].orx.rf.port,  gpioConfig.ch[1].orx.rf.pin,  gpioConfig.ch[1].orx.rf.enableLevel,
		  gpioConfig.ch[2].orx.rf.port,  gpioConfig.ch[2].orx.rf.pin,  gpioConfig.ch[2].orx.rf.enableLevel,
		  gpioConfig.ch[3].orx.rf.port,  gpioConfig.ch[3].orx.rf.pin,  gpioConfig.ch[3].orx.rf.enableLevel);
	printf("orx sw:   %02d  %02d  %02d | %02d  %02d  %02d | %02d  %02d  %02d | %02d  %02d  %02d\n",                                       
		  gpioConfig.ch[0].orx.sw.port,  gpioConfig.ch[0].orx.sw.pin,  gpioConfig.ch[0].orx.sw.enableLevel,
		  gpioConfig.ch[1].orx.sw.port,  gpioConfig.ch[1].orx.sw.pin,  gpioConfig.ch[1].orx.sw.enableLevel,
		  gpioConfig.ch[2].orx.sw.port,  gpioConfig.ch[2].orx.sw.pin,  gpioConfig.ch[2].orx.sw.enableLevel,
		  gpioConfig.ch[3].orx.sw.port,  gpioConfig.ch[3].orx.sw.pin,  gpioConfig.ch[3].orx.sw.enableLevel);
		  
	printf("-----------------------------------------\n");
	
	return;
}

void freeJson(xzJSON *json) {
    if (json != NULL) {
        xzJSON_Delete(json);
	}
}

void ucp_jsonSave (const char *fileName, xzJSON *json)
{
	char *cjson = xzJSON_Print(json);
	FILE *fpw = NULL;
	
    fpw = fopen(fileName, "w+");
    if (NULL != fpw) {
        fwrite(cjson, strlen(cjson),1,fpw);
        fclose(fpw);
	}
	if (cjson != NULL) {
        free(cjson);
	}
}

xzJSON* ucp_jsonLoad (const char *fileName)
{
	FILE *fpr = NULL;
	xzJSON *json;
	long len;
	
    fpr = fopen(fileName, "r");
    if (NULL == fpr) 
    {
        return ((xzJSON*)NULL);
    }
    
    fseek(fpr, 0, SEEK_END);

    len = ftell(fpr);
    fseek(fpr, 0, SEEK_SET);
    char *data = (char*)malloc(len + 1);
    fread(data, 1, len, fpr);
    if (fpr != NULL) 
	{
        fclose(fpr);
	}
	
	json = xzJSON_Parse(data);
	
	return json;
}

void ucp_GenGpioConfig (const char *fileName)
{
	ucp_jesd_TrxGpioCfg_t gpioConfig;
	xzJSON *root = xzJSON_CreateObject();
	xzJSON *item;
	xzJSON *config;
	uint32_t i;
	
	memset(&gpioConfig, 0, sizeof(gpioConfig));

	item = xzJSON_GetObjectItem(root, "common");
	
	gpioConfig.version = 1;
	strcpy(gpioConfig.board, "EVMT");
	gpioConfig.maxCh = MAX_UCP_JESD_TRX_CH;
	gpioConfig.devClkSrc = 2;

	for (i = 0;i < gpioConfig.maxCh;i++)
	{
		gpioConfig.ch[i].tx.trx.port = 0;
		gpioConfig.ch[i].tx.trx.pin  = 0;
		gpioConfig.ch[i].tx.trx.enableLevel = UCP_JESD_TRX_GPIO_DISABLE;
		gpioConfig.ch[i].tx.rf.port = 0;
		gpioConfig.ch[i].tx.rf.pin  = 0;
		gpioConfig.ch[i].tx.rf.enableLevel = UCP_JESD_TRX_GPIO_DISABLE;
		gpioConfig.ch[i].tx.sw.port = 0;
		gpioConfig.ch[i].tx.sw.pin  = 0;
		gpioConfig.ch[i].tx.sw.enableLevel = UCP_JESD_TRX_GPIO_DISABLE;
		                 
		gpioConfig.ch[i].rx.trx.port = 0;
		gpioConfig.ch[i].rx.trx.pin  = 0;
		gpioConfig.ch[i].rx.trx.enableLevel = UCP_JESD_TRX_GPIO_DISABLE;
		gpioConfig.ch[i].rx.rf.port = 0;
		gpioConfig.ch[i].rx.rf.pin  = 0;
		gpioConfig.ch[i].rx.rf.enableLevel = UCP_JESD_TRX_GPIO_DISABLE;
		gpioConfig.ch[i].rx.sw.port = 0;
		gpioConfig.ch[i].rx.sw.pin  = 0;
		gpioConfig.ch[i].rx.sw.enableLevel = UCP_JESD_TRX_GPIO_DISABLE;
		                 
		gpioConfig.ch[i].orx.trx.port = 0;
		gpioConfig.ch[i].orx.trx.pin  = 0;
		gpioConfig.ch[i].orx.trx.enableLevel = UCP_JESD_TRX_GPIO_DISABLE;
		gpioConfig.ch[i].orx.rf.port = 0;
		gpioConfig.ch[i].orx.rf.pin  = 0;
		gpioConfig.ch[i].orx.rf.enableLevel = UCP_JESD_TRX_GPIO_DISABLE;
		gpioConfig.ch[i].orx.sw.port = 0;
		gpioConfig.ch[i].orx.sw.pin  = 0;
		gpioConfig.ch[i].orx.sw.enableLevel = UCP_JESD_TRX_GPIO_DISABLE;
	}

    gpioConfig.triger.port = 0;
    gpioConfig.triger.pin  = 0;
    gpioConfig.triger.enableLevel = UCP_JESD_TRX_GPIO_DISABLE;
	
	item = xzJSON_AddObjectToObject(root, "common");
	xzJSON_AddStringToObject(item, "board", gpioConfig.board);
	xzJSON_AddNumberToObject(item, "version", gpioConfig.version);
	xzJSON_AddNumberToObject(item, "maxCh", gpioConfig.maxCh);
	xzJSON_AddNumberToObject(item, "devClkSrc", gpioConfig.devClkSrc);
	xzJSON_AddNumberToObject(item, "uldelay", 0);
	xzJSON_AddNumberToObject(item, "dldelay", 0);
    xzJSON_AddStringToObject(item, "lvdsCoupling", gpioConfig.lvdsCoupling);
	
	item = xzJSON_CreateArray();
	for (i = 0;i < gpioConfig.maxCh;i++)
	{
		config = xzJSON_CreateObject();
		xzJSON_AddNumberToObject(config, "tx_trx_port",         gpioConfig.ch[i].tx.trx.port);
		xzJSON_AddNumberToObject(config, "tx_trx_pin",          gpioConfig.ch[i].tx.trx.pin);
		xzJSON_AddNumberToObject(config, "tx_trx_enableLevel",  gpioConfig.ch[i].tx.trx.enableLevel);
		xzJSON_AddNumberToObject(config, "tx_rf_port",          gpioConfig.ch[i].tx.rf.port);
		xzJSON_AddNumberToObject(config, "tx_rf_pin",           gpioConfig.ch[i].tx.rf.pin);
		xzJSON_AddNumberToObject(config, "tx_rf_enableLevel",   gpioConfig.ch[i].tx.rf.enableLevel);
		xzJSON_AddNumberToObject(config, "tx_sw_port",          gpioConfig.ch[i].tx.sw.port);
		xzJSON_AddNumberToObject(config, "tx_sw_pin",           gpioConfig.ch[i].tx.sw.pin);
		xzJSON_AddNumberToObject(config, "tx_sw_enableLevel",   gpioConfig.ch[i].tx.sw.enableLevel);
		
		xzJSON_AddNumberToObject(config, "rx_trx_port",         gpioConfig.ch[i].rx.trx.port);
		xzJSON_AddNumberToObject(config, "rx_trx_pin",          gpioConfig.ch[i].rx.trx.pin);
		xzJSON_AddNumberToObject(config, "rx_trx_enableLevel",  gpioConfig.ch[i].rx.trx.enableLevel);
		xzJSON_AddNumberToObject(config, "rx_rf_port",          gpioConfig.ch[i].rx.rf.port);
		xzJSON_AddNumberToObject(config, "rx_rf_pin",           gpioConfig.ch[i].rx.rf.pin);
		xzJSON_AddNumberToObject(config, "rx_rf_enableLevel",   gpioConfig.ch[i].rx.rf.enableLevel);
		xzJSON_AddNumberToObject(config, "rx_sw_port",          gpioConfig.ch[i].rx.sw.port);
		xzJSON_AddNumberToObject(config, "rx_sw_pin",           gpioConfig.ch[i].rx.sw.pin);
		xzJSON_AddNumberToObject(config, "rx_sw_enableLevel",   gpioConfig.ch[i].rx.sw.enableLevel);
		
		xzJSON_AddNumberToObject(config, "orx_trx_port",        gpioConfig.ch[i].orx.trx.port);
		xzJSON_AddNumberToObject(config, "orx_trx_pin",         gpioConfig.ch[i].orx.trx.pin);
		xzJSON_AddNumberToObject(config, "orx_trx_enableLevel", gpioConfig.ch[i].orx.trx.enableLevel);
		xzJSON_AddNumberToObject(config, "orx_rf_port",         gpioConfig.ch[i].orx.rf.port);
		xzJSON_AddNumberToObject(config, "orx_rf_pin",          gpioConfig.ch[i].orx.rf.pin);
		xzJSON_AddNumberToObject(config, "orx_rf_enableLevel",  gpioConfig.ch[i].orx.rf.enableLevel);
		xzJSON_AddNumberToObject(config, "orx_sw_port",         gpioConfig.ch[i].orx.sw.port);
		xzJSON_AddNumberToObject(config, "orx_sw_pin",          gpioConfig.ch[i].orx.sw.pin);
		xzJSON_AddNumberToObject(config, "orx_sw_enableLevel",  gpioConfig.ch[i].orx.sw.enableLevel);
		
		xzJSON_AddItemToArray(item, config);
	}

	config = xzJSON_CreateObject();
	xzJSON_AddNumberToObject(config, "triger_port",   gpioConfig.triger.port);
	xzJSON_AddNumberToObject(config, "triger_pin",    gpioConfig.triger.pin);
	xzJSON_AddNumberToObject(config, "triger_enableLevel", gpioConfig.triger.enableLevel);
	xzJSON_AddItemToArray(item, config);

	xzJSON_AddItemReferenceToObject(root, "config", item);
	printfJson(root);
	ucp_jsonSave(fileName, root);
	
	//xzJSON_Delete(root);
	//xzJSON_Delete(item);
	//xzJSON_Delete(config);
}

ucp_jesd_TrxGpioCfg_t ucp_GetGpioConfig (const char *fileName)
{
	ucp_jesd_TrxGpioCfg_t gpioConfig;
	xzJSON *root, *item, *array, *config;
	uint32_t i;

	root = ucp_jsonLoad(fileName);
	if (((xzJSON*)NULL) == root)
	{
	    printf("Error: Can't find gpio's config File!\n");
	    exit(1);
	}
	
	memset(&gpioConfig, 0, sizeof(gpioConfig));

	item = xzJSON_GetObjectItem(root, "common");
	config = xzJSON_GetObjectItem(item, "board");
	strcpy(gpioConfig.board, config->valuestring);
	config = xzJSON_GetObjectItem(item, "version");
	gpioConfig.version = config->valueint;
	config = xzJSON_GetObjectItem(item, "maxCh");
	gpioConfig.maxCh = config->valueint;
	config = xzJSON_GetObjectItem(item, "devClkSrc");
	gpioConfig.devClkSrc = config->valueint;
	config = xzJSON_GetObjectItem(item, "uldelay");
	gpioConfig.uldelay = config->valueint;
	config = xzJSON_GetObjectItem(item, "dldelay");
	gpioConfig.dldelay = config->valueint;	
    if (gpioConfig.version > 1)
    {
        config = xzJSON_GetObjectItem(item, "lvdsCoupling");
        strcpy(gpioConfig.lvdsCoupling, config->valuestring);
    }
    else
    {
        printf("Note: A new version of ucp_trx_gpioCfg.json is available, please update!\n");
    }
    
	item = xzJSON_GetObjectItem(root, "config");
	for (i = 0;i < gpioConfig.maxCh;i++)
	{
		array = xzJSON_GetArrayItem(item, i);
		
		config = xzJSON_GetObjectItem(array, "tx_trx_port");
		gpioConfig.ch[i].tx.trx.port = config->valueint;
		config = xzJSON_GetObjectItem(array, "tx_trx_pin");
		gpioConfig.ch[i].tx.trx.pin = config->valueint;
		config = xzJSON_GetObjectItem(array, "tx_trx_enableLevel");
		gpioConfig.ch[i].tx.trx.enableLevel = config->valueint;
		config = xzJSON_GetObjectItem(array, "tx_rf_port");
		gpioConfig.ch[i].tx.rf.port = config->valueint;
		config = xzJSON_GetObjectItem(array, "tx_rf_pin");
		gpioConfig.ch[i].tx.rf.pin = config->valueint;
		config = xzJSON_GetObjectItem(array, "tx_rf_enableLevel");
		gpioConfig.ch[i].tx.rf.enableLevel = config->valueint;
		config = xzJSON_GetObjectItem(array, "tx_sw_port");
		gpioConfig.ch[i].tx.sw.port = config->valueint;
		config = xzJSON_GetObjectItem(array, "tx_sw_pin");
		gpioConfig.ch[i].tx.sw.pin = config->valueint;
		config = xzJSON_GetObjectItem(array, "tx_sw_enableLevel");
		gpioConfig.ch[i].tx.sw.enableLevel = config->valueint;
		
		config = xzJSON_GetObjectItem(array, "rx_trx_port");
		gpioConfig.ch[i].rx.trx.port = config->valueint;
		config = xzJSON_GetObjectItem(array, "rx_trx_pin");
		gpioConfig.ch[i].rx.trx.pin = config->valueint;
		config = xzJSON_GetObjectItem(array, "rx_trx_enableLevel");
		gpioConfig.ch[i].rx.trx.enableLevel = config->valueint;
		config = xzJSON_GetObjectItem(array, "rx_rf_port");
		gpioConfig.ch[i].rx.rf.port = config->valueint;
		config = xzJSON_GetObjectItem(array, "rx_rf_pin");
		gpioConfig.ch[i].rx.rf.pin = config->valueint;
		config = xzJSON_GetObjectItem(array, "rx_rf_enableLevel");
		gpioConfig.ch[i].rx.rf.enableLevel = config->valueint;
		config = xzJSON_GetObjectItem(array, "rx_sw_port");
		gpioConfig.ch[i].rx.sw.port = config->valueint;
		config = xzJSON_GetObjectItem(array, "rx_sw_pin");
		gpioConfig.ch[i].rx.sw.pin = config->valueint;
		config = xzJSON_GetObjectItem(array, "rx_sw_enableLevel");
		gpioConfig.ch[i].rx.sw.enableLevel = config->valueint;
		
		config = xzJSON_GetObjectItem(array, "orx_trx_port");
		gpioConfig.ch[i].orx.trx.port = config->valueint;
		config = xzJSON_GetObjectItem(array, "orx_trx_pin");
		gpioConfig.ch[i].orx.trx.pin = config->valueint;
		config = xzJSON_GetObjectItem(array, "orx_trx_enableLevel");
		gpioConfig.ch[i].orx.trx.enableLevel = config->valueint;
		config = xzJSON_GetObjectItem(array, "orx_rf_port");
		gpioConfig.ch[i].orx.rf.port = config->valueint;
		config = xzJSON_GetObjectItem(array, "orx_rf_pin");
		gpioConfig.ch[i].orx.rf.pin = config->valueint;
		config = xzJSON_GetObjectItem(array, "orx_rf_enableLevel");
		gpioConfig.ch[i].orx.rf.enableLevel = config->valueint;
		config = xzJSON_GetObjectItem(array, "orx_sw_port");
		gpioConfig.ch[i].orx.sw.port = config->valueint;
		config = xzJSON_GetObjectItem(array, "orx_sw_pin");
		gpioConfig.ch[i].orx.sw.pin = config->valueint;
		config = xzJSON_GetObjectItem(array, "orx_sw_enableLevel");
		gpioConfig.ch[i].orx.sw.enableLevel = config->valueint;
	}

    array = xzJSON_GetArrayItem(item, 4);
    config = xzJSON_GetObjectItem(array, "triger_port");
    gpioConfig.triger.port = config->valueint;
    config = xzJSON_GetObjectItem(array, "triger_pin");
    gpioConfig.triger.pin = config->valueint;
    config = xzJSON_GetObjectItem(array, "triger_enableLevel");
    gpioConfig.triger.enableLevel = config->valueint;

	return gpioConfig;
}

ucp_rfic_cfg_t ucp_GetRficCfgInfo(void)
{
    ucp_rfic_cfg_t st_rfic_cfg;
    xzJSON *root   = NULL;
    xzJSON *item   = NULL;
    xzJSON *config = NULL;

    root = ucp_jsonLoad(RFIC_CFG_FILE_PATH);
    if (((xzJSON*)NULL) == root)
    {
        printf("rfic_get_cfg_info: load file error!\r\n");
        exit(1);
    }
    
    item = xzJSON_GetObjectItem(root, "common");
    config = xzJSON_GetObjectItem(item, "txLo");
    st_rfic_cfg.txLo = config->valuedouble;
    config = xzJSON_GetObjectItem(item, "rxLo");
    st_rfic_cfg.rxLo = config->valuedouble;
    config = xzJSON_GetObjectItem(item, "auxLo");
    st_rfic_cfg.auxLo = config->valuedouble;
    config = xzJSON_GetObjectItem(item, "initAtt");
    st_rfic_cfg.initAtt  = config->valueint;
    config = xzJSON_GetObjectItem(item, "initGain");
    st_rfic_cfg.initGain = config->valueint;

    item = xzJSON_GetObjectItem(root, "para");
    config = xzJSON_GetObjectItem(item, "sampleRate");
    st_rfic_cfg.sampleRate = config->valueint;
    config = xzJSON_GetObjectItem(item, "bw");
    st_rfic_cfg.bw   = config->valuedouble;
    config = xzJSON_GetObjectItem(item, "antNumb");
    st_rfic_cfg.antNumb   = config->valuedouble;
    config = xzJSON_GetObjectItem(item, "enFdd");
    st_rfic_cfg.enFdd   = config->valuedouble;
    config = xzJSON_GetObjectItem(item, "enOrx");
    st_rfic_cfg.enOrx   = config->valuedouble;
    config = xzJSON_GetObjectItem(item, "en204C");
    st_rfic_cfg.en204C   = config->valuedouble;
    config = xzJSON_GetObjectItem(item, "enUcpLog");
    st_rfic_cfg.enUcpLog = config->valuedouble;
    
    config = xzJSON_GetObjectItem(item, "calOrxGainIndex");
    st_rfic_cfg.calOrxGainIndex = config->valueint;

    item = xzJSON_GetObjectItem(item, "calChAttPara");
	config = xzJSON_GetObjectItem(item, "ch1");
    st_rfic_cfg.calChAttPara[0] = config->valueint;
    config = xzJSON_GetObjectItem(item, "ch2");
    st_rfic_cfg.calChAttPara[1] = config->valueint;
    config = xzJSON_GetObjectItem(item, "ch3");
    st_rfic_cfg.calChAttPara[2] = config->valueint;
    config = xzJSON_GetObjectItem(item, "ch4");
    st_rfic_cfg.calChAttPara[3] = config->valueint;
    
    xzJSON_Delete(root);

    return st_rfic_cfg;
}

ucp_rfic_calPara_t ucp_GetRficCalParaInfo(void)
{
    ucp_rfic_calPara_t st_rfic_para;
    xzJSON *root   = NULL;
    xzJSON *item   = NULL;
    xzJSON *config = NULL;
    
    root = ucp_jsonLoad(RFIC_CAL_FILE_PATH);
    if (((xzJSON*)NULL) == root)
    {
        printf("rfic_get_cfg_info: load file error!\r\n");
        exit(1);
    }
    
    config = xzJSON_GetObjectItem(root, "calOrxGainIndex");
    st_rfic_para.calOrxGainIndex = config->valueint;

    item = xzJSON_GetObjectItem(root, "calChAttPara");
	config = xzJSON_GetObjectItem(item, "ch1");
    st_rfic_para.calChAttPara[0] = config->valueint;
    config = xzJSON_GetObjectItem(item, "ch2");
    st_rfic_para.calChAttPara[1] = config->valueint;
    config = xzJSON_GetObjectItem(item, "ch3");
    st_rfic_para.calChAttPara[2] = config->valueint;
    config = xzJSON_GetObjectItem(item, "ch4");
    st_rfic_para.calChAttPara[3] = config->valueint;

    xzJSON_Delete(root);

    return st_rfic_para;
}

#if 0
int main(int argc, char *argv[]) 
{    
	ucp_jesd_TrxGpioCfg_t gpioConfig;
	
	ucp_GenGpioConfig("./ucp_trx_gpioCfg.json");
	gpioConfig = ucp_GetGpioConfig("./ucp_trx_gpioCfg_evb.json");
	ucp_printGpioConfigStruct(gpioConfig);
	
    return 0;
}
#endif
