//******************** (C) COPYRIGHT 2022 SmartLogic*******************************
// FileName           : ucp_reg_io.c
// Author             : boheng.lin@smartlogictech.com
// Date First Issued  : 2022-09-08 02:37:50 PM
// Last Modified      : 
// Description        :
// ------------------------------------------------------------
// Modification History:
// Version    Date       Author    Modification Description
//
//**********************************************************************************

#include <stdint.h>

#include <stdio.h>
#include <stdlib.h>
#include <fcntl.h>
#include <sys/ioctl.h>
#include <unistd.h>
#include <string.h>

#define ARGV_CMD_POS 1
#define ARGV_ADDR_POS 2
#define ARGV_DATA_POS 3
#define ARGV_RBYTE_POS 3
#define ARGV_WBYTE_POS 4

#define IOCTL_MMAPREG _IO('k',0x20)

static int regfd = 0;

typedef union c2u32_t
{
	char     c[4];
	uint32_t u;
} tC2u32;

typedef union c2u16_t
{
	char     c[2];
	uint16_t u;
} tC2u16;

int ucp_reg_init (void)
{
	if (0 != regfd)
	{
		close(regfd);
	}
	
	regfd = open("/dev/ioreg", O_RDWR);
	if (regfd < 0)  
	{
		printf("open(/dev/ioreg) failed.");    
		return 0;
	}
	
	return regfd;
}

void ucp_reg32_or_write(uint64_t reg, uint32_t mask)
{
    tC2u32 val;
        
    if((reg%4) != 0)
    {
        printf("Addr Err.\r\n");
        return;
    }

    // printf("orW:  %08X %08X\n", (uint32_t)reg, mask);
    val.u = 0;
    ioctl(regfd, IOCTL_MMAPREG, &reg);
    read(regfd,(char*)val.c, 4);
    val.u |= mask;
    ioctl(regfd, IOCTL_MMAPREG, &reg);
    write(regfd, val.c, 4);
                
    return;
}

void ucp_reg32_and_write(uint64_t reg, uint32_t mask)
{
    tC2u32 val;
            
    if((reg%4) != 0)
    {
        printf("Addr Err.\r\n");
        return;
    }

    // printf("andW: %08X %08X\n", (uint32_t)reg, mask);
    val.u = 0;
    mask = ~mask;
    ioctl(regfd, IOCTL_MMAPREG, &reg);
    read(regfd,(char*)val.c, 4);
    val.u &= mask;
    ioctl(regfd, IOCTL_MMAPREG, &reg);
    write(regfd, val.c, 4);
                
    return;
}

uint32_t ucp_reg32_and_read(uint64_t reg, uint32_t mask)
{
    tC2u32 val;
                
    if((reg%4) != 0)
    {
        printf("Addr Err.\r\n");
        return 0;
    }

    val.u = 0;
    ioctl(regfd, IOCTL_MMAPREG, &reg);
    read(regfd,(char*)val.c, 4);
    val.u &= mask;
                
    return val.u;

}

void ucp_reg16_write(uint64_t reg, uint16_t data)
{
	tC2u16 val;
	
	if((reg%2) != 0)
	{
		printf("Addr Err.\r\n");
		return;
	}
	
	val.u = data;
	ioctl(regfd, IOCTL_MMAPREG, &reg);
	write(regfd, val.c, 2);
			
    return;
}

uint16_t ucp_reg16_read(uint64_t reg)
{
    tC2u16 val;

	if((reg%2) != 0)
	{
		printf("Addr Err.\r\n");
		return 0;
	}

	val.u = 0;
    ioctl(regfd, IOCTL_MMAPREG, &reg);
	read(regfd,(char*)val.c, 2);
	
	return val.u;
}

void ucp_reg32_write(uint64_t reg, uint32_t data)
{
	tC2u32 val;
	
	if((reg%4) != 0)
	{
		printf("Addr Err.\r\n");
		return;
	}
	
	val.u = data;
	ioctl(regfd, IOCTL_MMAPREG, &reg);
	write(regfd, val.c, 4);
			
    return;
}

uint32_t ucp_reg32_read(uint64_t reg)
{
    tC2u32 val;

	if((reg%4) != 0)
	{
		printf("Addr Err. @%s\r\n", __func__);
		return 0;
	}

	val.u = 0;
    ioctl(regfd, IOCTL_MMAPREG, &reg);
	read(regfd,(char*)val.c, 4);
	
	return val.u;
}

void ucp_reg_test(void)
{
    ucp_reg_init();

    printf("reg 0 = 0x%X\n", ucp_reg32_read(0x4458000+0x17c));
    ucp_reg32_write(0x4458000+0x17c, 0x15c03001);
    printf("reg 1 = 0x%X\n", ucp_reg32_read(0x4458000+0x17c));
    ucp_reg32_or_write(0x4458000+0x17c, 0x01);
    printf("reg 2 = 0x%X\n", ucp_reg32_read(0x4458000+0x17c));
    ucp_reg32_and_write(0x4458000+0x17c, 0x10);
    printf("reg 3  = 0x%X\n", ucp_reg32_read(0x4458000+0x17c));
    printf("reg 4  = 0x%X\n", ucp_reg32_and_read(0x4458000+0x17c, 0x01));
    printf("reg 5  = 0x%X\n", ucp_reg32_and_read(0x4458000+0x17c, 0x10));
}


