/*------------------------------------------------------------
//                 Copyright (c) 2022 SmartLogic.
//                       ALL RIGHTS RESERVED
// -----------------------------------------------------------------
// Filename      : stc_drv.c
// Author        : weihua.li
// Created On    : 2022-11-23
// Last Modified :
// -----------------------------------------------------------------
// Description:
//
//
// ----------------------------------------------------------------*/
#define _GNU_SOURCE
#include <stdio.h>
#include <string.h>
#include <sys/types.h>
//#include <asm-generic/unistd.h>
#include <errno.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <unistd.h>
#include <termios.h>
#include <stdlib.h>
#include <time.h>
#include <sys/ipc.h>
#include <sys/sem.h>
#include <linux/times.h>
#include <sys/time.h>
//#include <linux/interrupt.h>
#include <stdarg.h>

#include "ucp_printf.h"
#include "typedef.h"
#include "../inc/lc98s_drv.h"
#include "nmea.h"

#define PRINT_NO      (0)
#define PRINT_UTC     (1<<0)
#define PRINT_MSG     (1<<1)
#define PRINT_GGA     (1<<2)
#define PRINT_GSA     (1<<3)
#define PRINT_GSV     (1<<4)
#define PRINT_RMC     (1<<5)

drv_gps_msg_s g_gps_recv_msg;

uint8_t g_tx_buf[GPS_TX_BUF_SIZE];
uint8_t g_curRxIndex = 0;
uint8_t g_rx_cnt[2] = {0, 0};
uint8_t g_rx_buf[2][HALF_BUFSIZE];
int32_t g_gps_recv_task_id = -1;


gps_uart_s g_gps_uart = 
{
    .recv_ptr = 0,
    .deal_ptr = 0,
    .recv_cnt = 0,
    .deal_cnt = 0,
    .send_cnt = 0,    
    .send_buf_ptr = (uint8_t*)(g_tx_buf),
};

uint8_t g_almanach_flag;        /*Almanach flag*/
int32_t g_ubx_sem[GPS_SEM_NUM];
uint32_t g_tod_link_alarm = 0;
int32_t g_tfu_sync_sem = -1;   //pp1s中断同步信号量
int32_t g_tfu_to_time_sem = 0;  //tracking后释放给OM，计算帧号
int32_t g_tfu_init_flag = 0;
int32_t drv_uart_fd = -1;
int32_t g_sem_prj_id = 20;

static struct tGGA gga;
static struct tGSA gsa;
static struct tGSV gsv;
static struct tRMC rmc;
static uint16_t printMask = (PRINT_UTC);

extern void drv_tfu_phase_adjust(uint8_t count);
extern int32_t drv_semaphore_p(int32_t sem_id);
static int32_t drv_semaphore_timed_p(int32_t sem_id,int32_t timeout_us);
static int32_t drv_semaphore_v(int32_t sem_id);

extern void nmea_messageConfig (void);
extern void drv_set_odd_flag(uint8_t flag); /*1:odd  2:even*/

extern int32_t drv_thread_create(uint8_t* pthread_name, uint8_t thread_prio, uint32_t thread_size, void *callback, void* pArg);


int32_t drv_sem_create(int32_t prj_id)
{
    key_t key;
    int32_t sem_id;
    union semun sem_union;

    //key = ftok(MY_IPCKEY,prj_id);
    key = MY_IPCKEY + prj_id;
    sem_id = semget((key_t)key, 1, IPC_CREAT);
    if(-1 == sem_id)
    {
        UCP_PRINT_ERROR("semget error  sem_id:%d  err = %s!\n\r",sem_id,strerror(errno));
        return OSP_ERROR;
    }

    sem_union.val = 1;
    if(semctl(sem_id, 0, SETVAL, sem_union) == -1)
    {
        UCP_PRINT_ERROR("semctl error\n\r");
        return OSP_ERROR;
    }

    return sem_id;
}

int32_t drv_sem_create_sync(int32_t prj_id)
{
    key_t key;
    int32_t sem_id;
    union semun sem_union;

    //key = ftok(MY_IPCKEY,prj_id);
    key = MY_IPCKEY + prj_id;
    sem_id = semget((key_t)key, 1, IPC_CREAT);
    if(-1 == sem_id)
    {
        UCP_PRINT_ERROR("semget error  sem_id:%d  err = %s!\n\r",sem_id,strerror(errno));
        return OSP_ERROR;
    }

    sem_union.val = 0;
    if(semctl(sem_id, 0, SETVAL, sem_union) == -1)
    {
        UCP_PRINT_ERROR("semctl error\n\r");
        return OSP_ERROR;
    }

    return sem_id;
}

int32_t drv_semaphore_p(int32_t sem_id)
{
    struct sembuf sem_p;
    sem_p.sem_num = 0;
    sem_p.sem_op = -1;
    sem_p.sem_flg = SEM_UNDO;

    if(semop(sem_id, &sem_p, 1) == -1)
    {
        UCP_PRINT_ERROR("semaphore_p failed  err=%s \n\r",strerror(errno));
        return OSP_ERROR;
    }

    return OSP_OK;
}

static int32_t drv_semaphore_timed_p(int32_t sem_id,int32_t timeout_us)
{
    struct sembuf sem_p;
    struct timespec time;
    int32_t temp = timeout_us;

    if(temp >= 1000000)
    {
        time.tv_sec = temp/1000/1000;
        temp = temp%1000000;
    }
    else
    {
        time.tv_sec = 0;
    }

    time.tv_nsec = temp*1000;

    sem_p.sem_num = 0;
    sem_p.sem_op = -1;
    sem_p.sem_flg = SEM_UNDO;

    if(semtimedop(sem_id, &sem_p, 1,&time) == -1)
    {
        UCP_PRINT_ERROR("semtimedop failed");
        return OSP_ERROR;
    }

    return OSP_OK;
}


static int32_t drv_semaphore_v(int32_t sem_id)
{
    struct sembuf sem_b;

    sem_b.sem_num = 0;
    sem_b.sem_op = 1;
    sem_b.sem_flg = SEM_UNDO;
    if(semop(sem_id, &sem_b, 1) == -1)
    {
        UCP_PRINT_ERROR("semaphore_v failed sem_id%d err = %s! \n\r",sem_id, strerror(errno));
        return OSP_ERROR;
    }
    return OSP_OK;
}

int32_t set_opt(int32_t fd,int32_t nSpeed, int32_t nBits, int8_t nEvent, int32_t nStop)
{
    struct termios newtio,oldtio;

    if ( tcgetattr( fd,&oldtio) != 0)
    {
        perror("SetupSerial error");
        UCP_PRINT_ERROR("SetupSerial error\n\r");
        return -1;
    }

    bzero( &newtio, sizeof( newtio ) );
    newtio.c_cflag |= CLOCAL | CREAD;
    newtio.c_cflag &= ~CSIZE;

    switch( nBits )
    {
        case 7:
            newtio.c_cflag |= CS7;
        break;
        case 8:
            newtio.c_cflag |= CS8;
        break;
    }

    switch( nEvent )
    {
        case 'O':
            newtio.c_cflag |= PARENB;
            newtio.c_cflag |= PARODD;
            newtio.c_iflag |= (INPCK | ISTRIP);
        break;
        case 'E':
            newtio.c_iflag |= (INPCK | ISTRIP);
            newtio.c_cflag |= PARENB;
            newtio.c_cflag &= ~PARODD;
        break;
        case 'N':
            newtio.c_cflag &= ~PARENB;
        break;
    }

    switch( nSpeed )
    {
        case 2400:
            cfsetispeed(&newtio, B2400);
            cfsetospeed(&newtio, B2400);
        break;
        case 4800:
            cfsetispeed(&newtio, B4800);
            cfsetospeed(&newtio, B4800);
        break;
        case 9600:
            cfsetispeed(&newtio, B9600);
            cfsetospeed(&newtio, B9600);
        break;
        case 115200:
            cfsetispeed(&newtio, B115200);
            cfsetospeed(&newtio, B115200);
        break;
        default:
            cfsetispeed(&newtio, B9600);
            cfsetospeed(&newtio, B9600);
        break;
    }

    if( nStop == 1 )
    {
        newtio.c_cflag &= ~CSTOPB;
    }
    else if ( nStop == 2 )
    {
        newtio.c_cflag |= CSTOPB;
    }
    newtio.c_cc[VTIME] = 1;  //100ms
    newtio.c_cc[VMIN] = 64; //60;  
    tcflush(fd,TCIFLUSH);
    if((tcsetattr(fd,TCSANOW,&newtio))!=0)
    {
        perror("com set error");
        UCP_PRINT_ERROR("com set error\n\r");
        return -1;
    }
    UCP_PRINT_DEBUG("set done!\n");
    return 0;
}

static int32_t drv_tfu_uart_init(void)
{
    if(drv_uart_fd < 0)
    {
        drv_uart_fd = open( "/dev/ttyS2", O_RDWR);
        if (-1 == drv_uart_fd)
        {
            perror("Can't Open Serial Port");
            UCP_PRINT_ERROR("Can't Open Serial Port\n\r");
            return OSP_ERROR;
        }
    }
    
    if(fcntl(drv_uart_fd, F_SETFL, 0)<0)
    {
        UCP_PRINT_ERROR("fcntl failed!\n");
    }

    if(isatty(STDIN_FILENO) == 0)
    {
        UCP_PRINT_ERROR("standard input is not a terminal device\n");
    }

    if(set_opt(drv_uart_fd,115200,8,'N',1) < 0)
    {
        perror("set_opt error");
        UCP_PRINT_ERROR("set_opt error\n\r");
        return OSP_ERROR;
    }
    return OSP_OK;
}

static int32_t drv_uart_read(uint8_t *pdata, uint32_t len)
{
    int32_t read_bytes = 0;

    if(NULL == pdata)
    {
        return OSP_ERROR;
    }

    read_bytes = read(drv_uart_fd,pdata,len);
    if(read_bytes < 0)
    {
        // UCP_PRINT_ERROR("uart read error\n\r");
        return OSP_ERROR;
    }
    
    return read_bytes;
}

static int drv_tfu_uart_send (uint8_t *pdata, uint32_t len)
{
    int32_t write_count = 0;
    if((NULL == pdata)|(0 == len))
    {
        UCP_PRINT_ERROR("uart send para error");
        return OSP_ERROR;
    }

    write_count = write(drv_uart_fd,pdata,len);

    if(write_count < len)
    {
        UCP_PRINT_ERROR("uart send error write_count=%d,len=%d",write_count,len);
        return OSP_ERROR;
    }

    return OSP_OK;
}

int32_t drv_tfu_receiver_init(void)
{
    uint32_t i = 0;

    if(OSP_ERROR == (g_gps_uart.send_sem = drv_sem_create(g_sem_prj_id)))
    {
        UCP_PRINT_ERROR("TFU: create g_gps_uart.send_sem error!\n");
        return OSP_ERROR;
    }
    UCP_PRINT_DEBUG("g_gps_uart.send_sem=%d\n\r",g_gps_uart.send_sem);
    
    g_sem_prj_id++;
    for(i = 0; i < GPS_SEM_NUM; ++i)
    {
        if(OSP_ERROR == (g_ubx_sem[i]= drv_sem_create_sync(g_sem_prj_id++)))
        {
            UCP_PRINT_ERROR("drv_tfu_init semBCreate error  i:%d\n\r",i);
            return OSP_ERROR;
        }
        //g_sem_prj_id++;
    }

    g_gps_recv_task_id = drv_thread_create( (uint8_t *)"dgps_recv", 72, 8192,
                (void *)drv_gps_recv_task, NULL);
    if(OSP_ERROR == g_gps_recv_task_id)
    {
        UCP_PRINT_ERROR("lc98s: create GPS recv task error!\n");
        return OSP_ERROR;
    }    
    
    return OSP_OK;
}

void drv_gps_recv_task(void)
{
	uint8_t dealRxIndex, dealCnt; 
	int32_t recv_cnt, i, iCnt;
	uint8_t recv_buf[GPS_RX_BUF_SIZE];
	
	while(1)
	{
        recv_cnt = drv_uart_read(recv_buf, GPS_RX_BUF_SIZE);
    	if (recv_cnt > 0)
    	{
    		for (i = 0;i < recv_cnt;i++)
    		{
    			if (g_rx_cnt[g_curRxIndex] >= HALF_BUFSIZE)
    			{
    				g_rx_cnt[g_curRxIndex] = 0;
    			}
    			
    			if ('$' == recv_buf[i])
    			{
    				dealRxIndex = g_curRxIndex;
    				dealCnt = g_rx_cnt[g_curRxIndex];
    				g_rx_cnt[g_curRxIndex] = 0;
    				g_curRxIndex ^= 1;
    				g_rx_buf[dealRxIndex][dealCnt] = 0;
    				if (printMask & PRINT_MSG)
    				{
    					printf("%s", g_rx_buf[dealRxIndex]);
    				}
    				switch(NmeaGetType((int8_t*)g_rx_buf[dealRxIndex]))
    				{
    					case ENMEA_TYPE_GGA:
    					NmeaDealStr((int8_t*)g_rx_buf[dealRxIndex], &gga,sizeof(gga));
    					if (printMask & PRINT_GGA)
    					{
    						printf("#GGA:\r\n");
    						printf("Time:  %02d:%02d:%.3f\r\n", gga.hour + 8, gga.minute, gga.second);
    						printf("Lat:   %f\r\n", gga.lat);
    						printf("LatH:  %c\r\n", gga.latHemishere);
    						printf("Lon:   %f\r\n", gga.lon);
    						printf("LonH:  %c\r\n", gga.lonHemishere);
    						printf("Stat:  %d\r\n", gga.gpsState);
    						printf("NumU:  %d\r\n", gga.satNumber);
    						printf("HDOP:  %.1f\r\n", gga.hdop);
    						printf("Alt:   %f\r\n", gga.alt);
    						printf("DifT:  %f\r\n", gga.diffTime);
    						printf("DifI:  %d\r\n", gga.diffID);
    					}
    					nmea_messageConfig();
    					break;
    					
    					case ENMEA_TYPE_GSA:
    					NmeaDealStr((int8_t*)g_rx_buf[dealRxIndex], &gsa, sizeof(gsa));
    					if (printMask & PRINT_GSA)
    					{
    						printf("#GSA:\r\n");
    						printf("Mode:  %c\r\n", gsa.mode);
    						printf("Type:  %d\r\n", gsa.type);
    						printf("SatU:  ");
    						for (iCnt = 0; iCnt < 12; iCnt++)
    						{
    							if (gsa.prn[iCnt])
    							{
    								printf("%02d ", gsa.prn[iCnt]);
    							}
    						}
    						printf("\r\n");
    						printf("PDOP:  %.1f\r\n", gsa.pdop);
    						printf("HDOP:  %.1f\r\n", gsa.hdop);
    						printf("VDOP:  %.1f\r\n", gsa.vdop);
    					}
    					break;
    					
    					case ENMEA_TYPE_GSV:
    					NmeaDealStr((int8_t*)g_rx_buf[dealRxIndex], &gsv, sizeof(gsv));
    					if (printMask & PRINT_GSV)
    					{
    						printf("#GSV:\r\n");
    						printf("Total:%02d\r\n", gsv.total);
    						printf("Numb: %02d\r\n", gsv.numb);
    						printf("SatV: %02d\r\n", gsv.satInView);
    						for (iCnt = 0; iCnt < 4; iCnt++)
    						{
    							if (gsv.prn[iCnt])
    							{
    								printf("Sat:   ");
    								printf("%02d ", gsv.prn[iCnt]);
    								printf("%02d ", gsv.elev[iCnt]);
    								printf("%02d ", gsv.azim[iCnt]);
    								printf("%02d\r\n", gsv.snr[iCnt]);
    							}
    						}
    					}
    					break;
    					
    					case ENMEA_TYPE_RMC:
    					NmeaDealStr((int8_t*)g_rx_buf[dealRxIndex], &rmc, sizeof(rmc));
    					if (printMask & PRINT_RMC)
    					{
    						printf("#RMC:\r\n");
    						printf("Time:  %2d:%02d:%.3f\r\n", rmc.hour + 8, rmc.minute, rmc.second);
    						printf("Stat:  %c\r\n", rmc.state);
    						printf("Lat:   %f\r\n", rmc.lat);
    						printf("LatH:  %c\r\n", rmc.latHemishere);
    						printf("Lon:   %f\r\n", rmc.lon);
    						printf("LonH:  %c\r\n", rmc.lonHemishere);
    						printf("Speed: %f\r\n", rmc.speed);
    						printf("Azim:  %f\r\n", rmc.azim);
    						printf("Date:  %2d %02d %02d\r\n", rmc.year,rmc.month, rmc.day);
    						printf("Mag:   %f\r\n", rmc.magnetic);
    						printf("MAzim: %f\r\n", rmc.magneticAzim);
    						printf("Mode:  %c\r\n", rmc.mode);
    					}
    					
    					if (printMask & PRINT_UTC)
    					{
    						time_t utc;
    						get_src_time(&utc);
    						printf("fix: %d, utc: %lu\n", get_receiver_fix_status(), utc);
    					}
    					break;
    					
    					default:
    					break;
    				}
    			}
    			
    			g_rx_buf[g_curRxIndex][g_rx_cnt[g_curRxIndex]] = recv_buf[i];
    			g_rx_cnt[g_curRxIndex]++;
    		}
    	}
	}
}

void nmea_messageConfig (void)
{
	memset(g_tx_buf, 0, sizeof(g_tx_buf));
	strcpy((char*)g_tx_buf, "$PSTMCFGMSGL,0,1,44,0\r\n");
	drv_tfu_uart_send(g_tx_buf, strlen((char*)g_tx_buf));
	
	memset(g_tx_buf, 0, sizeof(g_tx_buf));
	strcpy((char*)g_tx_buf, "$PSTMSAVEPAR\r\n");
	drv_tfu_uart_send(g_tx_buf, strlen((char*)g_tx_buf));
	
	memset(g_tx_buf, 0, sizeof(g_tx_buf));
	strcpy((char*)g_tx_buf, "$PSTMSRR\r\n");
	drv_tfu_uart_send(g_tx_buf, strlen((char*)g_tx_buf));
}

int32_t reset_clock_module(void)
{
    return OSP_OK;
}

int32_t get_tfu_location_info(location_info_s *locat_ptr)
{
    if(NULL == locat_ptr)
    {
        UCP_PRINT_ERROR("locat_ptr == NULL\n\r");
        return OSP_ERROR;
    }
	
    return OSP_OK;
}

int32_t get_clock_tracking_state(tracking_info_s *trk_ptr)
{   
	trk_ptr = (tracking_info_s*)0;
    return OSP_OK;
}

int32_t get_receiver_fix_status()
{
    return (3 == gsa.type) ? 1 : 0;  //接收机锁定状态
}

int32_t get_src_time(time_t* time_ptr)
{
    struct tm t;
	time_t tmp_time;
	
	t.tm_year  = rmc.year + 2000 - 1900;
	t.tm_mon   = rmc.month - 1;
	t.tm_mday  = rmc.day;
	t.tm_hour  = rmc.hour;
	t.tm_min   = rmc.minute;
	t.tm_sec   = (int32_t)rmc.second;
	t.tm_isdst = -1;
	
    tmp_time = mktime(&t);
    *time_ptr  = tmp_time;
	
    return OSP_OK; 
}

int32_t drv_tfu_get_ublox_seconds(time_t* sec_ptr)
{   
    return get_src_time(sec_ptr);
}

int32_t init_clock_module(void)
{
    int32_t result = 0;
   
    if(1 == g_tfu_init_flag)
    {
        UCP_PRINT_ERROR("tfu init flag = 1");
        return OSP_ERROR;
    }
    else
    {
        result = drv_tfu_uart_init();
        if(OSP_ERROR == result)
        {
            UCP_PRINT_ERROR("uart init error\n\r");
            return OSP_ERROR;
        }

        /*tracking后释放给OM，计算帧号*/
        if(OSP_ERROR == (g_tfu_to_time_sem = drv_sem_create(g_sem_prj_id)))
        {
            UCP_PRINT_ERROR("g_tfu_to_time_sem create error\n\r");
            return OSP_ERROR;
        }
        UCP_PRINT_DEBUG("g_tfu_to_time_sem=%d\n\r",g_tfu_to_time_sem);

        g_sem_prj_id++;
        if(OSP_ERROR == (g_tfu_sync_sem = drv_sem_create_sync(g_sem_prj_id)))
        {
            UCP_PRINT_ERROR("g_tfu_sync_sem create error\n\r");
            return OSP_ERROR;
        }
        g_sem_prj_id++;        
        UCP_PRINT_DEBUG("g_tfu_sync_sem=%d\n\r",g_tfu_sync_sem);
        
        g_tfu_init_flag = 1;
        return OSP_OK;
    }
}

