/**
* @file     nmea.c
* @brief    This is the nmea file.
* @details
* @author   BohengLin
* @date     2014.1.21
* @version  V0.0.1
* @par      Copyright (c): Company
* @par      History:
*           V0.0.1: BohengLin,2014.1.21,build\n
*/

#include <stdlib.h>
#include <string.h>
#include <stdio.h>
#include <stdint.h>

#include "nmea.h"

#define TRUE  1
#define FALSE 0

#define MAX_NMEA_BYTES 512

static int8_t NmeaCheck(int8_t *inStr)
{
    uint32_t iCnt;
    uint8_t sum, check, checkStr[3];

    iCnt = 1;
    sum = 0;

    while (iCnt < MAX_NMEA_BYTES)
    {
       if (('*' == *(int8_t*)(inStr + iCnt)))
       {
           break;
       }

       sum ^= *(int8_t*)(inStr + iCnt);
       iCnt++;
    }

    checkStr[0] = *(int8_t*)(inStr + iCnt + 1);
    checkStr[1] = *(int8_t*)(inStr + iCnt + 2);
    checkStr[2] = '\0';

    check = (uint8_t)(strtol((const char*)checkStr,NULL,16) & 0xFF);

    return (check == sum) ? TRUE : FALSE;
}

static uint32_t NmeaGetValue(int8_t *inStr,uint32_t start,
                           int8_t *outStr,uint32_t outSize)
{
    uint32_t pos, len, iCnt;
    int8_t tmp;

    pos = 0;
    iCnt = 0;
    tmp = 0;
    len = (uint32_t)strlen((const char*)inStr);
    memset(outStr,0,outSize);

    while ((',' != tmp) && (pos < len))
    {
        tmp = *(int8_t*)(inStr + start + pos);

        if (pos < outSize)
        {
            if (' ' != tmp)
            {
                *(int8_t*)(outStr + iCnt) = tmp;
                iCnt++;
            }
        }
        else
        {
            return 0;
        }

        pos++;
    }

    *(int8_t*)(outStr + pos - 1) = '\0';

    return (start + pos);
}

static int8_t NmeaDealGGA(struct tGGA *gga,int8_t *str)
{
    uint32_t n;
    int8_t buf[125];

    n = NmeaGetValue(str,7,buf,sizeof(buf));
    gga->hour = (buf[0] - '0')*10 + (buf[1] - '0');
    gga->minute = (buf[2] - '0')*10 + (buf[3] - '0');
    gga->second = atof((const char*)&buf[4]);

    n = NmeaGetValue(str,n,buf,sizeof(buf));
    gga->lat = atof((const char*)buf);

    n = NmeaGetValue(str,n,buf,sizeof(buf));
    gga->latHemishere = buf[0];

    n = NmeaGetValue(str,n,buf,sizeof(buf));
    gga->lon = atof((const char*)buf);

    n = NmeaGetValue(str,n,buf,sizeof(buf));
    gga->lonHemishere = buf[0];

    n = NmeaGetValue(str,n,buf,sizeof(buf));
    gga->gpsState = buf[0] - '0';

    n = NmeaGetValue(str,n,buf,sizeof(buf));
    gga->satNumber = atoi((const char*)buf);

    n = NmeaGetValue(str,n,buf,sizeof(buf));
    gga->hdop = atof((const char*)buf);

    n = NmeaGetValue(str,n,buf,sizeof(buf));
    gga->alt = atof((const char*)buf);

    // M
    n = NmeaGetValue(str,n,buf,sizeof(buf));
    n = NmeaGetValue(str,n,buf,sizeof(buf));
    // M
    n = NmeaGetValue(str,n,buf,sizeof(buf));

    n = NmeaGetValue(str,n,buf,sizeof(buf));
    gga->diffTime = atof((const char*)buf);

    n = NmeaGetValue(str,n,buf,sizeof(buf));
    gga->diffID = atoi((const char*)buf);

    return TRUE;
}

static int8_t NmeaDealGSA(struct tGSA *gsa,int8_t *str)
{
    uint32_t n, iCnt;
    int8_t buf[125];

    n = NmeaGetValue(str,7,buf,sizeof(buf));
    gsa->mode = buf[0];

    n = NmeaGetValue(str,n,buf,sizeof(buf));
    gsa->type = buf[0] - '0';

    for (iCnt = 0; iCnt < 12; iCnt++)
    {
        buf[0] = 0;
        n = NmeaGetValue(str,n,buf,sizeof(buf));
        gsa->prn[iCnt] = atoi((const char*)buf);
    }

    n = NmeaGetValue(str,n,buf,sizeof(buf));
    gsa->pdop = atof((const char*)buf);

    n = NmeaGetValue(str,n,buf,sizeof(buf));
    gsa->hdop = atof((const char*)buf);

    n = NmeaGetValue(str,n,buf,sizeof(buf));
    gsa->vdop = atof((const char*)buf);

    return TRUE;
}

static int8_t NmeaDealGSV(struct tGSV *gsv,int8_t *str)
{
    uint32_t n, iCnt;
    int8_t buf[125];

    n = NmeaGetValue(str,7,buf,sizeof(buf));
    gsv->total = atoi((const char*)buf);

    n = NmeaGetValue(str,n,buf,sizeof(buf));
    gsv->numb = atoi((const char*)buf);

    n = NmeaGetValue(str,n,buf,sizeof(buf));
    gsv->satInView = atoi((const char*)buf);

    for (iCnt = 0; iCnt < 4; iCnt++)
    {
        buf[0] = 0;
        n = NmeaGetValue(str,n,buf,sizeof(buf));
        gsv->prn[iCnt] = atoi((const char*)buf);
        n = NmeaGetValue(str,n,buf,sizeof(buf));
        gsv->elev[iCnt] = atof((const char*)buf);
        n = NmeaGetValue(str,n,buf,sizeof(buf));
        gsv->azim[iCnt] = atof((const char*)buf);
        n = NmeaGetValue(str,n,buf,sizeof(buf));
        gsv->snr[iCnt] = (uint8_t)atol((const char*)buf);
    }

    return TRUE;
}

int8_t NmeaDealRMC(struct tRMC *rmc,int8_t *str)
{
    uint32_t n;
    int8_t buf[125];

    n = NmeaGetValue(str,7,buf,sizeof(buf));
    rmc->hour = (buf[0] - '0')*10 + (buf[1] - '0');
    rmc->minute = (buf[2] - '0')*10 + (buf[3] - '0');
    rmc->second = (buf[4] - '0')*10 + (buf[5] - '0');

    n = NmeaGetValue(str,n,buf,sizeof(buf));
    rmc->state = buf[0];

    n = NmeaGetValue(str,n,buf,sizeof(buf));
    rmc->lat = atof((const char*)buf);

    n = NmeaGetValue(str,n,buf,sizeof(buf));
    rmc->latHemishere = buf[0];

    n = NmeaGetValue(str,n,buf,sizeof(buf));
    rmc->lon = atof((const char*)buf);

    n = NmeaGetValue(str,n,buf,sizeof(buf));
    rmc->lonHemishere = buf[0];

    n = NmeaGetValue(str,n,buf,sizeof(buf));
    rmc->speed = atof((const char*)buf);

    n = NmeaGetValue(str,n,buf,sizeof(buf));
    rmc->azim = atof((const char*)buf);

    n = NmeaGetValue(str,n,buf,sizeof(buf));
    rmc->day = (buf[0] - '0')*10 + (buf[1] - '0');
    rmc->month = (buf[2] - '0')*10 + (buf[3] - '0');
    rmc->year = (buf[4] - '0')*10 + (buf[5] - '0');

    n = NmeaGetValue(str,n,buf,sizeof(buf));
    rmc->magnetic = atof((const char*)buf);

    n = NmeaGetValue(str,n,buf,sizeof(buf));
    rmc->magneticAzim = buf[0];

    n = NmeaGetValue(str,n,buf,sizeof(buf));
    rmc->mode = buf[0];

    return TRUE;
}

int8_t NmeaGetType(int8_t *inStr)
{
	uint16_t magic1, magic2, magic3;

	magic1 = *(int8_t*)(inStr + 3);
    magic2 = *(int8_t*)(inStr + 4);
    magic3 = *(int8_t*)(inStr + 5);

	if ('G' == magic1)
    {
        if ('G' == magic2)
        {
            return ENMEA_TYPE_GGA;
        }
        else if ('S' == magic2)
        {
            if ('A' == magic3)
            {
                return ENMEA_TYPE_GSA;
            }
            else if ('V' == magic3)
            {
                return ENMEA_TYPE_GSV;
            }
        }
    }
    else if ('R' == magic1)
    {
        return ENMEA_TYPE_RMC;
    }

    return ENMEA_TYPE_INVALID;
}

int8_t NmeaDealStr(int8_t *inStr, void *outStr, uint32_t outSize)
{
    uint16_t magic1, magic2, magic3;

    if (FALSE == NmeaCheck(inStr))
    {
        printf("Check err\r\n");
        return ENMEA_TYPE_INVALID;
    }

    magic1 = *(int8_t*)(inStr + 3);
    magic2 = *(int8_t*)(inStr + 4);
    magic3 = *(int8_t*)(inStr + 5);

    if ('G' == magic1)
    {
        if ('G' == magic2)
        {
            if (outSize >= sizeof(struct tGGA))
            {
                NmeaDealGGA(outStr, inStr);
                return ENMEA_TYPE_GGA;
            }
        }
        else if ('S' == magic2)
        {
            if ('A' == magic3)
            {
                if (outSize >= sizeof(struct tGSA))
                {
                    NmeaDealGSA(outStr,inStr);
                    return ENMEA_TYPE_GSA;
                }
            }
            else if ('V' == magic3)
            {
                if (outSize >= sizeof(struct tGSV))
                {
                    NmeaDealGSV(outStr, inStr);
                    return ENMEA_TYPE_GSV;
                }
            }
        }
    }
    else if ('R' == magic1)
    {
        if (outSize >= sizeof(struct tRMC))
        {
            NmeaDealRMC(outStr, inStr);
            return ENMEA_TYPE_RMC;
        }
    }

    return ENMEA_TYPE_INVALID;
}

#if PRJ_NMEA_TEST

void NmeaTest(void)
{
    uint32_t iCnt;
    struct tGGA gga;
    struct tGSA gsa;
    struct tGSV gsv;
    struct tRMC rmc;
    int8_t ggaDate[] = "$GPGGA,020751.147,3413.4754,N,10852.8330,E,1,05,2.8,309.3,M,-28.4,M,,0000*7B\r\n";
    int8_t gsaDate[] = "$GPGSA,A,3,03,06,08,09,02,,,,,,,,3.0,2.8,1.0*3C\r\n";
    int8_t gsvDate[] = "$GPGSV,2,1,05,06,85,219,48,02,38,223,38,03,49,177,44,08,65,127,46*71\r\n";
    int8_t rmcDate[] = "$GPRMC,020751.147,A,3413.4754,N,10852.8330,E,0.42,67.92,251213,,,A*56\r\n";

    //NmeaDealGGA(&gga,ggaDate);
    NmeaDealStr(ggaDate,&gga,sizeof(gga));
    NmeaDealStr(gsaDate,&gsa,sizeof(gsa));
    NmeaDealStr(gsvDate,&gsv,sizeof(gsv));
    NmeaDealStr(rmcDate,&rmc,sizeof(rmc));

    NmeaCheck(ggaDate);

    printf("Time:  %2d:%02d:%2f\r\n",gga.hour + 8, gga.minute, gga.second);
    printf("Lat:   %f\r\n",gga.lat);
    printf("LatH:  %c\r\n",gga.latHemishere);
    printf("Lon:   %f\r\n",gga.lon);
    printf("LonH:  %c\r\n",gga.lonHemishere);
    printf("Stat:  %d\r\n",gga.gpsState);
    printf("NumU:  %d\r\n",gga.satNumber);
    printf("HDOP:  %f\r\n",gga.hdop);
    printf("Alt:   %f\r\n",gga.alt);
    printf("DifT:  %f\r\n",gga.diffTime);
    printf("DifI:  %d\r\n",gga.diffID);

    printf("Mode:  %c\r\n",gsa.mode);
    printf("Type:  %d\r\n",gsa.type);
    printf("SatU:  ");
    for (iCnt = 0; iCnt < 12; iCnt++)
    {
        if (gsa.prn[iCnt])
        {
            printf("%02d ",gsa.prn[iCnt]);
        }
    }
    printf("\r\n");
    printf("PDOP:  %f\r\n",gsa.pdop);
    printf("HDOP:  %f\r\n",gsa.hdop);
    printf("VDOP:  %f\r\n",gsa.vdop);

    printf("Total:%2d\r\n",gsv.total);
    printf("Numb: %2d\r\n",gsv.numb);
    printf("SatV: %2d\r\n",gsv.satInView);
    for (iCnt = 0; iCnt < 4; iCnt++)
    {
        if (gsv.prn[iCnt])
        {
            printf("Sat:   ");
            printf("%02d ",gsv.prn[iCnt]);
            printf("%2f ",gsv.elev[iCnt]);
            printf("%2f ",gsv.azim[iCnt]);
            printf("%2f\r\n",gsv.snr[iCnt]);
        }
    }

    printf("Time:  %2d:%02d:%02d\r\n",rmc.hour + 8,rmc.minute,rmc.second);
    printf("Stat:  %c\r\n",rmc.state);
    printf("Lat:   %f\r\n",rmc.lat);
    printf("LatH:  %c\r\n",rmc.latHemishere);
    printf("Lon:   %f\r\n",rmc.lon);
    printf("LonH:  %c\r\n",rmc.lonHemishere);
    printf("Speed: %f\r\n",rmc.speed);
    printf("Azim:  %f\r\n",rmc.azim);
    printf("Date:  %2d %02d %02d\r\n",rmc.year,rmc.month,rmc.day);
    printf("Mag:   %f\r\n",rmc.magnetic);
    printf("MAzim: %f\r\n",rmc.magneticAzim);
    printf("Mode:  %c\r\n",rmc.mode);


}

#endif
