/**
* @file     nmea.h
* @brief    This is the nmea file.
* @details
* @author   BohengLin
* @date     2014.1.21
* @version  V0.0.1
* @par      Copyright (c): Company
* @par      History:
*           V0.0.1: BohengLin,2014.1.21,build\n
*/

#ifndef _NMEA_H_
#define _NMEA_H_

#ifdef __cplusplus
extern "C" {
#endif

#include <stdint.h>

enum
{
    ENMEA_TYPE_INVALID = 0, \
    ENMEA_TYPE_GGA = 1, \
    ENMEA_TYPE_GSA, \
    ENMEA_TYPE_GSV, \
    ENMEA_TYPE_RMC
};

/**
$GPGGA,<1>,<2>,<3>,<4>,<5>,<6>,<7>,<8>,<9>,M,<10>,M,<11>,<12>*hh<CR><LF>
<1> UTC time，hhmmss (hour,minute,second)
<2> latitude ddmm.mmmm (degree,minute)
<3> hemishere of latitude (N or S)
<4> longitude dddmm.mmmm(degree,minute)
<5> hemishere of longitude (E or W)
<6> GPS state (0 = no fixed，1 = no diff，2 = diff，6 = estimate)
<7> number of sat(00~12)
<8> HDOP (0.5~99.9)
<9> altitude height(-9999.9~99999.9)
<10> 地球椭球面相对大地水准面的高度
<11> time of diff
<12> ID of diff station ( 0000~1023)
*/
struct tGGA
{
    int8_t hour;
    int8_t minute;
    double second;
    double lat;
    double lon;
    int8_t latHemishere;
    int8_t lonHemishere;
    int8_t gpsState;
    int8_t satNumber;
    double hdop;
    double alt;
    double diffTime;
    uint16_t diffID;
};

/**
<1> Mode M = manual A = auto
<2> Type 1 = No fix 2 = 2D  3 = 3D
<3> PRN  Sat in use(01~32)
<4> PDOP 0.5~99.9
<5> HDOP 0.5~99.9
<6> VDOP 0.5~99.9
*/
struct tGSA
{
    int8_t mode;
    int8_t type;
    int8_t prn[12];
    double pdop;
    double hdop;
    double vdop;
};

/**
<1> total of GSV
<2> Numb of GSV
<3> Sat in view 0~12
<4> PRN
<5> Elevation 00~90 degree
<6> Azimuth 000~359 degree
<7> SNR 00~99dB
*/
struct tGSV
{
    int8_t   total;
    int8_t   numb;
    uint16_t satInView;
    int8_t   prn[4];
    uint16_t elev[4];
    uint16_t azim[4];
    int8_t   snr[4];
};

/**
<1> UTC time，hhmmss (hour,minute,second)
<2> state A =  value V = invalid
<3> latitude ddmm.mmmm (degree,minute)
<4> hemishere of latitude (N or S)
<5> longitude dddmm.mmmm(degree,minute)
<6> hemishere of longitude (E or W)
<7> speed 000.0~999.9
<8> Azimuth 000~359 degree
<9> UTC date，ddmmyy (day,month,year)
<10> magnetic declination 000.0~180.0
<11> The direction of magnetic declination, E or W
<12>  mode A =  self D = diff E = estimate N= invalid
*/
struct tRMC
{
    int8_t hour;
    int8_t minute;
    double second;
    double lat;
    double lon;
    int8_t latHemishere;
    int8_t lonHemishere;
    double speed;
    double azim;
    int8_t state;
    int8_t year;
    int8_t month;
    int8_t day;
    double magnetic;
    double magneticAzim;
    int8_t mode;
};

int8_t NmeaGetType(int8_t *inStr);
int8_t NmeaDealStr(int8_t *inStr,void *outStr,uint32_t outSize);

#ifdef __cplusplus
}
#endif

#endif
