// +FHDR------------------------------------------------------------
//                 Copyright (c) 2022 SmartLogic.
//                       ALL RIGHTS RESERVED
// -----------------------------------------------------------------
// Filename      : main.c
// Author        : xianfeng.du
// Created On    : 2022-06-25
// Last Modified :
// -----------------------------------------------------------------
// Description:
//
//
// -FHDR------------------------------------------------------------

#define _GNU_SOURCE
#include <sched.h>
#include <unistd.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <errno.h>
#include <unistd.h>
#include <pthread.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <sys/ioctl.h>
#include <fcntl.h>
#include <sys/mman.h>

#include "ucp_printf.h"
#include "stc_drv_api.h"
#include "stc_drv.h"
#include "ublox_drv.h"

#define MAX_PARA_NUM 4

#define CP_GPIO1_REG_BASE_ADDR   (0x04D10000)   //CP_GPIO1模块基地址
#define CP_GPIO1_REG_LEN         (0x8000)

#define LOCK_8A34002               0x01
#define UNLOCK_8A34002             0x00
   
#define STC_HOLD_OVER_CNT          90     //S
#define STC_DISABLE_CNT            86400  //3600*24

#define TOD_LOCK_THRESHOLD          20 //0x1400000000UL   //20ns
#define MAX_PP1S_INTERVAL 2700000000UL
#define FRAME_NUM_MASK   1023 
#define SECOND2FRAMENUM  100

uint32_t *g_8a34002_lock_ptr = NULL; 

time_t g_sys_time;
int32_t g_hscc_dump_task_id = -1;
int32_t g_stc_sync_task_id = -1;

static uint64_t get_arm_cycle()
{
    uint64_t cycle;

    asm volatile("mrs %0, pmccntr_el0" : "=r" (cycle));

    return cycle;
}

uint32_t get_8a34002_lock_status()
{
    return (*g_8a34002_lock_ptr & BIT30);
}

int32_t get_sys_time(time_t* time_ptr)
{
    if(NULL == time_ptr)
    {      
         UCP_PRINT_ERROR("tfu: get_sys_time error!");
         return OSP_ERROR;
    }
    *time_ptr = g_sys_time;

    return OSP_OK;
}

uint64_t stc_update_sync_state_task()
{
    int32_t ret = 0;
    //uint32_t ex_pp1s_irq_cnt = 0;
    uint32_t jitter_idx;
    time_t sec_count;
    static uint32_t sync_flag = 0;
    static uint32_t jitter_num = 0;
    static uint32_t jitter_mem[4] = {0,0,0,0};  
    static uint64_t last_cycle = 0;
    uint64_t current_cycle = 0;
    uint64_t pp1s_interval = 0;
    uint32_t lock_flag = 0;    
    int32_t phase_diff;
    stc_state_s* stc_state_ptr = get_stc_state();
    arm_stc_regs *stc_regs_ptr = get_stc_reg_base();
    /*uint32_t tod_s = 0;
    uint64_t tod_t = 0;
    uint32_t stc_cnt = 0;*/
    while(1)
    {
    	ret = stc_wait_for_expps(); //pend 
    	if(STC_OK != ret)
    	{
    		UCP_PRINT_ERROR("stc wait for 1PPS_IN interrupt error\n");
    		continue;
    	}
    	
        /*tod_s = stc_regs_ptr->tod_reg_tod_lo;
        tod_t = ((stc_regs_ptr->tod_reg_tod_mi & 0xffff) << 16) | (tod_s >> 16);
        tod_s = stc_regs_ptr->tod_reg_tod_hi;     	
        stc_cnt = read_stc_local_timer();
        UCP_PRINT_DEBUG("tod_t = %ld,stc_cnt = %d",tod_t,stc_cnt);*/

        g_sys_time++;
        //UCP_PRINT_DEBUG("ex_pp1s_irq_cnt = %d,g_sys_time = %ld,sec_count = %ld",ex_pp1s_irq_cnt,g_sys_time,sec_count);
        lock_flag = get_8a34002_lock_status();//read status of 8A34002:lock
        //stc_adjust_frequency(); 
        if(lock_flag) //locked  
        {
            phase_diff = stc_adjust_phase(TOD_LOCK_THRESHOLD);
            UCP_PRINT_DEBUG("diff_ns = %d,tracking_cnt = %d,holdover_cnt = %d\n",phase_diff,stc_state_ptr->phase.tracking_cnt,stc_state_ptr->phase.holdover_cnt);
            
            if(EX_SYNCE == stc_state_ptr->hscc_dump_src)
            {
                stc_adjust_frequency(); 
            }
        }
        else //unlock
        {
            if(CLK_TRACKING == stc_state_ptr->state)
            {
                if(STC_HOLD_OVER_CNT < ++stc_state_ptr->phase.holdover_cnt)
                {
                    stc_state_ptr->phase.holdover_cnt = STC_HOLD_OVER_CNT;
                    stc_state_ptr->phase.tracking_cnt = 0;
                    stc_state_ptr->state = CLK_HOLD_OVER;
                    UCP_PRINT_DEBUG("change from LOCK to HOLDOVER!!");
                }
            }
            else if(CLK_HOLD_OVER == stc_state_ptr->state)
            {
                if(STC_DISABLE_CNT < ++stc_state_ptr->phase.disable_cnt)
                {
                    stc_state_ptr->phase.disable_cnt = STC_DISABLE_CNT;
                    stc_state_ptr->state = CLK_DISABLE;
                    UCP_PRINT_DEBUG("change to CLK_DISABLE!!");
                    sync_flag = 0;
                }                    
            }
        }
        
        current_cycle = get_arm_cycle();
        pp1s_interval = current_cycle - last_cycle;
        last_cycle = current_cycle;

        /*maintain time*/
        usleep(200000);
        if(GNSS_1PPS_IN == stc_state_ptr->pp1s_src)
        {
            lock_flag = get_receiver_fix_status();
            ret = get_src_time(&sec_count);
            if(OSP_ERROR == ret)
            {
                //UCP_PRINT_ERROR("stc get gnss second error");
                //return OSP_ERROR;
                continue;
            }
        }
        else if(GMAC0_1PPS_IN == stc_state_ptr->pp1s_src)
        {
            sec_count = get_gmac_src_time();
        }
        else if(TMAC_1PPS_IN == stc_state_ptr->pp1s_src)
        {
            sec_count = get_tmac_src_time();
        }        
        else
        {
            //return OSP_ERROR;
            continue;
        }
        /*tod_s = stc_regs_ptr->tod_reg_tod_lo;
        tod_s = stc_regs_ptr->tod_reg_tod_mi;
        tod_t = stc_regs_ptr->tod_reg_tod_hi;
        tod_t <<= 16;
        tod_t |= (tod_s >> 16);
        UCP_PRINT_DEBUG("g_sys_time = %ld,sec_count = %ld,tod_t = %ld",g_sys_time,sec_count,tod_t);*/
        //UCP_PRINT_LOG("g_sys_time = %ld,sec_count = %ld,cycle = %ld",g_sys_time,sec_count,pp1s_interval);
        UCP_PRINT_DEBUG("g_sys_time = %ld,sec_count = %ld",g_sys_time,sec_count);
        
        if(sync_flag)
        {
            if(1 == sync_flag)
            {
                sync_flag = 2;
                stc_regs_ptr->tod_reg_config |= BIT4;  //set tod_incr_en,TOD second auto add
            }
            
            if(g_sys_time == sec_count)
            {
                if((CLK_TRACKING == stc_state_ptr->state) && (pp1s_interval < MAX_PP1S_INTERVAL))  
                {
                    set_ape_preset_value(((g_sys_time + 1) * SECOND2FRAMENUM) & FRAME_NUM_MASK);
                    //stc_adjust_sniffer_phase(sec_count); //test
                }
                
                /*-- clear jitter count --*/
                jitter_num = 0;
                UCP_PRINT_LOG("g_sys_time=sec_count,sec_count=%ld,g_sys_time=%ld",sec_count,g_sys_time);
            }
            else
            {
                /* --get clock source lock state --*/
                if(lock_flag) /*1:lock   0:unlock*/
                {
                    /*-- save time jump record --  */
                    if(abs(g_sys_time - sec_count) > GPS_TIME_JUMP_20MIN)
                    {
                        UCP_PRINT_DEBUG("maintain jump 20 min");
                    }
                    else
                    {
                        /*-- if jitter success, adjust g_sys_time --*/
                        jitter_idx = jitter_num & 0x3;
                        jitter_mem[jitter_idx] = sec_count; 
                        UCP_PRINT_DEBUG("jitter_num = %d,sec_count = %ld,g_sys_time = %ld",jitter_num,sec_count,g_sys_time);
                        if((2 == jitter_idx)/*continues gps second,2 second interval*/
                            && (1 == (jitter_mem[2] - jitter_mem[1]))
                            && (1 == (jitter_mem[1]  - jitter_mem[0])))
                        {
                            g_sys_time = sec_count; 
                            UCP_PRINT_DEBUG("g_sys_time(PP2S) calibration!jitter_num=%d",jitter_num);
                            UCP_PRINT_DEBUG("sec_count1=%ld,g_sys_time1=%ld",sec_count,g_sys_time);
                            jitter_num = 0;
                            memset(jitter_mem, 0, sizeof(jitter_mem));
                        }
                        else
                        {
                            jitter_num++;
                        }
                    }
                }
                else
                {
                    UCP_PRINT_ERROR("tfu: clk src unlock, can not maintain time.\n");
                }
            }
        }
        else if(0 == sync_flag)
        {
            if(CLK_TRACKING == stc_state_ptr->state)
            {
                sync_flag = 1;
                stc_state_ptr->pesudo_flag = ZERO_FLAG;
                g_sys_time = sec_count;
                set_su_reg(g_sys_time + 1); //set tod su reg
                set_sync_status_to_ape(1);  //set locked flag to ape
                UCP_PRINT_DEBUG("stc tracking ok !!!!!! maintain g_sys_time:%ld\n",g_sys_time);
            }
        } 
    }
    return STC_OK;
}

uint64_t stc_hscc_dump_task()
{
    //uint32_t hscc_dump_irq_cnt = 0;
    int32_t ret = 0;
    while(1)
    {
    	ret = stc_wait_for_hscc(); //pend 
    	if(STC_OK != ret)
    	{
    		UCP_PRINT_ERROR("stc wait for HSCC_DUMP interrupt error\n");
    		//return LOGIC_ERROR1;
    		continue;
    	}

        stc_adjust_frequency(); 
    }
    return STC_OK;
}

#if 0
uint64_t stc_tod_1pps_task()
{
    uint32_t jitter_idx,tod_1pps_irq_cnt;
    int32_t ret = 0;
    time_t sec_count;
    static uint32_t sync_flag = 0;
    static uint32_t jitter_num = 0;
    static uint32_t jitter_mem[4] = {0,0,0,0};
    
	ret = read(g_stc_fd, &tod_1pps_irq_cnt, STC_TOD_1PPS); //pend 
	if(STC_OK != ret)
	{
		UCP_PRINT_ERROR("stc wait for interrupt error\n");
		return LOGIC_ERROR1;
	}

    g_sys_time++;
    UCP_PRINT_DEBUG("g_sys_time = %#lx,sync_flag = %d,irq = %d",g_sys_time,sync_flag,tod_1pps_irq_cnt);
    usleep(150000);
    ret = drv_tfu_get_ublox_seconds(&sec_count);
    if(OSP_ERROR == ret)
    {
        UCP_PRINT_ERROR("stc get ublox second error");
        return OSP_ERROR;
    }

    if(1 == sync_flag)
    {
        if(g_sys_time == sec_count)
        {
            /*-- clear jitter count --*/
            jitter_num = 0;
            UCP_PRINT_LOG("g_sys_time=sec_count,sec_count=%ld,g_sys_time=%ld",sec_count,g_sys_time);
        }
        else
        {
            /* --get gps lock state --*/
            if(get_receiver_fix_status()) /*1:lock   0:unlock*/
            {
                /*-- save time jump record --  */
                if(abs(g_sys_time - sec_count) > GPS_TIME_JUMP_20MIN)
                {
                    UCP_PRINT_DEBUG("maintain jump 20 min");
                }
                else
                {
                    /*-- if jitter success, adjust g_sys_time --*/
                    jitter_idx = jitter_num & 0x3;
                    jitter_mem[jitter_idx] = sec_count; 
                    UCP_PRINT_DEBUG("jitter_num = %d,sec_count = %ld,g_sys_time = %ld",jitter_num,sec_count,g_sys_time);
                    if((2 == jitter_idx)/*continues gps second,2 second interval*/
                        && (1 == (jitter_mem[2] - jitter_mem[1]))
                        && (1 == (jitter_mem[1]  - jitter_mem[0])))
                    {
                        g_sys_time = sec_count; 
                        UCP_PRINT_DEBUG("g_sys_time(PP2S) calibration!jitter_num=%d",jitter_num);
                        UCP_PRINT_DEBUG("sec_count1=%ld,g_sys_time1=%ld",sec_count,g_sys_time);
                        jitter_num = 0;
                        memset(jitter_mem, 0, sizeof(jitter_mem));
                    }
                    else
                    {
                        jitter_num++;
                    }
                }
            }
            else
            {
                UCP_PRINT_ERROR("tfu: clk src unlock, can not maintain time.\n");
            }
        }
    }
    else if(0 == sync_flag)
    {
        if(CLK_TRACKING == stc_state_ptr->state)
        {
            sync_flag = 1;
            g_sys_time = sec_count;
            UCP_PRINT_DEBUG("maintain g_sys_time:%ld",g_sys_time);
        }
    }   
    return OSP_OK;
}
#endif

int32_t drv_thread_create(uint8_t* pthread_name, uint8_t thread_prio, uint32_t thread_size, void *callback, void* pArg)
{

    pthread_t thread_id;
    pthread_attr_t stthread_attr;        /*线程属性*/
    struct sched_param stprior_param;     
    int32_t result = 0;                    

    result = pthread_attr_init(&stthread_attr);
    if (STC_OK != result)
    {
        UCP_PRINT_ERROR(" pthread_attr_init() fail return = %d, err = %s!\n", result, strerror(errno));
        return LOGIC_ERROR1;
    }

    result = pthread_attr_setinheritsched(&stthread_attr, PTHREAD_EXPLICIT_SCHED);
    if (STC_OK != result)
    {
        UCP_PRINT_ERROR("Failed. pthread_attr_setinheritsched() return = %d, err = %s!\n", result, strerror(errno));
        return LOGIC_ERROR2;
    }


    result = pthread_attr_setschedpolicy(&stthread_attr, SCHED_RR);
    if (STC_OK != result)
    {
        UCP_PRINT_ERROR("Failed. pthread_attr_setschedpolicy() return = %d, err = %s!\n", result, strerror(errno));
        return LOGIC_ERROR3;
    }

    result = pthread_attr_setscope(&stthread_attr, PTHREAD_SCOPE_SYSTEM);
    if (STC_OK != result)
    {
        UCP_PRINT_ERROR(" Failed. pthread_attr_setscope() return = %d, err = %s!\n", result, strerror(errno));
        return LOGIC_ERROR4;
    }

    result = pthread_attr_setdetachstate(&stthread_attr, PTHREAD_CREATE_DETACHED);
    if (STC_OK != result)
    {
        UCP_PRINT_ERROR(" Failed. pthread_attr_setdetachstate() return = %d, err = %s!\n", result, strerror(errno));
        return LOGIC_ERROR5;
    }



    result = pthread_attr_getschedparam(&stthread_attr, &stprior_param);
    if (STC_OK != result)
    {
        UCP_PRINT_ERROR("Failed. pthread_attr_getschedparam() return = %d, err = %s!\n", result, strerror(errno));
        return LOGIC_ERROR6;
    }

    stprior_param.sched_priority = thread_prio;
    result = pthread_attr_setschedparam(&stthread_attr, &stprior_param);
    if (STC_OK!= result)
    {
        UCP_PRINT_ERROR("Failed. pthread_attr_setschedparam() return = %d, err = %s!\n", result, strerror(errno));
        return LOGIC_ERROR7;
    }

    /*result = pthread_attr_setstacksize(&stthread_attr, thread_size);
    if (STC_OK != result)
    {
        UCP_PRINT_ERROR(" Failed. pthread_attr_setstacksize() return = %d, err = %s!\n", result, strerror(errno));
        return LOGIC_ERROR8;
    }*/

    result = pthread_create(&thread_id, &stthread_attr, callback, pArg);
    if (STC_OK != result)
    {
        UCP_PRINT_ERROR("[GalTaskCreate]: Failed. pthread_create() return = %d, err = %s!\n", result, strerror(errno));
        return LOGIC_ERROR9;
    }

    result = pthread_attr_destroy(&stthread_attr);
    if (STC_OK != result)
    {
        UCP_PRINT_ERROR(" Failed. pthread_attr_destroy() return = %d, err = %s!\n", result, strerror(errno));
        return LOGIC_ERROR10;
    }

    return thread_id;
}


int32_t main(int32_t argc, char* argvp[])
{
    void *gpio_regs_ptr = NULL; //
    int32_t g_main_mem_fd = -1;
    
	UCP_PRINT_DEBUG("Hello world from A72.");

    cpu_set_t mask;
    CPU_ZERO(&mask);
    CPU_SET(0,&mask);
    sched_setaffinity(0,sizeof(cpu_set_t),&mask);

	int32_t args[MAX_PARA_NUM] = {0,0,0,0};
	uint32_t count = argc - 1;
	if(count > MAX_PARA_NUM) {
        UCP_PRINT_ERROR("parameter number[%d] error",count);
        return -1;
    }

	for (uint32_t i = 0; i < count; i++) {
		args[i] = (int32_t)strtoul(argvp[i+1],NULL,0);
	}


    g_main_mem_fd = open("/dev/mem", O_RDWR|O_SYNC);
    if(g_main_mem_fd < 0)
    {
        UCP_PRINT_ERROR("open /dev/mem error");
        return LOGIC_ERROR1;
    }

    if(0 == args[0])  //gnss 配置接收机
    {

        UCP_PRINT_DEBUG("entered gps testmode.");
        if(0 != init_clock_module())
        {
            UCP_PRINT_ERROR("Init clock_module error!!");
            return -2;
        }

        if(0 != drv_tfu_receiver_init())
        {
            UCP_PRINT_ERROR("Init ublox error!!");
            //return -2;
        }
    }
    
    if(0 != init_stc())
    {
        UCP_PRINT_ERROR("Init stc error!!");
        return -3;
    }

#ifdef EVMYFT
        gpio_regs_ptr = get_ap_gpio_reg_base();
        *(uint32_t *)(gpio_regs_ptr + AP_GPIO_REG_LEN + 0x18c) |= (BIT2 | BIT3); //ap_gpiob30 in
#else
        uint32_t *rf_lvds_pmux1_reg_ptr = NULL; //8a34002 cp_gpiob30

        if(rf_lvds_pmux1_reg_ptr == NULL)
        {
            rf_lvds_pmux1_reg_ptr = (uint32_t *)mmap(NULL,0x1000, PROT_READ|PROT_WRITE, MAP_SHARED,
                                g_main_mem_fd, 0x04da0000);
            if(-1 == (int64_t)rf_lvds_pmux1_reg_ptr)
            {
                UCP_PRINT_ERROR("mmap lvds gpiob30(8a34002 lock status) pinmux error!! return = %ld\n",(uint64_t)rf_lvds_pmux1_reg_ptr);
                return LOGIC_ERROR5;
            }
            else
            {
                *(rf_lvds_pmux1_reg_ptr + 0x26) |= (BIT28 | BIT29);  //0x04da0098   cp_gpiob30 pad 8a34002 lock 
                munmap((void*)rf_lvds_pmux1_reg_ptr,0x1000);
            }
        }

        if(gpio_regs_ptr == NULL)  //cp_gpiob30  0x04D10000
        {
            gpio_regs_ptr = mmap(NULL, CP_GPIO1_REG_LEN, PROT_READ|PROT_WRITE, MAP_SHARED,
                                g_main_mem_fd, CP_GPIO1_REG_BASE_ADDR);
            if(-1 == (int64_t)gpio_regs_ptr)
            {
                UCP_PRINT_ERROR("mmap cp_gpio1 error!! return = %ld\n",(uint64_t)gpio_regs_ptr);
                return LOGIC_ERROR4;
            }
        }
#endif

    g_8a34002_lock_ptr = (uint32_t *)(gpio_regs_ptr + 0x54);

    g_stc_sync_task_id = drv_thread_create( (uint8_t *)"stcsynctask", 71, 8192,
                (void *)stc_update_sync_state_task, NULL);
    if(OSP_ERROR == g_stc_sync_task_id)
    {
        UCP_PRINT_ERROR("tfu: create stcsynctask error!\n");
        return LOGIC_ERROR5;
    }

    g_hscc_dump_task_id = drv_thread_create( (uint8_t *)"hsccdumptask", 68, 4096,
                (void *)stc_hscc_dump_task, NULL);
    if(OSP_ERROR == g_hscc_dump_task_id)
    {
        UCP_PRINT_ERROR("stc: create hsccdumptask error!\n");
        return LOGIC_ERROR6;
    }

    if(0 == args[0])  //gnss
    {
        set_xpps_out_source(TOD_1PPS_OUT,1);
        select_xpps_in_source(GNSS_1PPS_IN);
    }
    else if(1 == args[0])  //GMAC 1588
    {
        UCP_PRINT_DEBUG("entered GMAC 1588 testmode.");
        select_xpps_in_source(GMAC0_1PPS_IN);
    }
    else if(2 == args[0])  //TMAC 1588
    {
        UCP_PRINT_DEBUG("entered TMAC 1588 testmode.");    
        select_xpps_in_source(TMAC_1PPS_IN);
    }
    
    enable_stc_irq(STC_EX_1PPS_IN);

	while (1)
	{
	    usleep(100);
	}

    close(g_main_mem_fd);	
    
	return 0;
}

