/*------------------------------------------------------------
//                 Copyright (c) 2022 SmartLogic.
//                       ALL RIGHTS RESERVED
// -----------------------------------------------------------------
// Filename      : stc_drv.c
// Author        : weihua.li
// Created On    : 2022-11-23
// Last Modified :
// -----------------------------------------------------------------
// Description:
//
//
// ----------------------------------------------------------------*/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <errno.h>
#include <unistd.h>
#include <pthread.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <sys/ioctl.h>
#include <fcntl.h>
#include <sys/mman.h>
#include <sys/time.h>
#include "typedef.h"
#include "stc_drv_api.h"
#include "stc_drv.h"
#include "ucp_printf.h"
/*==============================================================================
    Constant / Defines
==============================================================================*/

/*    常量定义，并对常量定义进行简要说明 */

/*==============================================================================
    Global variable Definitions
==============================================================================*/
arm_stc_regs *g_stc_regs_ptr = NULL;  //0x08568000
void *g_ecs_subctrl_regs_ptr = NULL;  //0x08460000
void *g_ecs_crg_regs_ptr = NULL;   //0x08430000
void *g_ap_gpio_pinmux_regs_ptr = NULL;    //0x04450000-0x04458000
uint32_t *g_gmac0_tod_ptr = NULL;  //0x01a40000 + 0xb08
uint32_t *g_tmac_tod_ptr = NULL;  //0x09090000 + 0xd08
uint32_t *g_sfn_ptr = NULL;  //0x0A4f2220
uint32_t *g_sniffer_ptr = NULL;  //0x0A4f2140
int32_t g_drv_mem_fd = -1;

stc_state_s g_stc_state = 
{
    .pp1s_src = GNSS_1PPS_IN,
    .hscc_dump_src = HSCC_RESERVED,
    .synce_flag = 0,
    .cal_period = 1,
    .state = CLK_WARM_UP,
    .freq = {
        .integral = 0,
        .p_ratio = 0.5,
        .i_ratio = 0.5,
        .tracking_cnt = 0,
        .holdover_cnt = 0,
        .disable_cnt = 0,
        
    },
    .phase = {
        .integral = 0,
        .p_ratio = 0.7218,
        .i_ratio = 0.2308,
        .tracking_cnt = 0,
        .holdover_cnt = 0,
        .disable_cnt = 0,

    },
};   //stc状态

uint32_t g_init_stc_flag = 0;/*模块初始化标志0:未初始化，1:已初始化*/
int32_t g_stc_fd = -1;   /*STC ko fd*/


/*==============================================================================
    Local Object Definitions
==============================================================================*/

/*    局部对象定义，并对其进行简要说明 */

/*==============================================================================
    Static Variable Definitions
==============================================================================*/

/*    静态变量定义，并对其进行简要说明 */

/*==============================================================================
    Forward Declarations
==============================================================================*/

/*    前置声明 */

/*==============================================================================
    Function Definitions
==============================================================================*/
static int32_t map_stc_reg_space()
{
    //uint32_t *ecs_crg_reg5_ptr = NULL;   //stc_cdr_clk_sel
    //uint32_t *ecs_crg_reg8_ptr = NULL;   //jecs2_div
    uint32_t *pb14_ctrl_reg_ptr = NULL;   //pb14_ctrl 
    uint32_t *pb_pmux_reg_ptr = NULL; //pp1s in->gpioa29
    void *tmp_ptr = NULL;
    
    if(g_drv_mem_fd < 0)
    {
        g_drv_mem_fd = open("/dev/mem", O_RDWR|O_SYNC);
        if(g_drv_mem_fd < 0)
        {
            UCP_PRINT_ERROR("open /dev/mem error");
            return LOGIC_ERROR1;
        }
    }


    tmp_ptr = mmap(NULL, GMAC0_REG_LEN, PROT_READ|PROT_WRITE, MAP_SHARED,
                        g_drv_mem_fd, GMAC0_REG_BASE_ADDR);
    if(-1 == (int64_t)tmp_ptr)
    {
        UCP_PRINT_ERROR("mmap gmac0 error!! return = %ld\n",(uint64_t)tmp_ptr);
        return LOGIC_ERROR4;
    }
    else
    {
        g_gmac0_tod_ptr = (uint32_t *)(tmp_ptr + GMAC0_TOD_REG);
    }

    tmp_ptr = mmap(NULL, TMAC_REG_LEN, PROT_READ|PROT_WRITE, MAP_SHARED,
                        g_drv_mem_fd, TMAC_REG_BASE_ADDR);
    if(-1 == (int64_t)tmp_ptr)
    {
        UCP_PRINT_ERROR("mmap tmac error!! return = %ld\n",(uint64_t)tmp_ptr);
        return LOGIC_ERROR7;
    }
    else
    {
        g_tmac_tod_ptr = (uint32_t *)(tmp_ptr + TMAC0_TOD_REG);
    }

    if(g_stc_regs_ptr == NULL)
    {
        g_stc_regs_ptr = mmap(NULL, STC_REG_LEN, PROT_READ|PROT_WRITE, MAP_SHARED,
                            g_drv_mem_fd, STC_REG_BASE_ADDR);
        if(-1 == (int64_t)g_stc_regs_ptr)
        {
            UCP_PRINT_ERROR("mmap stc regs error!! return = %ld\n",(uint64_t)g_stc_regs_ptr);
            g_stc_regs_ptr = NULL;
            return LOGIC_ERROR2;
        }
    }

    if(g_ecs_subctrl_regs_ptr == NULL)
    {
        g_ecs_subctrl_regs_ptr = mmap(NULL, ECS_SUBCTRL_REG_LEN, PROT_READ|PROT_WRITE, MAP_SHARED,
                            g_drv_mem_fd, ECS_SUBCTRL_REG_BASE_ADDR);
        if(-1 == (int64_t)g_ecs_subctrl_regs_ptr)
        {
            UCP_PRINT_ERROR("mmap ecs_subctrl error!! return = %ld\n",(uint64_t)g_ecs_subctrl_regs_ptr);
            return LOGIC_ERROR3;
        }
    }

    if(g_ecs_crg_regs_ptr == NULL)
    {
        g_ecs_crg_regs_ptr = mmap(NULL, ECS_CRG_REG_LEN, PROT_READ|PROT_WRITE, MAP_SHARED,
                            g_drv_mem_fd, ECS_CRG_REG_BASE_ADDR);
        if(-1 == (int64_t)g_ecs_crg_regs_ptr)
        {
            UCP_PRINT_ERROR("mmap ecs_crg error!! return = %ld\n",(uint64_t)g_ecs_crg_regs_ptr);
            return LOGIC_ERROR4;
        }
    } 
    
    if(g_ap_gpio_pinmux_regs_ptr == NULL)
    {
        g_ap_gpio_pinmux_regs_ptr = mmap(NULL, AP_GPIO_PINMUX_REG_LEN, PROT_READ|PROT_WRITE, MAP_SHARED,
                            g_drv_mem_fd, AP_GPIO_PINMUX_REG_BASE_ADDR);
        if(-1 == (int64_t)g_ap_gpio_pinmux_regs_ptr)
        {
            UCP_PRINT_ERROR("mmap AP_GPIO pinmux error!! return = %ld\n",(uint64_t)g_ap_gpio_pinmux_regs_ptr);
            return LOGIC_ERROR3;
        }
    }

    tmp_ptr = mmap(NULL, SHARE_MEM_LEN, PROT_READ|PROT_WRITE, MAP_SHARED,
                        g_drv_mem_fd, SHARE_MEM_BASE_ADDR);
    if(-1 == (int64_t)tmp_ptr)
    {
        UCP_PRINT_ERROR("mmap g_sfn_ptr!! return = %ld\n",(uint64_t)tmp_ptr);
        return LOGIC_ERROR6;
    }
    else
    {
        g_sfn_ptr = (uint32_t *)(tmp_ptr + SFN_BASE_ADDR - SHARE_MEM_BASE_ADDR);
        g_sniffer_ptr = (uint32_t *)(tmp_ptr + SNIFFER_BASE_ADDR - SHARE_MEM_BASE_ADDR);
        //*(g_sniffer_ptr + 1) = 0;
        *g_sfn_ptr = 0xaa;
    }

    /*config TMAC/ECPRI synce clk */
    /*ecs_crg_reg5_ptr = (uint32_t *)(g_ecs_crg_regs_ptr + 0x14);   //stc_cdr_clk_sel
    ecs_crg_reg8_ptr = (uint32_t *)(g_ecs_crg_regs_ptr + 0x20);   //jecs2_div
    *ecs_crg_reg8_ptr = 0x520000;  
    *ecs_crg_reg5_ptr |= BIT31;  */

    /*EX_1PPS_IN CFG*/
    pb14_ctrl_reg_ptr = (uint32_t *)(g_ap_gpio_pinmux_regs_ptr + AP_GPIO_REG_LEN + 0xbc);  //PB14_CTRL_REG
    *pb14_ctrl_reg_ptr |= (BIT6 | BIT7);
    pb_pmux_reg_ptr = (uint32_t *)(g_ap_gpio_pinmux_regs_ptr + AP_GPIO_REG_LEN + 0x180);  //PB_PMUX_REG 
    *pb_pmux_reg_ptr = (*pb_pmux_reg_ptr & 0xcfffffff) | BIT29;  //sel:GNSS_PPS_IN
    
    return STC_OK;
}

/********获取P_CLK时钟值*********
从前传接口驱动中获取***********/
static uint32_t get_pclk_value()
{
    uint32_t tmp_clk = g_stc_regs_ptr->tod_reg_nf;

    if(0xc0000000 != (tmp_clk & 0xc0000000))
    {
        return LOGIC_ERROR1;
    }
    else
    {
        g_stc_state.p_clk = g_stc_regs_ptr->tod_reg_nf & 0x3fffffff; //更新状态
        g_stc_state.p_clk_period = 1.000000000001 / g_stc_state.p_clk;
        g_stc_state.phase.magic_num = 1.000000000001 / g_stc_state.p_clk;
    }
    return STC_OK;
}

int32_t set_ape_preset_value(uint32_t cal_sub_bfn)
{
    static uint32_t valid_flag = 0xa5a5a5a5;
    //struct timeval  begin;
    
    *g_sfn_ptr = 0xaa;
    *(g_sfn_ptr + 1) = cal_sub_bfn;
    *(g_sfn_ptr + 2) = valid_flag;
    *g_sfn_ptr = 0x55;
    valid_flag = ~valid_flag;
    //gettimeofday(&begin, NULL);
    //UCP_PRINT_DEBUG("s = %ld,u = %ld, sfn = %d",begin.tv_sec,begin.tv_usec,cal_sub_bfn);
    return STC_OK;
}

int32_t set_sync_status_to_ape(uint32_t sync_status)
{
    *(g_sfn_ptr + 3) = sync_status;  //set locked flag to ape

    return STC_OK;
}

int32_t stc_wait_for_expps()
{
    int32_t ret = -1;
    uint32_t ex_pp1s_irq_cnt;

    if(-1 == g_stc_fd)
    {
        g_stc_fd = open(STC_DEV_NAME,O_RDWR);//O_RDWR
        if(-1 == g_stc_fd)
        {
            printf("open stc-dev device failed\n\r");
            return LOGIC_ERROR1;
        }
    }
    
    ret = read(g_stc_fd, &ex_pp1s_irq_cnt, STC_EX_1PPS_IN); //pend 

    return ret;

}

int32_t stc_wait_for_hscc()
{
    int32_t ret = -1;
    uint32_t hscc_dump_irq_cnt = 0;

    if(-1 == g_stc_fd)
    {
        g_stc_fd = open(STC_DEV_NAME,O_RDWR);//O_RDWR
        if(-1 == g_stc_fd)
        {
            printf("open stc-dev device failed\n\r");
            return LOGIC_ERROR1;
        }
    }
    
    ret = read(g_stc_fd, &hscc_dump_irq_cnt, STC_HSCC_DUMP); //pend 
    
    return ret;
}

int32_t enable_stc_irq(stc_int_type_e irq_type)
{
    if(-1 == g_stc_fd)
    {
        g_stc_fd = open(STC_DEV_NAME,O_RDWR);//O_RDWR
        if(-1 == g_stc_fd)
        {
            printf("open stc-dev device failed\n\r");
            return LOGIC_ERROR2;
        }
    }

    if(STC_OK == ioctl(g_stc_fd,STC_INT_CFG,&irq_type))
    {
        return STC_OK;
    }
    else
    {
        return LOGIC_ERROR1;
    }
}

int32_t disable_stc_irq(stc_int_type_e irq_type)
{
    g_stc_regs_ptr->tod_reg_irq_en &= ~irq_type;
    return STC_OK;
}

/*选择送给A72和stc的外部1PPS源*/
int32_t select_xpps_in_source(pp1s_soure_e src)
{
    uint32_t stc_sel;   //配置jecs_subctrl_reg33:stc_sel,选择xpps_in的输入
    uint32_t *stc_sel_ptr = (uint32_t *)(g_ecs_subctrl_regs_ptr + 0x84);

    if(src > GNSS_1PPS_IN)
    {
        return PARAMETER1_ERROR;
    }
    
    //配置输入1pps源寄存器
    stc_sel = *stc_sel_ptr;
    //stc_sel = 0xfffffc7f;
    ///stc_sel |= src << 7;
    /*统一使用8a34002输出的1pps，因此固定为GNSS_1PPS_IN*/
    *stc_sel_ptr = (stc_sel & ~(BIT7 | BIT8 | BIT9)) | (GNSS_1PPS_IN << 7); 
    //*stc_sel_ptr = (stc_sel & ~(BIT7 | BIT8 | BIT9)) | (src << 7);
    
    g_stc_state.pp1s_src = src; //更新状态

    return STC_OK;
}

/*设置输出1PPS源*/
int32_t set_xpps_out_source(pp1s_output_e src,uint32_t enable)
{
    uint32_t gnss_sel;   //配置jecs_subctrl_reg33,选择输出到pad的1pps信号
    uint32_t *gnss_sel_ptr = (uint32_t *)(g_ecs_subctrl_regs_ptr + 0x84);
    uint32_t *pc_mux_reg_ptr = (g_ap_gpio_pinmux_regs_ptr + AP_GPIO_REG_LEN + 0x184);  //PINMUX:PC_MUX_REG 0x04458184
    uint32_t out_src = src;

    if(src > TOD_1PPS_OUT)
    {
        return PARAMETER1_ERROR;
    }

    if(!g_stc_state.default_ft)   
    {
        UCP_PRINT_ERROR("does not init stc,please init stc first!");
        return LOGIC_ERROR2;
    }

    if(1 == enable)  //enable pps out
    {
        g_stc_regs_ptr->tod_reg_config |= BIT3;
    }
    else   //disable pps out
    {
        g_stc_regs_ptr->tod_reg_config &= ~BIT3;
        out_src = STC_1PPS_OUT;
    }

    *pc_mux_reg_ptr = (*pc_mux_reg_ptr & 0xcfffffff) | BIT29;  //sel:GNSS_PPS_OUT

    //配置输出1pps源寄存器
    gnss_sel = *gnss_sel_ptr;
    //gnss_sel &= 0xffffff8f;
    //gnss_sel |= src << 4;
    *gnss_sel_ptr = (gnss_sel & ~(BIT4 | BIT5 | BIT6)) | (out_src << 4);

    g_stc_regs_ptr->tod_reg_ft_lo = g_stc_state.default_ft & 0xffffffff;
    g_stc_regs_ptr->tod_reg_ft_hi = g_stc_state.default_ft >> 32; //恢复默认值 

    UCP_PRINT_DEBUG("pps out = %d(1:enable,0:disable),default_value = %#lx\n",enable,g_stc_state.default_ft);
    
    return STC_OK;
}

/*选择hscc_dump中断的输入*/
int32_t select_hscc_dump_source(hscc_dump_soure_e src_type)
{
    if(src_type > EX_SYNCE)
    {
        return PARAMETER1_ERROR;
    }
    
    g_stc_regs_ptr->tod_reg_config &= ~(BIT0 | BIT1);
    g_stc_regs_ptr->tod_reg_config |= src_type;

    g_stc_state.hscc_dump_src = src_type;

    return STC_OK;
}

/*设置RT寄存器，高32bit一般为10^9ns（0x3B9ACA00 1s），低32bit为0*/
void set_rt_reg(uint32_t value)
{
    g_stc_regs_ptr->tod_reg_rt_lo = 0;
    g_stc_regs_ptr->tod_reg_rt_hi = value;
    
    return;
}

/*设置NSF_INIT寄存器，TOD的低48bit
hi_value：ns值
lo_value：ns值的小数，高16bit有效，低16bit忽略*/
void set_nsf_init_reg(uint32_t lo_value, uint32_t hi_value)
{
    g_stc_regs_ptr->tod_reg_nsf_init_lo = lo_value & 0xffff0000;
    g_stc_regs_ptr->tod_reg_nsf_init_hi = hi_value;
    return;
}

/*设置SU寄存器,配置TOD秒的初值,有效值为低48bit*/
void set_su_reg(uint64_t     value)
{
    g_stc_regs_ptr->tod_reg_su_lo = value;
    g_stc_regs_ptr->tod_reg_su_hi = (value >> 32) & 0xffff; //取value的32-47bit

    g_stc_regs_ptr->tod_reg_config &= ~BIT4;  // clear tod_incr_en
    
    return;
}

/*设置tod累加步进值FT
FT没有配置之前，stc TOD流程不启动
在配置FT前，先配置：
1、set_rt_reg
2、set_nsf_init_reg
3、set_su_reg
一旦配置了FT的值，stc TOD流程就启动了*/
void set_ft_init_value(uint32_t pclk)
{
    //(10^9 * 2^32) = 0x3B9ACA0000000000ULL
    uint64_t coff = DEFAULT_RT_VALUE / pclk;
    /*double clk_2_ns = SECOND2NS / pclk;  //pclk的周期（以ns为单位）
    uint32_t hi_of_ft = (uint32_t)clk_2_ns;  //取clk_2_ns的整数部分，ns
    uint32_t lo_of_ft = (clk_2_ns - hi_of_ft) * coff;  //小数部分*2^32*/
    
    g_stc_regs_ptr->tod_reg_ft_lo = coff & 0xffffffff;
    g_stc_regs_ptr->tod_reg_ft_hi = coff >> 32;
    
    g_stc_state.default_ft = coff;

    UCP_PRINT_DEBUG("default_ft = %#lx\n",g_stc_state.default_ft);

    return;
}


int32_t set_default_ft_value()
{
    if(!g_stc_state.default_ft)   
    {
        UCP_PRINT_ERROR("set default ft error!");
        return LOGIC_ERROR1;
    }
    
    g_stc_regs_ptr->tod_reg_ft_lo = g_stc_state.default_ft & 0xffffffff;
    g_stc_regs_ptr->tod_reg_ft_hi = g_stc_state.default_ft >> 32; //恢复默认值 

    UCP_PRINT_DEBUG("default_value = %#lx\n",g_stc_state.default_ft);

    return STC_OK;
}


/*设置频率校准*/
int32_t set_fsync_frequncy(uint32_t frequncy)
{
    g_stc_regs_ptr->tod_reg_nf = g_stc_state.synce_clk / frequncy;
    g_stc_state.cal_period = frequncy;  //更新状态

    return STC_OK;
}


/*选择STC内部 synce时钟源*/
int32_t config_synce(uint32_t synce_flag, synce_src_e interface, uint32_t clk)
{
    uint32_t *eth_clk_sel_ptr = (uint32_t *)(g_ecs_subctrl_regs_ptr + 0x84);
    uint32_t *ecs_crg_reg61_ptr = (uint32_t *)(g_ecs_crg_regs_ptr + 0xf4);
    uint32_t stc_serdes_clk_sel;
    
    g_stc_state.synce_flag = synce_flag;
    if(1 == synce_flag)
    {
        if(SYNCE_GMAC == interface)  //B 选择sfp_eth_clk
        {
            *eth_clk_sel_ptr |= BIT1; 
        }
        else //A 选择eth_serdes_rx_clk
        {
            stc_serdes_clk_sel = *ecs_crg_reg61_ptr;
            stc_serdes_clk_sel &= ~(BIT2 | BIT3);
            if(SYNCE_TMAC == interface)
            {
                stc_serdes_clk_sel |= BIT2;
                *ecs_crg_reg61_ptr = stc_serdes_clk_sel;
            }

            *eth_clk_sel_ptr &= ~BIT1;  //最终的输出，选择eth_erdes_rx_clk
        }
        
        g_stc_state.synce_clk = clk;
        g_stc_regs_ptr->tod_reg_nf = clk / g_stc_state.cal_period; //写入synce分频
    }

    return STC_OK;    
}

/*调整频率，实现频率同步*/
double stc_adjust_frequency(void)
{
    uint32_t hscc_value = g_stc_regs_ptr->tod_reg_hscc;   //读取HSCC寄存器值
    int32_t diff = hscc_value - g_stc_state.p_clk; //计算实际CLK与读取的计数值之间的差值
    double delta;
    
#ifdef SL_ADJ_FREQ
    g_stc_state.freq.integral += diff; 
    delta = g_stc_state.freq.p_ratio * diff + g_stc_state.freq.i_ratio * g_stc_state.freq.integral;
#else
    delta = diff * g_stc_state.p_clk_period; //频偏百分比
    //UCP_PRINT_DEBUG("hscc_value = %d, pclk = %d,fre_delta = %-16.10f",hscc_value,g_stc_state.p_clk,delta);
#endif
    /*根据差值，通过SPI接口调整外部VCXO或OCXO的频率*/
    return delta;     
}

/*调整相位，实现时间同步*/
int32_t stc_adjust_phase(uint32_t phase_diff)
{
    uint32_t nsf_reg_lo;   
    int32_t diff_ns,track_ns;  //phase diff(ns)
    static uint32_t first_sync_flag = 0;
    int64_t nsf_value;
    int64_t rt_value = DEFAULT_RT_VALUE;
    int64_t rt_hf_value = DEFAULT_RT_HALF;
    uint64_t ft_new;
    int64_t diff;
    uint32_t tod_lo,tod_mi,nano_sec;
    double delta; 

    nsf_reg_lo = g_stc_regs_ptr->tod_reg_nsf_1pps_lo; 
    ft_new = g_stc_regs_ptr->tod_reg_nsf_1pps_hi;
    nsf_value = (ft_new << 32) | nsf_reg_lo;  //获取当前nsf寄存器值
    if(nsf_value < rt_hf_value)  //STC pp1s 提前，ft过大
    {
        diff = nsf_value;
        track_ns = diff >> 32;
        //track_ns = ft_new;
        diff_ns = track_ns;
    }
    else  //STC pp1s 滞后，ft过小
    {
        diff = nsf_value - rt_value;
        //track_ns = 1000000000 - ft_new;
        track_ns = (rt_value - nsf_value) >> 32;
        diff_ns = -track_ns;
    }

    if(!first_sync_flag)
    {
        g_stc_regs_ptr->tod_reg_ft_lo = 0;
        g_stc_regs_ptr->tod_reg_ft_hi = 0; //先停止计数

        tod_lo = g_stc_regs_ptr->tod_reg_tod_lo;  
        tod_mi = g_stc_regs_ptr->tod_reg_tod_mi; 
        nsf_reg_lo = g_stc_regs_ptr->tod_reg_tod_hi;
        nsf_reg_lo = ((tod_mi & 0xffff) << 16) | (tod_lo >> 16);  //计算出当前的ns值

        /*gnss pps起点是0，计算计数初值*/        
        if(nsf_reg_lo > ft_new)  //计算stc pps与gnss pps相差
        {
            nano_sec = nsf_reg_lo - ft_new;
        }
        else
        {
            nano_sec = 1000000000 - ft_new + nsf_reg_lo;
        }
        g_stc_regs_ptr->tod_reg_nsf_init_lo = 0;
        g_stc_regs_ptr->tod_reg_nsf_init_hi = nano_sec + 904;

        g_stc_regs_ptr->tod_reg_ft_lo = g_stc_state.default_ft & 0xffffffff;
        g_stc_regs_ptr->tod_reg_ft_hi = g_stc_state.default_ft >> 32; //恢复计数  
        
        first_sync_flag = 1;
        UCP_PRINT_DEBUG("dump_1pps = %ld,tod_ns = %d,cal_ns = %d",ft_new,nsf_reg_lo,nano_sec);        
        return diff_ns;
    }

    if(track_ns  < phase_diff)
    {
        g_stc_state.phase.status = 1;
        if(++g_stc_state.phase.tracking_cnt > STC_LOCK_CNT)
        {
            g_stc_state.phase.tracking_cnt = STC_LOCK_CNT;
            g_stc_state.phase.holdover_cnt = 0;
            g_stc_state.phase.disable_cnt = 0;
            g_stc_state.state = CLK_TRACKING;
        }
    }
    else
    {
        g_stc_state.phase.tracking_cnt = 0;
        g_stc_state.phase.status = 0;
    }
    
    g_stc_state.phase.integral += diff;    

    /*根据差值，设置Ft寄存器值，使|Rt-nsf|最小*/
    delta = g_stc_state.phase.p_ratio * diff + g_stc_state.phase.i_ratio * g_stc_state.phase.integral;
    ft_new = g_stc_state.default_ft - delta * g_stc_state.phase.magic_num;
    //UCP_PRINT_DEBUG("delta = %f, ft_new = %#lx",delta,ft_new);
    
    g_stc_regs_ptr->tod_reg_ft_lo = ft_new & 0xffffffff;
    g_stc_regs_ptr->tod_reg_ft_hi = ft_new >> 32;
    
    //UCP_PRINT_DEBUG("diff_ns = %d,tracking_cnt = %d,holdover_cnt = %d,ft_new = %lx\n",diff_ns,g_stc_state.phase.tracking_cnt,g_stc_state.phase.holdover_cnt,ft_new);

    return diff_ns;    
}

/*phase_diff:相位差，单位 ns*/
int32_t stc_adjust_sniffer_phase(int32_t phase_diff,uint32_t flag)
{
    uint64_t ft_new;
    double delta;
    int64_t diff = phase_diff;
    uint32_t tod_lo,tod_mi;
    uint64_t tod_second;
    static uint32_t first_sync_flag = 0;

    if((flag)||(!first_sync_flag))
    {
        first_sync_flag = 1;
        
        g_stc_regs_ptr->tod_reg_ft_lo = 0; //ft
        g_stc_regs_ptr->tod_reg_ft_hi = 0;
        //g_stc_regs_ptr->tod_reg_config &= 0xef;//clear tod_incr_en
        
        tod_lo = g_stc_regs_ptr->tod_reg_tod_lo;  
        tod_mi = g_stc_regs_ptr->tod_reg_tod_mi; 
        tod_second = g_stc_regs_ptr->tod_reg_tod_hi;
        ft_new = ((tod_mi & 0xffff) << 16) | (tod_lo >> 16);
        diff = (ft_new + 904) - diff;
        tod_second = (tod_second << 16) | (tod_mi >> 16);
        if(diff >= 1000000000)
        {
            diff -= 1000000000;
            tod_second += 1;
        }
        else if(diff < 0)
        {
            diff += 1000000000;
            tod_second -= 1;
        }
        tod_second += 1;
        //g_stc_regs_ptr->tod_reg_su_lo = tod_second;
        //g_stc_regs_ptr->tod_reg_su_hi = tod_second >> 32;  //set su
        
        g_stc_regs_ptr->tod_reg_nsf_init_lo = 0;
        g_stc_regs_ptr->tod_reg_nsf_init_hi = diff;  //set nsf_init
        /*g_stc_regs_ptr->tod_reg_int_status = 4;  //clear hscc_dump(tod) int  */ 
        g_stc_regs_ptr->tod_reg_ft_lo = g_stc_state.default_ft; // set ft
        g_stc_regs_ptr->tod_reg_ft_hi = g_stc_state.default_ft >> 32;

        /*do{
            usleep(1000);
        }while(!(g_stc_regs_ptr->tod_reg_int_status & 0x4));  //wait hscc_dump(tod) int

        g_stc_regs_ptr->tod_reg_config |= 0x10; //set tod_incr_en,TOD second auto add */ 
        UCP_PRINT_DEBUG("phase_diff = %d,tod_ns = %ld,diff = %ld",phase_diff,ft_new,diff);

        return STC_OK;
    }
    
    if((phase_diff  < SNIFFER_LOCK_THRESHOLD) && (phase_diff  > -SNIFFER_LOCK_THRESHOLD))
    {
        g_stc_state.phase.status = 1;
        if(++g_stc_state.phase.tracking_cnt > STC_LOCK_CNT)
        {
            g_stc_state.phase.tracking_cnt = STC_LOCK_CNT;
            g_stc_state.phase.holdover_cnt = 0;
            g_stc_state.phase.disable_cnt = 0;
            g_stc_state.state = CLK_TRACKING;
        }
    }
    else
    {
        g_stc_state.phase.tracking_cnt = 0;
        g_stc_state.phase.status = 0;
    } 

    diff <<= 32;    
    g_stc_state.phase.integral += diff;    

    /*根据差值，设置Ft寄存器值，使|Rt-nsf|最小*/
    delta = g_stc_state.phase.p_ratio * diff + g_stc_state.phase.i_ratio * g_stc_state.phase.integral;
    ft_new = g_stc_state.default_ft - delta * g_stc_state.phase.magic_num;
#ifdef SL_ADJ_FREQ    
    UCP_PRINT_DEBUG("phase_diff = %d,diff = %ld, ft_new = %#lx",phase_diff,diff,ft_new);
#endif    
    
    g_stc_regs_ptr->tod_reg_ft_lo = ft_new & 0xffffffff;
    g_stc_regs_ptr->tod_reg_ft_hi = ft_new >> 32;

    return STC_OK;
}

uint32_t read_stc_local_timer()
{
    if(g_drv_mem_fd < 0)
    {
        g_drv_mem_fd = open("/dev/mem", O_RDWR|O_SYNC);
        if(g_drv_mem_fd < 0)
        {
            UCP_PRINT_ERROR("open /dev/mem error");
            return LOGIC_ERROR1;
        }
    }

    if(g_stc_regs_ptr == NULL)
    {
        g_stc_regs_ptr = mmap(NULL, STC_REG_LEN, PROT_READ|PROT_WRITE, MAP_SHARED,
                            g_drv_mem_fd, STC_REG_BASE_ADDR);
        if(-1 == (int64_t)g_stc_regs_ptr)
        {
            UCP_PRINT_ERROR("mmap stc regs error!! return = %ld\n",(uint64_t)g_stc_regs_ptr);
            g_stc_regs_ptr = NULL;
            return LOGIC_ERROR2;
        }
    }

    return *((uint32_t*)g_stc_regs_ptr + STC_LTBG_REG_OFFSET);
}

int32_t set_clk_mode(clk_flag_e pseudo_flag)
{
    g_stc_state.pesudo_flag = pseudo_flag;
    return STC_OK;
}

/*------------------------------------------------------------------------------
*
*    Function Name: init_stc
*
*    Input(s):
*        <none>
*
*    Output(s):
*        <none>
*
*    Returns:
*        STC_OK;
*        <0
*
*    Description:
*        实现STC模块初始化，包括中断使能等。由于芯片
*        级驱动的初始化均采用默认配置，故在板级初始化时，针对特殊应用，
*        需调用芯片级驱动提供的相关配置接口，使芯片工作在稳定状态。
*
------------------------------------------------------------------------------*/
int32_t init_stc()
{
    if(1 == g_init_stc_flag)
    {
        return STC_OK;
    }

	UCP_PRINT_DEBUG("stc version: %s",TFU_VER);

    if(STC_OK != map_stc_reg_space())
    {
        UCP_PRINT_ERROR("map stc reg error!");
        return LOGIC_ERROR1;
    }
    
    if(-1 == g_stc_fd)
    {
        g_stc_fd = open(STC_DEV_NAME,O_RDWR);//O_RDWR
        if(-1 == g_stc_fd)
        {
            UCP_PRINT_ERROR("open stc-dev device failed!!!");
            return LOGIC_ERROR3;
        }
    }

    if(STC_OK != get_pclk_value())
    {
        UCP_PRINT_ERROR("get pclk error!");
        return LOGIC_ERROR4;
    }
    else
    {
        set_rt_reg(0x3B9ACA00);
        set_su_reg(100);
        select_hscc_dump_source(EX_1PPS_IN);
        select_xpps_in_source(GNSS_1PPS_IN);
        set_ft_init_value(g_stc_state.p_clk);
        //set_xpps_out_source(TOD_1PPS_OUT);
        //select_xpps_in_source(GNSS_1PPS_IN);
        //select_xpps_in_source(GMAC0_1PPS_IN);
        //enable_stc_irq(STC_EX_1PPS_IN);
    } 

    g_init_stc_flag = 1;
    
    return STC_OK;
}

uint32_t get_gmac_src_time()
{
    return *g_gmac0_tod_ptr;
}

uint32_t get_tmac_src_time()
{
    return *g_tmac_tod_ptr;
}

int32_t get_clock_module_status(volatile clock_module_status_s* clk_module_status_ptr)
{
    if(NULL == clk_module_status_ptr)
    {
        UCP_PRINT_ERROR("clk_module_status_ptr is null!");
        return LOGIC_ERROR1;
    }

    clk_module_status_ptr->status = g_stc_state.state;

    if(TRUE_FLAG == g_stc_state.pesudo_flag)
    {
        clk_module_status_ptr->status = CLK_TRACKING;
    }

    return STC_OK;
}

stc_state_s * get_stc_state()
{
    return &g_stc_state;
}

arm_stc_regs * get_stc_reg_base()
{
    return g_stc_regs_ptr;
}

void * get_ap_gpio_reg_base()
{
    return g_ap_gpio_pinmux_regs_ptr;
}


/* End of stc_drv.c */
