/*------------------------------------------------------------
//                 Copyright (c) 2022 SmartLogic.
//                       ALL RIGHTS RESERVED
// -----------------------------------------------------------------
// Filename      : stc_drv.c
// Author        : weihua.li
// Created On    : 2022-11-23
// Last Modified :
// -----------------------------------------------------------------
// Description:
//
//
// ----------------------------------------------------------------*/
#define _GNU_SOURCE
#include <stdio.h>
#include <string.h>
#include <sys/types.h>
//#include <asm-generic/unistd.h>
#include <errno.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <unistd.h>
#include <termios.h>
#include <stdlib.h>
#include <time.h>
#include <sys/ipc.h>
#include <sys/sem.h>
#include <linux/times.h>
#include <sys/time.h>
//#include <linux/interrupt.h>
#include <stdarg.h>
#include "typedef.h"
#include "ucp_printf.h"
#include "ublox_drv.h"

drv_gps_msg_s g_gps_recv_msg;
int32_t g_gps_recv_task_id = -1;


uint8_t g_tx_buf[UBLOX_TX_BUF_SIZE] = {SYNC1_UBLOX,SYNC2_UBLOX};
ublox_uart_s g_ublox_uart = 
{
    .recv_ptr = 0,
    .deal_ptr = 0,
    .recv_cnt = 0,
    .deal_cnt = 0,
    .send_cnt = 0,    
    .send_buf_ptr = (ubx_msg_s*)(g_tx_buf + 2),
};

uint8_t g_almanach_flag;        /*Almanach flag*/
int32_t g_ubx_sem[UBX_SEM_NUM];
uint32_t g_tod_link_alarm = 0;
int32_t g_tfu_sync_sem = -1;   //pp1s中断同步信号量
int32_t g_tfu_to_time_sem = 0;  //tracking后释放给OM，计算帧号
int32_t g_tfu_init_flag = 0;
int32_t drv_uart_fd = -1;
int32_t g_sem_prj_id = 20;

extern void drv_tfu_phase_adjust(uint8_t count);
extern int32_t drv_semaphore_p(int32_t sem_id);
static int32_t drv_semaphore_timed_p(int32_t sem_id,int32_t timeout_us);
static int32_t drv_semaphore_v(int32_t sem_id);

extern void drv_set_odd_flag(uint8_t flag);/*1:odd  2:even*/
int32_t drv_thread_create(uint8_t* pthread_name, uint8_t thread_prio, uint32_t thread_size, void *callback, void* pArg);

int32_t drv_sem_create(int32_t prj_id)
{
    key_t key;
    int32_t sem_id;
    union semun sem_union;

    //key = ftok(MY_IPCKEY,prj_id);
    key = MY_IPCKEY + prj_id;
    sem_id = semget((key_t)key, 1, IPC_CREAT);
    if(-1 == sem_id)
    {
        UCP_PRINT_ERROR("semget error  sem_id:%d  err = %s!\n\r",sem_id,strerror(errno));
        return OSP_ERROR;
    }

    sem_union.val = 1;
    if(semctl(sem_id, 0, SETVAL, sem_union) == -1)
    {
        UCP_PRINT_ERROR("semctl error\n\r");
        return OSP_ERROR;
    }

    return sem_id;
}

int32_t drv_sem_create_sync(int32_t prj_id)
{
    key_t key;
    int32_t sem_id;
    union semun sem_union;

    //key = ftok(MY_IPCKEY,prj_id);
    key = MY_IPCKEY + prj_id;
    sem_id = semget((key_t)key, 1, IPC_CREAT);
    if(-1 == sem_id)
    {
        UCP_PRINT_ERROR("semget error  sem_id:%d  err = %s!\n\r",sem_id,strerror(errno));
        return OSP_ERROR;
    }

    sem_union.val = 0;
    if(semctl(sem_id, 0, SETVAL, sem_union) == -1)
    {
        UCP_PRINT_ERROR("semctl error\n\r");
        return OSP_ERROR;
    }

    return sem_id;
}

int32_t drv_semaphore_p(int32_t sem_id)
{
    struct sembuf sem_p;
    sem_p.sem_num = 0;
    sem_p.sem_op = -1;
    sem_p.sem_flg = SEM_UNDO;

    if(semop(sem_id, &sem_p, 1) == -1)
    {
        UCP_PRINT_ERROR("semaphore_p failed  err=%s \n\r",strerror(errno));
        return OSP_ERROR;
    }

    return OSP_OK;
}

static int32_t drv_semaphore_timed_p(int32_t sem_id,int32_t timeout_us)
{
    struct sembuf sem_p;
    struct timespec time;
    int32_t temp = timeout_us;

    if(temp >= 1000000)
    {
        time.tv_sec = temp/1000/1000;
        temp = temp%1000000;
    }
    else
    {
        time.tv_sec = 0;
    }

    time.tv_nsec = temp*1000;

    sem_p.sem_num = 0;
    sem_p.sem_op = -1;
    sem_p.sem_flg = SEM_UNDO;

    if(semtimedop(sem_id, &sem_p, 1,&time) == -1)
    {
        UCP_PRINT_ERROR("semtimedop failed");
        return OSP_ERROR;
    }

    return OSP_OK;
}


static int32_t drv_semaphore_v(int32_t sem_id)
{
    struct sembuf sem_b;

    sem_b.sem_num = 0;
    sem_b.sem_op = 1;
    sem_b.sem_flg = SEM_UNDO;
    if(semop(sem_id, &sem_b, 1) == -1)
    {
        UCP_PRINT_ERROR("semaphore_v failed sem_id%d err = %s! \n\r",sem_id, strerror(errno));
        return OSP_ERROR;
    }
    return OSP_OK;
}

int32_t set_opt(int32_t fd,int32_t nSpeed, int32_t nBits, int8_t nEvent, int32_t nStop)
{
    struct termios newtio,oldtio;

    if ( tcgetattr( fd,&oldtio) != 0)
    {
        perror("SetupSerial error");
        UCP_PRINT_ERROR("SetupSerial error\n\r");
        return -1;
    }

    bzero( &newtio, sizeof( newtio ) );
    newtio.c_cflag |= CLOCAL | CREAD;
    newtio.c_cflag &= ~CSIZE;

    switch( nBits )
    {
        case 7:
            newtio.c_cflag |= CS7;
        break;
        case 8:
            newtio.c_cflag |= CS8;
        break;
    }

    switch( nEvent )
    {
        case 'O':
            newtio.c_cflag |= PARENB;
            newtio.c_cflag |= PARODD;
            newtio.c_iflag |= (INPCK | ISTRIP);
        break;
        case 'E':
            newtio.c_iflag |= (INPCK | ISTRIP);
            newtio.c_cflag |= PARENB;
            newtio.c_cflag &= ~PARODD;
        break;
        case 'N':
            newtio.c_cflag &= ~PARENB;
        break;
    }

    switch( nSpeed )
    {
        case 2400:
            cfsetispeed(&newtio, B2400);
            cfsetospeed(&newtio, B2400);
        break;
        case 4800:
            cfsetispeed(&newtio, B4800);
            cfsetospeed(&newtio, B4800);
        break;
        case 9600:
            cfsetispeed(&newtio, B9600);
            cfsetospeed(&newtio, B9600);
        break;
        case 115200:
            cfsetispeed(&newtio, B115200);
            cfsetospeed(&newtio, B115200);
        break;
        default:
            cfsetispeed(&newtio, B9600);
            cfsetospeed(&newtio, B9600);
        break;
    }

    if( nStop == 1 )
    {
        newtio.c_cflag &= ~CSTOPB;
    }
    else if ( nStop == 2 )
    {
        newtio.c_cflag |= CSTOPB;
    }
    newtio.c_cc[VTIME] = 1;  //100ms
    newtio.c_cc[VMIN] = 64; //60;  
    tcflush(fd,TCIFLUSH);
    if((tcsetattr(fd,TCSANOW,&newtio))!=0)
    {
        perror("com set error");
        UCP_PRINT_ERROR("com set error\n\r");
        return -1;
    }
    UCP_PRINT_DEBUG("set done!\n");
    return 0;
}


static int drv_tfu_uart_send (uint8_t *pdata, uint32_t len)
{
    int32_t write_count = 0;
    if((NULL == pdata)|(0 == len))
    {
        UCP_PRINT_ERROR("uart send para error");
        return OSP_ERROR;
    }

    write_count = write(drv_uart_fd,pdata,len);

    if(write_count < len)
    {
        UCP_PRINT_ERROR("uart send error write_count=%d,len=%d",write_count,len);
        return OSP_ERROR;
    }

    return OSP_OK;
}

static int32_t drv_send_ublox_msg(void)
{
    uint32_t i;
    uint8_t ck_a = 0, ck_b = 0;
    uint16_t pld_len, pld_end;
    int32_t result = 0;
   
    pld_len = REVS16(g_ublox_uart.send_buf_ptr->length);

    /*calc checksum */
    pld_end = pld_len + INDEX_OF_PAYLOAD;
    for(i = 2; i < pld_end; ++i)
    {
        ck_a += g_tx_buf[i];
        ck_b += ck_a;
    }
    g_tx_buf[pld_end] = ck_a;
    g_tx_buf[pld_end + 1] = ck_b;
        
    result = drv_tfu_uart_send(g_tx_buf, pld_end + 2);
    memset(g_tx_buf + 2, 0, UBLOX_TX_BUF_SIZE - 2);
    if(OSP_ERROR == result)
    {
        UCP_PRINT_ERROR("uart send msg error");
        return OSP_ERROR;
    }
    return OSP_OK;
}


int32_t drv_tfu_get_port_cfg(void)
{
    int32_t result = OSP_ERROR;

    drv_semaphore_p(g_ublox_uart.send_sem);/* get tx sem*/
    g_ublox_uart.send_buf_ptr->cls_id = CFG;
    g_ublox_uart.send_buf_ptr->msg_id = CFG_PRT;
    g_ublox_uart.send_buf_ptr->length = REVS16(POLL_LENGTH);
    result = drv_send_ublox_msg();
    if(OSP_ERROR == result)
    {
        UCP_PRINT_ERROR("send ublox msg error\n\r");
    //*******************************
        drv_semaphore_v(g_ublox_uart.send_sem);/*send tx sem*/
        return OSP_ERROR;
    }
    drv_semaphore_v(g_ublox_uart.send_sem);/*send tx sem*/
    if(OSP_OK != drv_semaphore_timed_p(g_ubx_sem[CFG_PRT_SEM], 3*1000000))
    {
        UCP_PRINT_ERROR("tfu: gps not reply! %s\n", __FUNCTION__);
        g_tod_link_alarm = 1;
        return OSP_ERROR;
    }
    else
    {
        g_tod_link_alarm = 0;
    }

    return OSP_OK;
}


int32_t drv_tfu_set_port_cfg(void)
{
    int32_t result = 0;

    drv_semaphore_p(g_ublox_uart.send_sem);
    g_ublox_uart.send_buf_ptr->cls_id = CFG;
    g_ublox_uart.send_buf_ptr->msg_id = CFG_PRT;
    g_ublox_uart.send_buf_ptr->length = REVS16(CFG_PRT_LEN);
    g_ublox_uart.send_buf_ptr->pay_load.config_port.portid = PORT_NUMBER;
    g_ublox_uart.send_buf_ptr->pay_load.config_port.res0 = 0;
    g_ublox_uart.send_buf_ptr->pay_load.config_port.res1 = 0;
    g_ublox_uart.send_buf_ptr->pay_load.config_port.mode = REVS32(PORT_MODE_8N1);
    g_ublox_uart.send_buf_ptr->pay_load.config_port.baudrate = REVS32(PORT_BAUDRATE);
    g_ublox_uart.send_buf_ptr->pay_load.config_port.inportmask = REVS16(PORT_PROTOCAL_IN);
    g_ublox_uart.send_buf_ptr->pay_load.config_port.outportmask = REVS16(PORT_PROTOCAL_OUT);
    g_ublox_uart.send_buf_ptr->pay_load.config_port.flags = 0;
    g_ublox_uart.send_buf_ptr->pay_load.config_port.pad = 0;
    result = drv_send_ublox_msg();
    if(OSP_ERROR == result)
    {
        UCP_PRINT_ERROR("send ublox msg error\n\r");
    //*******************************
        drv_semaphore_v(g_ublox_uart.send_sem);
        return OSP_ERROR;
    }
    drv_semaphore_v(g_ublox_uart.send_sem);

    if(OSP_OK != drv_semaphore_timed_p(g_ubx_sem[CFG_PRT_SEM], 2*1000000))
    {
        UCP_PRINT_ERROR("tfu: no response to %s!\n", __FUNCTION__);
        g_tod_link_alarm = 1;
        return OSP_ERROR;
    }
    else
    {
        g_tod_link_alarm = 0;
    }
    return OSP_OK;
}

int32_t drv_tfu_set_ant_cfg(void)
{
    int32_t  result = 0;

    /*drv_semaphore_p(g_ublox_uart.send_sem);

    g_ublox_uart.send_buf_ptr->cls_id = CFG;
    g_ublox_uart.send_buf_ptr->msg_id = CFG_ANT;
    g_ublox_uart.send_buf_ptr->length = POLL_LENGTH;

    result = drv_send_ublox_msg();
    if(OSP_ERROR == result)
    {
        UCP_PRINT_ERROR("poll ant cfg : send ublox msg error\n\r");
        drv_semaphore_v(g_ublox_uart.send_sem);
        return OSP_ERROR;
    }

    drv_semaphore_v(g_ublox_uart.send_sem);

    if(OSP_OK != drv_semaphore_timed_p(g_ubx_sem[CFG_ANT_SEM], 2*1000000))
    {
        UCP_PRINT_ERROR("poll ant cfg  error\n\r");
        g_tod_link_alarm = 1;
        return OSP_ERROR;
    }
    else
    {
        g_tod_link_alarm = 0;
    }*/

    drv_semaphore_p(g_ublox_uart.send_sem);

    g_ublox_uart.send_buf_ptr->cls_id = CFG;
    g_ublox_uart.send_buf_ptr->msg_id = CFG_ANT;
    g_ublox_uart.send_buf_ptr->length = REVS16(CFG_ANT_LEN);
    g_ublox_uart.send_buf_ptr->pay_load.config_ant.flags = REVS16(ANT_FLAGS);
    g_ublox_uart.send_buf_ptr->pay_load.config_ant.pins = REVS16(0xb9f0);

    result = drv_send_ublox_msg();
    drv_semaphore_v(g_ublox_uart.send_sem);
    if(OSP_OK != result)
    {
        UCP_PRINT_ERROR("ant cfg: send ublox msg error");
        return OSP_ERROR;
    }

    if(OSP_OK != drv_semaphore_timed_p(g_ubx_sem[CFG_ANT_SEM], 2*1000000))
    {
        UCP_PRINT_ERROR("set_ant_cfg error\n\r");
        return OSP_ERROR;
    }
    else
    {
        g_tod_link_alarm = 0;
    }
  
    return OSP_OK;
}


int32_t drv_tfu_set_tp_cfg(uint32_t tp_width, int8_t pps_polarity,int16_t cab_delay)
{
    int32_t result = 0;

    drv_semaphore_p(g_ublox_uart.send_sem);

    g_ublox_uart.send_buf_ptr->cls_id = CFG;
    g_ublox_uart.send_buf_ptr->msg_id = CFG_TP5;
    g_ublox_uart.send_buf_ptr->length = REVS16(CFG_TP5_LEN);
    g_ublox_uart.send_buf_ptr->pay_load.config_tp5.tp_idx = TP_IDX0;
    g_ublox_uart.send_buf_ptr->pay_load.config_tp5.cab_dly = REVS16(cab_delay);
    g_ublox_uart.send_buf_ptr->pay_load.config_tp5.rf_dly = REVS16(0);
    g_ublox_uart.send_buf_ptr->pay_load.config_tp5.freq_period = REVS16(TP_INTERVAL);
    g_ublox_uart.send_buf_ptr->pay_load.config_tp5.freq_period_locked = REVS16(TP_INTERVAL);
    g_ublox_uart.send_buf_ptr->pay_load.config_tp5.pulse_len = REVS16(0);  //no pulse before ublox locked
    g_ublox_uart.send_buf_ptr->pay_load.config_tp5.pulse_len_locked = REVS16(tp_width);
    g_ublox_uart.send_buf_ptr->pay_load.config_tp5.user_delay = REVS16(0);
    g_ublox_uart.send_buf_ptr->pay_load.config_tp5.active = 1;
    g_ublox_uart.send_buf_ptr->pay_load.config_tp5.lock_gnss_freq = 1;
    g_ublox_uart.send_buf_ptr->pay_load.config_tp5.lock_other_set = 1;
    g_ublox_uart.send_buf_ptr->pay_load.config_tp5.is_freq = 0;  //us
    g_ublox_uart.send_buf_ptr->pay_load.config_tp5.is_length = 1;  //us
    g_ublox_uart.send_buf_ptr->pay_load.config_tp5.align2tow = 1;
    g_ublox_uart.send_buf_ptr->pay_load.config_tp5.polarity = pps_polarity;
    g_ublox_uart.send_buf_ptr->pay_load.config_tp5.grid_utc_gnss = TP_TIME_GPS;
    
    result = drv_send_ublox_msg();
    if(OSP_ERROR == result)
    {
        UCP_PRINT_ERROR("set tp cfg: send ublox msg error\n\r");
        drv_semaphore_v(g_ublox_uart.send_sem);
        return OSP_ERROR;
    }

    drv_semaphore_v(g_ublox_uart.send_sem);

    if(OSP_OK != drv_semaphore_timed_p(g_ubx_sem[CFG_TP_SEM], 2*1000000))
    {
        g_tod_link_alarm = 1;
        return OSP_ERROR;
    }
    else
    {
        g_tod_link_alarm = 0;
    }
    return OSP_OK;
}


int32_t set_cable_time_delay(int16_t delay_time)
{
    int32_t result = 0;

    /*--get g_pulse_width ,and then be writed agian--*/
    drv_semaphore_p(g_ublox_uart.send_sem);

    g_ublox_uart.send_buf_ptr->cls_id = CFG;
    g_ublox_uart.send_buf_ptr->msg_id = CFG_TP5;
    g_ublox_uart.send_buf_ptr->length = POLL_LENGTH;

    result = drv_send_ublox_msg();
    if(OSP_ERROR == result)
    {
        UCP_PRINT_ERROR("set cabdelay : send ublox msg error\n\r");
        drv_semaphore_v(g_ublox_uart.send_sem);
        return OSP_ERROR;
    }

    drv_semaphore_v(g_ublox_uart.send_sem);

    if(OSP_OK != drv_semaphore_timed_p(g_ubx_sem[CFG_TP_SEM], 2*1000000))
    {
        return OSP_ERROR;
    }
    else
    {
        g_tod_link_alarm = 0;
    }
    
    if(OSP_OK != drv_tfu_set_tp_cfg(TP_PLUSE_WIDTH, TP_POSITIVE, delay_time))
    {
        return OSP_ERROR;
    }
    return OSP_OK;
}

#if 0
int32_t get_cable_time_delay(int16_t* delay_time_ptr)
{

    uint8_t cable_delay[8] = {0};
    uint32_t flash_result = -1;

    if(NULL == delay_time_ptr)
    {
        UCP_PRINT_ERROR("tfu: %s, delay_time_ptr is NULL.\n", __FUNCTION__);
        return OSP_ERROR;
    }

    flash_result = drv_flash_read(&cable_delay[0], 8, CABLE_DELAY_ADDR);
    if(0 == flash_result)
    {
        UCP_PRINT_ERROR("read flash error\n\r");
        return OSP_ERROR;
    }

    if((CABDLY_DELAY_CRC_BYTE1==cable_delay[0]) && (CABDLY_DELAY_CRC_BYTE2==cable_delay[1]))
    {
        memcpy(delay_time_ptr, cable_delay+2, 2);
        UCP_PRINT_DEBUG("valid cable delay = %d \n",*((int16_t* )(&cable_delay[2])));
        return OSP_OK;
    }
    else
    {
        UCP_PRINT_ERROR("invalid cable delay = %x%x \n",cable_delay[0],cable_delay[1]);
        return OSP_ERROR;
    }
}
#endif

int32_t drv_tfu_set_nav5_cfg(void)
{
    int32_t result = 0;

    drv_semaphore_p(g_ublox_uart.send_sem);

    g_ublox_uart.send_buf_ptr->cls_id = CFG;
    g_ublox_uart.send_buf_ptr->msg_id = CFG_NAV5;
    g_ublox_uart.send_buf_ptr->length = REVS16(CFG_NAV5_LEN);
    g_ublox_uart.send_buf_ptr->pay_load.config_nav5.fix_mode = NAV5_FIXMODE;
    g_ublox_uart.send_buf_ptr->pay_load.config_nav5.pacc = REVS16(NAV5_PACC);
    g_ublox_uart.send_buf_ptr->pay_load.config_nav5.tacc = REVS16(NAV5_TACC);
    
    result = drv_send_ublox_msg();
    if(OSP_ERROR == result)
    {
        UCP_PRINT_ERROR("set nav5 cfg: send ublox msg error \n\r");
        drv_semaphore_v(g_ublox_uart.send_sem);
        return OSP_ERROR;
    }
    drv_semaphore_v(g_ublox_uart.send_sem);

    if(OSP_OK != drv_semaphore_timed_p(g_ubx_sem[CFG_NAV5_SEM], 3*1000000))
    {

        return OSP_ERROR;
    }
    else
    {
        g_tod_link_alarm = 0;
    }
    return OSP_OK;
}


int32_t drv_tfu_set_msg_cfg(uint8_t cls, uint8_t msg, uint8_t rate)
{
    int32_t result = 0;

    drv_semaphore_p(g_ublox_uart.send_sem);

    g_ublox_uart.send_buf_ptr->cls_id = CFG;
    g_ublox_uart.send_buf_ptr->msg_id = CFG_MSG;
    g_ublox_uart.send_buf_ptr->length = REVS16(CFG_MSG_LEN);
    g_ublox_uart.send_buf_ptr->pay_load.config_msg.cls = cls;
    g_ublox_uart.send_buf_ptr->pay_load.config_msg.msgid = msg;
    g_ublox_uart.send_buf_ptr->pay_load.config_msg.rate = rate;

    result = drv_send_ublox_msg();
    if(OSP_ERROR == result)
    {
        UCP_PRINT_ERROR("set msg cfg: send ublox msg error\n\r");
        drv_semaphore_v(g_ublox_uart.send_sem);
        return OSP_ERROR;
    }

    drv_semaphore_v(g_ublox_uart.send_sem);

    if(OSP_OK != drv_semaphore_timed_p(g_ubx_sem[CFG_MSG_SEM], 2*1000000))
    {        
        return OSP_ERROR;
    }
    else
    {
        g_tod_link_alarm = 0;
    }
    return OSP_OK;
}


int32_t drv_tfu_config_ublox(void)
{
    uint8_t i = 0;
    /**/
#if 0
    for(i=0;i<3;i++)
    {
        if(OSP_OK == drv_tfu_get_port_cfg())
        {
            break;
        }
        else
        {
            sleep(1);/*s*/
        }
    }
    if(3 == i)
    {
        TFU_PRINTF(LTE230_PRINT_ERROR,"ublox: get port cfg error!\n");
        return OSP_ERROR;
    }
//TFU_PRINTF(LTE230_PRINT_DEBUG,"get_port_cfg i=%d\n\r",i);
#endif

    tcflush(drv_uart_fd,TCIOFLUSH);
    
    for(i = 0; i < 3; i++)
    {
        if(OSP_OK == drv_tfu_set_port_cfg())
        {
            break;
        }
        else
        {
            sleep(1);
        }
    }
    if(3 == i)
    {            
        UCP_PRINT_ERROR("ublox: set port cfg error!\n");
        //return OSP_ERROR;
    }

#if 0
    /*close name gprmc*/
    for(i = 0; i < 3; i++)
    {
        if(OSP_OK == drv_tfu_set_msg_cfg(NMEA, RMC,0))
        {
            break;
        }
        else
        {
            sleep(1);
        }
    }
    if(3 == i)
    {
        UCP_PRINT_ERROR("ublox: close name gprmc error!\n");
        g_tod_link_alarm = 1;
        //return OSP_ERROR;
    }

    /*close GPVTG*/
    for(i = 0; i < 3; i++)
    {
        if(OSP_OK == drv_tfu_set_msg_cfg(NMEA, VTG,0))
        {
            break;
        }
        else
        {
            sleep(1);
        }
    }
    if(3 == i)
    {
        UCP_PRINT_ERROR("ublox: close gpvtg error!\n");
        g_tod_link_alarm = 1;
        //return OSP_ERROR;
    }
    
    /*close gpgga*/
    for(i = 0; i < 3; i++)
    {
        if(OSP_OK == drv_tfu_set_msg_cfg(NMEA, GGA,0))
        {
            break;
        }
        else
        {
            sleep(1);
        }
    }
    if(3 == i)
    {
        UCP_PRINT_ERROR("ublox:close gpgga error!\n");
        g_tod_link_alarm = 1;
        //return OSP_ERROR;
    }
    
    /*close gpgsa*/   
    for(i = 0; i < 3; i++)
    {
        if(OSP_OK == drv_tfu_set_msg_cfg(NMEA, GSA,0))
        {
            break;
        }
        else
        {
            sleep(1);
        }
    }
    if(3 == i)
    {
        UCP_PRINT_ERROR("ublox: close GPGSA error!\n");
        g_tod_link_alarm = 1;
        //return OSP_ERROR;
    }
    
    /*close gpgsv*/
    for(i = 0; i < 3; i++)
    {
        if(OSP_OK == drv_tfu_set_msg_cfg(NMEA, GSV,0))
        {
            break;
        }
        else
        {
            sleep(1);
        }
    }
    if(3 == i)
    {
        UCP_PRINT_ERROR("ublox: close gpgsv error!\n");
        g_tod_link_alarm = 1;
        //return OSP_ERROR;
    }
    
    /*close gpgll*/  
    for(i = 0; i < 3; i++)
    {
        if(OSP_OK == drv_tfu_set_msg_cfg(NMEA,GLL,0))
        {
            break;
        }
        else
        {
            sleep(1);
        }
    }
    if(3 == i)
    {
        UCP_PRINT_ERROR("ublox: close gpgll error!\n");
        g_tod_link_alarm = 1;
        //return OSP_ERROR;
    }
    
    /*close zda*/
    for(i = 0; i < 3; i++)
    {
        if(OSP_OK == drv_tfu_set_msg_cfg(NMEA, ZDA,0))
        {
            break;
        }
        else
        {
            sleep(1);
        }
    }
    if(3 == i)
    {
        UCP_PRINT_ERROR("ublox: close gpzda error!\n");
        g_tod_link_alarm = 1;
        //return OSP_ERROR;
    }
#endif
    /*set ant cfg*/
    for(i = 0; i < 3; i++)
    {
        if(OSP_OK == drv_tfu_set_ant_cfg())
        {
            break;
        }
        else
        {
            sleep(1);
        }
    }
    if(3 == i)
    {
        UCP_PRINT_ERROR("ublox: set ant cfg error!\n");
        g_tod_link_alarm = 1;
        //return OSP_ERROR;
    }

    for(i = 0; i < 3; i++)
    {
        if(OSP_OK == set_cable_time_delay(CABDLY_DELAY))
        {
            break;
        }
        else
        {
            sleep(1);
        }
    }
    if(3 == i)
    {
        UCP_PRINT_ERROR("set ublox cabdly error!\n");
        g_tod_link_alarm = 1;
        //return OSP_ERROR;
    }

    for(i = 0; i < 3; i++)
    {
        if(OSP_OK == drv_tfu_set_nav5_cfg())
        {
            break;
        }
        else
        {
            sleep(1);
        }
    }
    if(3 == i)
    {
        UCP_PRINT_ERROR("ublox: set nav5 cfg error!\n");
        g_tod_link_alarm = 1;
        //return OSP_ERROR;
    }

    /*NAV-sys_status,NAV-TIMEGPS*/
    for(i = 0; i < 3; i++)
    {
        if(OSP_OK == drv_tfu_set_msg_cfg(NAV, NAV_TIMEGPS,1))
        {
            break;
        }
        else
        {
            sleep(1);
        }
    }
    if(3 == i)
    {
        UCP_PRINT_ERROR("ublox: set msg cfg NAV, NAV TIMEGPS error!\n");
        g_tod_link_alarm = 1;
        //return OSP_ERROR;
    }

    for(i = 0; i < 3; i++)
    {
        if(OSP_OK == drv_tfu_set_msg_cfg(NAV, NAV_STATUS,1))
        {
        /*clear alarm*/
            break;
        }
        else
        {
            sleep(1);
        }
    }
    if(3 == i)
    {
        UCP_PRINT_ERROR("ublox: set msg cfg NAV, NAV STATUS error!\n");
        g_tod_link_alarm = 1;
        
        /*set alarm*/
        //return OSP_ERROR;
    }
#if 0
    for(i=0;i<3;i++)
    {
        if(OSP_OK == drv_tfu_set_msg_cfg(NAV, NAV_SVINFO,1))
        {
        /*clear alarm*/
            break;
        }
        else
        {
            sleep(1);
        }
    }
    if(3 == i)
    {
        TFU_PRINTF(LTE230_PRINT_ERROR,"ublox: set msg cfg NAV, NAV SVINFO error!\n");
        g_tod_link_alarm = 1;
    /*set alarm*/
        return OSP_ERROR;
    }
#endif
#if 0  //20230227

    for(i = 0; i < 3; i++)
    {
        if(OSP_OK == drv_tfu_set_msg_cfg(MON, MON_HW,1))
        {
            break;
        }
        else
        {
            sleep(1);
        }
    }
    if(3 == i)
    {
        UCP_PRINT_ERROR("ublox: set msg cfg MON, MON HW error!\n");
        g_tod_link_alarm = 1;
        //return OSP_ERROR;
    }
#endif
#if 0
 for(i=0;i<3;i++)
    {
        if(OSP_OK == drv_tfu_set_msg_cfg(NAV, NAV_POSLLH,3))
        {
            break;
        }
        else
        {
            sleep(1);
        }
    }
    if(3 == i)
    {
        TFU_PRINTF(LTE230_PRINT_ERROR,"ublox: set msg cfg MON, MON HW error!%\n");
        g_tod_link_alarm = 1;
        return OSP_ERROR;
    }
#endif  
#if 0
 for(i=0;i<3;i++)
    {
        if(OSP_OK == drv_tfu_set_msg_cfg(NAV, NAV_SVINFO,3))
        {
            break;
        }
        else
        {
            sleep(1);
        }
    }
    if(3 == i)
    {
        TFU_PRINTF(LTE230_PRINT_ERROR,"ublox: set msg cfg MON, MON HW error!%\n");
        g_tod_link_alarm = 1;
        return OSP_ERROR;
    }
#endif

    return OSP_OK;
}


int32_t drv_tfu_receiver_init(void)
{
    uint32_t i = 0;
    int32_t result = 0;

    if(OSP_ERROR == (g_ublox_uart.send_sem = drv_sem_create(g_sem_prj_id)))
    {
        UCP_PRINT_ERROR("TFU: create g_ublox_uart.send_sem error!\n");
        return OSP_ERROR;
    }
    UCP_PRINT_DEBUG("g_ublox_uart.send_sem=%d\n\r",g_ublox_uart.send_sem);
    
    g_sem_prj_id++;
    for(i = 0; i < UBX_SEM_NUM; ++i)
    {
        if(OSP_ERROR == (g_ubx_sem[i]= drv_sem_create_sync(g_sem_prj_id++)))
        {
            UCP_PRINT_ERROR("drv_tfu_init semBCreate error  i:%d\n\r",i);
            return OSP_ERROR;
        }
        //g_sem_prj_id++;
    }
    
    g_gps_recv_task_id = drv_thread_create( (uint8_t *)"dgps_recv", 72, 8192,
                (void *)drv_gps_recv_task, NULL);
    if(OSP_ERROR == g_gps_recv_task_id)
    {
        UCP_PRINT_ERROR("ublox: create GPS recv task error!\n");
        return OSP_ERROR;
    }
    
    result = drv_tfu_config_ublox();
    if(OSP_ERROR == result)
    {
        UCP_PRINT_ERROR("config ublox error\n\r");
        return OSP_ERROR;
    }

    return OSP_OK;
}

int32_t drv_handle_ublox_msg(ubx_msg_s *rx_msg_ptr)
{
    uint8_t cls = 0, msg = 0;
    chn_info_s* chn_info_ptr;
    uint32_t i = 0;
    cls = rx_msg_ptr->cls_id;
    msg = rx_msg_ptr->msg_id;
    UCP_PRINT_LOG("gps data cls=%#x msg=%#x msg_length=%d",cls,msg,rx_msg_ptr->length);
    switch(cls)
    {
        case ACK: 
        {
            switch(msg)
            {
                case ACK_ACK: /*ack*/
                {
                    switch(rx_msg_ptr->pay_load.ack_msg.msgid)
                    {
                        case CFG_PRT:
                        {
                            drv_semaphore_v(g_ubx_sem[CFG_PRT_SEM]);
                            UCP_PRINT_LOG("tfu: give g_ubx_sem[CFG_PRT_SEM]...");
                            break;
                        }
                        case CFG_MSG:
                        {
                            drv_semaphore_v(g_ubx_sem[CFG_MSG_SEM]);
                            UCP_PRINT_LOG("tfu: give g_ubx_sem[CFG_MSG_SEM]...");
                            break;
                        }
                        case CFG_TP5:
                        {
                            drv_semaphore_v(g_ubx_sem[CFG_TP_SEM]);
                            UCP_PRINT_LOG("tfu:give g_ubx_sem[CFG_TP_SEM]...");
                            break;
                        }
                        case CFG_CFG:
                        {
                            drv_semaphore_v(g_ubx_sem[CFG_CFG_SEM]);
                            UCP_PRINT_LOG("tfu: g_ubx_sem[CFG_MSG_SEM]...");
                            break;
                        }
                        case CFG_ANT:
                        {
                            drv_semaphore_v(g_ubx_sem[CFG_ANT_SEM]);
                            UCP_PRINT_LOG("tfu: g_ubx_sem[CFG_ANT_SEM]...");
                            break;
                        }
                        case CFG_NAV5:
                        {
                            drv_semaphore_v(g_ubx_sem[CFG_NAV5_SEM]);
                            UCP_PRINT_LOG("tfu: g_ubx_sem[CFG_NAV5_SEM]...");
                            break;
                        }
                        case CFG_RST:
                        {
                            drv_semaphore_v(g_ubx_sem[CFG_RST_SEM]);
                            UCP_PRINT_LOG("tfu: g_ubx_sem[CFG_RST_SEM]...");
                            break; 
                        }
                        default:
                        {
                            UCP_PRINT_ERROR("tfu: unknown msg ack! msgid:%d\n",rx_msg_ptr->pay_load.ack_msg.msgid);
                            break;
                        }
                    }/*switch(g_rx_buf_ptr->pay_load.ack_msg.msgid)*/
                    break;
                }
                case ACK_NACK:/*nack*/
                {
                    UCP_PRINT_ERROR("ack_nack!!!");
                    return OSP_ERROR;
                }
                default:
                {
                    UCP_PRINT_ERROR("not ack, not nack msgid:%d\n\r",msg);
                    return OSP_ERROR;
                }
            }/*switch(msg)*/
            break;
        }
        case NAV:
        {
            switch(msg)
            {
                 case NAV_POSLLH:
                     g_gps_recv_msg.altitude = REVS32(rx_msg_ptr->pay_load.nav_pos.height);  
                     g_gps_recv_msg.latitude = REVS32(rx_msg_ptr->pay_load.nav_pos.lat);
                     g_gps_recv_msg.longitude = REVS32(rx_msg_ptr->pay_load.nav_pos.lon);  
                     UCP_PRINT_LOG("gps altitude=%d lat=%d lon=%d\n\r",g_gps_recv_msg.altitude,g_gps_recv_msg.latitude,g_gps_recv_msg.longitude);
                     drv_semaphore_v(g_ubx_sem[NAV_POSLLH_SEM]);
                     break;
                 case NAV_STATUS:
                    g_gps_recv_msg.lock_state = rx_msg_ptr->pay_load.nav_status.flags & 0x1;
                    g_gps_recv_msg.gps_fix = rx_msg_ptr->pay_load.nav_status.gps_fix;
                    g_gps_recv_msg.fix_flag = rx_msg_ptr->pay_load.nav_status.flags; 
                    g_gps_recv_msg.time_of_week = REVS32(rx_msg_ptr->pay_load.nav_status.i_tow) / 1000;
                    UCP_PRINT_LOG("gps lock_state=%d,time_of_week=%d",g_gps_recv_msg.lock_state,g_gps_recv_msg.time_of_week);
                    break;
                 case NAV_TIMEGPS:
                     g_gps_recv_msg.valid_flag = rx_msg_ptr->pay_load.nav_timegps.valid;
                     if(g_gps_recv_msg.valid_flag & (0x1 << 2))
                     {
                         g_gps_recv_msg.leap_sec = rx_msg_ptr->pay_load.nav_timegps.leap;       
                     }
                     g_gps_recv_msg.week_number = REVS16(rx_msg_ptr->pay_load.nav_timegps.week);
                     UCP_PRINT_LOG("week_number=%d",g_gps_recv_msg.week_number);
                     //drv_semaphore_v(g_ubx_sem[NAV_GPSTIME_SEM]);
                     break;

                 case NAV_SVINFO:
                     g_gps_recv_msg.num_ch = rx_msg_ptr->pay_load.nav_svinfo.num_ch;
                     chn_info_ptr = (chn_info_s*)(&rx_msg_ptr->pay_load.nav_svinfo.chn_info);
                     memset(g_gps_recv_msg.sta_id, 0, sizeof(g_gps_recv_msg.sta_id));
                     memset(g_gps_recv_msg.cno, 0, sizeof(g_gps_recv_msg.cno));
                     g_gps_recv_msg.tracking_num = 0;
                     g_gps_recv_msg.visable_num = 0;
                     g_almanach_flag = 0;
                     for(i = 0; i < g_gps_recv_msg.num_ch; i++)
                     {
                         int32_t j = 0, k = 0;
                         g_almanach_flag |= (chn_info_ptr+i)->flags;
                         if((chn_info_ptr+i)->cno > 0)
                         {
                             g_gps_recv_msg.visable_num++;
                             g_gps_recv_msg.sta_id[i] = (chn_info_ptr+i)->svid;
                             j++;
                             g_gps_recv_msg.cno[i] = (chn_info_ptr+i)->cno;
                             if(g_gps_recv_msg.cno[i] > 25)
                             {
                                 g_gps_recv_msg.tracking_num++;
                                 /*if(g_gps_recv_msg.cno[i] > 50)
                                 {
                                     g_gps_recv_msg.sig_over_high++;
                                 }*/
                             }
                             k++;
                         }
                         UCP_PRINT_DEBUG("i=%d chn=%d svid=%d flags=%d",i,(chn_info_ptr+i)->chn,(chn_info_ptr+i)->svid,(chn_info_ptr+i)->flags);
                         UCP_PRINT_DEBUG("cno=%d elev=%d azim=%d prres=%d\n\r",(chn_info_ptr+i)->cno,(chn_info_ptr+i)->elev,(chn_info_ptr+i)->azim,(chn_info_ptr+i)->prres);
                     }
                     UCP_PRINT_DEBUG("tracking_num:%d visable_num:%d\n\r",g_gps_recv_msg.tracking_num,g_gps_recv_msg.visable_num);
                     UCP_PRINT_DEBUG("tfu lock_flag=%#x num_ch=%d\n\r",g_gps_recv_msg.fix_flag,g_gps_recv_msg.num_ch);

                     drv_semaphore_v(g_ubx_sem[NAV_SVINFO_SEM]);
                     break;
                 default:break;
            }
            break;
        }
        case CFG: 
        {
            switch(msg)
            {
                case CFG_PRT:
                   UCP_PRINT_DEBUG("tfu: mode: %x.\n",REVS32(rx_msg_ptr->pay_load.config_port.mode));
                   UCP_PRINT_DEBUG("tfu: baudrate: %x.\n",REVS32(rx_msg_ptr->pay_load.config_port.baudrate));
                   UCP_PRINT_DEBUG("tfu: inportmask: %x.\n",REVS16(rx_msg_ptr->pay_load.config_port.inportmask));
                   UCP_PRINT_DEBUG("tfu: outportmask: %x.\n",REVS16(rx_msg_ptr->pay_load.config_port.outportmask));
                break;
                case CFG_MSG:
                
                break;
                case CFG_TP5:
                    g_gps_recv_msg.cab_dly = REVS16(rx_msg_ptr->pay_load.config_tp5.cab_dly);
                    g_gps_recv_msg.pulse_width = REVS32(rx_msg_ptr->pay_load.config_tp5.freq_period_locked);
                    g_gps_recv_msg.pps_status = rx_msg_ptr->pay_load.config_tp5.polarity;
                break;
                case CFG_ANT:
                    UCP_PRINT_DEBUG("cfg ant: flags: %x.\n",REVS32(rx_msg_ptr->pay_load.config_ant.flags));
                    UCP_PRINT_DEBUG("cfg ant: pins: %x.\n",REVS32(rx_msg_ptr->pay_load.config_ant.pins));
                    drv_semaphore_v(g_ubx_sem[CFG_ANT_SEM]);
                break;
                case CFG_RST:
                    UCP_PRINT_DEBUG("tfu:CFG.... CFG_RST\n");
                break;
                default:
                 break;
            }/*switch(msg)   CFG*/
            break;
        }
        case MON:
        {
            switch(msg)
            {
                case MON_HW:
                    g_gps_recv_msg.ant_state = rx_msg_ptr->pay_load.monitor_hw.astatus;
#if 0
                    if (ANT_OPEN_ALARM_VALUE == g_gps_recv_msg.ant_state)
                    {
                        /*dingyi*/
                         g_monitor_alarms |= (0x01 << 2); /*short*/
                    }
                    if (ANT_SHORT_ALARM_VALUE == g_gps_recv_msg.ant_state)
                    {
                         g_monitor_alarms |= (0x01 << 1);  /*open*/
                    }
#endif
                    //drv_semaphore_v(g_ubx_sem[MON_HW_SEM]);                    
                break;

                case MON_VER:
                    memset(g_gps_recv_msg.sw_version, 0, sizeof(g_gps_recv_msg.sw_version));
                    memset(g_gps_recv_msg.hw_version, 0, sizeof(g_gps_recv_msg.hw_version));
                    memcpy(g_gps_recv_msg.sw_version,rx_msg_ptr->pay_load.monitor_ver.sw_version,sizeof(g_gps_recv_msg.sw_version));
                    memcpy(g_gps_recv_msg.hw_version,rx_msg_ptr->pay_load.monitor_ver.hw_version,sizeof(g_gps_recv_msg.hw_version));
                    
                    break;
                
                default:
                    UCP_PRINT_DEBUG("tfu: unknown MON msg: %x.\n", msg);
                break;
            }/*switch(msg)  mon*/
            break;
        }
        default:
        {
            UCP_PRINT_DEBUG("tfu: unknown cls: %x.\n", cls);
            break;
        }
    }
    return OSP_OK;
}


int32_t drv_tfu_get_ublox_seconds(time_t* sec_ptr)
{   
    struct tm time_base = {0,0,0,6,0,80,0,0,0};
    if(NULL == sec_ptr)
    {
        UCP_PRINT_ERROR("tfu: get_ublox_seconds error -1.\n");
        return OSP_ERROR;
    }

    /*time of week and week number are valid*/
    if(TIME_VALID != (TIME_VALID & g_gps_recv_msg.valid_flag))
    {
         //UCP_PRINT_ERROR("tfu: time is invalid!  %x.\n", g_gps_recv_msg.valid_flag);
         return OSP_ERROR;
    }

    /*  *sec_ptr = mktime(1980,1,6,0,0,0)+ \ */
    *sec_ptr = mktime(&time_base)+ \
        GPS_SECONDS(g_gps_recv_msg.time_of_week, g_gps_recv_msg.week_number);
    return OSP_OK;
}

void deal_gps_data(void)
{
    int32_t i = 0,len,len_left = 0,check_len = 0;
    uint8_t *head_ptr;
    ubx_msg_s *rx_msg_ptr;
    ublox_uart_s *uart_ptr = &g_ublox_uart;
    uint8_t ck_a = 0, ck_b = 0;    

    //memset(&uart_ptr->recv_buf[uart_ptr->recv_ptr],0x0,255);
    uart_ptr->recv_cnt = drv_uart_read(&uart_ptr->recv_buf[uart_ptr->recv_ptr],HALF_BUFSIZE);
    if(uart_ptr->recv_cnt <= 0)
    {
        UCP_PRINT_ERROR("uart read error");
        return;
    }

    //uart_ptr->deal_ptr = 0;
    len = uart_ptr->recv_cnt + uart_ptr->deal_cnt; //本次接收+上次遗留的长度
    //uart_ptr->recv_buf[len] = '\0';
    //len_left = len;  

    while(uart_ptr->deal_ptr < len)  //maybe more than one message
    {
        if(SYNC1_UBLOX == uart_ptr->recv_buf[uart_ptr->deal_ptr++])
        {
            if(SYNC2_UBLOX == uart_ptr->recv_buf[uart_ptr->deal_ptr])
            {
                uart_ptr->deal_ptr--;
                uart_ptr->frame_flag = 1;  //search frame header ok!
                head_ptr = &uart_ptr->recv_buf[uart_ptr->deal_ptr + UBLOX_SYNC_LEN]; //class_id
            }
            else
            {
                continue;
            }
        }
        else
        {
            uart_ptr->frame_flag = 0;
            continue;
        }
        
        len_left = len - uart_ptr->deal_ptr;  
        if(len_left >= INDEX_OF_PAYLOAD) 
        {
            rx_msg_ptr = (ubx_msg_s*)head_ptr;
        }
        else  //the last 6 bytes
        {
            //memcpy(&uart_ptr->recv_buf[0],&uart_ptr->recv_buf[uart_ptr->deal_ptr],len_left);
            uart_ptr->deal_cnt = len_left;
            uart_ptr->recv_ptr += uart_ptr->recv_cnt;
            UCP_PRINT_DEBUG("Len of header is not enougth,len_left = %d,recv_ptr = %d,deal_ptr = %d",len_left,uart_ptr->recv_ptr,uart_ptr->deal_ptr);            
            if(uart_ptr->recv_ptr > HALF_BUFSIZE)
            {
                memcpy(&uart_ptr->recv_buf[0],&uart_ptr->recv_buf[uart_ptr->deal_ptr],len_left);
                uart_ptr->recv_ptr = len_left;
            }
            return;
        }
#if 0
        if(rx_msg_ptr->length > UBLOX_MAX_MEG_LENGTH)
        {
            UCP_PRINT_ERROR("msg len error len = %d ",rx_msg_ptr->length);
            //*(uint16_t *)head_ptr = 0;  clean sync
            uart_ptr->deal_ptr += INDEX_OF_PAYLOAD;
            continue;//data len error
        }  
#endif
        if(rx_msg_ptr->length + UBLOX_HEADER_SUM_LEN > len_left)  //message segment
        {
            UCP_PRINT_DEBUG("payload_len = %d,total_len = %d,left_len = %d,recv_ptr = %d,deal_ptr = %d,packet_len = %d",\
                    rx_msg_ptr->length,len,len_left,uart_ptr->recv_ptr,uart_ptr->deal_ptr,uart_ptr->recv_cnt);

            uart_ptr->deal_cnt = len_left;
            uart_ptr->recv_ptr += uart_ptr->recv_cnt;
            if(uart_ptr->recv_ptr > HALF_BUFSIZE)
            {
                memcpy(&uart_ptr->recv_buf[0],&uart_ptr->recv_buf[uart_ptr->deal_ptr],len_left);
                uart_ptr->recv_ptr = len_left;
            }
            //UCP_PRINT_DEBUG("next recv_ptr = %d\n",uart_ptr->recv_ptr);
            return;/*data len error*/
        }

        /*check the msg  */
        ck_a = 0;
        ck_b = 0;
        check_len = rx_msg_ptr->length + 4;
        for(i = 0; i < check_len; i++) //check sum: (class_id + msg_id + len + payload)
        {
            ck_a += *head_ptr++;
            ck_b += ck_a;
        }

        uart_ptr->deal_ptr += UBLOX_MSG_TOTAL_LEN(rx_msg_ptr->length); //header of next message 
        
        if((ck_a == *head_ptr++) && (ck_b == *head_ptr))
        {
            if(OSP_OK != drv_handle_ublox_msg(rx_msg_ptr))
            {
                UCP_PRINT_ERROR("handle ublox msg error");
                //continue;
            }            
        }
        else
        {
            UCP_PRINT_ERROR("ublox crc error");
            //continue;
        }
    }  

    uart_ptr->deal_ptr = 0;

    if(0 == uart_ptr->frame_flag)
    {
        // UCP_PRINT_ERROR("cann't find ublox header");
        //uart_ptr->recv_ptr = 0;
        if(SYNC1_UBLOX == uart_ptr->recv_buf[len - 1])
        {
            uart_ptr->recv_buf[0] = SYNC1_UBLOX;
            uart_ptr->deal_cnt = 1;
            uart_ptr->recv_ptr = 1;
            return; 
        }
    }

    uart_ptr->recv_ptr = 0;
    uart_ptr->deal_cnt = 0;
    return;
}

void drv_gps_recv_task(void)
{
    while(1)
    {
        deal_gps_data();
    }
}

int32_t drv_tfu_uart_init(void)
{
    if(drv_uart_fd < 0)
    {
        drv_uart_fd = open( "/dev/ttyS2", O_RDWR);
        if (-1 == drv_uart_fd)
        {
            perror("Can't Open Serial Port");
            UCP_PRINT_ERROR("Can't Open Serial Port\n\r");
            return OSP_ERROR;
        }
    }
    
    if(fcntl(drv_uart_fd, F_SETFL, 0)<0)
    {
        UCP_PRINT_ERROR("fcntl failed!\n");
    }

    if(isatty(STDIN_FILENO) == 0)
    {
        UCP_PRINT_ERROR("standard input is not a terminal device\n");
    }

    if(set_opt(drv_uart_fd,9600,8,'N',1) < 0)
    {
        perror("set_opt error");
        UCP_PRINT_ERROR("set_opt error\n\r");
        return OSP_ERROR;
    }
    return OSP_OK;
}

int32_t drv_uart_read(uint8_t *pdata, uint32_t len)
{
    int32_t read_bytes = 0;

    if(NULL == pdata)
    {
        return OSP_ERROR;
    }

    read_bytes = read(drv_uart_fd,pdata,len);
    if(read_bytes < 0)
    {
        // UCP_PRINT_ERROR("uart read error\n\r");
        return OSP_ERROR;
    }
    
    return read_bytes;
}

int32_t get_receiver_fix_status()
{
    return g_gps_recv_msg.lock_state;  //接收机锁定状态
}

int32_t reset_clock_module(void)
{

    (void)drv_semaphore_p(g_ublox_uart.send_sem);

    g_ublox_uart.send_buf_ptr->cls_id = CFG;
    g_ublox_uart.send_buf_ptr->msg_id = CFG_RST;
    g_ublox_uart.send_buf_ptr->length = REVS16(CFG_RST_LEN);

    g_ublox_uart.send_buf_ptr->pay_load.config_rst.nav_bbr = REVS16(RST_NAVBBR_COLD);
    g_ublox_uart.send_buf_ptr->pay_load.config_rst.rst_mode = RST_MODE_HW;

    drv_send_ublox_msg();
    drv_semaphore_v(g_ublox_uart.send_sem);

    if(OSP_OK != drv_tfu_config_ublox())
    {
        UCP_PRINT_ERROR("tfu: config_ublox error!");
        return OSP_ERROR;
    }    
    return OSP_OK;
}

int32_t get_src_time(time_t* time_ptr)
{
    time_t tmp_time;
    if(NULL == time_ptr)
    {
        UCP_PRINT_ERROR("tfu: get_src_time *time_prt is null!\n");
        return OSP_ERROR;
    }
    if(OSP_OK != drv_tfu_get_ublox_seconds(&tmp_time))
    {
        UCP_PRINT_ERROR("tfu: get gps time error !\n");
        return OSP_ERROR;
    }
    *time_ptr  = tmp_time;
    return OSP_OK; 
}


int32_t get_leap_time(uint8_t* leap_ptr)
{
    
    if(NULL == leap_ptr)
    {
        UCP_PRINT_ERROR("tfu: get_leap_time *leap_ptr is null!\n");
        return OSP_ERROR;
    }
    
    if(LEAP_VALID != (LEAP_VALID & g_gps_recv_msg.valid_flag))
    {
        *leap_ptr = 19;
        return OSP_OK;
    }
    
    *leap_ptr  = g_gps_recv_msg.leap_sec;
    return OSP_OK;
}


int32_t get_tfu_location_info(location_info_s *locat_ptr)
{
    if(NULL == locat_ptr)
    {
        UCP_PRINT_ERROR("locat_ptr == NULL\n\r");
        return OSP_ERROR;
    }
    (void)drv_semaphore_p(g_ublox_uart.send_sem);
    g_ublox_uart.send_buf_ptr->cls_id = NAV;
    g_ublox_uart.send_buf_ptr->msg_id = NAV_POSLLH;
    g_ublox_uart.send_buf_ptr->length = POLL_LENGTH;

    drv_send_ublox_msg();  
    drv_semaphore_v(g_ublox_uart.send_sem);
    if(OSP_OK != drv_semaphore_timed_p(g_ubx_sem[NAV_POSLLH_SEM], 2*1000000))
    {
        UCP_PRINT_ERROR("tfu: no position info back!\n");
        g_tod_link_alarm = 1;
        return OSP_ERROR;  
    }
    else
    {
        g_tod_link_alarm = 0;
    }

    locat_ptr->altitude = g_gps_recv_msg.altitude;
    locat_ptr->latitude = g_gps_recv_msg.latitude;
    locat_ptr->longitude = g_gps_recv_msg.longitude;

    return OSP_OK;
}

int32_t get_clock_tracking_state(tracking_info_s *trk_ptr)
{   
    uint8_t i;
    float* sig_level_ptr;

    if(NULL == trk_ptr)
    {
        UCP_PRINT_ERROR("trk_ptr == NULL\n\r");
        return OSP_ERROR;
    }

    sig_level_ptr = trk_ptr->sig_level;
    if(-1 == g_ublox_uart.send_sem)
    {
        return OSP_ERROR;
    }
    (void)drv_semaphore_p(g_ublox_uart.send_sem);
    g_ublox_uart.send_buf_ptr->cls_id = NAV;
    g_ublox_uart.send_buf_ptr->msg_id = NAV_SVINFO;
    g_ublox_uart.send_buf_ptr->length = POLL_LENGTH;

    drv_send_ublox_msg();  
    drv_semaphore_v(g_ublox_uart.send_sem);
    if(OSP_OK != drv_semaphore_timed_p(g_ubx_sem[NAV_SVINFO_SEM], 3*1000000))
    {
        UCP_PRINT_ERROR("tfu: no sv info back! \n");
        g_tod_link_alarm = 1;
        return OSP_ERROR;
    }
    else
    {
        g_tod_link_alarm = 0;
    }
    if(g_gps_recv_msg.fix_flag & GPS_FIX_OK)
    {
        trk_ptr->lock_flag = 1;
    }
    else
    {
        trk_ptr->lock_flag = 0;
    }
    
    if(g_gps_recv_msg.valid_flag & LEAP_VALID)
    {
        trk_ptr->leap_valid = 1;
    }
    else
    {
        trk_ptr->leap_valid = 0;
    }
    if(g_almanach_flag & NAV_ALMANACH)
    {
        trk_ptr->alma_complete = 1;
    }
    else
    {
        trk_ptr->alma_complete = 0;
    }
    trk_ptr->view_sats = g_gps_recv_msg.visable_num;
    trk_ptr->track_sats = g_gps_recv_msg.tracking_num;
    trk_ptr->survey_in = 0;

    for(i = 0; i < MIN(g_gps_recv_msg.visable_num,12); ++i)
    {
        *(sig_level_ptr++) = (float)g_gps_recv_msg.cno[i];          
    }
    //get_ad9548_lock_status(&phase_diff);
    //trk_ptr->pahse_diff = (int16_t)phase_diff;
    for(i = 0; i < MIN(g_gps_recv_msg.visable_num,12); i++)
    {
        UCP_PRINT_DEBUG(" %f",trk_ptr->sig_level[i]);
    }
    
    UCP_PRINT_DEBUG("get_clock_tracking_state: lock_flag=%d leap_valid=%d view_sats=%d\n\r",trk_ptr->lock_flag,trk_ptr->leap_valid,trk_ptr->view_sats);
    //UCP_PRINT_DEBUG"get_clock_tracking_state: track_sat=%d phase_diff=%d\n\r",trk_ptr->track_sats,trk_ptr->pahse_diff);

  
    return OSP_OK;
}

#if 0
int32_t get_clock_module_status(clk_modu_state_s* clk_modu_state_ptr)
{

    if(NULL == clk_modu_state_ptr)
    {
        UCP_PRINT_ERROR("clk_modu_state_ptr == NULL\n\r");
        return OSP_ERROR;
    }
    memset((void *)clk_modu_state_ptr, 0, sizeof(clk_modu_state_s));

    /* ------------get common_alarm -----------------------*/
    if(CLK_DISABLE == g_sync_state )
    {
        clk_modu_state_ptr->common_alarm |= COM_CLK_DISABLE_ALARM; 
    }

    /*-- if phase diff over, set bit2-- */
    if(g_phase_over_flow)
    {
        clk_modu_state_ptr->common_alarm |= COM_PHASE_DIFF_OVER_ALARM;
    }
    /*-- if hold over, set bit3 --*/
    if(CLK_HOLD_OVER == g_sync_state)
        clk_modu_state_ptr->common_alarm |= COM_HOLD_OVER_STATE_ALARM;

    /*-- if gps/bd tod link alarm, set bit4-- */
    if(g_tod_link_alarm)
    {
        clk_modu_state_ptr->common_alarm |= COM_TOD_LINK_ALARM;
    }

    /* ---------------get clk_gps_alarm --------------------*/

    /*--set TOD channel alarm, bit2-- */
    if(TOD_LINK_ALARM_VALUE == g_gps_recv_msg.ant_state)
    {
        clk_modu_state_ptr->clk_gps_alarm |= GPS_LINK_CHAN_FAULT_ALARM;
    }

    /* --set antenna short alarm-- */
    if(ANT_OPEN_ALARM_VALUE == g_gps_recv_msg.ant_state)
    {
        clk_modu_state_ptr->clk_gps_alarm |= GPS_ANT_OPEN_ALARM;
    }

    /* --set antenna open alarm-- */
    if(ANT_SHORT_ALARM_VALUE == g_gps_recv_msg.ant_state)
    {
        clk_modu_state_ptr->clk_gps_alarm |= GPS_ANT_SHORT_ALARM;
    }

    /* --set siglever too week alarm-- */
    if(g_gps_recv_msg.tracking_num < 3)
    {
        clk_modu_state_ptr->clk_gps_alarm |= GPS_ANT_SIGNAL_WEEK_ALARM;
    }
    /* --set siglever too strong alarm-- */
    if(g_gps_recv_msg.sig_over_high > 0)
    {
        clk_modu_state_ptr->clk_gps_alarm |= GPS_ANT_SIGNAL_STRONG_ALARM; 
    }

    /*-------------- get clk_forced_flag ---------------------*/
    clk_modu_state_ptr->clk_forced_flag = g_force_flag;

    /*------------- get clk_pesudo_flag ----------------------*/
    clk_modu_state_ptr->clk_pesudo_flag = g_pesudo_lock;

    /*--------------- get sync state -----------------------*/
    if(g_pesudo_lock)
    {
        clk_modu_state_ptr->clk_sync = CLK_TRACKING;
        clk_modu_state_ptr->common_alarm &= ~COM_CLK_DISABLE_ALARM; 
    }
    else
    {
        clk_modu_state_ptr->clk_sync = g_sync_state;
    }

    if(1 == g_gps_recv_msg.lock_state)
    {
        clk_modu_state_ptr->clk_gps_locked_flag = TRUE_FLAG;
    }
    else
    {
        clk_modu_state_ptr->clk_gps_locked_flag = ZERO_FLAG;
    }

    /*------------ get hold_over_time ---------------------*/
    clk_modu_state_ptr->hold_over_time = g_hold_over_time/HOLD_OVER_TIME_UNIT;

    /* ----------------get clk_src ------------------------*/
    clk_modu_state_ptr->clk_src = CLK_SRC_GPS;

    return OSP_OK;
}
#endif
int32_t init_clock_module(void)
{
    int32_t result = 0;
   
    if(1 == g_tfu_init_flag)
    {
        UCP_PRINT_ERROR("tfu init flag = 1");
        return OSP_ERROR;
    }
    else
    {
        result = drv_tfu_uart_init();
        if(OSP_ERROR == result)
        {
            UCP_PRINT_ERROR("uart init error\n\r");
            return OSP_ERROR;
        }

        /*tracking后释放给OM，计算帧号*/
        if(OSP_ERROR == (g_tfu_to_time_sem = drv_sem_create(g_sem_prj_id)))
        {
            UCP_PRINT_ERROR("g_tfu_to_time_sem create error\n\r");
            return OSP_ERROR;
        }
        UCP_PRINT_DEBUG("g_tfu_to_time_sem=%d\n\r",g_tfu_to_time_sem);

        g_sem_prj_id++;
        if(OSP_ERROR == (g_tfu_sync_sem = drv_sem_create_sync(g_sem_prj_id)))
        {
            UCP_PRINT_ERROR("g_tfu_sync_sem create error\n\r");
            return OSP_ERROR;
        }
        g_sem_prj_id++;        
        UCP_PRINT_DEBUG("g_tfu_sync_sem=%d\n\r",g_tfu_sync_sem);
        
        g_tfu_init_flag = 1;
        return OSP_OK;
    }
}

